@@ -1,6 +1,6 @@
 package OpenInteract2::Action::Box;
 
-# $Id: Box.pm,v 1.8 2004/05/22 01:51:18 lachoy Exp $
+# $Id: Box.pm,v 1.11 2004/10/24 15:03:01 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
@@ -10,7 +10,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Action::Box::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::Box::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -27,13 +27,21 @@ sub process_boxes {
     my ( $self ) = @_;
     $log ||= get_logger( LOG_APP );
 
-    $BOX_CONFIG ||= CTX->server_config->{box};
+    $BOX_CONFIG ||= CTX->lookup_box_config;
 
     my @base_actions = $self->_create_box_actions;
     push @base_actions, $self->_create_system_boxes;
     push @base_actions, $self->_create_custom_boxes;
+
+    my $controller = CTX->controller;
+    @base_actions = grep {
+        ! $controller->is_box_removed( $_->{name} )
+    } @base_actions;
+
     $log->is_info &&
-        $log->info( "Found ", scalar @base_actions, " boxes to process" );
+        $log->info( "Found ", scalar( @base_actions ), " boxes to process ",
+                    "after getting all boxes (added, system and custom) ",
+                    "and ensuring that none of them are to be removed" );
 
     my @sorted_actions =
         sort { $a->param( 'weight' ) <=> $b->param( 'weight' ) ||
@@ -169,7 +177,8 @@ BOX:
 
         foreach my $param_name ( keys %{ $use_info->{params} } ) {
             $log->is_debug &&
-                $log->debug( "Adding parameter to box: '$param_name' '$use_info->{params}{ $param_name }'" );
+                $log->debug( "Adding parameter to box: '$param_name' ",
+                             "'$use_info->{params}{ $param_name }'" );
             $box_action->param( $param_name, $use_info->{params}{ $param_name } );
         }
 
@@ -243,9 +252,12 @@ ACTION:
             next ACTION;
         }
         $shell_params->{content} = $base_content;
-        $shell_params->{label} = $action->param( 'title' );
-        $shell_params->{label_image_src} = $action->param( 'title_image_src' );
-        $shell_params->{label_image_alt} = $action->param( 'title_image_alt' );
+        $shell_params->{label} = $action->message_from_key_or_param(
+            'title', 'title_key' );
+        $shell_params->{label_image_src} = $action->message_from_key_or_param(
+            'title_image_src', 'title_image_src_key' );
+        $shell_params->{label_image_alt} = $action->message_from_key_or_param(
+            'title_image_alt', 'title_image_alt_key' );
         push @content, $action->generate_content( $shell_params,
                                                   { name => $shell_template } );
     }
@@ -264,8 +276,10 @@ OpenInteract2::Action::Box -- Handle input and output for independent "boxes"
 
  # Deposit all boxes in the current location on the page:
  [% OI.action_execute( 'boxes' ) %]
-
- # Define global box information in your server.ini
+ 
+ # Define global box information in server configuration
+ # ($WEBSITE/conf/server.ini)
+ 
  [box]
  handler            = MyWebsite::Handler::Box
  default_template   = base_box::main_box_shell
@@ -275,9 +289,10 @@ OpenInteract2::Action::Box -- Handle input and output for independent "boxes"
  system_box_method  =
  custom_box_handler =
  custom_box_method  =
-
- # Define an OI action (in conf/action.ini) to be used for a box with
- # a class and method:
+ 
+ # Define an OI action (in mypkg/conf/action.ini) to be used for a box
+ # with a class and method:
+ 
  [current_weather_box]
  class    = OpenInteract2::Action::Weather
  method   = box
@@ -285,6 +300,7 @@ OpenInteract2::Action::Box -- Handle input and output for independent "boxes"
  title    = Current Weather
 
  # Add a box ('name' maps to the above OI action):
+ 
  my $zip = CTX->request->auth_user->{zipcode};
  my $box = { name   => 'current_weather_box',
              weight => 2,
@@ -293,6 +309,7 @@ OpenInteract2::Action::Box -- Handle input and output for independent "boxes"
  CTX->controller->add_box( $box );
 
  # Add the same box from a template:
+ 
  [% user_zip = OI.login.zip_code;
     OI.box_add( 'current_weather_box',
                 weight   = 2,
@@ -300,28 +317,34 @@ OpenInteract2::Action::Box -- Handle input and output for independent "boxes"
                 zip_code = $user_zip ) -%]
 
  # Define an OI action (in conf/action.ini) to be used for a
- # template-only box:
+ # template-only box, using a localization key instead of a direct
+ # title :
+ 
  [frequent_links_box]
  name       = frequent_links_box
  template   = mypkg::box_frequent_links
  weight     = 8
- title      = Frequent Links
+ title_key  = frequent_links.title
  security   = no
 
  # Add a template-only box, overriding weight and title:
+ 
  my $box = { name   => 'frequent_links_box',
              weight => 2,
              title  => "Most visited sites" };
  CTX->controller->add_box( $box );
 
  # Add the same box from a template, overriding title:
+ 
  [% OI.box_add( 'frequent_links_box',
                 title  = 'Most visited sites' ) %]
 
  # Remove a box added in another part of the system
+ 
  CTX->controller->remove_box( 'motd' );
 
  # Remove the same box from a template
+ 
  [% OI.box_remove( 'motd' ) %]
 
 =head1 DESCRIPTION
@@ -345,7 +368,8 @@ boxes look the same. The standard box looks something like this:
 
 But you can create your own shell by defining the key 'box_template'
 in your theme to be a particular template (in the
-'package::template_name' format).
+'package::template_name' format) or by setting the global
+configuration key 'box.default_template'.
 
 =head1 CONFIGURATION
 
@@ -397,12 +421,12 @@ you know what you are doing you should not change it.
 
 B<default_template> ($) (optional)
 
-This is the template into which the box content gets put. Normally
+This is the template into which every box content gets put. Normally
 this is defined in the theme, but if for some reason someone blanked
 the template out this will fill in.
 
 The default template is C<base_box::main_box_shell>, which as the name
-would indicate is installed with this package. 
+would indicate is installed with this package.
 
 =item *
 
@@ -469,7 +493,7 @@ as the content it will have.
 
 The simplest case is a call:
 
- push @{ $R->{boxes} }, 'my_box_template';
+ CTX->controller->add_box( 'mypkg::my_box_template' );
 
 Which simply uses the scalar passed in as the template name and the
 box name, and uses all the defaults. However, you will likely get a
@@ -477,10 +501,9 @@ box with a title 'Generic Box', which is probably not what you want.
 
 Another example:
 
- push @{ $R->{boxes} }, { name     => 'mybox',
-                          template => 'mypkg::mybox',
-                          weight   => 1,
-                          title    => 'My First Box' };
+ CTX->controller->add_box({ template => 'mypkg::mybox',
+                            weight   => 1,
+                            title    => 'My First Box' });
 
 Each box can define the following parameters:
 
@@ -488,24 +511,10 @@ Each box can define the following parameters:
 
 =item *
 
-B<name> ($) (mandatory)
+B<name> ($)
 
-Just used to identify the box.
-
-=item *
-
-B<remove> ($) (optional)
-
-If you use this parameter you are telling the box handler to remove a
-box with name 'name'. This box does not have to be added by you or in
-your package -- for instance, you might want to always get rid of the
-'user_info' and 'login' boxes that come with OI:
-
- push @{ $R->{boxes} }, { name => 'user_info_box', remove => 'yes' },
-                        { name => 'login_box', remove => 'yes' };
-
-This does require you to know the name, but that should not be too
-onerous a burden.
+Just used to identify the box; if not provided we use the 'template'
+parameter.
 
 =item *
 
@@ -516,18 +525,40 @@ that.
 
 =item *
 
+B<title_key> ($) (optional)
+
+Localization key to use for box title, generally used in place of
+'title' and if both are present this will be used.
+
+=item *
+
 B<title_image_src> ($) (optional)
 
 Display an image for the title to be used in the 'shell' wrapper.
 
 =item *
 
+B<title_image_src_key> ($) (optional)
+
+Localization key to use for image title, generally used in place of
+'title_image_src' and if both are present this will be used.
+
+=item *
+
 B<title_image_alt> ($) (optional)
 
 Text to put in the 'alt' tag if using an image in the title.
 
 =item *
 
+B<title_image_alt_key> ($) (optional)
+
+Localization key to use for the 'alt' tag in the image title,
+generally used in place of 'title_image_alt' and if both are present
+this will be used.
+
+=item *
+
 B<weight> ($)
 
 Number between 1 (top) and 10 (bottom) indicating where you want the
@@ -553,10 +584,6 @@ that is implementing the box.
 
 =back
 
-=head1 BUGS
-
-None known.
-
 =head1 TO DO
 
 B<Cache base templates (wrappers)>
@@ -572,8 +599,8 @@ need to allow each box to define its own wrapper.
 
 =head1 SEE ALSO
 
-L<OpenInteract::SiteTemplate|OpenInteract::SiteTemplate>,
-L<OpenInteract::Theme|OpenInteract::Theme>
+L<OpenInteract2::SiteTemplate|OpenInteract2::SiteTemplate>,
+L<OpenInteract2::Theme|OpenInteract2::Theme>
 
 =head1 COPYRIGHT
 
