@@ -1,10 +1,9 @@
 package OpenInteract2::Action::Comments;
 
-# $Id: Comments.pm,v 1.5 2004/05/22 01:42:49 lachoy Exp $
+# $Id: Comments.pm,v 1.9 2004/12/05 08:51:22 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
-use DateTime;
 use HTML::Entities;
 use Log::Log4perl            qw( get_logger );
 use Mail::Sendmail;
@@ -12,7 +11,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Util;
 
-$OpenInteract2::Action::Comments::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::Comments::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -29,7 +28,7 @@ sub show_summary {
     unless ( $object and ! ( $obj_class and $obj_id ) ) {
         $log->warn( "Cannot display summary: no object or ",
                     "object class + ID given" );
-        return "No object or class/ID given for which to fetch a summary.";
+        return $self->_msg( 'comments.error.summary_data_missing' );
     }
 
     my %params = ();
@@ -42,9 +41,10 @@ sub show_summary {
     $log->is_debug &&
         $log->debug( "Fetching summary for '$obj_class: $obj_id'" );
     my $summaries = eval {
-        OpenInteract2::CommentSummary->fetch_group(
-                    { where => 'class = ? AND object_id = ?',
-                      value => [ $obj_class, scalar $obj_id ] })
+        OpenInteract2::CommentSummary->fetch_group({
+            where => 'class = ? AND object_id = ?',
+            value => [ $obj_class, scalar $obj_id ],
+        })
     };
     if ( $@ ) {
         $params{comment_error} = "$@";
@@ -58,10 +58,11 @@ sub show_summary {
         else {
             $log->is_info &&
                 $log->info( "No summary available, creating transient one" );
-            $summary = OpenInteract2::CommentSummary->new(
-                                        { num_comments => 0,
-                                          class        => $obj_class,
-                                          obj_id       => $obj_id });
+            $summary = OpenInteract2::CommentSummary->new({
+                num_comments => 0,
+                class        => $obj_class,
+                obj_id       => $obj_id
+            });
             $object = eval { $obj_class->fetch( $obj_id ) };
             if ( $@ ) {
                 $log->error( "FAILURE: Cannot fetch for summary object ",
@@ -100,19 +101,22 @@ sub list {
 
     # ...but we pass 1-based figures to the template (how humane)
 
-    my %params = ( lower_bound  => $lower_bound + 1,
-                   upper_bound  => $upper_bound + 1,
-                   page_num     => $page_num,
-                   page_size    => $page_size,
-                   num_comments => $request->param( 'num_comments' ) );
+    my %params = (
+        lower_bound  => $lower_bound + 1,
+        upper_bound  => $upper_bound + 1,
+        page_num     => $page_num,
+        page_size    => $page_size,
+        num_comments => $request->param( 'num_comments' ),
+    );
     my $comments = eval {
-        OpenInteract2::Comment->fetch_group(
-                    { limit        => "$lower_bound,$upper_bound",
-                      order        => 'posted_on DESC',
-                      column_group => 'summary' })
+        OpenInteract2::Comment->fetch_group({
+            limit        => "$lower_bound,$upper_bound",
+            order        => 'posted_on DESC',
+            column_group => 'summary',
+        })
     };
     if ( $@ ) {
-        $self->param_add( error_msg => "Failed to fetch comments: $@" );
+        $self->add_error_key( 'comments.error.cannot_fetch_listing', "$@" );
         $log->error( "Cannot fetch comments: $@" );
     }
     else {
@@ -160,28 +164,30 @@ sub list_by_object {
                         $request->param( 'object_id' );
         unless ( $obj_class and $obj_id ) {
             $log->error( 'Class/object_id not given to find object' );
-            return "Insufficient data supplied to fetch comments by object.";
+            return $self->_msg( 'comments.error.list_for_object_data_missing' );
         }
+
         $object = eval { $obj_class->fetch( $obj_id ) };
         if ( $@ ) {
             $log->error( "Failed to fetch '$obj_class: $obj_id': $@" );
-            return "Failed to fetch object with supplied information. " .
-                   "Error logged.";
+            return $self->_msg( 'comments.error.cannot_fetch_object_for_listing' );
         }
     }
-    my %params = ( object     => $object,
-                   summary    => $self->param( 'summary' ),
-                   standalone => $self->param( 'standalone' ) );
+    my %params = (
+        object     => $object,
+        summary    => $self->param( 'summary' ),
+        standalone => $self->param( 'standalone' ),
+    );
     my $comments = eval {
-        OpenInteract2::Comment->fetch_group(
-                    { where => 'class = ? and object_id = ?',
-                      value => [ ref $object, scalar( $object->id ) ],
-                      order => 'posted_on DESC' })
+        OpenInteract2::Comment->fetch_group({
+            where => 'class = ? and object_id = ?',
+            value => [ ref $object, scalar( $object->id ) ],
+            order => 'posted_on ASC'
+        })
     };
     if ( $@ ) {
         $log->error( "Error fetching comments: $@" );
-        $self->param_add(
-            error_msg => "Failed to fetch comments for listing: $@" );
+        $self->add_error_key( 'comments.error.cannot_fetch_by_object', "$@" );
     }
     else {
         $log->is_info &&
@@ -195,7 +201,7 @@ sub list_by_object {
 
 # Display a single comment
 
-sub show {
+sub display {
     my ( $self ) = @_;
     $log ||= get_logger( LOG_APP );
 
@@ -207,21 +213,18 @@ sub show {
         my $comment = eval { OpenInteract2::Comment->fetch( $comment_id ) };
         if ( $@ ) {
             $log->error( "Error retrieving comment '$comment_id': $@" );
-            $self->param_add(
-                error_msg => "Error fetching comment: $@" );
+            $self->add_error_key( 'comments.error.cannot_fetch', "$@" );
         }
         if ( $comment ) {
             $params{comment} = $comment;
         }
         else {
             $log->error( "No comment found for given ID '$comment_id'" );
-            $self->param_add(
-                error_msg => "No comment found for specified ID." );
+            $self->add_error_key( 'comments.error.not_found' );
         }
     }
     else {
-        $self->param_add(
-            error_msg => "Cannot display comment without a comment ID." );
+        $self->add_error_key( 'comments.error.no_id' );
     }
 
     return $self->generate_content(
@@ -274,15 +277,12 @@ sub _fetch_object_for_comment {
     if ( $obj_class ) {
         $object = eval { $obj_class->fetch( $comment->{object_id} ) };
         if ( $@ ) {
-            my $msg = "Cannot fetch object to which comment is attached: $@";
-            $self->param_add( error_msg => $msg );
+            $self->add_error_key( 'comments.error.cannot_fetch_object', "$@" );
             $object = undef;
         }
     }
     else {
-        my $msg = 'Cannot fetch object to which comment is attached: ' .
-                  'no class specified in comment';
-        $self->param_add( error_msg => $msg );
+        $self->add_error_key( 'comments.error.no_class_for_object' );
     }
     return $object;
 }
@@ -337,9 +337,9 @@ sub add {
         $comment->{ $field } = $value
     }
 
-    # Stick in right now...
+    # Stick in right now (with timezone)...
 
-    $comment->{posted_on} = DateTime->now();
+    $comment->{posted_on} = CTX->create_date();
 
     # Ensure URLs at least start with HTTP...
 
@@ -354,7 +354,10 @@ sub add {
 
     # Escape any remaining HTMLisms
 
-    my $pre_escaped = $comment->{content};
+    # ...but store the unescaped version for the re-editing (if this
+    # is a preview)
+
+    $self->param( pre_escaped => $comment->{content} );
 
     $comment->{content} = HTML::Entities::encode( $comment->{content} );
     $comment->{subject} = HTML::Entities::encode( $comment->{subject} );
@@ -384,14 +387,12 @@ sub add {
         push @required_missing, $required{ $_ } unless ( $comment->{ $_ } );
     }
 
-    $self->param( pre_escaped   => $pre_escaped );
     $self->param( comment       => $comment );
     $self->param( form_settings => \%form_settings );
 
     if ( scalar @required_missing ) {
-        my $msg = q{Data are required for the following fields: } .
-                  join( ', ', @required_missing );
-        $self->param_add( error_msg => $msg );
+        $self->add_error_key( 'comments.error.data_missing',
+                              join( ', ', @required_missing ) );
         return $self->_show_editable;
     }
 
@@ -416,9 +417,12 @@ sub add {
         my $cookie_name = $self->param( 'cookie_name' ) ||
                           $self->param( 'default_cookie_name' ) ||
                           'comment_info';
-        OpenInteract2::Cookie->create({ name    => $cookie_name,
-                                        value   => $cookie_info,
-                                        expires => '+6M' });
+        OpenInteract2::Cookie->create({
+            name    => $cookie_name,
+            value   => $cookie_info,
+            expires => '+6M',
+            HEADER  => 'yes',
+        });
         $log->is_info &&
             $log->info( "Created 'remember' cookie with '$cookie_info'" );
     }
@@ -426,10 +430,10 @@ sub add {
     eval { $comment->save };
     if ( $@ ) {
         $log->error( "Failed to add comment: $@" );
-        $self->param_add( error_msg => "Error adding comment: $@" );
+        $self->add_error_key( 'comments.error.cannot_add', "$@" );
     }
     else {
-        $self->param_add( status_msg => "Comment successfully added." );
+        $self->add_error_key( 'comments.status.add_ok' );
 
         # These are used for the listing page we go to next...
 
@@ -442,7 +446,7 @@ sub add {
         $self->_process_notifications( $comment );
         my $notify_status = $self->_add_user_notification( $comment );
         if ( $notify_status ) {
-            $self->param_add( status_msg => $notify_status );
+            $self->add_status( $notify_status );
         }
     }
 
@@ -487,10 +491,11 @@ sub _add_auto_notifications {
         my ( $name, $email ) = split /\s*\|\s*/, $_;
         eval {
             OpenInteract2::CommentNotify->new({
-                         class     => $comment->{class},
-                         object_id => $comment->{object_id},
-                         name      => $name,
-                         email     => lc $email })->save()
+                class     => $comment->{class},
+                object_id => $comment->{object_id},
+                name      => $name,
+                email     => lc $email
+            })->save()
         };
         if ( $@ ) {
             $log->error( "Failed to add notification for ",
@@ -530,17 +535,17 @@ sub _add_user_notification {
         $log->is_info &&
             $log->info( "Posted wants to be notified but didn't ",
                         "provide an email address" );
-        return join( '', 'Could not add notification since you did ' .
-                         'not give me your email address. Sorry.' );
+        $self->add_error_key( 'comments.error.cannot_add_notify_no_email' );
+        return;
     }
 
     unless ( $comment->{poster_email} =~ /$Mail::Sendmail::address_rx/ ) {
         $log->is_info &&
             $log->info( "Posted wants to be notified but provided a bad ",
                         "email address: '$comment->{poster_email}'" );
-        return join( '', 'Could not add notification since the email ' .
-                         "address you gave ($comment->{poster_email}) ",
-                         "seems to be invalid. Sorry." );
+        $self->add_error_key( 'comments.error.cannot_add_notify_bad_email',
+                              $comment->{poster_email} );
+        return;
     }
 
     # Fetch the existing notifications and see if this email address
@@ -548,37 +553,40 @@ sub _add_user_notification {
 
     my $notes = eval {
         OpenInteract2::CommentNotify->fetch_group({
-                                  where => 'class = ? AND object_id = ?',
-                                  value => [ $comment->{class},
-                                             $comment->{object_id} ] })
+            where => 'class = ? AND object_id = ?',
+            value => [ $comment->{class}, $comment->{object_id} ],
+        })
     };
     if ( $@ ) {
         $log->error( "Error fetching notifications for: ",
                      "'$comment->{class}: $comment->{object_id}': $@" );
-        return 'Failed to fetch existing notifications for dupe check, ' .
-               'so I could not add yours.';
+        $self->add_error_key( 'comments.error.cannot_add_notify_error_dupe_check' );
+        return
     }
 
     my %existing_mail = map { lc $_->{email} => 1 } @{ $notes };
     if ( $existing_mail{ lc $comment->{poster_email} } ) {
         $log->is_info &&
             $log->info( "No notification added: already exists in thread" );
-        return 'Did not add a notification to this thread since one ' .
-               'already exists for the given email address.';
+        $self->add_error_key( 'comments.error.cannot_add_notify_is_dupe' );
+        return;
     }
 
     eval {
         OpenInteract2::CommentNotify->new({
-                         class     => $comment->{class},
-                         object_id => $comment->{object_id},
-                         name      => $comment->{poster_name},
-                         email     => lc $comment->{poster_email} })->save()
+            class     => $comment->{class},
+            object_id => $comment->{object_id},
+            name      => $comment->{poster_name},
+            email     => lc $comment->{poster_email}
+        })->save()
     };
     if ( $@ ) {
         $log->error( "Failed to save notification: $@" );
-        return 'Your notification entry addition failed, sorry.';
+        $self->add_error_key( 'comments.error.cannot_add_notify_persist', "$@" );
+        return;
     }
-    return 'Your notification entry added successfully.';
+    $self->add_status_key( 'comments.status.add_notify_ok' );
+    return;
 }
 
 sub _process_notifications {
@@ -586,10 +594,10 @@ sub _process_notifications {
     $log ||= get_logger( LOG_APP );
 
     my $notes = eval {
-        OpenInteract2::CommentNotify->fetch_group(
-                         { where => 'class = ? AND object_id = ?',
-                           value => [ $comment->{class},
-                                      $comment->{object_id} ] })
+        OpenInteract2::CommentNotify->fetch_group({
+            where => 'class = ? AND object_id = ?',
+            value => [ $comment->{class}, $comment->{object_id} ],
+        })
     };
     if ( $@ ) {
         $log->error( "Failed to fetch notifications for processing: $@" );
@@ -608,7 +616,7 @@ sub _process_notifications {
                    summary     => $summary,
                    server_name => $server_name );
     my $message = $self->generate_content(
-                    \%params, { name => 'comment::notification_email' } );
+        \%params, { name => 'comments::notification_email' });
     my $subject = $self->_create_email_subject;
     my $success = 0;
     my $from_address = CTX->lookup_mail_config->{content_email};
@@ -620,11 +628,12 @@ sub _process_notifications {
                    ? qq("$note->{name}" <$note->{email}>)
                    : $note->{email};
         eval {
-            OpenInteract2::Util->send_email(
-                         { to      => $to,
-                           from    => $from_address,
-                           subject => $subject,
-                           message => $message })
+            OpenInteract2::Util->send_email({
+                to      => $to,
+                from    => $from_address,
+                subject => $subject,
+                message => $message
+            })
         };
         if ( $@ ) {
             $log->error( "Failed to send to '$to': $@" );
@@ -650,7 +659,7 @@ sub _create_email_subject {
 
 sub remove {
     my ( $self ) = @_;
-    $self->param_add( error_msg => 'REMOVE not implemented yet' );
+    $self->add_error( 'REMOVE not implemented yet' );
     return $self->list_by_object;
 }
 
@@ -678,20 +687,22 @@ sub show_notify {
     my %params = ();
 
     $params{notes} = eval {
-        OpenInteract2::CommentNotify->fetch_group(
-                              { where => 'class = ? AND object_id = ?',
-                                value => [ $obj_class, $obj_id ] })
+        OpenInteract2::CommentNotify->fetch_group({
+            where => 'class = ? AND object_id = ?',
+            value => [ $obj_class, $obj_id ]
+        })
     };
     if ( $@ ) {
         $log->error( "Error fetching notifications for ",
                      "[$obj_class: $obj_id]: $@" );
-        $self->param_add( error_msg => "Failed to fetch notifications: $@" );
+        $self->add_error_key( 'comments.error.cannot_fetch_notify', "$@" );
     }
     else {
         my $summaries = eval {
-            OpenInteract2::CommentSummary->fetch_group(
-                              { where => 'class = ? AND object_id = ?',
-                                value => [ $obj_class, $obj_id ] })
+            OpenInteract2::CommentSummary->fetch_group({
+                where => 'class = ? AND object_id = ?',
+                value => [ $obj_class, $obj_id ]
+            })
         };
         $params{summary} = $summaries->[0];
     }
@@ -706,12 +717,14 @@ sub comment_recent {
                      5; # last-ditch effort...
     my %params = ();
     my $comments = eval {
-        OpenInteract2::Comment->fetch_group({ limit        => $recent_num,
-                                              order        => 'posted_on DESC',
-                                              column_group => 'summary' })
+        OpenInteract2::Comment->fetch_group({
+            limit        => $recent_num,
+            order        => 'posted_on DESC',
+            column_group => 'summary',
+        })
     };
     if ( $@ ) {
-        $self->param_add( error_msg => "Failed to get recent comments: $@" );
+        $self->add_error_key( 'comments.error.cannot_fetch_recent', "$@" );
     }
     else {
         $params{comments} = $comments;
