@@ -1,6 +1,6 @@
 package OpenInteract2::Action::Error;
 
-# $Id: Error.pm,v 1.9 2003/06/27 06:02:13 lachoy Exp $
+# $Id: Error.pm,v 1.10 2004/02/18 05:25:23 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::CommonSearch
@@ -10,7 +10,9 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use Text::Wrap               qw();
 
-$OpenInteract2::Action::Error::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::Error::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+
+my ( $log );
 
 sub _search_query_customize {
     my ( $self ) = @_;
@@ -81,7 +83,7 @@ sub _display_customize {
 
 sub remove {
     my ( $self ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     my $request = CTX->request;
     my @error_id = $request->param( 'error_id' );
@@ -118,4 +120,4 @@ sub remove {
     return $self->execute( task=> 'search_form' );
 }
 
-1;
+1;
\ No newline at end of file
