@@ -1,6 +1,6 @@
 package OpenInteract2::Action::News;
 
-# $Id: News.pm,v 1.8 2004/02/18 05:25:25 lachoy Exp $
+# $Id: News.pm,v 1.12 2004/12/05 21:15:53 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::CommonSearch
@@ -16,7 +16,7 @@ use OpenInteract2::Context     qw( CTX );
 use OpenInteract2::Util;
 use SPOPS::Secure              qw( SEC_LEVEL_WRITE );
 
-$OpenInteract2::Action::News::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::News::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -42,12 +42,19 @@ sub latest {
     my @values = ( OpenInteract2::Util->now, 'yes' );
     my $news_class = CTX->lookup_object( 'news' );
     my $items = eval {
-        $news_class->fetch_group({ where => $where,
-                                   value => \@values,
-                                   order => 'posted_on DESC',
-                                   limit => $num_items })
+        $news_class->fetch_group({
+            where => $where,
+            value => \@values,
+            order => 'posted_on DESC',
+            limit => $num_items,
+        })
     };
-    $params{news_list} = $self->_massage_news_list( $items );
+    if ( $@ ) {
+        $self->add_error_key( 'news.error.fetch_multiple', $@ );
+    }
+    else {
+        $params{news_list} = $self->_massage_news_list( $items );
+    }
     return $self->generate_content( \%params );
 }
 
@@ -120,13 +127,16 @@ sub search {
         }
         $log->is_info &&
             $log->info( "Given search begin/end dates of ",
-                        "'", $begin_date->strftime( '%Y-%m-%d' ), "'",
+                        "'", $begin_date->strftime( '%Y-%m-%d' ), "' and ",
                         "'", $end_date->strftime( '%Y-%m-%d' ), "'" );
-        $where .= 'AND ( posted_on >= ? AND posted_on < ? )';
+        $where .= ' AND ( posted_on >= ? AND posted_on <= ? ) ';
         push @values, $begin_date->strftime( '%Y-%m-%d' ),
                       $end_date->strftime( '%Y-%m-%d' );
     }
 
+    $log->is_debug &&
+        $log->debug( "Quering news objects with: $where\n",
+                     "and values: ", join( ', ', @values ) );
     my $news_class = CTX->lookup_object( 'news' );
     my $items = eval {
         $news_class->fetch_group({ where        => $where,
@@ -205,16 +215,31 @@ sub _update_customize {
     $self->_set_defaults( $news );
 }
 
+sub _ds { return ref( $_[0] ) ? $_[0]->strftime( '%Y-%m-%d %H:%M' ) : $_[0] }
+
 sub _set_defaults {
     my ( $self, $news ) = @_;
+    $log ||= get_logger( LOG_APP );
 
-    $news->{active_on} ||= DateTime->now;
-    $news->{posted_on} ||= DateTime->now;
+    $log->is_info &&
+        $log->info( "Before setting date defaults: ",
+                    "[active_on: ", _ds( $news->{active_on} ), "] ",
+                    "[posted_on: ", _ds( $news->{posted_on} ), "] ",
+                    "[expires_on: ", _ds( $news->{expires_on} ), "] " );
+
+    $news->{active_on} ||= CTX->create_date;
+    $news->{posted_on} ||= CTX->create_date;
     unless ( $news->{expires_on} ) {
         my $expire_days = $self->param( 'default_expire' );
-        $news->{expires_on} = DateTime->now->add( days => $expire_days );
+        $news->{expires_on} = CTX->create_date->add( days => $expire_days );
     }
 
+    $log->is_info &&
+        $log->info( "After setting date defaults: ",
+                    "[active_on: ", _ds( $news->{active_on} ), "] ",
+                    "[posted_on: ", _ds( $news->{posted_on} ), "] ",
+                    "[expires_on: ", _ds( $news->{expires_on} ), "] " );
+
     # substitute <p> for hard returns where needed
 
     $news->{news_item} =~ s/(\r\n\r\n)(?!(<p|<pre|<blockquote))/$1<p>/g;
@@ -266,21 +291,14 @@ sub show_summary {
     my ( $self ) = @_;
     $log ||= get_logger( LOG_APP );
 
-    my $sections = eval {
-        CTX->lookup_object( 'news_section' )
-           ->fetch_group({ order => 'section' })
-    };
-    if ( $@ ) {
-        $log->error( "Failed to get news sections: $@" );
-        $self->param_add( error_msg => "Failed to get news sections: $@" );
-    }
+    my $sections = $self->_get_sections;
     my $news = eval {
         CTX->lookup_object( 'news' )
            ->fetch_group({ order => 'posted_on DESC' })
     };
     if ( $@ ) {
         $log->error( "Failed to get news objects: $@" );
-        $self->param_add( error_msg => "Failed to get news items: $@" );
+        $self->add_error_key( 'news.error.fetch_multiple', $@ );
     }
     return $self->generate_content(
                     { section_list => $sections, news_list => $news } );
@@ -301,9 +319,8 @@ NEWS:
         $attempt++;
         my $news = eval { $news_class->fetch( $news_id ) };
         if ( $@ ) {
-            my $msg = "Failed to fetch news object [$news_id]: $@";
-            $log->error( $msg );
-            $self->param_add( error_msg => $msg );
+            $log->error( "Cannot fetch news '$news_id': $@" );
+            $self->add_error_key( 'news.error.fetch', $news_id, $@ );
             next NEWS;
         }
         $news->{title} = $request->param( "title_$news_id" );
@@ -311,16 +328,14 @@ NEWS:
         $news->{active}  = $request->param( "active_$news_id" );
         eval { $news->save };
         if ( $@ ) {
-            my $msg = "Failed to save news object [$news_id]: $@";
-            $log->error( $msg );
-            $self->param_add( error_msg => $msg );
+            $log->error( "Failed to save news object '$news_id': $@" );
+            $self->add_error_key( 'news.error.save', $news_id, $@ );
         }
         else {
             $success++;
         }
     }
-    $self->param_add(
-        status_msg => "Attempted: $attempt; successful updates $success" );
+    $self->add_status_key( 'news.status.multi_updates', $attempt, $success );
     $self->clear_cache();
     return $self->execute({ task => 'home' });
 }
@@ -334,12 +349,11 @@ sub _get_sections {
            ->fetch_group({ order => 'section' })
     };
     if ( $@ ) {
-        my $msg = "Failed to retrieve news sections: $@";
-        $self->param_add( error_msg => $msg );
+        $log->error( "Failed to get news sections: $@" );
+        $self->add_error_key( 'news.error.fetch_sections', $@ );
     }
     $sections ||= [];
     return $sections;
 }
 
-
-1;
\ No newline at end of file
+1;
