@@ -1,6 +1,6 @@
 package OpenInteract2::Action::ObjectActivity;
 
-# $Id: ObjectActivity.pm,v 1.6 2003/06/25 14:10:51 lachoy Exp $
+# $Id: ObjectActivity.pm,v 1.7 2004/02/18 05:25:25 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::CommonSearch );
@@ -8,7 +8,9 @@ use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Action::ObjectActivity::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::ObjectActivity::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+
+my ( $log );
 
 my $DATE_FMT = '%Y-%m-%d';
 
@@ -31,7 +33,7 @@ sub _search_form_customize {
 
 sub _search_query_customize {
     my ( $self ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     my $request = CTX->request;
 
@@ -93,7 +95,7 @@ sub _search_customize {
 
 sub _set_object_info {
     my ( $self, $activity_iter ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     my @new_activity = ();
     my $user_class = CTX->lookup_object( 'user' );
@@ -141,4 +143,4 @@ sub _set_object_info {
     return \@new_activity;
 }
 
-1;
+1;
\ No newline at end of file
