@@ -1,6 +1,6 @@
 package OpenInteract2::Action::Page;
 
-# $Id: Page.pm,v 1.18 2004/05/22 15:02:58 lachoy Exp $
+# $Id: Page.pm,v 1.23 2004/11/08 14:48:41 sjn Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::CommonSearch
@@ -17,7 +17,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use SPOPS::Secure            qw( SEC_LEVEL_WRITE );
 
-$OpenInteract2::Action::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::Page::VERSION = sprintf("%d.%02d", q$Revision: 1.23 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -29,7 +29,7 @@ use constant DEFAULT_EXPIRE => DateTime::Duration->new( years => 1 );
 # browser and in the normal template setup; others (pdf, ps, mov,
 # etc.) get sent to the user directly
 
-my %DISPLAY_TYPES = map { $_ => 1 } ( 'text/html' );
+my %DISPLAY_TYPES = map { $_ => 1 } ( 'text/html', 'text/css', 'text/plain' );
 
 # Use this to separate your single document into multiple pages
 
@@ -189,11 +189,11 @@ sub add_subdirectory {
     eval { File::Path::mkpath( $full_dir, undef, 0775 ) };
     if ( $@ ) {
         $self->param_add(
-               error_msg => "Failed to create [$display_path]: $@" );
+               error_msg => "Failed to create '$display_path': $@" );
     }
     else {
         $self->param_add(
-               status_msg => "Directory [$display_path] created ok" );
+               status_msg => "Directory '$display_path' created ok" );
     }
     return $self->generate_content(
                \%params, { name => 'base_page::directory_edit_status' } );
@@ -293,7 +293,7 @@ sub remove_directory {
     my $view_directory = join( '/', @pieces );
     $log->is_debug &&
         $log->debug( "Trying to view directory [$view_directory]" );
-    my $status_msg = "Removed directory [$directory] ok";
+    my $status_msg = "Removed directory '$directory' ok";
     return $self->generate_content(
                          { status_msg       => $status_msg,
                            directory        => $directory,
@@ -412,7 +412,8 @@ sub rename_file {
     }
     $log->is_debug &&
         $log->debug( "Page saved with new location ok" );
-    $self->param_add( status_msg => "File renamed ok" );
+    $self->param_add( status_msg => "File renamed from '$old_location' " .
+                                    "to '$new_location' ok" );
     return $self->generate_content(
                          { directory  => $old_page->{directory},
                            location   => $old_page->{location} },
@@ -748,10 +749,26 @@ sub _show_displayable_page {
 
     # Use page metadata to modify display
 
-    my @boxes = grep { $_ } map { s/^\s+// }
-                                split( /\s+/, $page->{boxes} );
+    $page->{boxes} ||= "";
+    my @box_add    = ();
+    my @box_remove = ();
+    foreach ( split /\s+/, $page->{boxes} ) {
+        s/^\s+//;
+        s/\s+$//;
+        if ( /^\-/ ) {
+            push @box_remove, $_;
+        }
+        else {
+            s/^\+//;
+            push @box_add, $_;
+        }
+    }
 
-    my %params = ( boxes => \@boxes, page => $page );
+    my %params = (
+        box_add    => \@box_add,
+        box_remove => \@box_remove,
+        page       => $page,
+    );
 
     # Grab content we're actually going to show
 
@@ -1086,26 +1103,21 @@ but override the C<display()> method for our special needs.
 
 B<directory_list>: implemented in this class
 
-B<search_form>: implemented in
-L<OpenInteract2::Action::Common|OpenInteract2::Action::Common>
+B<search_form>: implemented in L<OpenInteract2::Action::CommonSearch>
 
-B<search>: implemented in
-L<OpenInteract2::Action::Common|OpenInteract2::Action::Common>
+B<search>: implemented in L<OpenInteract2::Action::CommonSearch>
 
 B<display>: implemented in this class
 
-B<edit>: implemented in
-L<OpenInteract2::Action::Common|OpenInteract2::Action::Common>
+B<display_form>: implemented in L<OpenInteract2::Action::CommonUpdate>
 
-B<remove>: implemented in
-L<OpenInteract2::Action::Common|OpenInteract2::Action::Common>
+B<remove>: implemented in L<OpenInteract2::Action::CommonRemove>
 
-B<notify>: implemented in
-L<OpenInteract2::Action::Common|OpenInteract2::Action::Common>
+B<notify>: implemented in L<OpenInteract2::Action::Common>
 
 =head1 SEE ALSO
 
-L<OpenInteract2::Action::Common|OpenInteract2::Action::Common>
+L<OpenInteract2::Action::Common>
 
 =head1 COPYRIGHT
 
