@@ -1,6 +1,6 @@
 package OpenInteract2::Action::PageDirectory;
 
-# $Id: PageDirectory.pm,v 1.4 2003/06/25 14:10:49 lachoy Exp $
+# $Id: PageDirectory.pm,v 1.7 2004/04/09 11:38:26 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::CommonUpdate
@@ -11,16 +11,25 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use SPOPS::Secure            qw( SEC_LEVEL_WRITE );
 
-$OpenInteract2::Action::PageDirectory::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::PageDirectory::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+
+my ( $log );
 
 sub list {
     my ( $self ) = @_;
-    my $handlers = eval {
+    $log ||= get_logger( LOG_APP );
+
+    my %params = ();
+    $params{iterator} = eval {
         CTX->lookup_object( 'page_directory' )->fetch_iterator;
     };
+    if ( $@ ) {
+        my $msg = "Failed to fetch directory handlers: $@";
+        $log->error( $msg );
+        $self->param_add( error_msg => $msg );
+    }
     return $self->generate_content(
-                    { iterator => $handlers },
-                    { name => 'base_page::page_directory_handler_list' } );
+        \%params, { name => 'base_page::page_directory_handler_list' } );
 }
 
 # Just grab all the actions available
@@ -37,18 +46,22 @@ sub _display_form_customize {
 
 sub _display_customize {
     my ( $self, $params ) = @_;
+    $log ||= get_logger( LOG_APP );
+
     $params->{action_list} = eval {
         CTX->lookup_object( 'page_directory' )->list_directory_actions
     };
     if ( $@ ) {
-        $self->param_add( error_msg => "Failed to lookup action types: $@" );
+        my $msg = "Failed to lookup action types: $@";
+        $log->error( $msg );
+        $self->param_add( error_msg => $msg );
     }
     return undef;
 }
 
 sub _update_customize {
     my ( $self, $dir, $old_data, $update_options ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     # If the user changed the directory, then we need to set the ID so
     # the UPDATE works properly.
@@ -56,8 +69,8 @@ sub _update_customize {
     if ( $old_data->{directory} and $dir->{directory} ne $old_data->{directory} ) {
         $log->is_debug &&
             $log->debug( "User changed directory from ",
-                              "[$old_data->{directory}] ",
-                              "to [$dir->{directory}]" );
+                         "'$old_data->{directory}' ",
+                         "to '$dir->{directory}'" );
         $update_options->{use_id} = $old_data->{directory};
     }
     return undef;
@@ -65,4 +78,3 @@ sub _update_customize {
 
 1;
 
-
