@@ -1,18 +1,20 @@
 package OpenInteract2::Action::PageDirectoryIndex;
 
-# $Id: PageDirectoryIndex.pm,v 1.8 2003/06/25 14:10:49 lachoy Exp $
+# $Id: PageDirectoryIndex.pm,v 1.13 2004/05/11 03:24:15 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
 use File::Basename;
-use File::Spec;
+use File::Spec::Functions    qw( catdir );
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error oi_security_error );
 use SPOPS::Secure            qw( :level );
 
-$OpenInteract2::Action::PageDirectoryIndex::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::PageDirectoryIndex::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
+
+my ( $log );
 
 use constant DEFAULT_IMAGE_SOURCE => '/images/icons/unknown.gif';
 use constant DEFAULT_INDEX_FILE   => 'index.html';
@@ -21,7 +23,7 @@ my %MIME = ();
 
 sub simple_index {
     my ( $self ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     $self->refresh_content_types();
     my $apply_dir = $self->param( 'directory' )
@@ -36,6 +38,8 @@ sub simple_index {
         $security_level = $page_class->check_security({
                                         object_id => $apply_dir });
         if ( $security_level < SEC_LEVEL_READ ) {
+            $log->error( "Security failure prevents display of simple ",
+                         "index; needed READ found $security_level" );
             oi_security_error "Cannot display page: permission denied",
                               { security_required => SEC_LEVEL_READ,
                                 security_found    => $security_level };
@@ -46,10 +50,11 @@ sub simple_index {
 
     $apply_dir =~ s|/$||;
 
-    my $page_iter = eval { $page_class->fetch_iterator({
-                              where => 'directory = ?',
-                              value => [ $apply_dir ],
-                              order => 'location' }) };
+    my $page_iter = eval {
+        $page_class->fetch_iterator({ where => 'directory = ?',
+                                      value => [ $apply_dir ],
+                                      order => 'location' })
+    };
     if ( $@ ) {
         $self->param( error_msg => "$@" );
         return $self->generate_content(
@@ -70,11 +75,11 @@ sub simple_index {
 
     my @dirs = ();
 
-    my $html_dir = CTX->server_config->{dir}{html};
+    my $html_dir = CTX->lookup_directory( 'html' );
     $html_dir =~ s|/$||;
-    my $fs_dir   = File::Spec->catdir( $html_dir, $apply_dir );
+    my $fs_dir   = catdir( $html_dir, $apply_dir );
     $log->is_debug &&
-        $log->debug( "Trying to read dirs from [$fs_dir]" );
+        $log->debug( "Trying to read dirs from '$fs_dir'" );
     eval { opendir( D, $fs_dir ) || die $! };
     if ( $@ ) {
         $self->param( error_msg => "Failed reading subdirectories: $@" );
@@ -89,7 +94,7 @@ sub simple_index {
                    this_dir       => $apply_dir,
                    dir_list       => \@dirs,
                    has_parent     => $parent,
-                   default_iamge  => DEFAULT_IMAGE_SOURCE,
+                   default_image  => DEFAULT_IMAGE_SOURCE,
                    mime           => \%MIME,
                    security_level => $security_level,
                    dir_trim       => \&dir_trim );
@@ -110,12 +115,9 @@ sub dir_trim {
 
 sub file_index {
     my ( $self ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     my $index_files = $self->param( 'index_files' );
-    $log->is_debug &&
-        $log->debug( "Index files in action param: ",
-                     CTX->dump( $index_files ) );
     unless( ref $index_files eq 'ARRAY' and scalar @{ $index_files } ) {
         $index_files = [ DEFAULT_INDEX_FILE ];
     }
@@ -128,19 +130,20 @@ sub file_index {
     my @locations = map { join( '/', $params{directory}, $_ ) }
                         @{ $index_files };
 
+    my $page_class = CTX->lookup_object( 'page' );
     foreach my $location ( @locations ) {
         $log->is_debug &&
-            $log->debug( "Trying to fetch page location [$location]" );
+            $log->debug( "Trying to fetch page location '$location'" );
         my $page = eval {
-            CTX->lookup_object( 'page' )->fetch( $location )
+            $page_class->fetch_by_location( $location )
         };
         if ( $@ ) {
             $log->error( "Encountered error trying to retrieve page ",
-                         "[$location]: $@. Continuing with others..." );
+                         "'$location': $@. Continuing with others..." );
         }
-        if ( $page ) {
+        elsif ( $page ) {
             $log->is_debug &&
-                $log->debug( "Matching location [$page->{location}]" );
+                $log->debug( "Matching location '$page->{location}'" );
             my $page_action = CTX->lookup_action( 'page' );
 
             # TODO: If we standardize on copying 'core' properties
@@ -153,17 +156,22 @@ sub file_index {
 
     # Location not found, return the appropriate message
 
-    oi_error "No directory index found for $params{directory}";
+    my $error_msg = "No directory index found for '$params{directory}'";
+    $log->error( $error_msg );
+    oi_error $error_msg;
 }
 
 
 sub refresh_content_types {
     my ( $self ) = @_;
     return if ( scalar keys %MIME );
-    my $ct_iter = eval { CTX->lookup_object( 'content_type' )
-                            ->fetch_iterator };
+    my $ct_iter = eval {
+        CTX->lookup_object( 'content_type' )->fetch_iterator
+    };
     if ( $@ ) {
-        oi_error "Error looking up content types: $@";
+        my $msg = "Error looking up content types: $@";
+        $log->error( $msg );
+        oi_error $msg;
     }
     while ( my $ct = $ct_iter->get_next ) {
         $MIME{ $ct->{mime_type} } = $ct;
