@@ -1,6 +1,6 @@
 package OpenInteract2::Action::PageScan;
 
-# $Id: PageScan.pm,v 1.4 2003/06/25 14:10:49 lachoy Exp $
+# $Id: PageScan.pm,v 1.6 2004/03/21 23:08:05 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
@@ -9,7 +9,9 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::PageScan;
 
-$OpenInteract2::Action::PageScan::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::PageScan::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+
+my ( $log );
 
 sub display {
     my ( $self ) = @_;
@@ -19,7 +21,7 @@ sub display {
 
 sub run {
     my ( $self ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     my $scan_dir = CTX->request->param( 'scan_directory' );
 
@@ -32,8 +34,8 @@ sub run {
     foreach my $location ( @{ $new_files } ) {
         my $file_info = $scanner->get_file_info( $location );
         $log->is_debug &&
-            $log->debug( "Trying to add file [$location] ",
-                         "[$file_info->{mime_type}]" );
+            $log->debug( "Trying to add file '$location' ",
+                         "'$file_info->{mime_type}'" );
         my $page = eval { $scanner->add_location( $location, $file_info ) };
         if ( $@ ) {
             push @errors, { error => "$@", location => $location };
