@@ -1,6 +1,6 @@
 package OpenInteract2::Action::SiteTemplate;
 
-# $Id: SiteTemplate.pm,v 1.13 2004/05/22 15:04:36 lachoy Exp $
+# $Id: SiteTemplate.pm,v 1.14 2004/12/05 08:51:20 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use SPOPS::Secure            qw( SEC_LEVEL_WRITE );
 
-$OpenInteract2::Action::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -17,8 +17,7 @@ sub list {
     my ( $self ) = @_;
     $log ||= get_logger( LOG_APP );
 
-    $log->is_info &&
-        $log->info( "Listing templates in system" );
+    $log->is_info && $log->info( "Listing templates in system" );
     my $website_dir = CTX->lookup_directory( 'website' );
     my $packages = CTX->repository->fetch_all_packages();
     my $tmpl_class = CTX->lookup_class( 'template' );
@@ -29,9 +28,8 @@ sub list {
                          $tmpl_class->fetch_by_package( $pkg->name );
         };
         if ( $@ ) {
-            my $msg = "Failed to fetch templates in " . $pkg->name . ": $@";
+            my $msg = $self->add_error_key( '', $pkg->name, $@ );
             $log->error( $msg );
-            $self->param_add( error_msg => $msg );
         }
     }
 
@@ -40,9 +38,8 @@ sub list {
         $templates{ '' } = $tmpl_class->fetch_by_package( '' )
     };
     if ( $@ ) {
-        my $msg = "Failed to get global templates: $@";
+        my $msg = $self->add_error_key( 'base_template.error.fetch_global', $@ );
         $log->error( $msg );
-        $self->param_add( error_msg => $msg );
     }
     return $self->generate_content(
                     { package_templates => \%templates },
@@ -76,9 +73,12 @@ sub display_form {
             my $fq_name = $tmpl_class->create_name( $package, $name );
             $template = eval { $tmpl_class->fetch( $fq_name ) };
             if ( $@ || ! $template ) {
-                my $error = $@ || 'not found';
-                $self->param_add(
-                    error_msg => "Failed to fetch template [$fq_name]: $error" );
+                if ( $@ ) {
+                    $self->add_error_key( 'base_template.error.fetch', $fq_name, $@ );
+                }
+                else {
+                    $self->add_error_key( 'base_template.error.does_not_exist', $fq_name );
+                }
                 return $self->execute({ task => 'list' });
             }
         }
@@ -111,10 +111,10 @@ sub update {
     my ( $self ) = @_;
     $log ||= get_logger( LOG_APP );
 
-    $log->is_info &&
-        $log->info( "Updating existing template" );
+    $log->is_info && $log->info( "Updating existing template" );
     CTX->response->return_url(
-        OpenInteract2::URL->create_from_action( 'template' ) );
+        OpenInteract2::URL->create_from_action( 'template' )
+    );
 
     my $request = CTX->request;
     my $package = $request->param( 'package_original' );
@@ -124,9 +124,12 @@ sub update {
     my $fq_name = $tmpl_class->create_name( $package, $name );
     my $template = eval { $tmpl_class->fetch( $fq_name ) };
     if ( $@ or ! $template ) {
-        my $error = $@ || 'not found';
-        $self->param_add(
-            error_msg => "Failed to fetch template [$fq_name]: $error" );
+        if ( $@ ) {
+            $self->add_error_key( 'base_template.error.fetch', $fq_name, $@ );
+        }
+        else {
+            $self->add_error_key( 'base_template.error.does_not_exist', $fq_name );
+        }
         return $self->execute({ task => 'list' });
     }
     $template->package( $request->param( 'package' ) );
@@ -134,13 +137,13 @@ sub update {
     $template->set_contents( $request->param( 'contents' ) );
     eval { $template->save };
     if ( $@ ) {
-        $self->param_add( error_msg => "Failed to save template: $@" );
+        $self->add_error_key( 'base_template.error.save', $@ );
         $self->param( template => $template );
         return $self->execute({ task => 'display_form' });
     }
     else {
         my $new_name = $template->create_name;
-        $self->param_add( status_msg => "Template $new_name saved ok" );
+        $self->add_status_key( 'base_template.status.update', $new_name );
         return $self->execute({ task => 'list' });
     }
 }
@@ -172,18 +175,17 @@ sub add {
     my $fq_name = $tmpl_class->create_name( $package, $name );
     my $existing_template = eval { $tmpl_class->fetch( $fq_name ) };
     if ( $existing_template ) {
-        $self->param_add(
-            error_msg => "Template [$fq_name] already exists, cannot create" );
+        $self->add_error_key( 'base_template.error.create_exists', $fq_name );
         return $self->execute({ task => 'display_add' });
     }
 
     eval { $template->save };
     if ( $@ ) {
-        $self->param_add( error_msg => "Failed to create template: $@" );
+        $self->add_error_key( 'base_template.error.create', $fq_name, $@ );
         return $self->execute({ task => 'display_add' });
     }
     else {
-        $self->param_add( status_msg => "Template $fq_name saved ok" );
+        $self->add_status_key( 'base_template.status.create', $fq_name );
         return $self->execute({ task => 'list' });
     }
 }
@@ -209,25 +211,21 @@ sub remove {
         $fq_name = $tmpl_class->create_name( $package, $name );
         $template = eval { $tmpl_class->fetch( $fq_name ) };
         if ( $@ ) {
-            $self->param_add(
-                error_msg => "Cannot fetch template [$fq_name]: $@" );
+            $self->add_error_key( 'base_template.error.fetch', $fq_name, $@ );
             return $self->execute({ task => 'list' });
         }
     }
     if ( $template ) {
         eval { $template->remove };
         if ( $@ ) {
-            $self->param_add(
-                error_msg => "Error removing template $fq_name: $@" );
+            $self->add_error_key( 'base_template.error.remove', $fq_name, $@ );
         }
         else {
-            $self->param_add(
-                status_msg => "Template $fq_name removed ok" );
+            $self->add_status_key( 'base_template.status.remove', $fq_name );
         }
     }
     else {
-        $self->param_add(
-            error_msg => "Template [$fq_name] does not seem to exist" );
+        $self->add_error_key( 'base_template.error.does_not_exist', $fq_name );
     }
     return $self->execute({ task => 'list' });
 }
