@@ -1,6 +1,6 @@
 package OpenInteract2::Action::SystemDoc;
 
-# $Id: SystemDoc.pm,v 1.10 2004/02/18 05:25:25 lachoy Exp $
+# $Id: SystemDoc.pm,v 1.13 2004/12/05 08:51:24 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
@@ -10,7 +10,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Package;
 use Pod::POM;
 
-$OpenInteract2::Action::SystemDoc::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::SystemDoc::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -130,114 +130,37 @@ sub display {
     $log ||= get_logger( LOG_APP );
 
     my $request = CTX->request;
-    my ( $pod_file, $html_file, $text_file, $title, $error );
+    my %params = map { $_ => '' }
+                     qw( pod_file  html_file text_file title error );
 
     # If this is a package, display the doc
 
     my $package_spec = $request->param( 'package' );
     if ( $package_spec ) {
-        my ( $package_name, $ver ) =
-            OpenInteract2::Package->parse_full_name( $package_spec );
-        my $doc = $request->param( 'doc' );
-        my $repos = CTX->repository;
-        if ( $doc =~ /\.(html|txt|pod)$/ ) {
-            my $full_filename = $repos->find_file( $package_name, $doc );
-            $log->is_debug &&
-                $log->debug( "Found [$full_filename] in [$package_name]" );
-            $pod_file  = $full_filename  if ( $doc =~ /\.pod$/ );
-            $html_file = $full_filename  if ( $doc =~ /\.html$/ );
-            $text_file = $full_filename  if ( $doc =~ /\.txt$/ );
-            $title = "Display Document from Package: $package_name";
-            $error = "Cannot find package documentation: $doc";
-        }
+        $self->_display_package_params( $package_spec, \%params );
     }
     else {
         my $module = $self->param( 'module' )
                      || $request->param( 'module' );
-
-        # ewww! ick!
-        # TODO: Can we programmatically use Pod::Perldoc to do this?
-        $pod_file = $POD_CACHE{ $module } || `perldoc -l $module`;
-
-        chomp $pod_file;
-        if ( $pod_file ) {
-            $log->is_info &&
-                $log->info( "Found [$pod_file] from [$module]" );
-        }
-        else {
-            $pod_file = $INC{ _uncolonify( $module ) };
-            $log->is_info &&
-                $log->info( "Found [$pod_file] from %INC" );
-        }
-        if ( -f $pod_file ) {
-            $POD_CACHE{ $module } = $pod_file;
-        }
-        $title = "Display Module: $module";
-        $error = "Cannot find module: $module";
+        $self->_display_module_params( $module, \%params );
     }
 
     my ( $content );
 
-    if ( -f $pod_file ) {
-        $log->is_debug &&
-            $log->debug( "Trying to view pod in [$pod_file]" );
-        my $parser = Pod::POM->new();
-        my $pom = $parser->parse( $pod_file );
-        unless ( $pom ) {
-            $log->error( "Pod::POM did not return an object: ",
-                         $parser->error() );
-            return '<p>Error parsing POD: ' . $parser->error() . '</p>';
-        }
-
-        eval { require OpenInteract2::PodView };
-        if ( $@ ) {
-            my $msg = "Failed to load POD viewer: $@";
-            $log->error( $msg );
-            $self->param_add( error_msg => $msg );
-            $content = 'No content';
-        }
-        else {
-            $content = eval { OpenInteract2::PodView->print( $pom ) };
-            if ( $@ ) {
-                $log->error( "Failed to output html from pod: $@" );
-                $content = "Failed to display module: $@";
-            }
-            else {
-                $content =~ s/^.*<BODY>//sm;
-                $content =~ s|</BODY>.*$||sm;
-            }
-        }
+    if ( -f $params{pod_file} ) {
+        $content = $self->_show_pod( \%params );
     }
 
-    elsif ( -f $html_file ) {
-        eval { open( HTML, $html_file ) || die $! };
-        if ( $@ ) {
-            my $msg = "Error opening HTML file: $@";
-            $log->error( "(File: $html_file) $msg" );
-            return "<p>$msg</p>";
-        }
-        local $/ = undef;
-        $content = <HTML>;
-        close( HTML );
-        $content =~ s/^.*<BODY>//sm;
-        $content =~ s|</BODY>.*$||sm;
+    elsif ( -f $params{html_file} ) {
+        $content = $self->_show_html( \%params );
     }
 
-    elsif ( -f $text_file ) {
-        eval { open( TEXT, $text_file ) || die $! };
-        if ( $@ ) {
-            my $msg = "Error opening TEXT file: $@";
-            $log->error( "(File: $text_file) $msg" );
-            return "<p>$msg</p>";
-        }
-        local $/ = undef;
-        $content = <TEXT>;
-        close( TEXT );
-        $content = qq(<pre class="systemDocText">$content</pre>);
+    elsif ( -f $params{text_file} ) {
+        $content = $self->_show_text( \%params );
     }
 
     else {
-        return '<p>Error $error.</p>';
+        return "<p>$params{error}.</p>";
     }
 
     unless ( $content ) {
@@ -248,6 +171,108 @@ sub display {
                     { name => 'system_doc::doc_display' } );
 }
 
+sub _display_package_params {
+    my ( $self, $package_spec, $params ) = @_;
+    my ( $package_name, $ver ) =
+            OpenInteract2::Package->parse_full_name( $package_spec );
+    my $request = CTX->request;
+    my $doc = $request->param( 'doc' );
+    my $repos = CTX->repository;
+    if ( $doc =~ /\.(html|txt|pod)$/ ) {
+        my $full_filename = $repos->find_file( $package_name, $doc );
+        $log->is_debug &&
+            $log->debug( "Found [$full_filename] in [$package_name]" );
+        $params->{pod_file}  = $full_filename  if ( $doc =~ /\.pod$/ );
+        $params->{html_file} = $full_filename  if ( $doc =~ /\.html$/ );
+        $params->{text_file} = $full_filename  if ( $doc =~ /\.txt$/ );
+        $params->{title} = $self->_msg( 'sys_doc.package.doc_title', $package_name );
+        $params->{error} = $self->_msg( 'sys_doc.error.cannot_find_package_doc', $doc );
+    }
+}
+
+sub _display_module_params {
+    my ( $self, $module, $params ) = @_;
+
+    # ewww! ick!
+    # TODO: Can we programmatically use Pod::Perldoc to do this?
+    $params->{pod_file} = $POD_CACHE{ $module } || `perldoc -l $module`;
+
+    chomp $params->{pod_file};
+    if ( $params->{pod_file} ) {
+        $log->is_info &&
+            $log->info( "Found [$params->{pod_file}] from [$module]" );
+    }
+    else {
+        $params->{pod_file} = $INC{ _uncolonify( $module ) };
+        $log->is_info &&
+            $log->info( "Found [$params->{pod_file}] from %INC" );
+    }
+    if ( -f $params->{pod_file} ) {
+        $POD_CACHE{ $module } = $params->{pod_file};
+    }
+    $params->{title} = $self->_msg( 'sys_doc.module.doc_title', $module );
+    $params->{error} = $self->_msg( 'sys_doc.error.cannot_find_module_doc', $module );
+}
+
+sub _show_pod {
+    my ( $self, $params ) = @_;
+    $log->is_debug &&
+        $log->debug( "Trying to view pod in [$params->{pod_file}]" );
+    my $parser = Pod::POM->new();
+    my $pom = $parser->parse( $params->{pod_file} );
+    unless ( $pom ) {
+        $log->error( "Pod::POM did not return an object: ",
+                     $parser->error() );
+        my $msg = $self->_msg( 'sys_doc.error.pod_parse', $parser->error() );
+        return qq(<p>$msg</p>);
+    }
+
+    eval { require OpenInteract2::PodView };
+    if ( $@ ) {
+        $log->error( "No POD viewer: $@" );
+        $self->add_error_key( 'sys_doc.error.pod_viewer', $@ );
+        return $self->_msg( 'sys_doc.pod.no_content' );
+    }
+    my $content = eval { OpenInteract2::PodView->print( $pom ) };
+    if ( $@ ) {
+        $log->error( "Failed to output html from pod: $@" );
+        return $self->_msg( 'sys_doc.pod.cannot_display_module', $@ );
+    }
+    $content =~ s/^.*<BODY>//sm;
+    $content =~ s|</BODY>.*$||sm;
+    return $content;
+}
+
+sub _show_html {
+    my ( $self, $params ) = @_;
+    eval { open( HTML, $params->{html_file} ) || die $! };
+    if ( $@ ) {
+        my $msg = $self->_msg( 'sys_doc.error.cannot_open_file',
+                               $params->{html_file}, $@ );
+        $log->error( $msg );
+        return "<p>$msg</p>";
+    }
+    my $content = join( '', <HTML> );
+    close( HTML );
+    $content =~ s/^.*<BODY>//sm;
+    $content =~ s|</BODY>.*$||sm;
+    return $content;
+}
+
+sub _show_text {
+    my ( $self, $params ) = @_;
+    eval { open( TEXT, $params->{text_file} ) || die $! };
+    if ( $@ ) {
+        my $msg = $self->_msg( 'sys_doc.error.cannot_open_file',
+                               $params->{text_file}, $@ );
+        $log->error( $msg );
+        return "<p>$msg</p>";
+    }
+    my $content = join( '', <TEXT> );
+    close( TEXT );
+    return qq(<pre class="systemDocText">$content</pre>);
+}
+
 1;
 
 __END__
@@ -303,10 +328,6 @@ B<Get more meta information>
 System documentation needs more meta information so we can better
 display title and other information on the listing page.
 
-=head1 BUGS
-
-None known.
-
 =head1 COPYRIGHT
 
 Copyright (c) 2001-2004 Chris Winters. All rights reserved.
@@ -316,4 +337,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
