@@ -1,23 +1,26 @@
 package OpenInteract2::Action::TemplatesUsedBox;
 
-# $Id: TemplatesUsedBox.pm,v 1.9 2004/02/18 05:23:09 lachoy Exp $
+# $Id: TemplatesUsedBox.pm,v 1.11 2004/11/28 06:40:19 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
+use Log::Log4perl            qw( get_logger );
+use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Action::TemplatesUsedBox::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::TemplatesUsedBox::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
-# Simple handler to put the list of templates used into a more
-# manageable form -- note that we can handle template objects and
-# 'package::name' strings in \@{ $R->{templates_used} }
+my ( $log );
 
 sub handler {
     my ( $self ) = @_;
-    my $controller = $self->controller;
-    my $request = CTX->request;
+    $log ||= get_logger( LOG_APP );
+    my $controller = CTX->controller;
     unless ( $controller->isa( 'OpenInteract2::Controller::ManageTemplates' ) ) {
-        return $request->language_handle->maketext( 'base_template.error.no_manage' );
+        $log->error( "Controller is not setup to handle templates; it is of type ",
+                     "'", ref( $controller ), "' which should have ",
+                     "OpenInteract2::Controller::ManageTemplates in its \@ISA" );
+        return $self->_msg( 'base_template.error.no_manage' );
     }
     my %tmpl_by_package = ();
     my %tmpl_used       = ();
@@ -27,6 +30,7 @@ sub handler {
         my ( $package, $name, $full_name );
         if ( ref $template ) {
             ( $package, $name ) = ( $template->{package}, $template->{name} );
+            $full_name = $template_class->create_name( $package, $name );
         }
         else {
             ( $package, $name ) = $template_class->parse_name( $template );
@@ -36,12 +40,14 @@ sub handler {
             }
             $full_name = $template;
         }
+        next if ( $name eq '_anonymous_' );
         next if ( $tmpl_used{ $package }{ $name } );
         $tmpl_used{ $package }{ $name }++;
-        push @{ $tmpl_by_package{ $package } },
-                            { name      => $name,
-                              package   => $package,
-                              full_name => $full_name };
+        push @{ $tmpl_by_package{ $package } }, {
+            name      => $name,
+            package   => $package,
+            full_name => $full_name
+        };
     }
     foreach my $package ( keys %tmpl_by_package ) {
         $tmpl_by_package{ $package } = [ sort { $b->{name} cmp $a->{name} }
@@ -67,16 +73,24 @@ OpenInteract2::Action::TemplatesUsedBox -- Generate 'Templates Used' box content
 
 =head1 DESCRIPTION
 
-B<templates_used> (if in 'site admin' group)
+This action supports a box which by default is referenced by the
+'templates_used_box' name. This box lists templates used in the
+current request. To work properly the controller must have
+L<OpenInteract2::Controller::ManageTemplates> in its C<@ISA>. (You can
+also create your own action to pull the templates from the
+controller.)
 
-Displays a listing of the templates used for a request along with
-links so you can quickly jump to one and edit it.
+This action provides the template a variable 'templates_used' which
+holds a hashref of templates keyed by package. Each value is a an
+array reference of hash references, each with the keys: 'name',
+'package' and 'full_name'. For example, the default template used for
+this box you would have:
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
+ base_template => [
+       { name      => 'templates_used_box',
+         package   => 'base_template',
+         full_name => 'base_template::templates_used_box' },
+ ],
 
 =head1 SEE ALSO
 
@@ -84,7 +98,7 @@ L<OpenInteract2::Action::Box|OpenInteract2::Action::Box>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2003 Chris Winters. All rights reserved.
+Copyright (c) 2001-2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
