@@ -1,15 +1,17 @@
 package OpenInteract2::Page::Database;
 
-# $Id: Database.pm,v 1.2 2003/06/25 14:10:49 lachoy Exp $
+# $Id: Database.pm,v 1.3 2004/02/18 05:25:24 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
+my ( $log );
+
 sub load {
     my ( $class, $page ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     my $page_content = eval { $page->page_content };
     if ( $@ ) {
@@ -57,4 +59,4 @@ sub remove {
     return $page_content->remove;
 }
 
-1;
+1;
\ No newline at end of file
