@@ -1,6 +1,6 @@
 package OpenInteract2::Page::File;
 
-# $Id: File.pm,v 1.8 2004/05/11 03:24:40 lachoy Exp $
+# $Id: File.pm,v 1.9 2004/06/10 22:13:33 lachoy Exp $
 
 use strict;
 use File::Basename           qw();
@@ -89,8 +89,8 @@ sub save {
                 $log->debug( "Temp file exists, removing..." );
             eval { unlink( $tmp_location ) || die $! };
             if ( $@ ) {
-                $log->error( "Failed to remove temp file: $@" );
-                oi_error "Cannot remove old temp file: $!";
+                $log->error( "Failed to remove temp file '$tmp_location': $@" );
+                oi_error "Cannot remove old temp file: $@";
             }
             $log->is_debug &&
                 $log->debug( "Temp file removed ok" );
@@ -103,9 +103,10 @@ sub save {
 
     eval { open( NEW, '>', $tmp_location ) || die $! };
     if ( $@ ) {
-        my $msg = "Cannot open temp file for writing: $@";
-        $log->error( $msg );
-        oi_error $msg;
+        my $error = $@;
+        $log->error( "Cannot open temp file '$tmp_location' for ",
+                     "writing: $error" );
+        oi_error "Cannot open temp file for writing: $error";
     }
 
     if ( $log->is_debug ) {
