@@ -1,6 +1,6 @@
 package OpenInteract2::Page::Http;
 
-# $Id: Http.pm,v 1.4 2003/06/25 14:10:49 lachoy Exp $
+# $Id: Http.pm,v 1.6 2004/02/18 05:25:24 lachoy Exp $
 
 use strict;
 use HTTP::Request;
@@ -16,9 +16,11 @@ BEGIN {
     $AGENT->agent( "OpenInteract2 Requester " . $AGENT->agent );
 }
 
+my ( $log );
+
 sub load {
     my ( $class, $page ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     unless ( $page->{content_location} ) {
         $log->error( "No content location available -- cannot display" );
@@ -47,7 +49,7 @@ sub rewrite_content { return $_[1] }
 
 sub save {
     my ( $class, $page ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
     $log->warn( "Location $page->{location} cannot be saved, since ",
                 "it's using HTTP storage." );
     return 1;
@@ -56,7 +58,7 @@ sub save {
 
 sub rename_content {
     my ( $class, $page, $old_location ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
     $log->warn( "Cannot rename content from [$old_location] to ",
                 "[$page->{location}] since it's using HTTP storage." );
     return 1;
@@ -65,7 +67,7 @@ sub rename_content {
 
 sub remove {
     my ( $class, $page ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
     $log->warn( "Location $page->{location} cannot be removed, since ",
                 "it's using HTTP storage." );
     return 1;
@@ -124,11 +126,11 @@ L<OpenInteract2::Page|OpenInteract2::Page>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2003 Chris Winters. All rights reserved.
+Copyright (c) 2001-2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
