@@ -1,6 +1,6 @@
 package OpenInteract2::PageDirectory;
 
-# $Id: PageDirectory.pm,v 1.5 2003/06/25 14:10:49 lachoy Exp $
+# $Id: PageDirectory.pm,v 1.9 2004/04/09 12:36:40 lachoy Exp $
 
 use strict;
 use File::Basename ();
@@ -9,7 +9,10 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::PageDirectory::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+@OpenInteract2::PageDirectory::ISA     = qw( OpenInteract2::PageDirectoryPersist );
+$OpenInteract2::PageDirectory::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+
+my ( $log );
 
 sub list_directory_actions {
     my ( $class ) = @_;
@@ -24,28 +27,28 @@ sub list_directory_actions {
 # flagged on
 
 sub fetch_by_directory {
-    my ( $class, $dir ) = @_;
-    my $log = get_logger( LOG_APP );
+    my ( $class, $dir_name ) = @_;
+    $log ||= get_logger( LOG_APP );
 
-    unless ( $dir ) {
+    unless ( $dir_name ) {
         oi_error "Must pass directory to fetch";
     }
 
-    my $initial_dir_name = $class->_ensure_trailing_slash( $dir );
+    my $initial_dir_name = $class->_ensure_trailing_slash( $dir_name );
     $log->is_debug &&
-        $log->debug( "Initial dir fetch attempt [$initial_dir_name]" );
+        $log->debug( "Initial dir fetch attempt '$initial_dir_name'" );
     my $dir = $class->fetch( $initial_dir_name );
     if ( $dir ) {
         $log->is_debug &&
             $log->debug( "Directory object found matching ",
-                         "[$initial_dir_name]" );
+                         "'$initial_dir_name'" );
         return $dir;
     }
 
     # We only want parents that have inheritance enabled
 
     my $where = ' subdirs_inherit = ? ';
-    my $value = [ 'yes' ];
+    my @value = ( 'yes' );
 
     my $all_parents = $class->explode_dir( $initial_dir_name );
 
@@ -54,8 +57,8 @@ sub fetch_by_directory {
     if ( scalar @{ $all_parents } > 1 ) { shift @{ $all_parents } }
 
     $log->is_debug &&
-        $log->debug( "Found parents of [$dir]: [",
-                     join( '] [', @{ $all_parents } ), "]" );
+        $log->debug( "Found parents of '$dir': [",
+                     join( "' '", @{ $all_parents } ), "'" );
 
 
     # Form a WHERE clause from the parents
@@ -63,10 +66,12 @@ sub fetch_by_directory {
     my $parent_where = join( ' OR ', map { "directory = ?" }
                                          @{ $all_parents } );
     $where .= " AND ( $parent_where ) ";
-    push @{ $value }, @{ $all_parents };
-
+    push @value, @{ $all_parents };
+    $log->is_debug &&
+        $log->debug( "Trying to find parents with '$where' and dirs: ",
+                     join( ', ', @value ) );
     my $parent_dirs = $class->fetch_group({ where => $where,
-                                            value => $value });
+                                            value => \@value });
 
     # No parents found (most of the time)
 
@@ -187,19 +192,9 @@ B<pre_save_action>
 Ensure that every directory saved to the database has a '/' at the
 end.
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
-=head1 SEE ALSO
-
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2003 Chris Winters. All rights reserved.
+Copyright (c) 2001-2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
