@@ -1,16 +1,16 @@
 package OpenInteract2::PageScan;
 
-# $Id: PageScan.pm,v 1.3 2003/06/11 02:40:58 lachoy Exp $
+# $Id: PageScan.pm,v 1.7 2004/04/09 11:38:26 lachoy Exp $
 
 use strict;
-use base qw( Class::Accessor );
+use base qw( Class::Accessor::Fast );
 use DateTime;
 use File::Find               qw();
-use File::Spec               qw();
+use File::Spec::Functions    qw( catfile );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::PageScan::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::PageScan::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_EXPIRES_IN => 365;
 use constant DEFAULT_MIME_TYPE  => 'text/html';
@@ -61,8 +61,8 @@ sub initialize {
         $self->page_class( $page_class );
     }
     unless ( UNIVERSAL::isa( $self->page_class, 'SPOPS' ) ) {
-        oi_error "The supplied page class [", $self->page_class, "] ",
-                 "is not a valid SPOPS class.";
+        oi_error sprintf( "Page class '%s' not a valid SPOPS class.",
+                          $self->page_class );
     }
 
     # Ensure the file root is either the HTML root or under it. We
@@ -71,18 +71,18 @@ sub initialize {
 
     my $html_root = $self->html_root;
     unless ( $html_root ) {
-        my $server_config = eval { CTX->server_config };
-        if ( $@ or ! $server_config ) {
+        $html_root = CTX->lookup_directory( 'html' );
+        if ( $html_root =~ /^\$/ ) {
             oi_error "You must either define 'html_root' in the ",
-                     "new() constructor or have an OpenInteract2::Request ",
+                     "new() constructor or have an OpenInteract2::Context ",
                      "object available";
         }
-        $self->html_root( $server_config->{dir}{html} );
+        $self->html_root( $html_root );
         $html_root = $self->html_root;
     }
     unless ( -d $html_root ) {
         oi_error "The parameter 'html_root' must point to an existing ",
-                 "directory. (Current: [$html_root])";
+                 "directory. (Currently: $html_root)";
     }
 
     # Finally, ensure the html root does not have a trailing '/'
@@ -99,8 +99,9 @@ sub initialize {
     $self->file_root( $tmp_root );
 
     unless ( -d $self->absolute_filesystem_root ) {
-        oi_error "Filesystem root directory does not exist. ",
-                 "(Current: [", $self->absolute_filesystem_root, "]";
+        oi_error sprintf( "Filesystem root directory does not exist. " .
+                          "(Currently: %s)",
+                          $self->absolute_filesystem_root );
     }
 }
 
@@ -124,13 +125,14 @@ my $FF_OBJ        = undef;
 sub find_new_files {
     my ( $self ) = @_;
 
-    my $pc = $self->page_class;
-
     %FF_NEW   = ();
-    %FF_EXIST = map { $_ => 1 }
-                    @{ $pc->db_select({ select => [ 'location' ],
-                                        from   => [ $pc->table_name ],
-                                        return => 'single-list' }) };
+
+    my $existing_locations = $self->page_class->db_select(
+        { select => [ 'location' ],
+          from   => [ $self->page_class->table_name ],
+          return => 'single-list' });
+
+    %FF_EXIST = map { $_ => 1 } @{ $existing_locations };
     $FF_OBJ   = $self;
     File::Find::find( \&descend, $self->absolute_filesystem_root );
     return [ sort keys %FF_NEW ];
@@ -140,10 +142,12 @@ sub find_new_files {
 sub add_location {
     my ( $self, $location, $file_info ) = @_;
 
-    unless ( $location ) { die "No location given to add\n" }
+    unless ( $location ) {
+        oi_error "Called 'add_location()' with no location to add"
+    }
     $file_info ||= $self->get_file_info( $location );
     my $web_root_location = $self->absolute_web_location( $location );
-    $self->DEBUG && warn "Trying to create new location at [$web_root_location]\n";
+    $self->DEBUG && warn "Trying to create new location at '$web_root_location'\n";
     my $do_parse = ( $file_info->{mime_type} =~ /^text/ ) ? "yes" : "no";
     my %page_params = ( location   => $web_root_location,
                         mime_type  => $file_info->{mime_type},
@@ -162,7 +166,7 @@ sub get_file_info {
     my ( $self, $location ) = @_;
     my $full_filename = $self->absolute_filesystem_location( $location );
     unless ( -f $full_filename ) {
-        oi_error "File [$full_filename] does not exist";
+        oi_error "File '$full_filename' does not exist";
     }
 
     my $mime_type = $self->page_class->mime_type_file( $full_filename ) ||
@@ -170,15 +174,18 @@ sub get_file_info {
                     DEFAULT_MIME_TYPE;
     my %info = ( mime_type => $mime_type,
                  size      => (stat $full_filename)[7] );
-    return \%info unless ( $mime_type eq 'text/html' );
 
-    open( FILE, $full_filename )
-        || oi_error "Cannot open [$full_filename] to find HTML title: $!";
-    while ( <FILE> ) {
-        chomp;
-        $info{title} = $1 if ( m|<title>(.*?)</title>|i );
+    # If it's HTML try to pull the title out
+
+    if ( $mime_type eq 'text/html' ) {
+        open( FILE, $full_filename )
+            || oi_error "Cannot open '$full_filename' to find HTML title: $!";
+        while ( <FILE> ) {
+            chomp;
+            $info{title} = $1 if ( m|<title>(.*?)</title>|i );
+        }
+        close( FILE );
     }
-    close( FILE );
     return \%info;
 }
 
@@ -188,7 +195,7 @@ sub get_file_info {
 sub absolute_filesystem_root {
     my ( $self ) = @_;
     return $self->html_root  unless ( $self->file_root );
-    return File::Spec->catfile( $self->html_root, $self->file_root );
+    return catfile( $self->html_root, $self->file_root );
 }
 
 
@@ -197,7 +204,7 @@ sub absolute_filesystem_root {
 sub absolute_filesystem_location {
     my ( $self, $location ) = @_;
     $location =~ s|^/||;
-    return File::Spec->catfile( $self->absolute_filesystem_root, $location );
+    return catfile( $self->absolute_filesystem_root, $location );
 }
 
 
@@ -230,7 +237,7 @@ sub descend {
          ! $FF_OBJ->keep_funny_characters ) {
         eval { rename( $filename, $cleaned_filename ) || die $! };
         if ( $@ ) {
-            warn "Tried to rename [$filename] to [$cleaned_filename] due to ",
+            warn "Tried to rename '$filename' to '$cleaned_filename' due to ",
                  "non-allowable characters. Rename failed: $@. Skipping file.\n";
             return;
         }
@@ -241,7 +248,7 @@ sub descend {
 
     my $full_web_location = join( '/', $web_dir, $filename );
     if ( $FF_EXIST{ $full_web_location } ) {
-        $FF_OBJ->DEBUG && warn "Location [$full_web_location] already exists\n";
+        $FF_OBJ->DEBUG && warn "Location '$full_web_location' already exists\n";
         return;
     }
 
@@ -254,14 +261,14 @@ sub descend {
     $part_web_location =~ s|^/$file_root/||;
     foreach my $p ( @{ $FF_OBJ->file_skip } ) {
         if ( $part_web_location =~ m{$p} ) {
-            $FF_OBJ->DEBUG && warn "Skip [$part_web_location] with pattern [$p]\n";
+            $FF_OBJ->DEBUG && warn "Skip '$part_web_location' with pattern '$p'\n";
             return;
         }
     }
 
     # None of the criteria matched, so track this as new
 
-    $FF_OBJ->DEBUG && warn "Location is new [$part_web_location]\n";
+    $FF_OBJ->DEBUG && warn "Location is new '$part_web_location'\n";
     $FF_NEW{ $part_web_location }++;
 }
 
@@ -479,14 +486,6 @@ Set to 1 for debugging messages.
 
 Default: 0
 
-=head1 BUGS
-
-None known.
-
-=head1 TO DO
-
-Nothing known.
-
 =head1 SEE ALSO
 
 L<File::Find|File::Find>
