@@ -1,15 +1,18 @@
 package OpenInteract2::SQLInstall::Base;
 
-# $Id: Base.pm,v 1.3 2003/03/27 13:09:10 lachoy Exp $
+# $Id: Base.pm,v 1.4 2003/10/20 03:05:53 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SQLInstall );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
+# NOTE: No data needs to be migrated since the sessions are transient
+# and object keys are recreated as we go
+
 sub get_structure_set {
     my ( $self ) = @_;
-    my $session_ds = CTX->server_config->{session_info}{datasource};
+    my $session_ds = CTX->lookup_session_config->{datasource};
     return [ "datasource: $session_ds", 'system' ];
 }
 
