@@ -1,6 +1,6 @@
 package OpenInteract2::SQLInstall::News;
 
-# $Id: News.pm,v 1.1 2003/03/28 12:57:53 lachoy Exp $
+# $Id: News.pm,v 1.2 2003/10/20 03:05:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SQLInstall );
@@ -21,6 +21,13 @@ my %FILES = (
                'news_section_generator.sql' ],
 );
 
+sub get_migration_information {
+    my ( $self ) = @_;
+    my %news_info    = ( spops_class => 'OpenInteract2::News' );
+    my %section_info = ( spops_class => 'OpenInteract2::NewsSection' );
+    return [ \%news_info, \%section_info ];
+}
+
 sub get_structure_set {
     return 'news';
 }
