@@ -1,21 +1,35 @@
 package OpenInteract2::SQLInstall::ObjectActivity;
 
-# $Id: ObjectActivity.pm,v 1.2 2003/04/21 14:00:21 lachoy Exp $
+# $Id: ObjectActivity.pm,v 1.4 2004/02/26 14:00:35 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SQLInstall );
 
-my @TABLES = ( 'object_track.sql' );
-
 my %FILES = (
- oracle => [ 'object_track_oracle.sql',
+ oracle  => [ 'object_track_oracle.sql',
              'object_track_sequence.sql' ],
- pg     => [ 'object_track.sql',
+ pg      => [ 'object_track.sql',
              'object_track_sequence.sql' ],
- ib     => [ 'object_track_interbase.sql',
+ ib      => [ 'object_track_interbase.sql',
              'object_track_generator.sql' ],
+ default => [ 'object_track.sql' ],
 );
 
+sub get_migration_information {
+    my ( $self ) = @_;
+    my %track_info = (
+        spops_class   => 'OpenInteract2::ObjectAction',
+        transform_sub => \&_modify_class_names,
+    );
+    return [ \%track_info ];
+}
+
+sub _modify_class_names {
+    my ( $info, $record, $sec ) = @_;
+    $sec->{class} =~ s/^\w+::/OpenInteract2::/;
+    $sec->{class} =~ s/^OpenInteract2::NewItem$/OpenInteract2::WhatsNew/;
+}
+
 sub get_structure_set {
     return 'object_action';
 }
@@ -32,7 +46,7 @@ sub get_structure_file {
         return $FILES{ib};
     }
     else {
-        return [ @TABLES ];
+        return $FILES{default};
     }
 }
 
