@@ -1,6 +1,6 @@
 package OpenInteract2::SQLInstall::Page;
 
-# $Id: Page.pm,v 1.1 2003/03/25 02:40:21 lachoy Exp $
+# $Id: Page.pm,v 1.3 2004/05/22 01:53:46 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SQLInstall );
@@ -11,20 +11,44 @@ my @TABLES = ( 'page.sql',
                'page_directory.sql' );
 
 my %FILES = (
-  oracle => [ 'page_oracle.sql',
+  oracle => [ 'page.sql',
+              'page_sequence.sql',
               'page_content_oracle.sql',
               'content_type_oracle.sql',
               'content_type_sequence.sql',
               'page_directory_oracle.sql' ],
   pg     => [ @TABLES,
+              'page_sequence.sql',
               'content_type_sequence.sql' ],
-  ib     => [ 'page_interbase.sql',
+  ib     => [ 'page.sql',
+              'page_generator.sql',
               'page_content_interbase.sql',
               'content_type.sql',
               'page_directory.sql',
               'content_type_generator.sql' ],
 );
 
+sub get_migration_information {
+    my ( $self ) = @_;
+    my %page = (
+        spops_class => 'OpenInteract2::Page',
+        field       => [ qw{ location directory title author keywords boxes
+                             template_parse main_template active_on expires_on
+                             is_active content_location storage mime_type
+                             page_size notes } ],
+    );
+    my %page_directory  = (
+        spops_class => 'OpenInteract2::PageDirectory',
+    );
+    my %content_type = (
+        spops_class => 'OpenInteract2::ContentType',
+    );
+    my %page_content = (
+        spops_class => 'OpenInteract2::PageContent',
+    );
+    return [ \%page, \%page_directory, \%content_type, \%page_content, ];
+}
+
 sub get_structure_set {
     return 'page';
 }
