@@ -1,6 +1,6 @@
 package OpenInteract2::SQLInstall::Security;
 
-# $Id: Security.pm,v 1.1 2003/03/25 04:36:48 lachoy Exp $
+# $Id: Security.pm,v 1.4 2004/02/26 13:42:10 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SQLInstall );
@@ -14,9 +14,25 @@ my %FILES = (
                'sys_security_sequence.sql' ],
    ib     => [ 'sys_security_interbase.sql',
                'sys_security_generator.sql' ],
-   security      => [ 'install_security.dat' ],
+   security => [ 'install_security.dat' ],
 );
 
+sub get_migration_information {
+    my ( $self ) = @_;
+    my %sec_info = (
+        spops_class   => 'OpenInteract2::Security',
+        transform_sub => \&_modify_class_names,
+    );
+    return [ \%sec_info ];
+}
+
+sub _modify_class_names {
+    my ( $info, $record, $sec ) = @_;
+    $sec->{class} =~ s/^\w+::/OpenInteract2::/;
+    $sec->{class} =~ s/^OpenInteract2::Handler/OpenInteract2::Action/;
+    $sec->{class} =~ s/^OpenInteract2::NewItem$/OpenInteract2::WhatsNew/;
+}
+
 sub get_structure_set {
     return 'security';
 }
