@@ -1,6 +1,6 @@
 package OpenInteract2::SQLInstall::Theme;
 
-# $Id: Theme.pm,v 1.1 2003/03/26 02:24:14 lachoy Exp $
+# $Id: Theme.pm,v 1.2 2003/10/20 03:05:54 lachoy Exp $
 
 # Do installation of SQL for this package
 
@@ -24,6 +24,13 @@ my %FILES = (
               'theme_prop_generator.sql' ],
 );
 
+sub get_migration_information {
+    my ( $self ) = @_;
+    my %theme_info = ( spops_class => 'OpenInteract2::Theme' );
+    my %prop_info  = ( spops_class => 'OpenInteract2::ThemeProp' );
+    return [ \%theme_info, \%prop_info ];
+}
+
 sub get_structure_set {
     return 'theme';
 }
