@@ -1,6 +1,6 @@
 package OpenInteract2::SQLInstall::User;
 
-# $Id: User.pm,v 1.11 2004/02/22 15:10:59 lachoy Exp $
+# $Id: User.pm,v 1.14 2004/06/13 19:42:20 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SQLInstall );
@@ -9,6 +9,9 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use SPOPS::Utility;
 
+my @FIELDS = qw( is_ldap );
+__PACKAGE__->mk_accessors( @FIELDS );
+
 my @TABLES = ( 'sys_user.sql', 'sys_user_language.sql' );
 
 my %FILES = (
@@ -29,7 +32,16 @@ sub get_migration_information {
 }
 
 sub get_structure_set {
-    return 'user';
+    my ( $self ) = @_;
+    my $user_ds = CTX->spops_config->{user}{datasource};
+    my $ds_info = CTX->lookup_datasource_config( $user_ds );
+    if ( $ds_info->{type} eq 'DBI' ) {
+        return 'user';
+    }
+    else {
+        $self->is_ldap( 'yes' );
+        return 'system';
+    }
 }
 
 sub get_structure_file {
@@ -63,6 +75,12 @@ sub install_data {
     my ( $self ) = @_;
     $log ||= get_logger( LOG_INIT );
 
+    # No user data if LDAP (language data ok)
+
+    if ( $self->is_ldap ) {
+        return $self->SUPER::install_data();
+    }
+
     my $action_name = 'create administrator';
 
     my $mail_config = CTX->lookup_mail_config;
@@ -142,6 +160,11 @@ Note that you can disable changing the superuser password from
 C<oi2_manage> by settting the
 'login.disable_superuser_password_change' to a true value.
 
+=head2 LDAP Notes
+
+If you are using LDAP for your user objects this does not create any
+new user objects.
+
 =head1 COPYRIGHT
 
 Copyright (c) 2001-2004 Chris Winters. All rights reserved.
