@@ -1,6 +1,6 @@
 package OpenInteract2::SQLInstall::WhatsNew;
 
-# $Id: WhatsNew.pm,v 1.2 2004/02/25 16:05:47 lachoy Exp $
+# $Id: WhatsNew.pm,v 1.3 2004/06/07 03:56:31 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SQLInstall );
@@ -15,12 +15,23 @@ my %FILES = (
 sub get_migration_information {
     my ( $self ) = @_;
     my %new_info = (
-        spops_class => 'OpenInteract2::WhatsNew',
-        table       => 'new_listing',
+        spops_class   => 'OpenInteract2::WhatsNew',
+        table         => 'new_listing',
+        transform_sub => [ \&_munge_show_url, \&_munge_object_class ],
     );
     return [ \%new_info ];
 }
 
+sub _munge_show_url {
+    my ( $info, $old_row, $summary ) = @_;
+    $summary->{url} =~ s|/show/|/display/|g;
+}
+
+sub _munge_object_class {
+    my ( $info, $old_row, $summary ) = @_;
+    $summary->{class} =~ s|^([^:]+)|OpenInteract2|;
+}
+
 sub get_structure_set {
     return 'whats_new';
 }
