@@ -1,6 +1,6 @@
 package OpenInteract2::SiteTemplate;
 
-# $Id: SiteTemplate.pm,v 1.11 2004/02/18 05:23:09 lachoy Exp $
+# $Id: SiteTemplate.pm,v 1.12 2004/11/27 19:00:28 lachoy Exp $
 
 use strict;
 use base qw( Exporter Class::Accessor::Fast );
@@ -12,7 +12,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SiteTemplate::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -336,8 +336,15 @@ sub _lookup_site_template_dir {
 sub _lookup_package_template_dir {
     my ( $class, $package_name ) = @_;
     return undef unless ( $package_name );
+    $log ||= get_logger( LOG_TEMPLATE );
     my $package = CTX->repository
                      ->fetch_package( $package_name );
+    unless ( $package ) {
+        $log->warn( "Trying to lookup package template directory for ",
+                    "'$package_name' but the repository didn't return ",
+                    "a package for that name" );
+        return undef;
+    }
     return File::Spec->catfile( $package->directory, 'template' );
 }
 
