@@ -1,13 +1,16 @@
 package OpenInteract2::Theme;
 
-# $Id: Theme.pm,v 1.4 2003/06/25 14:10:50 lachoy Exp $
+# $Id: Theme.pm,v 1.7 2004/02/18 05:23:08 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Theme::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+@OpenInteract2::Theme::ISA     = qw( OpenInteract2::ThemePersist );
+$OpenInteract2::Theme::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+
+my ( $log );
 
 
 # Find the properties for this theme and its parent, which
@@ -18,7 +21,7 @@ $OpenInteract2::Theme::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\
 sub discover_properties {
     my ( $self ) = @_;
     return $self->{tmp_properties}  if ( ref $self->{tmp_properties} );
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     my $theme      = $self;
     my @theme_list = ( $theme );
@@ -70,7 +73,7 @@ sub all_values {
 
 sub property_value {
     my ( $self, $prop_name ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     $prop_name = lc $prop_name;
     $log->is_debug &&
@@ -145,11 +148,11 @@ None known.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2003 Chris Winters. All rights reserved.
+Copyright (c) 2001-2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
