@@ -1,10 +1,12 @@
 package OpenInteract2::User::AuthSmb;
 
-# $Id: AuthSmb.pm,v 1.3 2003/06/25 14:10:50 lachoy Exp $
+# $Id: AuthSmb.pm,v 1.7 2004/02/18 05:25:24 lachoy Exp $
 
 # Note: You MUST specify OpenInteract2::User in your object's 'isa'
 
 use strict;
+use base qw( OpenInteract2::User );
+
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
@@ -17,11 +19,13 @@ use constant SMB_SERVER_ERROR   => 1;
 use constant SMB_PROTOCOL_ERROR => 2;
 use constant SMB_LOGON_ERROR    => 3;
 
-$OpenInteract2::User::AuthSmb::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::User::AuthSmb::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+
+my ( $log );
 
 sub check_password {
     my ( $self, $check_pw ) = @_;
-    my $log = get_logger( LOG_APP );
+    $log ||= get_logger( LOG_APP );
 
     return undef unless ( $check_pw );
     require Authen::Smb;
@@ -176,7 +180,7 @@ scheme...
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2003 Chris Winters. All rights reserved.
+Copyright (c) 2001-2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
@@ -187,4 +191,3 @@ Chris Winters E<lt>chris@cwinters.comE<gt>
 
 Thanks to Optiron, Inc. (http://www.optiron.com/) for donating the
 time necessary to create and test this module.
-
