@@ -1,6 +1,6 @@
 package Apache::OpenInteract2;
 
-# $Id: OpenInteract2.pm,v 1.14 2004/03/19 05:51:02 lachoy Exp $
+# $Id: OpenInteract2.pm,v 1.16 2004/11/09 13:28:08 sjn Exp $
 
 use strict;
 use Apache::Constants        qw( OK );
@@ -19,8 +19,9 @@ sub handler($$) {
 
     $log->is_info &&
         $log->info( scalar( localtime ), ": request from ",
-                    "[", $r->connection->remote_ip, "] for URL ",
-                    "[", $r->uri, '?', scalar( $r->args ), "]" );
+                    "'", $r->connection->remote_ip, "' for URL ",
+                    "'", $r->uri, ( defined scalar( $r->args ) && "?" . scalar( $r->args ) ),
+                    "'" );
 
     my $response = OpenInteract2::Response->new({ apache => $r });
     my $request  = OpenInteract2::Request->new({ apache => $r });
