@@ -1,4 +1,4 @@
-# $Id: OpenInteract2.pm,v 1.10 2004/05/22 15:58:43 lachoy Exp $
+# $Id: OpenInteract2.pm,v 1.11 2004/06/13 02:05:31 lachoy Exp $
 
 # This is just the daemon with a product token...
 
@@ -30,7 +30,7 @@ use HTTP::Status;
 use IO::File;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Auth;
-use OpenInteract2::Config::Ini;
+use OpenInteract2::Config::IniFile;
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Controller;
@@ -156,7 +156,7 @@ sub _init_oi2_base {
     my ( $self ) = @_;
     OpenInteract2::Log->init_from_website( $self->website_dir );
     my $ctx = OpenInteract2::Context->create(
-                                   { website_dir => $self->website_dir });
+        { website_dir => $self->website_dir });
     $ctx->assign_request_type( 'lwp' );
     $ctx->assign_response_type( 'lwp' );
     $self->deploy_url( $ctx->DEPLOY_URL );
@@ -177,8 +177,8 @@ sub _init_read_daemon_options {
                 'log', "Using daemon configuration from website directory" );
         $self->daemon_config_file( $daemon_config_file );
     }
-    $config =
-        OpenInteract2::Config::Ini->new({ filename => $self->daemon_config_file });
+    $config = OpenInteract2::Config::IniFile->read_config({
+        filename => $self->daemon_config_file });
     unless ( ref $config->{socket} eq 'HASH' ) {
         die "No options specified under 'socket' section of ",
             "configuration file '", $self->daemon_conf_file, "'\n";
