@@ -1,6 +1,6 @@
 package OpenInteract2::Action::Common;
 
-# $Id: Common.pm,v 1.15 2004/02/18 05:25:26 lachoy Exp $
+# $Id: Common.pm,v 1.20 2004/12/05 08:52:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error oi_security_error );
 
-$OpenInteract2::Action::Common::VERSION   = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::Common::VERSION   = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 $OpenInteract2::Action::Common::AUTOLOAD  = '';
@@ -76,12 +76,12 @@ sub _common_set_defaults {
     while ( my ( $key, $value ) = each %{ $defaults } ) {
         if ( $self->param( $key ) ) {
             $log->is_debug &&
-                $log->debug( "NOT settting default for [$tag]: [$key], value ",
-                             "already exists [", $self->param( $key ), "]" );
+                $log->debug( "NOT settting default for '$tag' = '$key', value ",
+                             "already exists '", $self->param( $key ), "'" );
         }
         else {
             $log->is_debug &&
-                $log->debug( "Setting default for [$tag]: [$key] [$value]" );
+                $log->debug( "Setting default for '$tag' = '$key' '$value'" );
             $self->param( $key, $value );
         }
     }
@@ -97,20 +97,13 @@ sub _common_check_object_class {
     $log ||= get_logger( LOG_ACTION );
     unless ( $object_type ) {
         $log->warn( "No object type specified" );
-        my $msg = join( '', "Object type is undefined. How can we know ",
-                            "what to search or return? Please set it in ",
-                            "your action configuration using the key ",
-                            "c_object_type." );
-        $self->param_add( error_msg => $msg );
+        $self->add_error_key( 'action.error.no_object_type' );
         return 1;
     }
     my $object_class = eval { CTX->lookup_object( $object_type ) };
     if ( $@ or ! $object_class ) {
-        $log->warn( "No object class for [$object_type]" );
-        my $msg = join( '', "Class for given object type '$object_type' ",
-                            "is undefined. Maybe a typo in your action ",
-                            "configuration using the key c_object_type." );
-        $self->param_add( error_msg => $msg );
+        $log->warn( "No object class for '$object_type'" );
+        $self->add_error_key( 'action.error.no_class_for_type', $object_type );
         return 1;
     }
     $self->param( c_object_class => $object_class );
@@ -124,12 +117,8 @@ sub _common_check_id_field {
     my $object_class = $self->param( 'c_object_class' );
     my $id_field = eval { $object_class->id_field };
     if ( ! $id_field or $@ ) {
-        $log->warn( "No ID field for [$object_class]" );
-        my $msg = join( '', "Object ID field is undefined. We cannot know ",
-                            "how to fetch an existing object without it. ",
-                            "Please define the key 'id_field' in your ",
-                            "object configuration." );
-        $self->param_add( error_msg => $msg );
+        $log->warn( "No ID field for '$object_class'" );
+        $self->add_error_key( 'action.error.no_id_field' );
         return 1;
     }
     $self->param( c_id_field => $id_field );
@@ -154,20 +143,41 @@ sub _common_check_id {
         return 0;
     }
 
+    my $request = CTX->request;
     my $id_field = $self->param( 'c_id_field' );
+    my ( $alt_id_field );
     if ( ! defined $id and $id_field ) {
         $id = $self->param( $id_field )
-              || CTX->request->param( $id_field )
-              || CTX->request->param( 'id' );
+              || $request->param( $id_field )
+              || $request->param( 'id' );
     }
+
+    # If it's not found using that ID field, see if we've got another
+    # field mapped to the given ID field in the SPOPS object
+
+    unless ( defined $id ) {
+        my $object_class = $self->param( 'c_object_class' );
+        my $field_map = eval { $object_class->CONFIG->{field_map} } || {};
+        my %reverse_map = map { $field_map->{ $_ } => $_ } keys %{ $field_map };
+        $alt_id_field = $reverse_map{ $id_field } || $field_map->{ $id_field };
+        if ( $alt_id_field ) {
+            $log->is_debug &&
+                $log->debug( "Using mapped ID field '$alt_id_field'" );
+            $id = $self->param( $alt_id_field )
+                  || $request->param( $alt_id_field );
+            $self->param( c_id_field => $alt_id_field );
+        }
+    }
+
     if ( defined $id ) {
         $self->param( c_id => $id );
     }
     else {
-        $log->warn( "No ID found in action/request '$id_field'" );
-        my $msg = join( '', "No value found in action parameters or ",
-                            "request for ID field '$id_field'." );
-        $self->param_add( error_msg => $msg );
+        $log->warn( "No ID found in '$id_field' or '$alt_id_field'" );
+        $self->add_error_key( 'action.error.no_id_value', $id_field );
+        if ( $alt_id_field ) {
+            $self->add_error_key( 'action.error.no_alt_id_value', $alt_id_field );
+        }
         return 1;
     }
     return 0;
@@ -181,11 +191,8 @@ sub _common_check_template_specified {
     for ( @template_params ) {
         next unless ( $_ );
         unless ( $self->param( $_ ) ) {
-            $log->warn( "No value in template parameter [$_]" );
-            my $msg = join( '', "No template found in '$_' key. This " .
-                                "template is mandatory for the task to ",
-                                "function." );
-            $self->param_add( error_msg => $msg );
+            $log->warn( "No value in template parameter '$_'" );
+            $self->add_error_key( 'action.error.no_template', $_ );
             $num_errors++;
         }
     }
@@ -199,10 +206,8 @@ sub _common_check_param {
     my $num_errors = 0;
     for ( @params ) {
         unless ( $self->param( $_ ) ) {
-            $log->warn( "No value in parameter [$_]" );
-            my $msg = join( '', "Action parameter '$_' is undefined but ",
-                                "required for the task to function." );
-            $self->param_add( error_msg => $msg );
+            $log->warn( "No value in parameter '$_'" );
+            $self->add_error_key( 'action.error.param_required', $_ );
             $num_errors++;
         }
     }
@@ -222,10 +227,10 @@ sub _common_assign_properties {
     foreach my $field ( @standard ) {
         next unless ( $field );
         $log->is_debug &&
-            $log->debug( "Setting standard [$field] in object from request" );
+            $log->debug( "Setting standard '$field' in object from request" );
         eval { $object->{ $field } = $request->param( $field ) };
         if ( $@ ) {
-            $log->warn( "Failed to set object value for [$field]: $@" );
+            $log->warn( "Failed to set object value for '$field': $@" );
         }
     }
 
@@ -234,10 +239,10 @@ sub _common_assign_properties {
     foreach my $field ( @toggled ) {
         next unless ( $field );
         $log->is_debug &&
-            $log->debug( "Setting toggled [$field] in object from request" );
+            $log->debug( "Setting toggled '$field' in object from request" );
         eval { $object->{ $field } = $request->param_toggled( $field ) };
         if ( $@ ) {
-            $log->warn( "Failed to set object toggle for [$field]: $@" );
+            $log->warn( "Failed to set object toggle for '$field': $@" );
         }
     }
 
@@ -246,13 +251,13 @@ sub _common_assign_properties {
     foreach my $field ( @date ) {
         next unless ( $field );
         $log->is_debug &&
-            $log->debug( "Setting date [$field] in object from request" );
+            $log->debug( "Setting date '$field' in object from request" );
         eval {
             $object->{ $field }= $request->param_date(
                                        $field, $fields->{date_format} )
         };
         if ( $@ ) {
-            $log->warn( "Failed to set object date for [$field]: $@" );
+            $log->warn( "Failed to set object date for '$field': $@" );
         }
     }
 
@@ -261,13 +266,13 @@ sub _common_assign_properties {
     foreach my $field ( @datetime ) {
         next unless ( $field );
         $log->is_debug &&
-            $log->debug( "Setting datetime [$field] in object from request" );
+            $log->debug( "Setting datetime '$field' in object from request" );
         eval {
             $object->{ $field } = $request->param_datetime(
                                        $field, $fields->{datetime_format} )
         };
         if ( $@ ) {
-            $log->warn( "Failed to set object datetime for [$field]: $@" );
+            $log->warn( "Failed to set object datetime for '$field': $@" );
         }
     }
     return $object;
@@ -289,22 +294,20 @@ sub _common_fetch_object {
         return $object_class->new;
     }
     $log->is_debug &&
-        $log->debug( "Trying to fetch [$object_class: $id]" );
+        $log->debug( "Trying to fetch '$object_class': '$id'" );
     my $object = eval { $object_class->fetch( $id ) };
     if ( $@ ) {
         my $error = $@;
-        $log->error( "Caught exception fetching object: $@" );
+        $log->error( "Caught exception fetching object: $error" );
         if ( $error->isa( 'SPOPS::Exception::Security' ) ) {
-            my $msg = "Security violation: you do not have rights to " .
-                      "retrieve the requested object.";
-            $self->param_add( error_msg => $msg );
-            oi_error $@;
+            $self->add_error_key( 'action.error.security' );
         }
         else {
-            $self->param_add( error_msg => "Cannot retrieve object: $@" );
-            oi_error $error;
+            $self->add_error_key( 'action.error.fetch', $error );
         }
+        oi_error $error;
     }
+    $self->param( c_id => $id );
     return $object || $object_class->new;
 }
 
@@ -349,10 +352,10 @@ and in my search results template I had:
  [% END %]
  </ul>
 
-Since I haven't inherited a 'display' task or defined one myself, when
-I click on the created link I can expect an ugly error message from
-the dispatcher telling me that the task does not exist. Instead, I'll
-get something like:
+Since I have not inherited a 'display' task or defined one myself,
+when I click on the created link I can expect an ugly error message
+from the dispatcher telling me that the task does not exist. Instead,
+I will get something like:
 
  Display capability is not built into action 'foo'.
 
@@ -387,8 +390,8 @@ B<_common_assign_properties( $object, \%field_info )>
 
 Assign values from HTTP request into C<$object> as declared by
 C<\%field_info>. The data in C<\%field_info> tells us the names and
-types of data we'll be setting in the object. You can learn more about
-the different types of parameters we're reading in the various
+types of data we will be setting in the object. You can learn more
+about the different types of parameters we are reading in the various
 C<param_*> methods in
 L<OpenInteract2::Request|OpenInteract2::Request>.
 
@@ -471,7 +474,7 @@ If nothing is returned or the C<lookup_object()> method throws an
 exception the condition fails.
 
 If both conditions are true we set the parameter C<c_object_class> so
-you don't need to do the lookup yourself.
+you do not need to do the lookup yourself.
 
 B<_common_check_id_field()>
 
@@ -487,7 +490,7 @@ If no ID field is returned or the method throws an exception the
 condition fails.
 
 If the condition succeeds we set the parameter C<c_id_field> so you
-don't need to do the lookup yourself.
+do not need to do the lookup yourself.
 
 B<_common_check_id()>
 
@@ -495,31 +498,33 @@ Tries to find the ID for an object using a number of methods. We
 depend on the C<c_id_field> parameter being set, so you should run
 C<_common_check_id_field> before this check.
 
-Here's how we find the ID, in order.
+Here is how we find the ID, in order.
 
 =over 4
 
-=item *
+=item 1.
 
 Is there an action parameter with the name C<c_id>?
 
-=item *
+=item 2.
 
 Is there an action parameter with the same name as the ID field?
 
-=item *
+=item 3.
 
 Is there a request parameter with the same name as the ID field?
 
-=item *
+=item 4.
 
 Is there a request parameter with the name 'id'?
 
 =back
 
-The first check that finds an ID is used. If no ID is found the check
-fails. If an ID is found it's set in the action parameter C<c_id> so
-you don't need to do the lookup.
+The first check that finds an ID is used. If no ID is found and there
+is a corresponding entry in an SPOPS object 'field_map' configuration
+we rerun checks 2 and 3 above with the new ID field. If no ID value is
+still found the check fails. If an ID is found its value is set in the
+action parameter C<c_id> so you do not need to do the lookup.
 
 B<_common_check_template_specified( @template_parameters )>
 
@@ -593,4 +598,4 @@ Copyright (c) 2003-2004 Chris Winters. All rights reserved.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
