@@ -1,6 +1,6 @@
 package OpenInteract2::Action::CommonAdd;
 
-# $Id: CommonAdd.pm,v 1.16 2004/02/18 05:25:26 lachoy Exp $
+# $Id: CommonAdd.pm,v 1.21 2004/12/05 08:52:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::Common );
@@ -13,6 +13,7 @@ my ( $log );
 
 sub display_add {
     my ( $self ) = @_;
+    $self->param( c_task => 'display_add' );
     $self->_add_init_param;
     my $object_class = $self->param( 'c_object_class' );
 
@@ -35,6 +36,7 @@ sub display_add {
 
 sub add {
     my ( $self ) = @_;
+    $self->param( c_task => 'add' );
     $self->_add_init_param;
     CTX->response->return_url( $self->param( 'c_add_return_url' ) );
 
@@ -66,17 +68,21 @@ sub add {
     my %save_options = ();
     $self->_add_customize( $object, \%save_options );
 
+    $self->notify_observers( 'pre add', $object, \%save_options );
     eval { $object->save( \%save_options ) };
     if ( $@ ) {
         $log->error( "Failed to create object: $@" );
-        $self->param_add( error_msg => "Object creation failed: $@" );
+        $self->add_error_key( 'action.error.create', $@ );
         my $fail_task = $self->param( 'c_add_fail_task' );
         return $self->execute({ task => $fail_task });
     }
     $self->param( c_object => $object );
     $self->param( c_id => scalar $object->id );
-    $self->param( status_msg => 'Object created properly' );
+    my $title = "'" . $object->object_description->{title} . "'" || 'Object';
+    $self->add_status_key( 'action.status.create', $title );
     $self->_add_post_action;
+    $self->notify_observers( 'post add', $object );
+
     my $success_task = $self->param( 'c_add_task' );
     return $self->execute({ task => $success_task });
 }
@@ -124,7 +130,7 @@ OpenInteract2::Action::CommonAdd - Tasks to display empty form and create an obj
  
  use base qw( OpenInteract2::Action::CommonAdd );
  
- # Relevant configuration entries in your action.ini
+ # Relevant configuration entries in your conf/action.ini
  
  [myaction]
  ...
@@ -154,7 +160,8 @@ B<add> - Add the new object.
 
 Displays a possibly empty form to create a new object. The 'possibly'
 derives from your ability to pre-populate the object with default data
-so the user can do less typing. Because it's all about the users...
+so the user can do less typing. Because your job is all about the
+users...
 
 =head1 TEMPLATES USED FOR 'display_add'
 
@@ -179,9 +186,13 @@ These are in addition to the template parameters defined above.
 
 B<c_object_type> ($) (REQUIRED)
 
-SPOPS key for object you'll be displaying.
+SPOPS key for object you will be displaying.
 
-=head2 System-created
+=head2 System-created parameters
+
+B<c_task>
+
+Name of the task originally invoked: 'display_add'.
 
 B<c_object> ($)
 
@@ -206,7 +217,9 @@ None
 B<_add_customize( $object, \%save_options )>
 
 Called just before the C<save()> operation which creates the object in
-your datastore. You have three opportunities to affect the operation:
+your datastore. (Note that it is also before the 'pre add' observation
+is posted, see below.) You have three opportunities to affect the
+operation:
 
 =over 4
 
@@ -228,24 +241,24 @@ validation, quota ceiling inspections, time of day checking, etc.
 
 =back
 
-Here's an example of a validation check:
+Here is an example of a validation check:
 
  sub _add_customize {
      my ( $self, $object, $save_options ) = @_;
      if ( $self->widget_type eq 'Frobozz' and $self->size ne 'Large' ) {
-
-         # First set an error message to tell the user what's wrong...
-
+ 
+         # First set an error message to tell the user what is wrong...
+ 
          $self->add_view_message(
-             size => "Only large widgets of type Frobozz are allowed' );
-
+             size => "Only large widgets of type Frobozz are allowed" );
+ 
          # Next, provide the object with its values to the form so we
          # can prepopulate it...
-
+ 
          $self->param( c_object => $object );
-
+ 
          # ...and display the editing form again
-
+ 
          die $self->execute({ task => 'display_add' });
      }
  }
@@ -253,12 +266,47 @@ Here's an example of a validation check:
 B<_add_post_action>
 
 This method is called after the object has been successfully created
--- you'll find the object in the C<c_object> action parameter. You can
-perform any action you like in this method. Similar to
+-- you will find the object in the C<c_object> action parameter. You
+can perform any action you like in this method. Similar to
 C<_add_customize()>, if you throw a C<die> with content it will be
 displayed to the user rather than moving to the configured
 C<c_add_task>.
 
+=head1 OBSERVATIONS FIRED
+
+The C<add()> method fires two observations:
+
+B<pre add> C<( $action, 'pre add', $object, \%save_options )>
+
+This is fired just before the object is added, which means that the
+C<_add_customize()> method described above has already run.
+
+This gets passed the object to be saved and the options being sent to
+the C<save()> method:
+
+ package My::Observer;
+ 
+ sub update {
+     my ( $class, $action, $type, $object, $save_opts ) = @_
+     return unless ( $type eq 'pre add' );
+     ...
+ }
+
+B<post add> C<( $action, 'post add', $object )>
+
+This is fired after the object is added as well as after the
+C<_add_post_action()> described above.
+
+This gets passed the object to be saved:
+
+ package My::Observer;
+ 
+ sub update {
+     my ( $class, $action, $type, $object ) = @_;
+     return unless ( $type eq 'post add' );
+     ...
+ }
+
 =head1 CONFIGURATION FOR 'add'
 
 =head2 Basic
@@ -332,6 +380,10 @@ L<DateTime::Format::Strptime|DateTime::Format::Strptime>.
 
 =head2 System-created parameters
 
+B<c_task>
+
+Name of the task originally invoked: 'add'.
+
 B<c_object> ($)
 
 If the add is successful this will be set to the newly-created object.
@@ -347,4 +399,4 @@ Copyright (c) 2002-2004 Chris Winters. All rights reserved.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
