@@ -1,6 +1,6 @@
 package OpenInteract2::Action::CommonDisplay;
 
-# $Id: CommonDisplay.pm,v 1.11 2004/02/18 05:25:27 lachoy Exp $
+# $Id: CommonDisplay.pm,v 1.15 2004/12/05 08:52:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::Common );
@@ -12,6 +12,7 @@ my ( $log );
 
 sub display {
     my ( $self ) = @_;
+    $self->param( c_task => 'display' );
     $self->_display_init_param;
 
     $log ||= get_logger( LOG_ACTION );
@@ -23,7 +24,7 @@ sub display {
     }
     unless ( $object->is_saved ) {
         my $id = $self->param( 'c_id' );
-        $self->param_add( error_msg => "Object with ID $id not found" );
+        $self->add_error_key( 'action.error.not_found', $id );
         return $self->execute({ task => $fail_task });
     }
 
@@ -37,12 +38,10 @@ sub display {
             $log->is_info &&
                 $log->info( "Object [$object_class] [$id] failed ",
                             "'active' check [Status: $status]" );
-            $self->param_add( error_msg => "This object is currently " .
-                                           "inactive. Please check later." );
+            $self->add_error_key( 'action.error.inactive' );
             return $self->execute({ task => $fail_task });
         }
-        $log->is_debug &&
-            $log->debug( "Object passed 'active' check" );
+        $log->is_debug && $log->debug( "Object passed 'active' check" );
     }
 
     # Set both 'object' and the object type equal to the object so the
@@ -73,7 +72,7 @@ sub _display_init_param {
     $has_error +=
         $self->_common_check_template_specified( 'c_display_template' );
     if ( $has_error ) {
-        die $self->execute({ task => 'common_error' });
+        die $self->execute({ task => 'common_error' }), "\n";
     }
 }
 
@@ -117,14 +116,14 @@ B<display> - Display a non-editable object.
 
 The 'display' task simply retrieves a specified object and sends it to
 a template. If the object checks its active status we first do that,
-but we don't really do too much.
+but we do not really do too much.
 
 =head1 TEMPLATES USED FOR 'display'
 
 B<c_display_template> (no default)
 
 This it the template we send the object to. The same object can be
-found in two keys: 'object' and whatever you've set C<c_object_type>
+found in two keys: 'object' and whatever you have set C<c_object_type>
 to. So a handler manipulating 'doodad' objects will find the specified
 doodad in 'object' and 'doodad'.
 
@@ -143,7 +142,7 @@ These are in addition to the template parameters defined above.
 
 B<c_object_type> ($) (REQUIRED)
 
-SPOPS key for object you'll be displaying.
+SPOPS key for object you will be displaying.
 
 B<c_display_fail_task> ($)
 
@@ -160,6 +159,10 @@ C<c_display_fail_task>.
 
 =head2 System-created parameters
 
+B<c_task>
+
+Name of the task originally invoked: 'display'.
+
 B<c_object_class> ($)
 
 SPOPS object class derived from C<c_object_type>.
@@ -178,4 +181,4 @@ Copyright (c) 2002-2004 Chris Winters. All rights reserved.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
