@@ -1,6 +1,6 @@
 package OpenInteract2::Action::CommonRemove;
 
-# $Id: CommonRemove.pm,v 1.13 2004/02/18 05:25:27 lachoy Exp $
+# $Id: CommonRemove.pm,v 1.18 2004/12/05 08:52:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::Common );
@@ -13,17 +13,23 @@ my ( $log );
 
 sub remove {
     my ( $self ) = @_;
+    $self->param( c_task => 'remove' );
     $self->_remove_init_param;
     $log ||= get_logger( LOG_ACTION );
 
     my $fail_task = $self->param( 'c_remove_fail_task' );
     my $object = eval { $self->_common_fetch_object };
     if ( $@ ) {
+        $self->add_eror_key( 'action.error.fetch_for_remove', $@ );
         return $self->execute({ task => $fail_task });
     }
-    unless ( $object and $object->is_saved ) {
-        $self->param_add( error_msg => 'Cannot fetch object for removal. ' .
-                                       'No modifications made.' );
+    unless ( $object ) {
+        $self->add_eror_key( 'action.error.not_found',
+                             $self->param( 'c_id' ) );
+        return $self->execute({ task => $fail_task });
+    }
+    unless ( $object->is_saved ) {
+        $self->add_eror_key( 'action.error.remove_not_saved' );
         return $self->execute({ task => $fail_task });
     }
 
@@ -34,23 +40,25 @@ sub remove {
     if ( $object->{tmp_security_level} < SEC_LEVEL_WRITE ) {
         my $sec_fail_task = $self->param( 'c_remove_security_fail_task' )
                             || $fail_task;
-        $self->param_add(
-            error_msg => 'Insufficient access rights to remove this ' .
-                         'object. No modifications made.' );
+        $self->add_error_key( 'action.error.remove_security' );
         return $self->execute({ task => $sec_fail_task });
     }
 
     $self->_remove_customize;
+    $self->notify_observers( 'pre remove', $object );
 
     eval { $object->remove };
     if ( $@ ) {
-        $self->param_add( error_msg => "Object removal failed: $@" );
+        $self->add_error_key( 'action.error.remove', $@ );
         $log->error( "Failed to remove ", $self->param( 'c_object_class' ),
                      "with ID" , $object->id, ": $@" );
         return $self->execute({ task => $fail_task });
     }
 
-    $self->param_add( status_msg => 'Object successfully removed.' );
+    $self->notify_observers( 'post remove', $object );
+
+    my $title = "'" . $object->object_description->{title} . "'" || 'Object';
+    $self->add_status_key( 'action.status.remove', $title );
     my $success_task = $self->param( 'c_remove_task' );
     return $self->execute({ task => $success_task });
 }
@@ -137,6 +145,39 @@ from the method. This content will be sent on to the user. This gives
 you an opportunity to do any necessary validation, quota ceiling
 inspections, time of day checking, etc.
 
+=head1 OBSERVATIONS FIRED
+
+The C<remove()> method fires two observations:
+
+B<pre remove> C<( $action, 'pre remove', $object )>
+
+This is fired just before the object is removed, which means that the
+C<_remove_customize()> method described above has already run.
+
+This gets passed the object to be removed:
+
+ package My::Observer;
+ 
+ sub update {
+     my ( $class, $action, $type, $object ) = @_
+     return unless ( $type eq 'pre remove' );
+     ...
+ }
+
+B<post remove> C<( $action, 'post remove', $object )>
+
+This is fired after the object is removed. This gets passed the object
+that was removed -- if you try to call C<save()> on this object you
+will get an exception.
+
+ package My::Observer;
+ 
+ sub update {
+     my ( $class, $action, $type, $object ) = @_;
+     return unless ( $type eq 'post remove' );
+     ...
+ }
+
 =head1 CONFIGURATION FOR 'remove'
 
 =head2 Basic
@@ -167,6 +208,10 @@ available in the C<c_object> action parameter.
 
 =head2 System-created parameters
 
+B<c_task>
+
+Name of the task originally invoked: 'remove'.
+
 B<c_object_class>
 
 See L<OpenInteract2::Common|OpenInteract2::Common>
@@ -177,7 +222,7 @@ See L<OpenInteract2::Common|OpenInteract2::Common>
 
 B<c_id>
 
-The ID of the object we're trying to remove.
+The ID of the object we are trying to remove.
 
 B<c_object>
 
@@ -190,4 +235,4 @@ Copyright (c) 2002-2004 Chris Winters. All rights reserved.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
