@@ -1,6 +1,6 @@
 package OpenInteract2::Action::CommonSearch;
 
-# $Id: CommonSearch.pm,v 1.13 2004/02/18 05:25:27 lachoy Exp $
+# $Id: CommonSearch.pm,v 1.17 2004/12/05 08:52:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::Common );
@@ -10,7 +10,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::ResultsManage;
 
-$OpenInteract2::Action::CommonSearch::VERSION   = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Action::CommonSearch::VERSION   = sprintf("%d.%02d", q$Revision: 1.17 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -19,6 +19,7 @@ my ( $log );
 
 sub search_form {
     my ( $self ) = @_;
+    $self->param( c_task => 'search_form' );
     $self->_search_form_init_param;
     my %tmpl_params = ();
     $self->_search_form_customize( \%tmpl_params );
@@ -30,11 +31,8 @@ sub search_form {
 sub _search_form_init_param {
     my ( $self ) = @_;
     unless ( $self->param( 'c_search_form_template' ) ) {
-        my $msg = join( '', "Template for search form is undefined. Please ",
-                            "set it in your action configuration using the ",
-                            "key 'c_search_form_template'." );
-        $self->param_add( error_msg => $msg );
-        die $self->execute({ task => 'common_error' });
+        $self->add_error_key( 'action.error.no_template', 'c_search_form_template' );
+        die $self->execute({ task => 'common_error' }), "\n";
     }
     return undef;
 }
@@ -45,68 +43,23 @@ sub _search_form_init_param {
 
 sub search {
     my ( $self ) = @_;
+    $self->param( c_task => 'search' );
     $self->_search_init_param;
     $log ||= get_logger( LOG_ACTION );
 
     my %tmpl_params = ();
 
-    my $req = CTX->request;
     my $is_paged = $self->param( 'c_search_results_paged' );
     if ( $is_paged eq 'yes' ) {
-        my $search_id = $req->param( 'search_id' );
-        my $results = OpenInteract2::ResultsManage->new();
-
-        # If the search has been run before, just set the ID
-
-        if ( $search_id ) {
-            $log->is_debug &&
-                $log->debug( "Retrieving search for ID [$search_id]" );
-            $results->{search_id} = $search_id;
-        }
-
-        # Otherwise, run the search and get an iterator back, then
-        # pass the iterator to ResultsManage so we can reuse the
-        # results
-
-        else {
-            $log->is_debug &&
-                $log->debug( "Running search for the first time" );
-            my $iterator = eval {
-                $self->_search_build_and_run({ is_paged => 'yes' })
-            };
-            $self->_search_catch_errors( "$@" );
-            $results->save( $iterator );
-            $log->is_debug &&
-                $log->debug( "Search ID [$results->{search_id}]" );
-        }
-
-        if ( $results->{search_id} ) {
-            my $this_page  = $req->param( 'page_num' ) || 1;
-            my $hits_per_page = $self->param( 'c_search_results_page_size' );
-            my ( $min, $max ) =
-                $results->find_page_boundaries( $this_page, $hits_per_page );
-            $tmpl_params{iterator}    = $results->retrieve(
-                                             { min    => $min,
-                                               max    => $max,
-                                               return => 'iterator' });
-            $tmpl_params{page_num}    = $this_page;
-            $tmpl_params{total_pages} = $results->find_total_page_count( $hits_per_page );
-            $tmpl_params{total_hits}  = $results->{num_records};
-            $tmpl_params{search_id}   = $results->{search_id};
-            $log->is_debug &&
-                $log->debug( "Search info: min: ($min); max: ($max)",
-                             "records ($results->{num_records})" );
-        }
-        else {
-            $log->warn( "No search ID from results, creating empty iterator" );
-            $tmpl_params{iterator} = SPOPS::Iterator->from_list( [] );
-        }
+        %tmpl_params = $self->_search_retrieve_paged_results;
     }
 
     # If we're not using paged results, then just run the normal
     # search and get back an iterator
 
     else {
+        $log->is_debug &&
+            $log->debug( "Search results not paged, using basic iterator" );
         $tmpl_params{iterator} = eval {
             $self->_search_build_and_run( \%tmpl_params )
         };
@@ -120,6 +73,61 @@ sub search {
                     \%tmpl_params, { name => $results_template } );
 }
 
+sub _search_retrieve_paged_results {
+    my ( $self ) = @_;
+    $log->is_debug && $log->debug( "Search results will be paged" );
+    my %display = ();
+
+    my $req = CTX->request;
+    my $search_id = $req->param( 'search_id' );
+    my $results = OpenInteract2::ResultsManage->new();
+
+    # If the search has been run before, just set the ID
+
+    if ( $search_id ) {
+        $log->is_debug &&
+            $log->debug( "Retrieving search for ID '$search_id'" );
+        $results->{search_id} = $search_id;
+    }
+
+    # Otherwise, run the search and get an iterator back, then pass
+    # the iterator to ResultsManage so we can reuse the results
+
+    else {
+        $log->is_debug &&
+            $log->debug( "Running search for the first time" );
+        my $iterator = eval {
+            $self->_search_build_and_run({ is_paged => 'yes' })
+        };
+        $self->_search_catch_errors( "$@" );
+        $results->save( $iterator );
+        $log->is_debug &&
+            $log->debug( "Got search ID from stored results '$results->{search_id}'" );
+    }
+
+    if ( $results->{search_id} ) {
+        my $this_page  = $req->param( 'page_num' ) || 1;
+        my $hits_per_page = $self->param( 'c_search_results_page_size' );
+        my ( $min, $max ) =
+                $results->find_page_boundaries( $this_page, $hits_per_page );
+        $display{iterator}    = $results->retrieve({
+                                     min         => $min,
+                                     max         => $max,
+                                     return_type => 'iterator' });
+        $display{page_num}    = $this_page;
+        $display{total_pages} = $results->find_total_page_count( $hits_per_page );
+        $display{total_hits}  = $results->{num_records};
+        $display{search_id}   = $results->{search_id};
+        $log->is_debug && $log->debug( "Search info: [min: $min] [max: $max] ",
+                                       "[records: $results->{num_records}]" );
+    }
+    else {
+        $log->warn( "No search ID from results, creating empty iterator" );
+        $display{iterator} = SPOPS::Iterator->from_list( [] );
+    }
+    return %display;
+}
+
 
 my %DEFAULTS = (
    c_search_results_paged         => 'yes',
@@ -156,18 +164,15 @@ sub _search_init_param {
                 # from making this arbitrarily complex (6, 8, ...)
 
                 unless ( $num_id_links == 2 || $num_id_links == 4 ) {
-                    my $msg = join( '', "Misconfigured search: there should be ",
-                                    "either two or four entries in the ",
-                                    "'c_search_table_links' section for table ",
-                                    "[$table] under action [", $self->name, "]" );
-                    $self->param_add( error_msg => $msg );
+                    $self->add_error_key( 'action.error.search_table_links',
+                                          $table, $self->name );
                     $has_error++;
                 }
             }
         }
     }
     if ( $has_error ) {
-        die $self->execute({ task => 'common_error' });
+        die $self->execute({ task => 'common_error' }), "\n";
     }
 
     # Now we're dealing with valid data...
@@ -185,16 +190,15 @@ sub _search_catch_errors {
     return unless ( $caught );
     my ( $msg, $task );
     if ( $caught =~ /^CAP: (.*)$/ ) {
-        $msg = join( '', "Your search has returned too many ",
-                         "results. ($1) Please try again." );
+        $msg = $self->_msg( 'action.error.search_too_many_results', $1 );
         $task = $self->param( 'c_search_results_cap_fail_task' );
     }
     else {
         $msg = $caught;
         $task = $self->param( 'c_search_fail_task' );
     }
-    $self->param_add( error_msg => $msg );
-    die $self->execute({ task => $task });
+    $self->add_error( $msg );
+    die $self->execute({ task => $task }), "\n";
 }
 
 # Build the search and run it, returning an iterator
@@ -208,17 +212,20 @@ sub _search_build_and_run {
 
     my $object_class = $self->param( 'c_object_class' );
 
-    # TODO: This is kind of yucky -- run the same search twice?
+    # TODO: This is kind of (!!!) yucky -- run the same search twice?
 
     my @tables = $self->param( 'c_search_query_tables' );
     my $where  = join( ' AND ', $self->param( 'c_search_query_where' ) );
     my @values = $self->param( 'c_search_query_values' );
     if ( my $num_limit_results = $self->param( 'c_search_results_cap' ) ) {
-        my $row = eval { $object_class->db_select({ select => [ 'count(*)' ],
-                                                    from   => \@tables,
-                                                    where  => $where,
-                                                    value  => \@values,
-                                                    return => 'single' }) };
+        my $row = eval {
+            $object_class->db_select({
+                select => [ 'count(*)' ],
+                from   => \@tables,
+                where  => $where,
+                value  => \@values,
+                return => 'single' })
+        };
         if ( $row->[0] > $num_limit_results ) {
             oi_error "CAP: $row->[0] > $num_limit_results";
         }
@@ -228,17 +235,21 @@ sub _search_build_and_run {
     my $limit = $self->param( 'c_search_query_limit' );
     my $order = $self->param( 'c_search_results_order' );
     my $additional_params = $self->_search_additional_params || {};
-    my $iter = eval { $object_class->fetch_iterator({
-                                         from  => \@tables,
-                                         where => $where,
-                                         value => \@values,
-                                         limit => $limit,
-                                         order => $order,
-                                         %{ $additional_params } }) };
+    my $iter = eval {
+        $object_class->fetch_iterator({
+            from  => \@tables,
+            where => $where,
+            value => \@values,
+            limit => $limit,
+            order => $order,
+            %{ $additional_params } })
+    };
     if ( $@ ) {
         $log->error( "Search failed: $@" );
         oi_error $@;
     }
+    $log->is_info &&
+        $log->info( "Got iterator from '$object_class' given query params" );
     return $iter;
 }
 
@@ -411,11 +422,11 @@ TABLE:
 
     $log->is_debug &&
         $log->debug( join( "\n",
-                           "Built: ",
-                           "  FROM: " .
+                           "Built SQL chunks: ",
+                           "   FROM: " .
                            join( ', ', $self->param( 'c_search_query_tables' ) ),
                            "  WHERE: " . join( ' AND ', $self->param( 'c_search_query_where' ) ),
-                           "  VALUES:" . join( ', ', $self->param( 'c_search_query_values' ) ),
+                           " VALUES: " . join( ', ', $self->param( 'c_search_query_values' ) ),
                          ) );
     return $self;
 }
@@ -519,7 +530,7 @@ template and display it.
 B<c_search_form_template>
 
 Fully qualified template name for your search form. If undefined
-you'll get the standard error page.
+you will get the standard error page.
 
 =head1 METHODS FOR 'search_form'
 
@@ -530,6 +541,15 @@ No additional methods are available for you to override.
 None. All you need to do is specify the template name as mentioned
 above.
 
+=head2 System-created parameters
+
+These are created by the task and available in any callbacks or from
+the view.
+
+B<c_task>
+
+Name of the task originally invoked: 'search_form'.
+
 =head1 DESCRIPTION FOR 'search'
 
 This task builds a SQL query from the given search criteria and
@@ -538,7 +558,7 @@ selected 1000 records.
 
 It also supports stepping through the search results a page at a time
 -- just set the C<c_search_results_paged> parameter to 'yes'. When
-you're generating URLs to page through searches, you should only need
+you are generating URLs to page through searches, you should only need
 to pass the following parameters after the first search:
 
 =over 4
@@ -558,7 +578,7 @@ B<page_num>: Page of the result set you'd like to view.
 B<c_search_results_template>
 
 Fully qualified template name for your search results. If undefined
-you'll get the standard error page.
+you will get the standard error page.
 
 These paramters are available to your template:
 
@@ -579,14 +599,14 @@ modify the fieldnames in C<_search_customize()>.
 
 =back
 
-And if you've set C<c_search_results_paged> (see below) to 'yes'
-you'll also get:
+And if you have set C<c_search_results_paged> (see below) to 'yes'
+you will also get:
 
 =over 4
 
 =item *
 
-B<page_num>: Page of the results we're currently on.
+B<page_num>: Page of the results we are currently on.
 
 =item *
 
@@ -602,11 +622,12 @@ B<search_id>: The ID of this search.
 
 =back
 
-If C<c_search_results_paged> is set to 'no', you'll get nothing beyond
-the default. The only difference is that 'iterator' will contain all
-of your search results. If you'd like to get all the results in a list
-so you can see how many there are, call 'get_all()' on the iterator
-and ask the returned arrayref how many members it contains.
+If C<c_search_results_paged> is set to 'no', you will get nothing
+beyond the default. The only difference is that 'iterator' will
+contain all of your search results. If you would like to get all the
+results in a list so you can see how many there are, call 'get_all()'
+on the iterator and ask the returned arrayref how many members it
+contains.
 
 =head1 METHODS FOR 'search'
 
@@ -625,9 +646,9 @@ Default: undef (no parameters)
 
 B<_search_criteria_customize()>
 
-If you'd like to modify the search criteria after it's been read in
-from the user but before it's been translated to SQL and executed,
-override this method. You have access to the parameter
+If you wouldd like to modify the search criteria after it has been
+read in from the user but before it hass been translated to SQL and
+executed, override this method. You have access to the parameter
 'c_search_critieria', a hashref of fields to values searched for. The
 value can be a scalar or an arrayref, depending on how many values the
 user submitted.
@@ -674,44 +695,44 @@ do something like this:
 
  sub _search_query_customize {
      my ( $self ) = @_;
-
+ 
      # Our query operator depends on $date_type...
-
+ 
      my $request = CTX->request;
      my $date_type = $request->param( 'date_order' );
      my $date_search = $request->param_date( 'filter_date' );
-
-     # Don't do anything unless both are defined
-
+ 
+     # Do not do anything unless both are defined
+ 
      return unless ( $date_type and $date_search );
      my $where = $self->param( 'c_search_query_where' )  || [];
      my $value = $self->param( 'c_search_query_values' ) || [];
-
+ 
      # ...now define the different operators
-
+ 
      if ( $date_type eq 'after' ) {
          push @{ $where }, 'object_time >= ?';
      }
      elsif ( $date_type eq 'before' ) {
          push @{ $where }, 'object_time <= ?';
      }
-
+ 
      # ... but the value is the same
-
+ 
      push @{ $value }, $date_search;
-
+ 
      # Now reset the parameters to the new values, just in case they
      # were previously undefined
-
+ 
      $self->param( c_search_query_where  => $where );
      $self->param( c_search_query_values => $value );
  }
 
 B<_search_customize( \%template_params )>
 
-This is called just before we generate the content. You're passed a
+This is called just before we generate the content. You are passed a
 hashref of the parameters that will be passed to the template, and you
-can modify them as needed. Typically you'll use this to pass
+can modify them as needed. Typically you will use this to pass
 additional parameters to the template.
 
 =head1 CONFIGURATION FOR 'search'
@@ -722,15 +743,17 @@ These are in addition to the template parameters defined above.
 
 B<c_object_type> ($) (REQUIRED)
 
-SPOPS key for object you'll be searching. You can build a search that
-spans tables from other objects, but you still have to return a single
-type of object. (See L<OpenInteract2::Common|OpenInteract2::Common>.)
+SPOPS key for object you will be searching. You can build a search
+that spans tables from other objects, but you still have to return a
+single type of object. (See
+L<OpenInteract2::Common|OpenInteract2::Common>.)
 
 =head2 Specifying search fields
 
-In these configuration entries you're presenting a list of fields used
-to build a search. This can include fields from other tables. Fields
-from other tables must be fully-qualified with the table name.
+In these configuration entries you are presenting a list of fields
+used to build a search. This can include fields from other
+tables. Fields from other tables must be fully-qualified with the
+table name.
 
 For instance, for a list of fields used to find users, I might list:
 
@@ -785,8 +808,8 @@ B<c_search_fields_right_exact>
 
 Zero or more fields to search using 'LIKE' and a wildcard '%' on the
 left-hand side of the search value, thus finding all objects where the
-given value matches the end of the object field. (This isn't used very
-often.)
+given value matches the end of the object field. (This is not used
+very often.)
 
 Example:
 
@@ -801,10 +824,10 @@ WHERE clause that joins the relevant tables together on the proper
 fields.
 
  NOTE: This discussion may seem confusing but it can be extremely
- useful: for instance, if you want to search by a person's city but
- the address information is in a separate table. If we stuck to the
- one-object/one-table mentality then you'd have to break normalization
- or some other hack.
+ useful: for instance, if you want to search by a city but the address
+ information is in a separate table from the 'person' objects. If we
+ stuck to the one-object/one-table mentality then you would have to
+ break normalization or some other hack.
 
 The values assigned to each table name enable us to build a join
 clause to link our table (the one with the object being searched) to
@@ -823,12 +846,12 @@ object) and an 'address' table. We want to find all people by the
  address = person.person_id
  address = address.person_id
 
-So we're saying that to link our object ('person') to another object
+So we are saying that to link our object ('person') to another object
 ('address'), we just find all the 'address' objects where the
 'person_id' field is a particular value. This is the classic
 one-to-many relational mapping.
 
-Here's what the statement might look like:
+Here is what the statement might look like:
 
  SELECT (person fields)
    FROM person, address
@@ -846,7 +869,7 @@ records for people by last name.
 This is the same as the first example but demonstrates that you can
 use non-key fields as well as key fields to specify a relationship.
 
-Here's what the statement might look like:
+Here is what the statement might look like:
 
  SELECT (phone_log fields)
    FROM phone_log, person
@@ -866,8 +889,8 @@ users in a particular group.
  group = group_user.group_id
  group = group.group_id
 
-This is fundamentally the same as the other two examples except we've
-chained two relationships together:
+This is fundamentally the same as the other two examples except we
+have chained two relationships together:
 
     FROM                 TO
  1. user.user_id         group_user.user_id
@@ -949,8 +972,12 @@ Default: 'search_form'
 
 =head2 System-created parameters
 
-These are created by the action when it's first initialized and during
-the search task.
+These are created by the action when it is first initialized and
+during the search task.
+
+B<c_task>
+
+Name of the task originally invoked: 'search'.
 
 B<c_object_class> ($)
 
@@ -995,7 +1022,7 @@ B<Modify page size on the fly>
 
 Allow the incoming URL to define page size as well as the page number.
 (Default page size still set in the action.) If a user sets this it
-should be saved in her session (or a cookie?) so it's sticky.
+should be saved in her session (or a cookie?) so it is sticky.
 
 =head1 COPYRIGHT
 
@@ -1003,4 +1030,4 @@ Copyright (c) 2003-2004 Chris Winters. All rights reserved.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
