@@ -1,6 +1,6 @@
 package OpenInteract2::Action::CommonUpdate;
 
-# $Id: CommonUpdate.pm,v 1.15 2004/02/18 05:25:27 lachoy Exp $
+# $Id: CommonUpdate.pm,v 1.20 2004/12/05 08:52:55 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Action::Common );
@@ -13,6 +13,7 @@ my ( $log );
 
 sub display_form {
     my ( $self ) = @_;
+    $self->param( c_task => 'display_form' );
     $self->_update_init_param;
     $log ||= get_logger( LOG_ACTION );
 
@@ -24,9 +25,8 @@ sub display_form {
         $object = eval { $object_class->fetch( $id ) };
         if ( $@ ) {
             $log->error( "Failed to fetch object [$object_class: $id]: $@" );
-            $self->param_add(
-                error_msg => "Cannot fetch object for update: $@" );
-            return $self->execute( task => $fail_task );
+            $self->add_error_key( 'action.error.fetch_for_update', $@ );
+            return $self->execute({ task => $fail_task });
         }
     }
 
@@ -43,6 +43,7 @@ sub display_form {
 
 sub update {
     my ( $self ) = @_;
+    $self->param( c_task => 'update' );
     $self->_update_init_param;
 
     $log ||= get_logger( LOG_ACTION );
@@ -55,9 +56,7 @@ sub update {
 
     unless ( $object and $object->is_saved ) {
         $log->error( "Object does not exist or is not saved, cannot update" );
-        my $msg = join( '', "You cannot update this object because it ",
-                            "has not yet been saved." );
-        $self->param_add( error_msg => $msg );
+        $self->add_error_key( 'action.error.update_not_saved' );
         return $self->execute({ task => $fail_task });
     }
 
@@ -66,9 +65,7 @@ sub update {
     if ( $object->{tmp_security_level} < SEC_LEVEL_WRITE ) {
         my $sec_fail_task = $self->param( 'c_update_security_fail_task' )
                             || $fail_task;
-        my $msg = join( '', 'You do not have sufficient access to ',
-                            'update this object. No modifications made.' );
-        $self->param_add( error_msg => $msg );
+        $self->add_error_key( 'action.error.update_security' );
         return $self->execute({ task => $sec_fail_task });
     }
 
@@ -92,15 +89,20 @@ sub update {
 
     my %save_options = ();
     $self->_update_customize( $object, $old_data, \%save_options );
+    $self->notify_observers( 'pre update', $object, $old_data, \%save_options );
+
     eval { $object->save( \%save_options ) };
     if ( $@ ) {
         $log->error( "Update of $object_spec failed: $@" );
-        $self->param_add( error_msg => "Object update failed: $@" );
+        $self->add_error_key( 'action.error.update', $@ );
         return $self->execute({ task => $fail_task });
     }
-    $self->param( status_msg => 'Object updated with changes' );
+    my $title = "'" . $object->object_description->{title} . "'" || 'Object';
+    $self->add_status_key( 'action.status.update', $title );
     $self->param( c_object_old_data => $old_data );
     $self->_update_post_action;
+    $self->notify_observers( 'post update', $object, $old_data );
+
     my $success_task = $self->param( 'c_update_task' );
     $log->is_debug &&
         $log->debug( "Update ok, executing task [$success_task]" );
@@ -200,7 +202,7 @@ B<c_display_form_template>
 Template used for editing the object. It will receive the object in
 the keys 'object' and '$object_type'.
 
-It's fairly common to use the same template as when creating a new
+It is fairly common to use the same template as when creating a new
 object.
 
 =head1 METHODS FOR 'display_form'
@@ -217,7 +219,7 @@ specified in C<c_display_form_template>.
 
 B<c_object_type> ($) (REQUIRED)
 
-SPOPS key for object you'll be displaying.
+SPOPS key for object you will be displaying.
 
 B<c_display_form_fail_task> ($)
 
@@ -227,6 +229,10 @@ Default: 'common_error'
 
 =head2 System-created parameters
 
+B<c_task>
+
+Name of the task originally invoked: 'display_form.
+
 B<c_object_class>
 
 See L<OpenInteract2::Common/_common_check_object_class>
@@ -258,20 +264,20 @@ None
 B<_update_customize( $object, \%old_data, \%save_options )>
 
 You can validate the data in C<$object> and ensure that invalid data
-don't get saved. You can also make any necessary customizations (such
-as setting defaults) to C<$object> before it's updated. You even have
+do not get saved. You can also make any necessary customizations (such
+as setting defaults) to C<$object> before it is updated. You even have
 access to its previous values in the C<\%old_data> mapping.
 
-If you've encountered an error condition (including invalid data),
+If you have encountered an error condition (including invalid data),
 throw a C<die> with the necessary content. The update will not happen
-and the user will see whatever you've generated.
+and the user will see whatever you have generated.
 
 You can also specify keys and values in C<\%save_options> which get
 passed along to the C<save()> call.
 
-Here's an example of validating your data using the 'view messages'
+Here is an example of validating your data using the 'view messages'
 found in the L<OpenInteract2::Action|OpenInteract2::Action>
-object. Here we'll assume that we have a database of books and
+object. Here we will assume that we have a database of books and
 someone is updating a particular book record:
 
  sub _update_customize {
@@ -293,11 +299,47 @@ someone is updating a particular book record:
 B<_update_post_action>
 
 This method is called after the object has been successfully updated
--- you'll find the object in the C<c_object> action parameter. You can
-perform any action you like after this. If you throw a C<die> with
+-- you will find the object in the C<c_object> action parameter. You
+can perform any action you like after this. If you throw a C<die> with
 content it will be displayed to the user rather than moving to the
 configured C<c_update_task>.
 
+=head1 OBSERVATIONS FIRED
+
+The C<update()> method fires two observations:
+
+B<pre update> C<( $action, 'pre update', $object, \%old_data, \%save_options )>
+
+This is fired just before the object is update, which means that the
+C<_update_customize()> method described above has already run.
+
+This gets passed the object to be updated, a hashref of the data in
+the old object, and the options being sent to the C<save()> method:
+
+ package My::Observer;
+ 
+ sub update {
+     my ( $class, $action, $type, $object, $old_data, $save_opts ) = @_
+     return unless ( $type eq 'pre update' );
+     ...
+ }
+
+B<post update> C<( $action, 'post update', $object, \%old_data )>
+
+This is fired after the object is updated as well as after the
+C<_update_post_action()> described above.
+
+This gets passed the object to be updated and a hashref with the data
+from the old object:
+
+ package My::Observer;
+ 
+ sub update {
+     my ( $class, $action, $type, $object, $old_data ) = @_;
+     return unless ( $type eq 'post update' );
+     ...
+ }
+
 =head1 CONFIGURATION FOR 'update'
 
 =head2 Basic
@@ -311,7 +353,7 @@ Default: 'display_form'
 B<c_update_security_fail_task> ($)
 
 Task to update on the specific failure of insufficient security. If
-this is not defined we'll just use C<c_update_fail_task>.
+this is not defined we will just use C<c_update_fail_task>.
 
 B<c_update_task> ($)
 
@@ -340,7 +382,7 @@ B<c_update_return_url>
 
 What I should set the 'return URL' to. This is used for links like
 'Login/Logout' where you perform an action and the system brings you
-back to a particular location. You don't want to come back to the
+back to a particular location. You do not want to come back to the
 '.../update/' URL.
 
 Note that this will be normalized to the deployment context at
@@ -354,8 +396,8 @@ Default: the URL formed by the default task for the current action.
 B<c_update_fields> ($ or \@)
 
 List the fields you just want assigned directly from the name. So if a
-form variable is named 'first_name' and you list 'first_name' here
-we'll assign that value to the object property 'first_name'.
+form variable is named 'first_name' and you list 'first_name' here we
+will assign that value to the object property 'first_name'.
 
 B<c_update_fields_toggled> ($ or \@)
 
@@ -381,20 +423,24 @@ multiple fields. (See L<OpenInteract2::Request/param_datetime>.)
 
 B<c_update_fields_date_format> ($)
 
-If you list one or more fields in C<c_update_fields_date> and they're
+If you list one or more fields in C<c_update_fields_date> and they are
 pulled from a single field, you need to let OI2 know how to parse the
 date. Just specify a C<strptime> format as specified in
 L<DateTime::Format::Strptime|DateTime::Format::Strptime>.
 
 B<c_update_fields_datetime_format> ($)
 
-If you list one or more fields in C<c_update_fields_datetime> and
-they're pulled from a single field, you need to let OI2 know how to
-parse the date and time. Just specify a C<strptime> format as
-specified in L<DateTime::Format::Strptime|DateTime::Format::Strptime>.
+If you list one or more fields in C<c_update_fields_datetime> and they
+are pulled from a single field, you need to let OI2 know how to parse
+the date and time. Just specify a C<strptime> format as specified in
+L<DateTime::Format::Strptime|DateTime::Format::Strptime>.
 
 =head2 System-created parameters
 
+B<c_task>
+
+Name of the task originally invoked: 'update'.
+
 B<c_object_class>
 
 See L<OpenInteract2::Common/_common_check_object_class>
@@ -405,18 +451,18 @@ See L<OpenInteract2::Common/_common_check_id_field>
 
 B<c_id> ($)
 
-The ID of the object we're trying to update.
+The ID of the object we are trying to update.
 
 B<c_object> ($)
 
-If we're able to fetch an object to update this will be set. Whether
+If we are able to fetch an object to update this will be set. Whether
 the update succeeds or fails the object should represent the state of
 the object in the database.
 
 B<c_object_old_data> (\%)
 
-If the update is successful we set this to the hashref of the previous
-record's data.
+If the update is successful we set this to the hashref of data from
+the previous record.
 
 =head1 COPYRIGHT
 
@@ -424,4 +470,4 @@ Copyright (c) 2003-2004 Chris Winters. All rights reserved.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
