@@ -1,6 +1,6 @@
 package OpenInteract2::Auth;
 
-# $Id: Auth.pm,v 1.18 2004/02/18 05:25:26 lachoy Exp $
+# $Id: Auth.pm,v 1.20 2004/10/05 01:27:51 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor::Fast );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Auth::VERSION  = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Auth::VERSION  = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( user groups );
 __PACKAGE__->mk_accessors( @FIELDS );
@@ -72,7 +72,7 @@ sub login {
         $self->is_logged_in( 'yes' );
     }
     else {
-        $AUTH_USER_CLASS->get_user( $self );;
+        $AUTH_USER_CLASS->get_user( $self );
     }
 
     # TODO: Throw exception here?
@@ -162,7 +162,7 @@ sub run_custom_handler {
     return if ( $USE_CUSTOM eq 'no' );
     $log->is_debug &&
         $log->debug( "Custom login handler/method being used: ",
-                     "[$CUSTOM_CLASS] [$CUSTOM_METHOD]" );
+                     "'$CUSTOM_CLASS' '$CUSTOM_METHOD'" );
     eval {
         $CUSTOM_CLASS->$CUSTOM_METHOD( $self );
     };
@@ -171,7 +171,7 @@ sub run_custom_handler {
         if ( $CUSTOM_FAIL_METHOD ) {
             $log->is_debug &&
                 $log->debug( "Custom login handler failure method: ",
-                             "[$CUSTOM_CLASS] [$CUSTOM_FAIL_METHOD]" );
+                             "'$CUSTOM_CLASS' '$CUSTOM_FAIL_METHOD'" );
             eval {
                 $CUSTOM_CLASS->$CUSTOM_FAIL_METHOD( $self );
 
@@ -214,7 +214,7 @@ sub _include_custom_class {
     }
     eval "require $CUSTOM_CLASS";
     if ( $@ ) {
-        $log->error( "Tried to use custom login handler [$CUSTOM_CLASS]",
+        $log->error( "Tried to use custom login handler '$CUSTOM_CLASS'",
                      "but requiring the class failed: $@" );
         return 'no';
     }
