@@ -1,13 +1,13 @@
 package OpenInteract2::Auth::User;
 
-# $Id: User.pm,v 1.20 2004/02/22 04:41:48 lachoy Exp $
+# $Id: User.pm,v 1.21 2004/10/05 03:05:09 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Auth::User::VERSION  = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Auth::User::VERSION  = sprintf("%d.%02d", q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -22,8 +22,7 @@ sub get_user {
     ( $user, $user_id ) = $class->_get_cached_user;
     if ( $user ) {
         $is_logged_in = 'yes';
-        $log->is_info &&
-            $log->info( "Found user from session cache" );
+        $log->is_info && $log->info( "Found user from session cache" );
     }
     else {
         $user_id ||= $class->_get_user_id;
@@ -136,7 +135,7 @@ sub _set_cached_user {
     $session->{_oi_cache}{user_refresh_on} = time + ( $user_refresh * 60 );
     $log->is_info &&
         $log->info( "Set user to session cache, expires in ",
-                     "[$user_refresh] minutes" );
+                     "'$user_refresh' minutes" );
 }
 
 # Just grab the user_id from somewhere
@@ -196,9 +195,11 @@ sub _login_user_from_input {
     $log->is_info &&
         $log->info( "Found login name [$login_name]" );
 
-    my $user = eval { CTX->lookup_object( 'user' )
-                         ->fetch_by_login_name( $login_name,
-                                                { skip_security => 1 } ) };
+    my $user = eval {
+        CTX->lookup_object( 'user' )
+           ->fetch_by_login_name( $login_name,
+                                  { skip_security => 1 } )
+       };
     if ( $@ ) {
       $log->error( "Error fetching user by login name: $@" );
     }
@@ -212,7 +213,7 @@ sub _login_user_from_input {
 
     # Check the password
 
-    my $password   = $request->param( $password_field );
+    my $password = $request->param( $password_field );
 
     unless ( $user->check_password( $password ) ) {
         $log->warn( "Password check for [$login_name] failed" );
