@@ -1,6 +1,6 @@
 package OpenInteract2::Config;
 
-# $Id: Config.pm,v 1.12 2004/02/18 05:25:26 lachoy Exp $
+# $Id: Config.pm,v 1.14 2004/11/27 20:34:15 lachoy Exp $
 
 use strict;
 use base qw( Class::Factory );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Config::VERSION   = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Config::VERSION   = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -22,7 +22,11 @@ my ( $log );
 
 sub new {
     my ( $pkg, $type, @params ) = @_;
-    $type ||= 'perl';
+    unless ( $type ) {
+        my @types = __PACKAGE__->get_loaded_types;
+        oi_error "You must specify a configuration type in 'new()'; ",
+                 "valid types are: ", join( ', ', @types );
+    }
     my $class = eval { $pkg->get_factory_class( $type ) };
     oi_error $@ if ( $@ ) ;
     my $data = $class->read_config( @params );
@@ -33,7 +37,7 @@ sub new {
 sub is_file_valid {
     my ( $class, $filename ) = @_;
     unless  ( -f $filename ) {
-        oi_error "Config file [$filename] does not exist";
+        oi_error "Config file '$filename' does not exist";
     }
 }
 
@@ -42,9 +46,10 @@ sub read_file {
     my ( $class, $filename ) = @_;
     $log ||= get_logger( LOG_CONFIG );
     $log->is_debug &&
-        $log->debug( "Config trying to read file [$filename]" );
+        $log->debug( "Config trying to read file '$filename'" );
+    $class->is_file_valid( $filename );
     open( CONF, '<', $filename )
-          || oi_error "Cannot open [$filename] for reading: $!";
+          || oi_error "Cannot read config '$filename': $!";
     my @lines = <CONF>;
     close( CONF );
     return \@lines;
@@ -252,4 +257,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
