@@ -1,13 +1,16 @@
 package OpenInteract2::Config::Ini;
 
-# $Id: Ini.pm,v 1.12 2004/02/18 05:25:27 lachoy Exp $
+# $Id: Ini.pm,v 1.18 2004/11/27 20:33:55 lachoy Exp $
 
 use strict;
+use File::Basename           qw( dirname );
+use File::Spec::Functions    qw( catfile );
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
+use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Config::Ini::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Config::Ini::VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -18,18 +21,22 @@ my ( $log );
 #   sections (\@): all full sections, in the order they were read
 #   comments (\%): key is full section name, value is comment scalar
 #   filename ($):  file read from
+#   directory ($): directory file read from
 
 sub new {
     my ( $pkg, $params ) = @_;
     my $class = ref $pkg || $pkg;
     my $self = bless( {}, $class );
     if ( $self->{_m}{filename} = $params->{filename} ) {
+        $self->{_m}{directory} = $params->{directory} || dirname( $params->{filename} );
         $self->_translate_ini( OpenInteract2::Config->read_file( $params->{filename} ) );
     }
     elsif ( $params->{content} ) {
+        $self->{_m}{directory} = $params->{directory} || '.';
         $self->_translate_ini( $params->{content} );
     }
     elsif ( $params->{struct} ) {
+        $self->{_m}{directory} = $params->{directory} || '.';
         $self->_translate_struct_to_ini( $params->{struct} );
     }
     return $self;
@@ -148,14 +155,18 @@ sub _translate_ini {
     my @comments = ();
     my ( $section, $sub_section );
 
+    my $line_number = 0;
     my ( $multiline_value, $multiline_param );
     my $in_multiline = 0;
 
+    my $resolved_lines = $self->_resolve_all_includes( $lines );
+
     # Cycle through the lines: skip blanks; accumulate comments for
     # each section; register section/subsection; add parameter/value
 
-    for ( @{ $lines } ) {
+    for ( @{ $resolved_lines } ) {
         chomp;
+        $line_number++;
         next if ( /^\s*$/ );
         if ( /^# Written by OpenInteract2::Config::Ini at/ ) {
             next;                 # ... get rid of current line
@@ -192,6 +203,20 @@ sub _translate_ini {
             $multiline_value = undef;
             $in_multiline = 0;
         }
+
+        # Line is assigning multiple values at once...
+        elsif ( /^\s*\@(.)/ ) {
+            my $separator = $1;
+            s/^\s*@.\s*//;
+            my ( $value_listing );
+            ( $param, $value_listing ) = /^\s*([^=]+?)\s*=\s*(.*)\s*$/;
+            if ( $this_multiline ) {
+                die "Cannot define multiple values (with a leading '\@') ",
+                    "on a line that is continued (with a trailing '\\') ",
+                    "at line number $line_number defining '$param'\n";
+            }
+            $value = [ split /\s*$separator\s*/, $value_listing ];
+        }
         else {
             ( $param, $value ) = /^\s*([^=]+?)\s*=\s*(.*)\s*$/;
             if ( $this_multiline ) {
@@ -202,9 +227,12 @@ sub _translate_ini {
             }
         }
 
-        $log->is_debug &&
-            $log->debug( "Set [$section $sub_section $param] ",
-                         "to [$value]" );
+        if ( $log->is_debug ) {
+            my $show_section = ( $sub_section )
+                                 ? "$section.$sub_section" : $section;
+            $log->debug( "Line $line_number: $show_section.$param ",
+                         "= '$value'" );
+        }
         $self->_read_item( $section, $sub_section, $param, $value );
     }
     return $self;
@@ -216,6 +244,35 @@ sub _translate_struct_to_ini {
 }
 
 
+sub _resolve_all_includes {
+    my ( $self, $content ) = @_;
+    my @resolved = ();
+    for ( @{ $content } ) {
+        chomp;
+        if ( /^\@INCLUDE\s*=\s*(.*)\s*$/ ) {
+            my $include_file = $1;
+            my $absolute_file = catfile( $self->{_m}{directory}, $include_file );
+            $log->is_debug &&
+                $log->debug( "Asked to include file '$include_file'; ",
+                             "using absolute filename ", $absolute_file );
+            my $included_raw = eval {
+                OpenInteract2::Config->read_file( $absolute_file )
+            };
+            if ( $@ ) {
+                oi_error "Failed to read INI configuration -- cannot \@INCLUDE ",
+                         "file '$include_file': $@";
+            }
+            my $included_resolved = $self->_resolve_all_includes( $included_raw );
+            push @resolved, @{ $included_resolved };
+        }
+        else {
+            push @resolved, "$_\n";
+        }
+    }
+    return \@resolved;
+}
+
+
 sub _read_section_head {
     my ( $self, $full_section, $comments ) = @_;
     my $comment_text = join "\n", @{ $comments };
@@ -255,17 +312,24 @@ sub _read_item {
 }
 
 
+# NOTE: $value can be a scalar or an arrayref (generally when a line
+# defines multiple values at once)
+
 sub _set_value {
     my ( $self, $set_in, $param, $value ) = @_;
     my $existing = $set_in->{ $param };
-    if ( $existing and ref $set_in->{ $param } eq 'ARRAY' ) {
-        push @{ $set_in->{ $param } }, $value;
+    my @values = ( ref $value ) ? @{ $value } : ( $value );
+    if ( $existing and ref $existing eq 'ARRAY' ) {
+        push @{ $set_in->{ $param } }, @values;
     }
     elsif ( $existing ) {
-        $set_in->{ $param } = [ $existing, $value ];
+        $set_in->{ $param } = [ $existing, @values ];
+    }
+    elsif ( scalar @values > 1 ) {
+        $set_in->{ $param } = \@values;
     }
     else {
-        $set_in->{ $param } = $value;
+        $set_in->{ $param } = $values[0];
     }
 }
 
@@ -278,11 +342,12 @@ sub write_file {
     $log ||= get_logger( LOG_CONFIG );
 
     $filename ||= $self->{_m}{filename} || 'config.ini';
-    my ( $original_filename );
+    my ( $original_filename ) = "";
     if ( -f $filename ) {
         $original_filename = $filename;
         $filename = "$filename.new";
     }
+    $original_filename ||= '';
 
     # Set 'Global' items from the config object root
 
@@ -351,9 +416,41 @@ OpenInteract2::Config::Ini - Read/write INI-style (++) configuration files
 
 =head1 SYNOPSIS
 
- my $config = OpenInteract2::Config::Ini->new({ filename => 'myconf.ini' });
+ # If no 'directory' specified @INCLUDE directives are assumed to be
+ # in the same directory as the 'filename'
+
+ my $config = OpenInteract2::Config::Ini->new({
+     filename => 'myconf.ini'
+ });
+ 
+ # Pass in an explicit directory to resolve @INCLUDE directives
+ 
+ my $config = OpenInteract2::Config::Ini->new({
+     filename  => 'myconf.ini',
+     directory => '/path/to/config',
+ });
+ 
+ # Use a string with INI sections instead of a file; @INCLUDE
+ # directives assumed to be in the current directory
+ 
+ my $config = OpenInteract2::Config::Ini->new({
+     content  => $some_string,
+ });
+
+ # Pass in an explicit directory to resolve @INCLUDE directives
+ 
+ my $config = OpenInteract2::Config::Ini->new({
+     content   => $some_string,
+     directory => '/path/to/config',
+ });
+ 
+ # Use the configuration just like a hash
  print "Main database driver is:", $config->{datasource}{main}{driver}, "\n";
  $config->{datasource}{main}{username} = 'mariolemieux';
+
+ # Write out the configuration; this should preserve order and
+ # comments
+ 
  $config->write_file;
 
 =head1 DESCRIPTION
@@ -384,11 +481,71 @@ the usage of multivalue keys:
  item = first
  item = second
 
+=item *
+
+From an idea I had in the shower we have another usage of multivalue
+keys:
+
+ @,item = first, second
+
+The leading '@' indicates we are declaring multiple values, the next
+character ',' indicates that we are separating the values with a
+comma. So you could also have:
+
+ @|item = first | second
+
+Similar to how we treat the '=' we swallow whitespace on both sides of
+the separation character. So the following evaluate to equivalent data
+structures:
+
+ @,item = first,second
+ @,item = first, second
+ @,item = first  ,   second
+
+You can also use multiple declarations of these to define a single
+field. That should prevent configuration lines from getting too long:
+
+ @,object_field = title, posted_on_date, author, editor
+ @,object_field = approved_by, approved_on, is_active,
+ @,object_field = active_on, content
+
+=item *
+
+From countless other configuration systems you can include the
+contents of other files inline using '@INCLUDE'. So given the
+following files:
+
+ File: db_config.ini
+ [db]
+ dsn = DBI:Pg:dbname=foo
+ user = foo
+ password = bar
+ 
+ File: caching.ini
+ [cache]
+ use = no
+ expiration = 600
+ class = OpenInteract2::Cache::File
+ 
+ [cache params]
+ directory = /path/to/cache
+ lock_directory = /path/to/cache_lock
+
+You can them bring them all together in one with:
+
+ File: server.ini
+ [Global]
+ version = 1.19
+ timezone = America/New_York
+ 
+ @INCLUDE = db_config.ini
+ @INCLUDE = caching.ini
+
 =back
 
 =head2 Example
 
-Given the following configuration in INI-style:
+Given the following configurations:
 
  [datasource]
  default_connection_db = main
@@ -477,10 +634,11 @@ parameter we will parse the file and fill the returned object with its values.
 If you pass in raw INI text in the parameter 'content' we try to
 translate it using the same means as reading a file.
 
-And if you pass in a hashref in the parameter 'struct' we attempt to
-map its keys and values to the internal format which can then be saved
-as normal. This will throw an exception if your structures are nested
-too deeply. For instance, this would be ok:
+B<NOTE: THIS DOES NOT WORK YET> And if you pass in a hashref in the
+parameter 'struct' we attempt to map its keys and values to the
+internal format which can then be saved as normal. This will throw an
+exception if your structures are nested too deeply. For instance, this
+would be ok:
 
  my $foo = {
     top_key => { myvalue => 1, yourvalue => [ 'one', 'two' ] },
@@ -546,7 +704,9 @@ values.
 
 B<set( $section, [ $sub_section ], $parameter, $value )>
 
-Set the key/value C<$parameter>/C<$value> pair in the configuration.
+Set the key/value C<$parameter>/C<$value> pair in the
+configuration. Note that C<$value> can be a simple scalar or an array
+reference.
 
 Returns: the value set
 
@@ -561,6 +721,13 @@ B<write_file( $filename )>
 Serializes the INI file (with comments, as applicable) to
 C<$filename>.
 
+Note: this B<DOES NOT> write any '@INCLUDE' directives back to the
+files we read them from. Everything will be written to the same
+file. (Patches welcome if you would like to change this, probably by
+tagging the sections read in from a file with that absolute filename
+and then writing those sections back out to the file from this
+method.)
+
 Items from the config object root go into 'Global'.
 
 Returns: the filename to which the INI structure was serialized.
@@ -578,10 +745,23 @@ C<DEBUG> with fair warning...
 B<_translate_ini( \@lines|$content )>
 
 Translate the arrayref C<\@lines> or the scalar C<content> from INI
-format into a Perl data structure.
+format into a Perl data structure. Before we translate them into a
+data structure we first resolve all '@INCLUDE' directives.
 
 Returns: the object filled with the content.
 
+B<_resolve_all_includes( \@lines )>
+
+Translate all '@INCLUDE' directives to the configuration they point
+to. Throws an exception if we cannot read the file specified in the
+directive. This file path is created by giving to C<catfile> in
+L<File::Spec> the metadata value 'directory' (which can be passed in
+to C<new()>) and the filename in the directive.
+
+Note that INCLUDE-ed files can themselves have '@INCLUDE' directives.
+
+Returns: arrayref of fully-resolved configuration.
+
 B<_read_section_head( $full_section, \@comments )>
 
 Splits the section into a section and sub-section, returning a
@@ -602,6 +782,8 @@ Returns: the value set
 
 B<_set_value( \%values, $parameter, $value )>
 
+Note that C<$value> can be a simple scalar or an array reference.
+
 Sets C<$parameter> to C<$value> in C<\%values>. We do not care where
 C<\%values> is in the tree.
 
@@ -637,4 +819,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
