@@ -1,6 +1,6 @@
 package OpenInteract2::Config::Initializer;
 
-# $Id: Initializer.pm,v 1.11 2004/02/18 05:25:27 lachoy Exp $
+# $Id: Initializer.pm,v 1.20 2004/11/30 03:12:11 lachoy Exp $
 
 use base qw( Class::Observable );
 use strict;
@@ -8,8 +8,10 @@ use Carp                     qw( croak );
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
+use OpenInteract2::Exception qw( oi_error );
+use OpenInteract2::URL;
 
-$OpenInteract2::Config::Initializer::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Config::Initializer::VERSION = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -39,12 +41,20 @@ sub read_observers {
         next unless ( $config );
         my $config_watcher = $config->config_watcher;
         next unless ( $config_watcher );
-        push @conf_watchers, @{ $config_watcher };
+        foreach my $watcher_class ( @{ $config_watcher } ) {
+            eval "require $watcher_class";
+            if ( $@ ) {
+                oi_error "Cannot find configured watcher '$watcher_class' ",
+                         "from package '", $package->name, "': $@";
+            }
+            $log->info( "Required watcher '$watcher_class' ok" );
+            push @conf_watchers, $watcher_class;
+        }
     }
 
     foreach my $watcher_class ( @conf_watchers ) {
         __PACKAGE__->add_observer( $watcher_class );
-        $log->info( "Adding custom config observer [$watcher_class]" );
+        $log->info( "Added custom config observer '$watcher_class'" );
     }
 
 }
@@ -156,7 +166,7 @@ sub _spops_fulltext {
             $log->is_debug &&
                 $log->debug( "Adding fulltext indexing for ",
                              "[$config->{key}: $config->{class}]" );
-            unshift @{ $config->{isa} }, 'OpenInteract2::FullText';
+            unshift @{ $config->{isa} }, 'OpenInteract2::FullTextRules';
         }
         else {
             $log->warn( "You set 'is_searchable' for [$config->{key}: ",
@@ -178,25 +188,66 @@ sub _spops_display_info {
     return unless ( ref $display_info eq 'HASH' );
     $log ||= get_logger( LOG_INIT );
     $log->info( "Translating correct URL for 'display' in '$config->{key}'" );
+    my $u = OpenInteract2::URL->new();
     if ( $display_info->{url} ) {
         $display_info->{url} =
-            OpenInteract2::URL->create( $display_info->{url} );
+            $u->create( $display_info->{url} );
     }
     elsif ( $display_info->{ACTION} ) {
         $display_info->{url} =
-            OpenInteract2::URL->create_from_action( $display_info->{ACTION},
-                                                    $display_info->{TASK} );
+            $u->create_from_action( $display_info->{ACTION},
+                                    $display_info->{TASK} );
         delete $display_info->{TASK};
         if ( $display_info->{TASK_EDIT} ) {
-            $display_info->{url_edit} =
-                OpenInteract2::URL->create_from_action( $display_info->{ACTION},
-                                                        $display_info->{TASK_EDIT} );
+            $display_info->{url_edit} = $u->create_from_action(
+                $display_info->{ACTION}, $display_info->{TASK_EDIT} );
             delete $display_info->{TASK_EDIT};
         }
         delete $display_info->{ACTION};
     }
 }
 
+
+# Changes:
+# [user has_a]
+# My::User = updater: updated_by; poster: posted_by
+
+# To:
+# user => {
+#    has_a => {
+#        'My::User' => {
+#           updater => 'updated_by',
+#           poster  => 'posted_by',
+#        }
+
+sub _spops_set_hasa {
+    my ( $init, $type, $config ) = @_;
+    return unless ( $type eq 'spops' );
+    my $hasa_conf = $config->{has_a};
+    return unless ( ref $hasa_conf eq 'HASH' );
+    $log ||= get_logger( LOG_INIT );
+    $log->is_info && $log->info( "Modifying has_a for '$config->{key}'" );
+
+    foreach my $hasa_class ( keys %{ $hasa_conf } ) {
+        my $mappings = $hasa_conf->{ $hasa_class };
+        if ( ref $mappings eq 'ARRAY' ) {
+            $mappings = join( '; ', @{ $mappings } );
+        }
+        $log->is_info &&
+            $log->info( "Will replace '$mappings' within ",
+                        "'$config->{key}.has_a'" );
+        my @pieces = split /\s*;\s*/, $mappings;
+        my %replacement = ();
+        foreach my $piece ( @pieces ) {
+            my ( $name, $field ) = split /\s*:\s*/, $piece, 2;
+            next unless ( $name and $field );
+            $replacement{ $name } = $field;
+            $log->is_info && $log->info( "Setting $name = $field" );
+        }
+        $config->{ $hasa_class } = \%replacement;
+    }
+}
+
 # DBI-only
 
 sub _config_is_dbi {
@@ -254,6 +305,7 @@ __PACKAGE__->add_observer( \&_spops_creation_security );
 __PACKAGE__->add_observer( \&_spops_date_conversion );
 __PACKAGE__->add_observer( \&_spops_fulltext );
 __PACKAGE__->add_observer( \&_spops_display_info );
+__PACKAGE__->add_observer( \&_spops_set_hasa );
 __PACKAGE__->add_observer( \&_spops_set_dbi );
 __PACKAGE__->add_observer( \&_spops_discover_field );
 __PACKAGE__->add_observer( \&_spops_set_ldap );
@@ -281,6 +333,7 @@ sub _action_assign_defaults {
     return unless ( $type eq 'action' );
 
     $log ||= get_logger( LOG_INIT );
+    return if ( $config->{redir} );
     $log->info( "Assigning action defaults to '$config->{name}'" );
     my $global_defaults = CTX->lookup_default_action_info;
     while ( my ( $action_item, $action_value ) =
@@ -387,13 +440,18 @@ OpenInteract2::Config::Initializer - Observable configuration initialization eve
  sub update {
      my ( $class, $type, $config ) = @_;
      return unless ( $type eq 'spops' );
-
+ 
      if ( $config->{is_googlable} eq 'yes' ) {
          push @{ $config->{rules_from} }, 'My::Googable';
      }
  }
  
- # Here's we'll dynamically add a filter to an action where
+ # Add a configuration observer in the server configuration
+ 
+ [config_watcher]
+ class = OpenInteract2::MyInitializerAction
+ 
+ # and in the class we'll dynamically add a filter to an action where
  # 'is_googlable' is 'yes'
  
  package OpenInteract2::MyInitializerAction;
@@ -404,10 +462,8 @@ OpenInteract2::Config::Initializer - Observable configuration initialization eve
  sub update {
      my ( $class, $type, $config ) = @_;
      return unless ( $type eq 'action' );
-
-     if ( $config->{is_googlable} eq 'yes' ) {
-         OpenInteract2::Filter->add_filter_to_action(
-                              'google', $config->{class} );
+     if ( 'yes' eq lc $config->{is_googlable} ) {
+         CTX->map_observer( google => $config->{class} );
      }
  }
 
@@ -447,47 +503,48 @@ that get expanded at runtime to something more complex.
 
 =head2 Built-in examples
 
-For example, if you've read
+For example, if you have read
 L<OpenInteract2::Manual::SPOPS|OpenInteract2::Manual::SPOPS> you know
 that OpenInteract 2.x allows you to declare security for an SPOPS
 object with:
 
  is_secure = yes
 
-In 1.x you had to add a class to the ISA.
+In 1.x you had to add a class to the ISA. Which do you think is easier
+to read and maintain?
 
 Or to enable fulltext searching of your object you can just add to
 your SPOPS configuration:
 
  is_searchable = yes
 
-and list the fields you'd like indexed. These are both implemented
-using this same event-based scheme.
+and list the fields whose content you would like indexed B<without
+caring about how they are indexed>. These are both implemented using
+this same event-based scheme.
 
-What happens in the first case is that for every object that's tagged
+What happens in the first case is that for every object that is tagged
 with 'is_secure' we simply add L<SPOPS::Secure|SPOPS::Secure> to the
-object's 'isa' field. And in the second case we add
-L<OpenInteract2::FullText|OpenInteract2::FullText> to the 'isa'.
+object 'isa' field. And in the second case we add
+L<OpenInteract2::FullTextRules|OpenInteract2::FullTextRules> to the 'isa'.
 
 =head2 Why?
 
 Everything (or nearly everything) you can do in the event can be done
 in the configuration, so why bother? The primary reason is that it
 makes for much more concise configuration files. More concise
-configuration means you're less likely to mess it up and that you'll
-hopefully be more willing to modify it when necessary rather than
+configuration means you are less likely to mess it up and that you
+will hopefully be more willing to modify it when necessary rather than
 throwing up your hands and hacking an ugly solution.
 
 This is also done for the same reason that you create accessors
-instead of allowing direct access to your object's data
-structures. For instance, we may modify the full text indexing
-implementation to require only an SPOPS ruleset rather than full
-inheritance.
+instead of allowing direct access to your object data structures. For
+instance, we may modify the full text indexing implementation to
+require only an SPOPS ruleset rather than full inheritance.
 
-With the simple declaration we don't have to change B<any> of our
+With the simple declaration we do not have to change B<any> of our
 SPOPS configurations with the change. If we added the class directly
 to the 'isa' people would have to change the configuration manually,
-or we'd have to add a runtime hook to modify the 'isa' anyway.
+or we would have to add a runtime hook to modify the 'isa' anyway.
 
 =head1 OBSERVERS
 
@@ -537,6 +594,50 @@ Configurations with 'field_discover' set to 'yes' get
 L<SPOPS::Tool::DBI::DiscoverField|SPOPS::Tool::DBI::DiscoverField>
 added to the 'rules_from' key.
 
+=item B<'has_a' Munging>
+
+Because we have restricted configurations to three levels deep some
+features cannot be adequately representetd. Complicated 'has_a'
+relationships are one of these.
+
+In the Perl data structure you might have something like:
+
+ {
+   user => {
+     ...
+     has_a => {
+        'My::User' => {
+           updater => 'updated_by',
+           poster  => 'posted_by',
+        },
+     },
+ }
+
+But if you try to do this with an unmodified configuration you will
+get this far:
+
+ [user has_a]
+ My::User = ARGH!
+
+Instead you can use a shortcut:
+
+ [user has_a]
+ My::User = updater: updated_by; poster: posted_by
+
+So each name and field is separated by a ':' and each set is separated
+by a ';'.
+
+Alternatively you can also represent them as a list:
+
+ My::User = updater: updated_by
+ My::User = poster: posted_by
+
+or a list using the lovable INI syntax addition:
+
+ @,My::User = updater: updated_by, poster: posted_by
+
+And the system will do the right thing.
+
 =item B<DBI Class>
 
 Configurations using a DBI datasource get L<SPOPS::DBI|SPOPS::DBI> and
@@ -560,7 +661,7 @@ These are the handlers for action configuration events:
 
 Read the hashref data from the 'action_info.default' server
 configuration key and assign it to the configuration where the
-configuration doesn't already have data defined.
+configuration does not already have data defined.
 
 =item B<Security Level Codes>
 
@@ -591,9 +692,9 @@ argument is the name of the class generated:
  sub my_localization_observer {
      my ( $init_class, $type, $localization_class ) = @_;
      return unless ( $type eq 'localization' );
-
+ 
      print "Processing '$localization_class':\n";
-
+ 
      # browse the keys for these localization messages
      no strict 'refs';
      my $this_lexicon = \%{ $localization_class . '::Lexicon' };
@@ -608,7 +709,7 @@ You should never be using this class directly. But just in case...
 
 B<new()>
 
-Creates a new object. (Doesn't hold anything right now.)
+Creates a new object. (Does not hold anything right now.)
 
 B<read_observers()>
 
@@ -624,4 +725,4 @@ Copyright (c) 2003-2004 Chris Winters. All rights reserved.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
