@@ -1,6 +1,6 @@
 package OpenInteract2::Config::Package;
 
-# $Id: Package.pm,v 1.18 2004/02/18 05:25:27 lachoy Exp $
+# $Id: Package.pm,v 1.19 2004/09/26 16:06:30 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor::Fast );
@@ -8,7 +8,7 @@ use File::Basename ();
 use File::Spec;
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Config::Package::VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Config::Package::VERSION = sprintf("%d.%02d", q$Revision: 1.19 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_FILENAME => 'package.conf';
 
@@ -21,7 +21,7 @@ sub get_required_fields { return [ @REQUIRED_FIELDS ] }
 my @SERIAL_FIELDS = qw( name version author url
                         spops_file action_file message_file module
                         sql_installer template_plugin
-                        filter config_watcher description );
+                        observer config_watcher description );
 my @OBJECT_FIELDS = qw( filename package_dir );
 
 # Define the keys in 'package.conf' that can be a list, meaning you
@@ -44,7 +44,7 @@ my %LIST_FIELDS = map { $_ => 1 } qw( author module spops_file action_file
 
 # NOTE: If you add a field here you must also add it to @SERIAL_FIELDS
 
-my %HASH_FIELDS = map { $_ => 1 } qw( template_plugin filter );
+my %HASH_FIELDS = map { $_ => 1 } qw( template_plugin observer );
 
 my @FIELDS      = ( @SERIAL_FIELDS, @OBJECT_FIELDS );
 OpenInteract2::Config::Package->mk_accessors( @FIELDS );
@@ -281,7 +281,7 @@ OpenInteract2::Config::Package - Read, write and check package config files
  author              Chuck <chuck@guy.com>
  url                 http://www.oirox.com/
  template_plugin     TestPlugin     OpenInteract2::Plugin::Test
- filter              mywiki         OpenInteract2::Filter::MyWiki
+ observer            mywiki         OpenInteract2::Filter::MyWiki
  description
  This package rocks!
 
@@ -337,7 +337,7 @@ Example:
 
  template_plugin    MyPlugin     OpenInteract2::Template::Plugin::MyPlugin
  template_plugin    MyPluginNew  OpenInteract2::Template::Plugin::MyPluginNew
- filter             mywiki       OpenInteract2::Filter::MyWiki
+ observer           mywiki       OpenInteract2::Filter::MyWiki
 
 Additionally, all data below the last entry C<description> is used as
 the description. Example:
@@ -556,11 +556,12 @@ Template Toolkit plugins defined by this package. Each plugin is
 defined by a space-separated key/value pair. The template users access
 the plugin by the key, the value is used to instantiate the plugin.
 
-B<filter> (\%)
+B<observers> (\%)
 
-Filters defined by this package. It should be in a space-separated
-key/value pair simiilar to C<template_plugin>, where the key defines
-the filter name and the value defines the filter class.
+Observers (commonly in the guise of filters) defined by this
+package. It should be in a space-separated key/value pair simiilar to
+C<template_plugin>, where the key defines the observer name and the
+value defines the observer class.
 
 B<config_watcher> (\@)
 
@@ -569,7 +570,7 @@ L<OpenInteract2::Config::Initializer|OpenInteract2::Config::Initializer>
 events at server startup. You can use this to create custom, concise
 directives for your SPOPS and/or Action configurations that get
 expanded into either more meaningful information or into data that can
-only be found at runtime. That's a little abstract: see
+only be found at runtime. That may be a little abstract: see
 L<OpenInteract2::Config::Initializer|OpenInteract2::Config::Initializer>
 for examples.
 
