@@ -1,18 +1,19 @@
 package OpenInteract2::Config::PackageChanges;
 
-# $Id: PackageChanges.pm,v 1.8 2004/02/18 05:25:27 lachoy Exp $
+# $Id: PackageChanges.pm,v 1.11 2004/09/27 04:16:06 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor::Fast Exporter );
-use File::Spec;
+use File::Spec::Functions    qw( catfile catdir );
 use OpenInteract2::Exception qw( oi_error );
+use Text::Wrap               qw( wrap );
 
-$OpenInteract2::Config::PackageChanges::VERSION  =  sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Config::PackageChanges::VERSION  =  sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 use constant CHANGES_FILE => 'Changes';
 @OpenInteract2::Config::PackageChanges::EXPORT_OK = qw( CHANGES_FILE );
 
-my @FIELDS = qw( source_package source_dir source_file source_content );
+my @FIELDS = qw( source_package source_dir source_file source_content comments );
 OpenInteract2::Config::PackageChanges->mk_accessors( @FIELDS );
 
 sub new {
@@ -51,8 +52,11 @@ sub read_config {
     my @content = $self->_read_content;
     my ( %last_entry );
     my @entries = ();
+    my @comments = ();
+
 LINE:
     for ( @content ) {
+        chomp;
         if ( /^(\d+.\d+)(.*)$/ ) {
             my $this_version = $1;
             my $this_date    = $2;
@@ -62,22 +66,30 @@ LINE:
                 %last_entry = ();
             }
             $last_entry{version} = $this_version;
-            chomp $this_date;
             $this_date =~ s/^\s+//;
             $this_date =~ s/\s+$//;
             $last_entry{date}    = $this_date;
             next LINE;
         }
 
+        # This skips any initial comments, tossing them aside
+
         unless ( keys %last_entry ) {
+            push @comments, $_;
             next LINE;
         }
-        s/^\s+//;
+
+        # Get rid of leading/trailing whitespace in the message...
+
+        s/^\s+/ /;
+        s/\s+$/ /;
         $last_entry{message} .= $_;
     }
+
     chomp $last_entry{message} if ( $last_entry{message} );
     push @entries, { %last_entry };
     $self->{_entries} = \@entries;
+    $self->comments( join( "\n", @comments ) );
     return $self;
 }
 
@@ -89,7 +101,7 @@ sub _read_content {
     }
     my $changes_file = $self->_get_full_config_file;
     open( CHANGES, '<', $changes_file )
-                    || oi_error "Failed to open [$changes_file]: $!";
+                    || oi_error "Failed to open '$changes_file': $!";
     my @lines = <CHANGES>;
     close( CHANGES );
     return @lines;
@@ -101,23 +113,52 @@ sub _get_full_config_file {
     my ( $changes_file );
     if ( $self->source_package ) {
         my $package_dir = $self->source_package->directory;
-        $changes_file = File::Spec->catfile( $package_dir, CHANGES_FILE );
+        $changes_file = catfile( $package_dir, CHANGES_FILE );
     }
     elsif ( $self->source_dir ) {
-        $changes_file = File::Spec->catfile( $self->source_dir, CHANGES_FILE );
+        $changes_file = catfile( $self->source_dir, CHANGES_FILE );
     }
     elsif ( $self->source_file ) {
         $changes_file = $self->source_file;
     }
     unless ( -f $changes_file ) {
-        oi_error "Specified file [$changes_file] does not exist";
+        oi_error "Specified file '$changes_file' does not exist";
     }
     return $changes_file;
 }
 
+sub write_config {
+    my ( $self, $outfile ) = @_;
+    local $Text::Wrap::columns = 70;
+    if ( -f $outfile ) {
+        rename( $outfile, "$outfile.bak" )
+            || oi_error "Cannot rename '$outfile' to backup: $!";
+    }
+    open( OUT, '>', $outfile )
+        || oi_error "Cannot write to '$outfile': $!";
+    if ( my $comments = $self->comments ) {
+        print OUT $comments, "\n";
+    }
+    foreach my $entry ( $self->entries ) {
+        print OUT $entry->{version}, '  ', $entry->{date}, "\n\n";
+        if ( $entry->{message} ) {
+            my $msg = $entry->{message};
+            $msg =~ s/^\s+//;
+            print OUT wrap( '      ', '      ', $msg ), "\n\n";
+        }
+    }
+}
+
 
 ########################################
-# RETRIEVE ENTRIES
+# MANIPULATE ENTRIES
+
+sub add_entry {
+    my ( $self, $version, $date, $message ) = @_;
+    unshift @{ $self->{_entries} }, { version => $version,
+                                      date    => $date,
+                                      message => $message };
+}
 
 sub entries {
     return @{ $_[0]->{_entries} };
@@ -152,11 +193,15 @@ sub before {
 sub _version_check {
     my ( $self, $version ) = @_;
     unless ( $version and $version =~ /^\d+\.\d+$/ ) {
-        oi_error "Version argument [$version] is invalid";
+        oi_error "Version argument '$version' is invalid, it ",
+                 "should match '\\d+\\.\\d+'";
     }
     return $version;
 }
 
+########################################
+# OTHER INFO
+
 1;
 
 __END__
@@ -213,7 +258,7 @@ A changelog looks something like this:
  
  0.08   Fri Mar 14 23:09:11 EDT 2003
  
-        Fix bug in frobnicator so it doesn't blow up whenever a value
+        Fix bug in frobnicator so it does not blow up whenever a value
         greater than 500 passed in...
 
 The parser assumes this format. The date can be formatted any way you
@@ -221,11 +266,11 @@ like, but we assume that something looking like a version at the
 beginning of a line marks a new entry.
 
 The only required piece of information for an entry is a version --
-some people may not add the date, or if they're going through a lot of
-changes quickly may not add a message for each version.
+some people may not add the date, or if they are going through a lot
+of changes quickly may not add a message for each version.
 
-BTW: Yes, it's not B<really> a configuration file. But it mostly fits,
-and it doesn't make sense to put this into
+BTW: Yes, it is not B<really> a configuration file. But it mostly
+fits, and it does not make sense to put this into
 L<OpenInteract2::Package|OpenInteract2::Package> and bulk that package
 up even more.
 
@@ -272,13 +317,21 @@ C<source_dir>, C<source_file> or C<source_content> properties.
 
 Returns: object
 
+B<write_config( $filename )>
+
+Writes out changelog to C<$filename>. Only preserves comments/text
+found before the first version.
+
+Throws exception if there is an error writing to the file or if
+C<$filename> already exists and we cannot rename it to a backup.
+
 =head2 Properties
 
 These properties only describe from where we get the changelog. If you
 pass them into C<new()>, you can remove the C<source_> from the
-beginning for brevity's sake.
+beginning for the sake of brevity.
 
-B<source_package>: We rely on the package to tell us whereits
+B<source_package>: We rely on the package to tell us where its
 directory is, then use the C<CHANGES_FILE> file in it.
 
 B<source_dir>: Find the file C<CHANGES_FILE> in it.
@@ -291,7 +344,7 @@ B<source_content>: Use this as the changelog.
 
 The following methods return entries from the changelog. Methods that
 return multiple entries B<always return them in reverse order> -- the
-newest entries are first, or earliest in the array. Even when you're
+newest entries are first, or earliest in the array. Even when you are
 returning the earliest changelog entries (like with C<first()> or
 C<before()>), the B<latest> ones will still be at the front of the
 returned list.
@@ -341,13 +394,13 @@ B<before( $version )>
 Returns: array of entries that have a version number less than or
 equal to C<$version>.
 
-=head1 BUGS
+=head2 Adding Changelog Entries
 
-None known.
+B<add_entry( $version, $date, $message )>
 
-=head1 TO DO
-
-Nothing known.
+Adds entry with changelog information to the internal list. This
+always puts the entry at the head of the list, assuming it is a new
+version.
 
 =head1 COPYRIGHT
 
