@@ -1,6 +1,6 @@
 package OpenInteract2::Config::PerlFile;
 
-# $Id: PerlFile.pm,v 1.5 2003/06/24 03:35:38 lachoy Exp $
+# $Id: PerlFile.pm,v 1.7 2004/02/18 05:25:27 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Config );
@@ -11,11 +11,13 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Config::PerlFile::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Config::PerlFile::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+
+my ( $log );
 
 sub read_config {
     my ( $class, $params ) = @_;
-    my $log = get_logger( LOG_CONFIG );
+    $log ||= get_logger( LOG_CONFIG );
 
     my ( $raw_config );
 
@@ -56,7 +58,7 @@ sub read_config {
 
 sub save_config {
     my ( $self, $filename ) = @_;
-    my $log = get_logger( LOG_CONFIG );
+    $log ||= get_logger( LOG_CONFIG );
 
     # TODO: Where does {config_file} property come from? should we set
     # it in read_config?
@@ -137,11 +139,11 @@ L<OpenInteract2::Config|OpenInteract2::Config>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2001-2003 Chris Winters. All rights reserved.
+Copyright (c) 2001-2004 Chris Winters. All rights reserved.
 
 This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
+Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
