@@ -1,6 +1,6 @@
 package OpenInteract2::ContentGenerator::TT2Process;
 
-# $Id: TT2Process.pm,v 1.18 2004/02/18 05:25:27 lachoy Exp $
+# $Id: TT2Process.pm,v 1.20 2004/11/28 01:02:50 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::ContentGenerator );
@@ -16,7 +16,7 @@ use OpenInteract2::TT2::Plugin;
 use OpenInteract2::TT2::Provider;
 use Template;
 
-$OpenInteract2::ContentGenerator::TT2Process::VERSION  = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::ContentGenerator::TT2Process::VERSION  = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -80,9 +80,15 @@ sub generate {
     $self->_customize_template_variables( $template_name, $template_vars );
 
     my ( $html );
-    $template->process( $source, $template_vars, \$html )
-        || oi_error "Cannot process template '$template_name': ",
-                    $template->error();
+    eval {
+        $template->process( $source, $template_vars, \$html )
+            || die "Cannot process template '$template_name': ",
+                   $template->error(), "\n";
+    };
+    if ( $@ ) {
+        $log->error( "Failed to process template '$template_name': $@" );
+        return $@;
+    }
     $log->is_info &&
         $log->info( "Processed template '$template_name' ok" );
     return $html;
@@ -182,7 +188,13 @@ sub _init_tt_config {
                         ? $init_params->{cache_size}
                         : DEFAULT_CACHE_SIZE;
     my $compile_ext = $init_params->{compile_ext} || DEFAULT_COMPILE_EXT;
-    my $compile_dir = CTX->lookup_directory( 'cache_tt' );
+
+    # Since we've moved the cache configuration give a default
+
+    my $base_compile_dir = $init_params->{compile_dir} || 'cache/tt';
+    my $compile_dir = File::Spec->catdir(
+        CTX->lookup_directory( 'website' ), $base_compile_dir
+    );
 
     # If the compile_dir isn't specified, be sure to set it **and**
     # the extension to undef, otherwise TT will try to compile/save
@@ -195,10 +207,12 @@ sub _init_tt_config {
     }
 
     $self->{_plugin_class}{OI} = 'OpenInteract2::TT2::Plugin';
-    return { PLUGINS     => { OI => 'OpenInteract2::TT2::Plugin' },
-             CACHE_SIZE  => $cache_size,
-             COMPILE_DIR => $compile_dir,
-             COMPILE_EXT => $compile_ext };
+    return {
+        PLUGINS     => { OI => 'OpenInteract2::TT2::Plugin' },
+        CACHE_SIZE  => $cache_size,
+        COMPILE_DIR => $compile_dir,
+        COMPILE_EXT => $compile_ext
+    };
 }
 
 
@@ -514,4 +528,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
