@@ -1,14 +1,15 @@
 package OpenInteract2::ContentGenerator::TemplateSource;
 
-# $Id: TemplateSource.pm,v 1.11 2004/02/18 05:25:27 lachoy Exp $
+# $Id: TemplateSource.pm,v 1.12 2004/12/05 21:02:08 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
+use OpenInteract2::SiteTemplate;
 
-$OpenInteract2::ContentGenerator::TemplateSource::VERSION  = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::ContentGenerator::TemplateSource::VERSION  = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -91,7 +92,7 @@ sub identify {
 
 sub load_source {
     my ( $class, $name ) = @_;
-    my $content_template = CTX->lookup_class( 'template' )->fetch( $name );
+    my $content_template = OpenInteract2::SiteTemplate->fetch( $name );
     unless ( $content_template ) {
        oi_error "Template with name [$name] not found.";
     }
@@ -223,4 +224,4 @@ Copyright (c) 2002-2004 Chris Winters. All rights reserved.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
