@@ -1,22 +1,23 @@
 package OpenInteract2::Context;
 
-# $Id: Context.pm,v 1.56 2004/03/19 03:04:23 lachoy Exp $
+# $Id: Context.pm,v 1.78 2004/12/05 21:10:32 lachoy Exp $
 
 use strict;
 use base                     qw( Exporter Class::Accessor::Fast );
 use Data::Dumper             qw( Dumper );
+use DateTime;
+use DateTime::TimeZone;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
-use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Log       qw( uchk );
 
-$OpenInteract2::Context::VERSION   = sprintf("%d.%02d", q$Revision: 1.56 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Context::VERSION   = sprintf("%d.%02d", q$Revision: 1.78 $ =~ /(\d+)\.(\d+)/);
 
 use constant DEFAULT_TEMP_LIB_DIR => 'templib';
 
-my ( $log_spops, $log_act );
+my ( $log_spops, $log_act, $log_init );
 
-sub version { return '1.99_04' }
+sub version { return '1.99_05' }
 
 # Exportable deployment URL call -- main, images, static
 
@@ -38,17 +39,18 @@ sub CTX { return $CTX }
      CTX DEPLOY_URL DEPLOY_IMAGE_URL DEPLOY_STATIC_URL
 );
 
+require OpenInteract2::Config;
 require OpenInteract2::Config::Base;
 require OpenInteract2::DatasourceManager;
-require OpenInteract2::Filter;
+require OpenInteract2::Observer;
 require OpenInteract2::Request;
 require OpenInteract2::Response;
-require OpenInteract2::Setup;
 require OpenInteract2::Action;
 require OpenInteract2::Controller;
+require OpenInteract2::Exception;
 
 my @CORE_FIELDS    = qw( base_config server_config repository packages cache
-                         datasource_manager );
+                         datasource_manager timezone timezone_object setup_class );
 my @REQUEST_FIELDS = qw( request response controller user group is_logged_in is_admin );
 __PACKAGE__->mk_accessors( @CORE_FIELDS, @REQUEST_FIELDS );
 
@@ -56,7 +58,7 @@ __PACKAGE__->mk_accessors( @CORE_FIELDS, @REQUEST_FIELDS );
 # CONSTRUCTOR AND INITIALIZATION
 
 # $item should be either a hashref of parameters (preferably with one
-# parameter 'website_dir') or an OI::Config::Base object
+# parameter 'website_dir') or an OI2::Config::Base object
 
 sub create {
     my ( $class, $item, $params ) = @_;
@@ -65,7 +67,10 @@ sub create {
     $params ||= {};
 
     my ( $website_dir );
-    $CTX = bless( {}, $class );
+
+    # Don't assign this to $CTX until after it's setup!
+    my $ctx = bless( {}, $class );
+
     my ( $base_config );
     if ( ref $item eq 'OpenInteract2::Config::Base' ) {
         $base_config = $item;
@@ -77,8 +82,9 @@ sub create {
                               website_dir => $item->{website_dir} })
         };
         if ( $@ ) {
-            oi_error "Cannot create base config object using website ",
-                     "directory '$item->{website_dir}': $@";
+            OpenInteract2::Exception->throw(
+                     "Cannot create base config object using website ",
+                     "directory '$item->{website_dir}': $@" );
         }
         $website_dir = $item->{website_dir};
     }
@@ -92,27 +98,34 @@ sub create {
         OpenInteract2::Log->init_screen;
     }
 
-    my $log_init = get_logger( LOG_INIT );
+    $log_init = get_logger( LOG_INIT );
 
     if ( $base_config ) {
-        $CTX->base_config( $base_config );
+        $ctx->base_config( $base_config );
         $log_init->is_debug && $log_init->debug( "Assigned base config ok" );
-        eval { $CTX->setup( $params ) };
+        eval { $ctx->setup( $params ) };
         if ( $@ ) {
-            $log_init->error( "Setup failed to run: $@" );
+            my $error = $@;
+            $CTX = undef;
+            $log_init->error( "Setup failed to run: $error" );
+            OpenInteract2::Exception->throw( $error );
         }
         else {
             $log_init->is_info && $log_init->info( "Setup ran ok" );
         }
     }
-    return $CTX;
+    return $CTX = $ctx
 }
 
 
 sub instance {
-    my ( $class ) = @_;
+    my ( $class, $no_exception ) = @_;
     return $CTX if ( $CTX );
-    oi_error "No context available; first call 'create()'";
+    if ( $no_exception ) {
+        return undef;
+    }
+    OpenInteract2::Exception->throw(
+        "No context available; first call 'create()'" );
 }
 
 
@@ -121,7 +134,6 @@ sub instance {
 sub setup {
     my ( $self, $params ) = @_;
     $params ||= {};
-    my $log_init = get_logger( LOG_INIT );
 
     my %skip = ();
     if ( $params->{skip} ) {
@@ -135,22 +147,55 @@ sub setup {
     unless ( $base_config and
              ref( $base_config ) eq 'OpenInteract2::Config::Base' ) {
         $log_init->error( "Cannot run setup() without base_config defined" );
-        oi_error "Cannot run setup() on context without a valid base ",
-                 "configuration object set";
+        OpenInteract2::Exception->throw(
+            "Cannot run setup() on context without a valid base ",
+            "configuration object set" );
     }
 
-    my $setup = OpenInteract2::Setup->new;
-    my $server_config = $setup->read_server_config;
-    $self->server_config( $server_config );
+    my $server_config = $self->_read_server_config;
     $log_init->is_info && $log_init->info( "Assigned server config ok" );
 
+    my $setup_class = $self->lookup_class( 'setup' );
+    $self->setup_class( $setup_class );
+    $log_init->is_info &&
+        $log_init->info( "Will use setup class '$setup_class'" );
+    eval "require $setup_class";
+    if ( $@ ) {
+        OpenInteract2::Exception->throw(
+            "Cannot require setup class '$setup_class': $@" );
+    }
+    $log_init->is_info &&
+        $log_init->info( "Required '$setup_class' ok; commencing setup" );
+
+    # go ahead and set the global context now... the other processes
+    # mostly just need access to the global configuration
+
+    $CTX = $self;
+
+    my $setup = $setup_class->new();
+    $setup->run_pre_process();
+
+    my $timezone = $server_config->{timezone};
+    unless ( $timezone ) {
+        $timezone = 'America/New_York';
+        $log_init->warn(
+            "No timezone set in server configuration! Please set the ",
+            "configuration key 'Global.timezone' to a valid ",
+            "DateTime::TimeZone value. (I'm going to be a cultural ",
+            "imperialist and assume '$timezone')."
+        );
+    }
+    my $timezone_object = DateTime::TimeZone->new( name => $timezone );
+    $self->timezone( $timezone );
+    $self->timezone_object( $timezone_object );
+
+    $log_init->is_info && $log_init->info( "Assigned timezone ok" );
+
     # Assign constants from server config to the context.
 
     $self->assign_deploy_url;
     $self->assign_deploy_image_url;
     $self->assign_deploy_static_url;
-    #$self->assign_request_type;
-    #$self->assign_response_type;
     $log_init->is_info &&
         $log_init->info( "Assigned constants from server config ok" );
 
@@ -159,6 +204,7 @@ sub setup {
         $skip{ 'initialize action' }++;
         $skip{ 'initialize spops' }++;
         $skip{ 'initialize controller' }++;
+        $skip{ 'initialize indexer' }++;
     }
     else {
         my $repository = $setup->read_repository;
@@ -169,11 +215,7 @@ sub setup {
         }
         $log_init->is_info &&
             $log_init->info( "Opened repository and read package definitions ok" );
-    }
-
-
-    unless ( $skip{ 'initialize temp lib' } ) {
-        $setup->create_temp_lib( $params );
+        $setup->create_temp_lib( $params, $skip{ 'initialize temp lib' } );
     }
 
     unless ( $skip{ 'initialize datasource' } ) {
@@ -184,12 +226,6 @@ sub setup {
         $setup->check_datasources();
     }
 
-    unless ( $skip{ 'initialize observer' } ) {
-        $setup->initialize_observers;
-        $log_init->is_info &&
-            $log_init->info( "Initialized observers ok" );
-    }
-
     if ( $skip{ 'initialize action' } ) {
         $skip{ 'initialze controller' }++;
     }
@@ -215,11 +251,21 @@ sub setup {
         $log_init->is_info && $log_init->info( "Assigned SPOPS table ok" );
     }
 
+    unless ( $skip{ 'initialize observer' } ) {
+        $setup->initialize_observers;
+        $log_init->is_info &&
+            $log_init->info( "Initialized observers ok" );
+    }
+
     unless ( $skip{ 'initialize messages' } ) {
         $setup->read_localized_messages;
         $log_init->is_info && $log_init->info( "Read localized messages ok" );
     }
 
+    unless ( $skip{ 'initialize indexer' } ) {
+        $setup->initialize_indexers;
+    }
+
     # Not optional...
 
     my $system_classes = $setup->read_system_classes;
@@ -227,6 +273,13 @@ sub setup {
         $log_init->info( "Required system classes ok: ",
                     join( ', ', @{ $system_classes } ) );
 
+    # Also not optional...
+
+    $setup->register_in_factory(
+        $server_config->{request}, 'OpenInteract2::Request' );
+    $setup->register_in_factory(
+        $server_config->{response}, 'OpenInteract2::Response' );
+
     unless ( $skip{ 'initialize session' } ) {
         $setup->require_session_classes( $server_config->{session_info} );
     }
@@ -254,10 +307,43 @@ sub setup {
             $log_init->info( "Initialized controller and default actions ok" );
     }
 
+    $setup->run_post_process();
+
     $log_init->is_debug && $log_init->info( "Initialized context ok" );
     return $self;
 }
 
+########################################
+# SERVER CONFIG
+
+# Just grab the config and set the runtime info.
+
+sub _read_server_config {
+    my ( $self ) = @_;
+    my $base_config = $self->base_config;
+    unless ( ref $base_config eq 'OpenInteract2::Config::Base' ) {
+        OpenInteract2::Exception->new(
+            "'base_config' property of context not set properly" );
+    }
+    my $server_config_file = $base_config->get_server_config_file;
+    unless ( $server_config_file ) {
+        OpenInteract2::Exception->new(
+            "Cannot read server configuration: file not defined ",
+            "in base config" );
+    }
+    my $config_type = $base_config->config_type;
+    $log_init->is_info &&
+        $log_init->info( "Trying to read '$config_type' file '$server_config_file'" );
+    my $server_conf = OpenInteract2::Config->new(
+        $config_type, { filename => $server_config_file } );
+    $log_init->is_info && $log_init->info( "Read server config ok" );
+    $server_conf->{dir}{website} = $base_config->website_dir;
+    $server_conf->translate_dirs;
+    $log_init->is_info &&
+        $log_init->info( "Translated server config directories ok" );
+    return $self->server_config( $server_conf );
+}
+
 
 ########################################
 # CONFIGURATION ASSIGNMENTS
@@ -272,13 +358,14 @@ sub setup {
 
 sub assign_deploy_url {
     my ( $self, $url ) = @_;
-    my $log_init = get_logger( LOG_INIT );
+
     $url ||= $self->server_config->{context_info}{deployed_under};
     $url = $self->_clean_deploy_url( $url );
     if ( $url and $url !~ m|^/| ) {
-        oi_error "Deployment URL must begin with a '/'. It may not ",
-                 "be a fully-qualified URL (e.g., 'http://foo.com/') ",
-                 "and it may not be a purely relative URL (e.g., 'oi')";
+        OpenInteract2::Exception->throw(
+            "Deployment URL must begin with a '/'. It may not ",
+            "be a fully-qualified URL (e.g., 'http://foo.com/') ",
+            "and it may not be a purely relative URL (e.g., 'oi')" );
     }
     $DEPLOY_URL = $url;
     $self->server_config->{context_info}{deployed_under} = $url;
@@ -288,7 +375,7 @@ sub assign_deploy_url {
 
 sub assign_deploy_image_url {
     my ( $self, $url ) = @_;
-    my $log_init = get_logger( LOG_INIT );
+
     $url ||= $self->server_config->{context_info}{deployed_under_image};
     $url = $self->_clean_deploy_url( $url );
     $DEPLOY_IMAGE_URL = $url;
@@ -300,7 +387,7 @@ sub assign_deploy_image_url {
 
 sub assign_deploy_static_url {
     my ( $self, $url ) = @_;
-    my $log_init = get_logger( LOG_INIT );
+
     $url ||= $self->server_config->{context_info}{deployed_under_static};
     $url = $self->_clean_deploy_url( $url );
     $DEPLOY_STATIC_URL = $url;
@@ -323,7 +410,7 @@ sub _clean_deploy_url {
 
 sub assign_request_type {
     my ( $self, $type ) = @_;
-    my $log_init = get_logger( LOG_INIT );
+
     $type ||= $self->server_config->{context_info}{request};
     $self->server_config->{context_info}{request} = $type;
     OpenInteract2::Request->set_implementation_type( $type );
@@ -334,7 +421,7 @@ sub assign_request_type {
 
 sub assign_response_type {
     my ( $self, $type ) = @_;
-    my $log_init = get_logger( LOG_INIT );
+
     $type ||= $self->server_config->{context_info}{response};
     $self->server_config->{context_info}{response} = $type;
     OpenInteract2::Response->set_implementation_type( $type );
@@ -342,6 +429,30 @@ sub assign_response_type {
         $log_init->info( "Assigned response type '$type'" );
 }
 
+########################################
+# DATE FACTORY
+
+sub create_date {
+    my ( $self, $params ) = @_;
+    $params ||= {};
+    if ( $params->{year} ) {
+        return DateTime->new(
+            time_zone => $self->timezone_object,
+            %{ $params }
+        );
+    }
+    elsif ( $params->{epoch} ) {
+        return DateTime->from_epoch(
+            time_zone => $self->timezone_object,
+            epoch     => $params->{epoch},
+        );
+    }
+    else {
+        return DateTime->now(
+            time_zone => $self->timezone_object
+        );
+    }
+}
 
 ########################################
 # ACTION LOOKUP
@@ -350,12 +461,13 @@ sub lookup_action_name {
     my ( $self, $action_url ) = @_;
     $log_act ||= get_logger( LOG_ACTION );
     unless ( $action_url ) {
-        oi_error "Cannot lookup action without action name without URL";
+        OpenInteract2::Exception->throw(
+            "Cannot lookup action without action name without URL" );
     }
     $log_act->is_debug &&
         $log_act->debug( "Try to find action name for URL '$action_url'" );
     my $server_config = $self->server_config;
-    my $action_name = $server_config->{action_url}{ $action_url };
+    my $action_name = $server_config->{action_url}{ $action_url } || '';
     $log_act->is_debug &&
         $log_act->debug( "Found name '$action_name' for URL '$action_url'" );
     return $action_name;
@@ -367,7 +479,8 @@ sub lookup_action_info {
     unless ( $action_name ) {
         $log_act->error( "No action name given to lookup info; called ",
                          "from: ", join( ' | ', caller ) );
-        oi_error "Cannot lookup action without action name";
+        OpenInteract2::Exception->throw(
+            "Cannot lookup action without action name" );
     }
 
     $log_act->is_debug &&
@@ -380,7 +493,8 @@ sub lookup_action_info {
 
     unless ( $action_info ) {
         $log_act->error( "Action '$action_name' not found in action table" );
-        oi_error "Action '$action_name' not found in action table";
+        OpenInteract2::Exception->throw(
+            "Action '$action_name' not found in action table" );
     }
 
     $log_act->is_debug &&
@@ -412,7 +526,8 @@ sub lookup_action {
     my $action_info = $self->lookup_action_info( $action_name );
     unless ( $action_info ) {
         $log_act->error( "No action found for '$action_name'" );
-        oi_error "No action defined for '$action_name'";
+        OpenInteract2::Exception->throw(
+            "No action defined for '$action_name'" );
     }
     return OpenInteract2::Action->new( $action_info, $props );
 }
@@ -425,8 +540,9 @@ sub lookup_action_none {
     unless ( $action_info ) {
         $log_act->error( "Please define the server configuration entry ",
                          "under 'action_info.none'" );
-        oi_error "The 'none' item under 'action_info' is not defined. ",
-                 "Please check your server configuration.";
+        OpenInteract2::Exception->throw(
+            "The 'none' item under 'action_info' is not defined. ",
+            "Please check your server configuration." );
     }
     if ( my $action_name = $action_info->{redir} ) {
         return $self->lookup_action( $action_name );
@@ -442,8 +558,9 @@ sub lookup_action_not_found {
     unless ( $action_info ) {
         $log_act->error( "Please define the server configuration entry ",
                          "under 'action_info.not_found'" );
-        oi_error "The 'not_found' item under 'action_info' is not ",
-                 "defined. Please check your server configuration.";
+        OpenInteract2::Exception->throw(
+            "The 'not_found' item under 'action_info' is not ",
+            "defined. Please check your server configuration." );
     }
     if ( my $action_name = $action_info->{redir} ) {
         return $self->lookup_action( $action_name );
@@ -466,13 +583,14 @@ sub lookup_object {
     $log_spops ||= get_logger( LOG_SPOPS );
     unless ( $object_name ) {
         $log_spops->error( "Must lookup object class using name" );
-        oi_error "Cannot lookup object class without object name";
+        OpenInteract2::Exception->throw(
+            "Cannot lookup object class without object name" );
     }
     my $spops_config = $self->spops_config;
     unless ( $spops_config->{ lc $object_name } ) {
         my $msg = "No object class found for '$object_name'";
         $log_spops->error( $msg );
-        oi_error $msg;
+        OpenInteract2::Exception->throw( $msg );
     }
     my $use_name = lc $object_name;
 
@@ -499,6 +617,45 @@ sub lookup_controller_config {
     return $self->server_config->{controller};
 }
 
+########################################
+# FULLTEXT INDEXING LOOKUP
+
+sub lookup_fulltext_config {
+    my ( $self, $name ) = @_;
+    if ( $name ) {
+        return $self->server_config->{fulltext}{ $name };
+    }
+    return $self->server_config->{fulltext};
+}
+
+sub fulltext_indexer {
+    my ( $self, $indexer_name ) = @_;
+    $log_act ||= get_logger( LOG_ACTION );
+
+    my $all_config = $self->lookup_fulltext_config;
+    unless ( $indexer_name ) {
+        $indexer_name = $all_config->{default};
+        unless ( $indexer_name ) {
+            OpenInteract2::Exception->throw(
+                "No fulltext indexer defined in server configuration ",
+                "key 'fulltext.default'" );
+        }
+    }
+
+    $log_act->is_debug &&
+        $log_act->debug( "Fulltext indexer configured: $indexer_name" );
+    my $ft_config = $all_config->{ $indexer_name };
+    unless ( ref $ft_config eq 'HASH' ) {
+        OpenInteract2::Exception->throw(
+            "Fulltext indexer '$indexer_name' set in server ",
+            "configuration key 'fulltext.default' does not ",
+            "have corresponding configuration section." );
+    }
+
+    my $ft_class = $ft_config->{class};
+    return $ft_class->new( $ft_config );
+}
+
 ########################################
 # CONTENT GENERATOR LOOKUP
 
@@ -511,26 +668,31 @@ sub lookup_content_generator_config {
 }
 
 ########################################
-# FILTERS
+# OBSERVERS
 
-sub lookup_filter {
+sub lookup_observer {
     my ( $self, $name ) = @_;
     if ( $name ) {
-        return $self->{filters}{ $name };
+        return $self->{observers}{ $name };
     }
-    return $self->{filters};
+    return $self->{observers};
 }
 
-sub set_filter_registry {
+sub set_observer_registry {
     my ( $self, $registry ) = @_;
-    $self->{filters} = $registry;
+    $self->{observers} = $registry;
     return;
 }
 
-sub add_filter {
-    my ( $self, $filter_name, $filter_info ) = @_;
-    OpenInteract2::Filter->register_filter(
-            $filter_name, $filter_info, $self->{filters} );
+sub add_observer {
+    my ( $self, $observer_name, $observer_info ) = @_;
+    OpenInteract2::Observer->register_observer(
+            $observer_name, $observer_info, $self->{observers} );
+}
+
+sub map_observer {
+    my ( $self, $observer_name, $action_or_name ) = @_;
+    OpenInteract2::Observer->add_observer_to_action( $observer_name, $action_or_name );
 }
 
 ########################################
@@ -603,6 +765,11 @@ sub lookup_redirect_config {
     return $self->server_config->{redirect};
 }
 
+sub lookup_box_config {
+    my ( $self ) = @_;
+    return $self->server_config->{box};
+}
+
 ########################################
 # CLASS LOOKUP
 
@@ -629,12 +796,22 @@ sub action_table {
         $self->server_config->{action} = $table;
         my %url_to_name = ();
         while ( my ( $name, $info ) = each %{ $table } ) {
+            next if ( $info->{redir} );
             $log_act->is_debug &&
                 $log_act->debug( "Finding URL(s) for action '$name'" );
-            my $action = OpenInteract2::Action->new( $info );
-            my $respond_urls = $action->get_dispatch_urls;
-            $url_to_name{ $_ } = $name for ( @{ $respond_urls } );
-            $info->{url_primary} = $respond_urls->[0];
+            my $action = eval { OpenInteract2::Action->new( $info ) };
+            if ( $@ ) {
+                $log_act->error(
+                    "Failed to create action '$name' when assigned a new ",
+                    "set of action configurations. Will remove action data ",
+                    "from action table. Error: $@" );
+                delete $self->server_config->{action}->{ $name };
+            }
+            else {
+                my $respond_urls = $action->get_dispatch_urls;
+                $url_to_name{ $_ } = $name for ( @{ $respond_urls } );
+                $info->{url_primary} = $respond_urls->[0];
+            }
         }
         $self->server_config->{action_url} = \%url_to_name;
     }
@@ -796,6 +973,10 @@ OpenInteract2::Context - Provides the environment for a server
  # is to import it
  my $ctx = OpenInteract2::Context->instance;
  
+ # Get the context but don't throw an exception if it 
+ # doesn't exist yet, just return undef
+ my $ctx = OpenInteract2::Context->instance( 1 ); 
+
  # Get the information (\%) for the 'TT' content generator
  my $generator_info = CTX->lookup_content_generator_config( 'TT' );
 
@@ -893,12 +1074,15 @@ the context. (See properties C<repository> and C<packages>)
 
 =head2 Class Methods
 
-B<instance()>
+B<instance( [ $no_exception ] )>
 
 This is the method you will see many times when the object is not
 being imported, since it returns the current context. There is only
 one context object available at any one time. If the context has not
-yet been created (with C<create()>), throws an exception.
+yet been created (with C<create()>) then we either throw an exception
+if C<$no_exception> is false or return undef if C<$no_exception> is
+true. (Subclasses of L<OpenInteract2::Exception> should set
+C<$no_exception> to avoid an infinite loop...)
 
 Returns: L<OpenInteract2::Context|OpenInteract2::Context> object
 
@@ -955,7 +1139,7 @@ directory, C<setup()> will be called automatically.
 
 You can skip steps of the process by passing the step name in an
 arrayref 'skip' in C<\%params>. (You normally pass these to
-C<create()>.) This is most useful when you're creating a website for
+C<create()>.) This is most useful when you are creating a website for
 the first time.
 
 For instance, if you do not wish to activate the SPOPS objects:
@@ -1033,6 +1217,33 @@ Initialize the main controller with default actions. (Skip:
 
 Returns: the context object
 
+=head2 Object Methods: Date/Time
+
+B<timezone()>
+
+Returns the string from the server configuration key
+'Global.timezone'.
+
+B<timezone_object()>
+
+Returns a L<DateTime::TimeZone> object corresponding to the server
+configuration key 'Global.timezone'.
+
+B<create_date( \%params )>
+
+A factory for creating L<DateTime> objects using the C<timezone()>
+from the context. Any parameters in C<\%params> will be passed along
+to the L<DateTime> constructor (with one exception, see below) but if
+you do not specify a C<year> then we assume you want the current time
+and call the L<DateTime> C<now()> method.
+
+The exception: when you specify 'epoch' in C<\%params> we call the
+C<from_epoch()> method instead of the constructor.
+
+This is just a shortcut method and you instead may want to get the
+timezone from the context to create your own L<DateTime> objects. Up
+to you.
+
 =head2 Object Methods: Actions
 
 B<lookup_action( $action_name [, \%values )>
@@ -1040,7 +1251,7 @@ B<lookup_action( $action_name [, \%values )>
 Looks up the information for C<$action_name> in the action table and
 returns a L<OpenInteract2::Action|OpenInteract2::Action> object
 created from it. We also pass along C<\%values> as the second argument
-to C<new()> -- any properties found there will override what's in the
+to C<new()> -- any properties found there will override what is in the
 action table configuration, and any properties there will be set into
 the resulting object.
 
@@ -1221,23 +1432,28 @@ B<lookup_default_ldap_datasource_name()>
 
 Returns the datasource name in 'datasource_config.ldap'.
 
-=head2 Object Methods: Filters
+=head2 Object Methods: Observers
 
-B<lookup_filter( [ $name ] )>
+B<lookup_observer( [ $observer_name ] )>
 
-Returns filter mapped to C<$name>, or returns hashref of all
-name-to-filter pairs
+Returns observer mapped to C<$observer_name>, or returns hashref of
+all name-to-observer pairs
 
-B<set_filter_registry( \%registry )>
+B<set_observer_registry( \%registry )>
 
-Assigns a full filter registry to the context. The registry is a
-hashref of name-to-filter pairs.
+Assigns a full observer registry to the context. The registry is a
+hashref of name-to-observer pairs.
 
-B<add_filter( $name, \%info )>
+B<add_observer( $observer_name, \%info )>
 
-Shortcut to C<register_filter> method of
-L<OpenInteract2::Filter|OpenInteract2::Filter> that passes the
-context's filter registry as the last argument.
+Shortcut to C<register_observer()> method of
+L<OpenInteract2::Observer|OpenInteract2::Observer> that passes the
+context observer registry as the last argument.
+
+B<map_observer( $observer_name, $action_name )>
+
+Shortcut to C<add_observer_to_action()> method of
+L<OpenInteract2::Observer|OpenInteract2::Observer>.
 
 =head2 Object Methods: Controller
 
@@ -1272,10 +1488,30 @@ technology, like C<SOAP>.
 
 Returns: an object with a parent of
 L<OpenInteract2::ContentGenerator|OpenInteract2::ContentGenerator>.
-Generally you'd only call C<generate()> on it with the appropriate
+Generally you would only call C<generate()> on it with the appropriate
 parameters to get the generated content -- these are initialized in
 C<setup()>.
 
+=head2 Object Methods: Full-text Indexer
+
+B<lookup_fulltext_config( [ $indexer_name ] )>
+
+Returns the data (a hashref) associated with C<$indexer_name>. If you
+want the object associated with C<$indexer_name> use
+C<fulltext_indexer()>, below. If you do not provide C<$indexer_name>
+returns a hashref of all fulltext indexer information, keys as the
+indexer names and values as the data associated with them. There is
+also the additional key 'default' which holds the name of the default
+fulltext indexer.
+
+B<fulltext_indexer( [ $indexer_name ] )>
+
+Return the L<OpenInteract2::FullTextSearch> object associated with
+C<$indexer_name>. If C<$indexer_name> not provided it uses the value
+of the server configuration key 'fulltext.default'.
+
+Return: an object with the parent of L<OpenInteract2::FullTextSearch>.
+
 =head2 Object Methods: Deployment Context
 
 There are three separate deployment contexts used in OpenInteract2:
@@ -1408,14 +1644,14 @@ directory. This can be specified in the base configuration
 (C<conf/base.conf>) or a default (C<tmplib/>) is provided. Both are
 relative to the website directory.
 
-This method doesn't care of the directory exists or not, it just
+This method does not care of the directory exists or not, it just
 creates the name.
 
 Returns: fully-qualified directory
 
 B<lookup_temp_lib_refresh_filename()>
 
-Relative name of file in the temporary library directory that's used
+Relative name of file in the temporary library directory that is used
 (by L<OpenInteract2::Setup|OpenInteract2::Setup>) to identify whether
 the directory needs refreshed. Normally this is 'refresh.txt'.
 
@@ -1462,6 +1698,10 @@ B<lookup_redirect_config()>
 
 Looks up the redirect configuration.
 
+B<lookup_box_config()>
+
+Looks up the configuration for boxes, found in the 'box' section.
+
 =head1 PROPERTIES
 
 The following are simple get/set properties of the context object.
