@@ -1,6 +1,6 @@
 package OpenInteract2::Controller;
 
-# $Id: Controller.pm,v 1.21 2004/05/22 14:47:53 lachoy Exp $
+# $Id: Controller.pm,v 1.23 2004/09/26 23:52:42 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor::Fast Class::Factory );
@@ -9,7 +9,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Controller::VERSION  = sprintf("%d.%02d", q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Controller::VERSION  = sprintf("%d.%02d", q$Revision: 1.23 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -47,7 +47,8 @@ sub new {
     # action but I don't want to create a framework without any use
     # cases...
 
-    # Add a filter at runtime to the main action. So you could do:
+    # Add a filter (observer) at runtime to the main action. So you
+    # could do:
     #
     # /news/display/?news_id=55&OI_FILTER=pittsburghese
     #
@@ -61,7 +62,7 @@ sub new {
     my @filter_add = $request->param( 'OI_FILTER' );
     if ( scalar @filter_add ) {
         foreach my $filter_name ( @filter_add ) {
-            OpenInteract2::Filter->add_filter_to_action( $filter_name, $action );
+            CTX->map_observer( $filter_name, $action );
         }
     }
 
@@ -106,7 +107,7 @@ sub _find_action {
         };
         if ( $@ ) {
             $log->warn( "Caught exception from Context trying to lookup ",
-                        "action [$action_name]: $@\nUsing action ",
+                        "action '$action_name': $@\nUsing action ",
                         "specified for 'notfound'" );
             $action = $NOTFOUND_ACTION->clone();
         }
@@ -117,7 +118,7 @@ sub _find_action {
     else {
         $log->is_debug &&
             $log->debug( "Using action specified for 'none': ",
-                         "[", $NONE_ACTION->name, "]" );
+                         "'", $NONE_ACTION->name, "'" );
         $action = $NONE_ACTION->clone();
     }
     $log->is_debug &&
