@@ -1,6 +1,6 @@
 package OpenInteract2::Controller::MainTemplate;
 
-# $Id: MainTemplate.pm,v 1.6 2004/05/22 14:47:13 lachoy Exp $
+# $Id: MainTemplate.pm,v 1.7 2004/06/02 20:13:25 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Controller
@@ -11,11 +11,11 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Controller::MainTemplate::VERSION  = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Controller::MainTemplate::VERSION  = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
-my @FIELDS = qw( no_template main_template_key page_title );
+my @FIELDS = qw( no_template main_template main_template_key page_title );
 __PACKAGE__->mk_accessors( @FIELDS );
 
 sub init {
@@ -27,19 +27,14 @@ sub init {
     $self->init_templates;
 }
 
-# TODO: Remove this when themes up
-sub main_template {
-    return 'base_main';
-}
-
 sub execute {
     my ( $self ) = @_;
     $log ||= get_logger( LOG_ACTION );
 
     my $action = $self->initial_action;
     $log->is_debug &&
-        $log->debug( "Executing top-level action [", $action->name, "] ",
-                     "with task [", $action->task, "]" );
+        $log->debug( "Executing top-level action '", $action->name, "' ",
+                     "with task '", $action->task, "'" );
 
     my $content = eval { $action->execute };
     if ( $@ ) {
@@ -54,7 +49,7 @@ sub execute {
 
     if ( my $send_file = CTX->response->send_file ) {
         $log->is_info &&
-            $log->info( "Action specified return file [$send_file]" );
+            $log->info( "Action specified return file '$send_file'" );
         return;
     }
 
@@ -74,12 +69,19 @@ sub execute {
     $self->add_content_param( content => $content );
 
     my $template_name = $self->main_template;
-    unless ( $template_name ) {
+    if ( $template_name ) {
+        $log->is_info &&
+            $log->info( "Using main template name '$template_name'  as ",
+                        "set directly in controller" );
+    }
+    else {
         my $template_key = $self->main_template_key || 'main_template';
-        $template_name = $self->request->theme_values->{ $template_key };
+        $template_name = CTX->request->theme_values->{ $template_key };
+        $log->is_info &&
+            $log->info( "Assigned main template name '$template_name' ",
+                        "using the template key '$template_key' from ",
+                        "theme with ID '", CTX->request->theme->id, "'" );
     }
-    $log->is_debug &&
-        $log->debug( "Using full page template [$template_name]" );
 
     my $generator = CTX->content_generator( $self->generator_type );
     my $full_content = eval {
