@@ -1,6 +1,6 @@
 package OpenInteract2::DatasourceManager;
 
-# $Id: DatasourceManager.pm,v 1.14 2004/02/18 05:25:26 lachoy Exp $
+# $Id: DatasourceManager.pm,v 1.16 2004/11/09 13:49:37 sjn Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
@@ -8,7 +8,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::DatasourceManager::VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::DatasourceManager::VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -34,6 +34,9 @@ sub datasource {
 
     if ( $log->is_debug ) {
         my @call_info = caller(2);
+        unless ( $call_info[0] ) {
+            @call_info = caller(1);
+        }
         $log->debug( "Trying to find datasource '$ds_name' from ",
                       join( ' - ', $call_info[0], $call_info[3], $call_info[2] ) );
     }
@@ -44,6 +47,7 @@ sub datasource {
     if ( $connection ) {
         my $rv = eval { $connection->ping };
         if ( $@ or ! $rv ) {
+            $rv = "undef()" unless defined $rv;
             $log->warn( "Cannot ping connection '$ds_name': [Error: $@] ",
                         "[Return: $rv]; will try to reopen..." );
         }
@@ -289,4 +293,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
