@@ -1,17 +1,20 @@
 package OpenInteract2::Exception::Security;
 
-# $Id: Security.pm,v 1.6 2004/02/18 05:25:28 lachoy Exp $
+# $Id: Security.pm,v 1.10 2004/06/11 13:01:51 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Exception Class::Accessor::Fast );
+use OpenInteract2::Context qw( CTX );
 use SPOPS::Secure qw( :verbose :level );
 
-$OpenInteract2::Exception::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Exception::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
 
 my @FIELDS = qw( security_required security_found );
 OpenInteract2::Exception::Security->mk_accessors( @FIELDS );
 sub Fields { return @FIELDS }
 
+my $DEFAULT_MSG = "Security violation. Object requires '%s' but got '%s'";
+
 my %LEVELS = (
    SEC_LEVEL_NONE()    => SEC_LEVEL_NONE_VERBOSE,
    SEC_LEVEL_SUMMARY() => SEC_LEVEL_SUMMARY_VERBOSE,
@@ -21,13 +24,25 @@ my %LEVELS = (
 
 sub full_message {
     my ( $self ) = @_;
-    my $req = ( $self->security_required )
-                ? $LEVELS{ $self->security_required }
-                : 'none specified';
-    my $fnd = ( $self->security_found )
-                ? $LEVELS{ $self->security_found }
-                : 'none specified';
-    return "Security violation. Object requires [$req] but got [$fnd]";
+    my $required = ( $self->security_required )
+                     ? $LEVELS{ $self->security_required }
+                     : 'none specified';
+    my $found = ( $self->security_found )
+                  ? $LEVELS{ $self->security_found }
+                  : 'none specified';
+
+    my ( $msg );
+    if ( CTX && CTX->request ) {
+        $msg = eval {
+            CTX->request
+               ->language_handle
+                ->maketext( 'global.exception.security', $required, $found );
+        };
+    }
+    unless ( $msg ) {
+        $msg = sprintf( $DEFAULT_MSG, $required, $found );
+    }
+    return $msg;
 }
 
 1;
