@@ -1,11 +1,23 @@
 package OpenInteract2::Log;
 
-# $Id: Log.pm,v 1.4 2003/08/22 03:02:46 lachoy Exp $
+# $Id: Log.pm,v 1.6 2004/03/16 21:00:18 lachoy Exp $
 
 use strict;
+use base qw( Exporter );
 use Log::Log4perl qw( :levels get_logger );
 use Log::Log4perl::Appender;
 
+@OpenInteract2::Log::EXPORT_OK = qw( uchk );
+
+# Create a logging message by treating the first argument as a sprintf
+# string and the remainder of the arguments as the parameters to set,
+# each of which will be undef-tested before processing
+
+sub uchk {
+    my ( $msg, @args ) = @_;
+    return sprintf( $msg, map { ( defined $_ ) ? $_ : '' } @args );
+}
+
 my $DEFAULT_LEVEL     = $WARN;
 my $DEFAULT_CONF_FILE = 'log4perl.conf';
 
@@ -114,7 +126,7 @@ is used.
 
 =head1 COPYRIGHT
 
-Copyright (c) 2002-2003 Chris Winters. All rights reserved.
+Copyright (c) 2002-2004 Chris Winters. All rights reserved.
 
 =head1 AUTHORS
 
