@@ -1,6 +1,6 @@
 package OpenInteract2::Manage;
 
-# $Id: Manage.pm,v 1.38 2004/05/22 01:56:03 lachoy Exp $
+# $Id: Manage.pm,v 1.41 2004/11/09 13:49:37 sjn Exp $
 
 use strict;
 use base qw( Exporter Class::Factory Class::Observable );
@@ -13,7 +13,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error oi_param_error );
 use OpenInteract2::Setup;
 
-$OpenInteract2::Manage::VERSION = sprintf("%d.%02d", q$Revision: 1.38 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::VERSION = sprintf("%d.%02d", q$Revision: 1.41 $ =~ /(\d+)\.(\d+)/);
 
 my $SYSTEM_PACKAGES = [
     qw/ base       base_box        base_error    base_group
@@ -377,10 +377,12 @@ sub all_parameters_long_options {
     my $all_params = $class->all_parameters;
     my @opt = ();
     while ( my ( $name, $info ) = each %{ $all_params } ) {
-        if ( $info->{is_boolean} eq 'yes' ) {
+        if ( defined $info->{is_boolean} and
+             $info->{is_boolean} eq 'yes' ) {
             push @opt, $name;
         }
-        elsif ( $info->{is_multivalued} eq 'yes' ) {
+        elsif ( defined $info->{is_multivalued} and
+                $info->{is_multivalued} eq 'yes' ) {
             push @opt, "$name=s@";
         }
         else {
@@ -451,7 +453,7 @@ sub merge_status_by_action {
         unless ( $current_action ) {
             $current_action = $s->{action};
         }
-        if ( $s->{action} ne $current_action ) {
+        if ( defined $s->{action} and $s->{action} ne $current_action ) {
             push @new_status, { action => $current_action,
                                 status => [ @tmp_status ] };
             @tmp_status = ();
@@ -466,6 +468,27 @@ sub merge_status_by_action {
     return @new_status;
 }
 
+# shortcut for adding bad/good status
+
+sub _fail {
+    my ( $self, $action, $msg, %additional ) = @_;
+    $self->_add_status({ is_ok    => 'no',
+                         action   => $action,
+                         message  => $msg,
+                         %additional });
+    return;
+}
+
+sub _ok {
+    my ( $self, $action, $msg, %additional ) = @_;
+    $self->_add_status({ is_ok    => 'yes',
+                         action   => $action,
+                         message  => $msg,
+                         %additional });
+    return;
+}
+
+
 
 ########################################
 # INFRASTRUCTURE (SUBCLASSES)
@@ -485,6 +508,48 @@ sub _setup_context {
     OpenInteract2::Context->create( $base_config, @params );
 }
 
+# Creates status entry with all files removed/skipped/updated
+
+sub _create_sync_status {
+    my ( $self, $dirsync, $dir ) = @_;
+    my %status = ();
+    my @failed = $dirsync->entries_failed;
+    if ( scalar @failed ) {
+        %status = ( is_ok   => 'no',
+                    message => "Following files from $dir had failures: " .
+                               join( ', ', @failed ) );
+    }
+    else {
+        %status = ( is_ok   => 'yes',
+                    message => "Mirrored $dir directory ok" );
+    }
+    my @updated = $dirsync->entries_updated;
+    if ( scalar @updated ) {
+        $status{updated} = "Updated items: " . join( ', ', @updated );
+    }
+    else {
+        $status{updated} = 'No items updated';
+    }
+
+    my @removed = $dirsync->entries_removed;
+    if ( scalar @removed ) {
+        $status{removed} = "Removed items: " . join( ', ', @removed );
+    }
+    else {
+        $status{removed} = 'No items removed';
+    }
+
+    my @skipped = $dirsync->entries_skipped;
+    if ( scalar @skipped ) {
+        $status{skipped} = "Skipped items: " . join( ', ', @skipped );
+    }
+    else {
+        $status{skipped} = 'No items skipped';
+    }
+    return \%status;
+}
+
+
 ########################################
 # FACTORY
 
