@@ -1,11 +1,11 @@
 package OpenInteract2::Manage::Package::CreatePackage;
 
-# $Id: CreatePackage.pm,v 1.12 2004/02/17 04:30:20 lachoy Exp $
+# $Id: CreatePackage.pm,v 1.13 2004/06/13 18:19:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Package );
 
-$OpenInteract2::Manage::Package::CreatePackage::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Package::CreatePackage::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 # METADATA
 
@@ -62,14 +62,13 @@ sub run_task {
         chdir( $self->param( 'package_dir' ) );
     }
     my $package_name = $self->param( 'package' )->[0];
-    my $package = OpenInteract2::Package->create_skeleton(
-                         { name       => $package_name,
-                           sample_dir => $self->param( 'sample_dir' ) });
-    my $msg = sprintf( 'Package %s created ok in %s', $package->name,
-                                                      $package->directory );
-    $self->_add_status( { is_ok   => 'yes',
-                          action  => "Create package $package_name",
-                          message => $msg } );
+    my $package = OpenInteract2::Package->create_skeleton({
+        name       => $package_name,
+        sample_dir => $self->param( 'sample_dir' )
+    });
+    my $msg = sprintf( 'Package %s created ok in %s',
+                       $package->name, $package->directory );
+    $self->_ok( "create package $package_name", $msg );
     return;
 }
 
@@ -94,9 +93,9 @@ OpenInteract2::Manage::Package::CreatePackage - Create a sample package
  my $package_name = 'dev_package';
  my $source_dir   = '/home/httpd/OpenInteract-2.0';
  my $task = OpenInteract2::Manage->new(
-                      'create_package', { package_dir => $package_dir,
-                                          source_dir  => $source_dir,
-                                          package     => $package_name } );
+     'create_package', { package_dir => $package_dir,
+                         source_dir  => $source_dir,
+                         package     => $package_name } );
  my @status = $task->execute;
  foreach my $s ( @status ) {
      print "Action:    $s->{action}\n",
