@@ -1,13 +1,13 @@
 package OpenInteract2::Manage::Package::Export;
 
-# $Id: Export.pm,v 1.11 2004/02/17 04:30:20 lachoy Exp $
+# $Id: Export.pm,v 1.12 2004/06/13 18:19:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Package );
 use Cwd qw( cwd );
-use File::Spec;
+use File::Spec::Functions qw( catdir );
 
-$OpenInteract2::Manage::Package::Export::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Package::Export::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 # METADATA
 
@@ -91,31 +91,26 @@ sub _read_package_dirs {
     my ( $self, $base_package_dir, $package_names ) = @_;
     eval { opendir( PKGDIR, $base_package_dir )  || die $! };
     if ( $@ ) {
-        $self->_add_status( { is_ok   => 'no',
-                              action  => 'read packages from directory',
-                              message => "Cannot open directory: $@" } );
+        $self->_fail( 'read packages from directory',
+                      "Cannot open directory: $@" );
         return ();
     }
     my @dirs_in_base = grep ! /^\./,
-                       grep { -d File::Spec->catdir( $base_package_dir, $_ ) }
+                       grep { -d catdir( $base_package_dir, $_ ) }
                        readdir( PKGDIR );
     my @export_dirs = ();
 PACKAGE:
     foreach my $package_name ( @{ $package_names } ) {
-        my $target_dir = File::Spec->catdir( $base_package_dir,
-                                             $package_name );
+        my $target_dir = catdir( $base_package_dir, $package_name );
         unless ( -d $target_dir ) {
             my @matching = grep /^$package_name-\-\d/, @dirs_in_base;
             unless ( scalar @matching ) {
                 my $msg = "Cannot find directory for $package_name in " .
                           "$base_package_dir";
-                $self->_add_status({ is_ok   => 'no',
-                                     action  => 'match package to directory',
-                                     message => $msg });
+                $self->_fail( 'match package to directory', $msg );
                 next PACKAGE;
             }
-            $target_dir = File::Spec->catdir( $base_package_dir,
-                                              $matching[0] );
+            $target_dir = catdir( $base_package_dir, $matching[0] );
         }
         push @export_dirs, $target_dir;
     }
@@ -141,7 +136,7 @@ OpenInteract2::Manage::Package::Export - Export a package into a portable format
  
  my $package_dir = '/home/me/work/pkg/mypkg';
  my $task = OpenInteract2::Manage->new(
-                      'export_package', { package_dir => $package_dir } );
+     'export_package', { package_dir => $package_dir } );
  my ( $status ) = $task->execute;
  print "Exported ok? $status->{is_ok}\n",
        "Filename:    $status->{filename}\n",
