@@ -1,15 +1,14 @@
 package OpenInteract2::Manage::Website;
 
-# $Id: Website.pm,v 1.18 2004/05/22 01:58:42 lachoy Exp $
+# $Id: Website.pm,v 1.21 2004/12/05 18:50:11 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage );
-use File::Spec;
-use OpenInteract2::Config::Readonly;
+use File::Spec::Functions    qw( catdir catfile );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Package   qw( DISTRIBUTION_EXTENSION );
 
-$OpenInteract2::Manage::Website::VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::VERSION = sprintf("%d.%02d", q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/);
 
 sub setup_task {
     my ( $self ) = @_;
@@ -56,9 +55,9 @@ PACKAGE:
         my $package_file = $package_dist->{ $package_name };
         return unless ( $package_file );
         my $install_task = OpenInteract2::Manage->new(
-                                        'install_package',
-                                        { package_file => $package_file,
-                                          website_dir  => $website_dir } );
+            'install_package', { package_file => $package_file,
+                                 website_dir  => $website_dir }
+        );
 
         # The package install fires a 'progress' observation that it's done
         # installing the package, which is useful for *our* observers
@@ -68,10 +67,8 @@ PACKAGE:
 
         eval { $install_task->execute };
         if ( $@ ) {
-            $self->_add_status(
-                    { is_ok   => 'no',
-                      action  => 'install package',
-                      message => "Failed to install $package_name: $@" } );
+            $self->_fail( 'install package',
+                          "Failed to install $package_name: $@" );
         }
         else {
             $self->_add_status( $install_task->get_status );
@@ -94,7 +91,7 @@ sub _match_system_packages {
     # the filename of the package distributed
 
     my $ext = DISTRIBUTION_EXTENSION;
-    my $package_dir = File::Spec->catdir( $dir, 'pkg' );
+    my $package_dir = catdir( $dir, 'pkg' );
     eval { opendir( PKG, $package_dir ) || die $! };
     if ( $@ ) {
         oi_error "Cannot open package dir [$dir/pkg/] for reading: $@";
@@ -105,7 +102,7 @@ sub _match_system_packages {
     foreach my $package_file ( @package_files ) {
         my ( $package_name ) = $package_file =~ /^(.*)\-\d+\.\d+\.$ext$/;
         $package_match{ $package_name } =
-            File::Spec->catfile( $package_dir, $package_file );
+            catfile( $package_dir, $package_file );
     }
     return \%package_match;
 }
@@ -115,24 +112,38 @@ sub _get_package_installer {
     my $full_action = "install SQL structure";
     my $package = $repository->fetch_package( $package_name );
     unless ( $package ) {
-        $self->_add_status(
-                { is_ok   => 'no',
-                  action  => $full_action,
-                  message => "Package $package_name not installed" } );
+        $self->_fail( $full_action,
+                      "Package $package_name not installed" );
         return ();
     }
     my $installer =
         OpenInteract2::SQLInstall->new_from_package( $package );
     unless ( $installer ) {
-        $self->_add_status(
-                { is_ok   => 'yes',
-                  action  => $full_action,
-                  message => "No SQL installer specified for $package_name" });
+        $self->_ok( $full_action,
+                    "No SQL installer specified for $package_name" );
         return ();
     }
     return $installer;
 }
 
+
+# Try to get the class corresponding to the SPOPS name
+sub _check_spops_key {
+    my ( $self, $spops_key ) = @_;
+    my $ctx = OpenInteract2::Context->instance;
+    my $obj_class = eval { $ctx->lookup_object( $spops_key ) };
+    if ( $@ or ! $obj_class ) {
+        my $error_msg = $@ || 'none returned';
+        my $msg = "Cannot retrieve objects without a class -- no match " .
+                  "for '$spops_key'. (Error: $error_msg)";
+
+        # use 'die' instead of 'oi_error' here since the top level
+        # MUST deal with the error
+        die $msg, "\n";
+    }
+    return $obj_class;
+}
+
 1;
 
 __END__
