@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website::CleanExpiredSessions;
 
-# $Id: CleanExpiredSessions.pm,v 1.2 2004/02/17 04:30:20 lachoy Exp $
+# $Id: CleanExpiredSessions.pm,v 1.4 2004/06/13 18:19:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
@@ -12,7 +12,7 @@ use Storable                 qw( thaw );
 my $TEMP_TRACK_FILE = 'tmp_session_id';
 my $DECODE          = 'base64';
 
-$OpenInteract2::Manage::Website::CleanExpiredSessions::VERSION = sprintf("%d.%02d", q$Revision: 1.2 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::CleanExpiredSessions::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 # METADATA
 
@@ -64,18 +64,18 @@ sub run_task {
     my $session_info = CTX->lookup_session_config;
     unless ( $session_info->{datasource} ) {
         my $msg = "'Cannot run: nothing defined in 'session_info.datasource'";
-        return _bail( $action, $msg );
+        return $self->_fail( $action, $msg );
     }
     my $dbh = CTX->datasource( $session_info->{datasource} );
 
     $count = eval { $self->_get_session_ids( $dbh ) };
     if ( $@ ) {
-        return _bail( $action, "Failed to get session IDs: $@" );
+        return $self->_fail( $action, "Failed to get session IDs: $@" );
     }
 
     eval { open( IDLIST, '<', $TEMP_TRACK_FILE ) || die $! };
     if ( $@ ) {
-        return _bail( $action, "Cannot reopen session list: $@" );
+        return $self->_fail( $action, "Cannot reopen session list: $@" );
     }
 
     my $below_thresh = time - ( $self->param( 'expire_time' ) * 86400 );
@@ -100,7 +100,7 @@ ID:
             $sth->finish;
         };
         if ( $@ ) {
-            return _bail( $action, "Cannot get session from db: $@" );
+            return $self->_fail( $action, "Cannot get session from db: $@" );
         }
 
         my $session = $self->_decode( $raw_data );
@@ -133,9 +133,7 @@ ID:
     if ( $analyze ) {
         $msg .= " (analysis only, no sessions removed)";
     }
-    $self->_add_status({ is_ok    => 'yes',
-                         action   => $action,
-                         message  => $msg });
+    $self->_ok( $action, $msg );
 }
 
 sub tear_down_task {
@@ -145,14 +143,6 @@ sub tear_down_task {
     }
 }
 
-sub _bail {
-    my ( $self, $action, $msg ) = @_;
-    $self->_add_status({ is_ok    => 'no',
-                         action   => $action,
-                         message  => $msg });
-    return undef;
-}
-
 # Grab all the session_ids and print them to a file, one per line, so
 # we only have to keep one handle open
 
@@ -206,10 +196,9 @@ OpenInteract2::Manage::Website::CleanExpiredSessions - Remove expired and empty
  use strict;
  use OpenInteract2::Manage;
  
- my %PARAMS = ( expire_time => 60 );
- my $website_dir = '/home/httpd/mysite';
  my $task = OpenInteract2::Manage->new(
-                      'clean_sessions', \%PARAMS );
+     'clean_sessions', { website_dir => '/home/httpd/mysite',
+                         expire_time => 60 });
  my @status = $task->execute;
  foreach my $s ( @status ) {
      my $ok_label      = ( $s->{is_ok} eq 'yes' )
