@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website::Create;
 
-# $Id: Create.pm,v 1.21 2004/05/22 04:21:36 lachoy Exp $
+# $Id: Create.pm,v 1.23 2004/12/05 18:50:11 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
@@ -13,7 +13,7 @@ use OpenInteract2::Manage    qw( SYSTEM_PACKAGES );
 use OpenInteract2::Package;
 use OpenInteract2::Repository;
 
-$OpenInteract2::Manage::Website::Create::VERSION = sprintf("%d.%02d", q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::Create::VERSION = sprintf("%d.%02d", q$Revision: 1.23 $ =~ /(\d+)\.(\d+)/);
 
 # think about merging this with info from OI2::Manage::Website::SetDirectoryPermissions
 
@@ -21,6 +21,8 @@ my @WEBSITE_SUBDIR = (
    [ 0770, 'cache' ],
    [ 0770, 'cache', 'tt' ],
    [ 0770, 'cache', 'content' ],
+   [ 0770, 'cache', 'sessions' ],
+   [ 0770, 'cache', 'sessions_lock' ],
    [ 0777, 'cgi-bin' ],
    [ 0777, 'conf' ],
    [ 0777, 'error' ],
@@ -54,6 +56,7 @@ sub get_parameters {
                         "Directory where website will be created. It must " .
                         "not already exist when you run the task.",
                is_required => 'yes',
+               do_validate => 'yes',
         },
     };
 }
@@ -67,7 +70,7 @@ sub validate_param {
     my ( $self, $name, $value ) = @_;
     if ( $name eq 'website_dir' ) {
         if ( -d $value ) {
-            return "Website directory [$value] already exists; cannot " .
+            return "Website directory '$value' already exists; cannot " .
                    "create website over an existing site";
         }
         return;
@@ -138,11 +141,12 @@ sub run_task {
     $self->notify_observers( progress => 'Packages installed' );
 
     $self->_set_nowrite_files( $website_dir, $source_dir );
-    $self->_add_status_head(
-            { action  => 'create website',
-              is_ok   => 'yes',
-              message => 'All directories and files created, all ' .
-                         'packages installed' });
+    $self->_add_status_head({
+        action  => 'create website',
+        is_ok   => 'yes',
+        message => 'All directories and files created, all ' .
+                   'packages installed',
+    });
 }
 
 
@@ -161,10 +165,12 @@ sub _create_directories {
         if ( $@ ) {
             oi_error "Cannot create subdirectory in [$full_subdir]: $@";
         }
-        $self->_add_status( { is_ok    => 'yes',
-                              action   => 'create subdirectory',
-                              filename => $full_subdir,
-                              message  => 'Directory created' } );
+        $self->_add_status({
+            is_ok    => 'yes',
+            action   => 'create subdirectory',
+            filename => $full_subdir,
+            message  => 'Directory created',
+        });
     }
 }
 
@@ -176,10 +182,12 @@ sub _copy_widgets {
                          ->new( $source_widget_dir )
                          ->run( $website_dir );
     foreach my $copied ( @{ $transferred } ) {
-        $self->_add_status( { is_ok   => 'yes',
-                              action  => 'copy widget',
-                              message => 'Copied file from sample site',
-                              filename => $copied } );
+        $self->_add_status({
+            is_ok   => 'yes',
+            action  => 'copy widget',
+            message => 'Copied file from sample site',
+            filename => $copied,
+        });
     }
 }
 
@@ -191,10 +199,12 @@ sub _copy_messages {
                          ->new( $source_msg_dir )
                          ->run( $website_dir, \%vars );
     foreach my $copied ( @{ $transferred } ) {
-        $self->_add_status( { is_ok    => 'yes',
-                              action   => 'copy localized messages',
-                              message  => 'Copied file from sample site',
-                              filename => $copied } );
+        $self->_add_status({
+            is_ok    => 'yes',
+            action   => 'copy localized messages',
+            message  => 'Copied file from sample site',
+            filename => $copied,
+        });
     }
 }
 
@@ -206,10 +216,12 @@ sub _copy_server_conf {
                          ->new( $source_conf_dir )
                          ->run( $website_dir, \%vars );
     foreach my $copied ( @{ $transferred } ) {
-        $self->_add_status( { is_ok   => 'yes',
-                              action  => 'copy server config',
-                              message => 'Copied file from sample site',
-                              filename => $copied } );
+        $self->_add_status({
+            is_ok   => 'yes',
+            action  => 'copy server config',
+            message => 'Copied file from sample site',
+            filename => $copied,
+        });
     }
 }
 
@@ -249,10 +261,12 @@ sub _copy_webserver_conf {
                          ->new( $source_apache_dir )
                          ->run( $website_dir, \%vars );
     foreach my $copied ( @{ $transferred } ) {
-        $self->_add_status( { is_ok   => 'yes',
-                              action  => "copy $desc config",
-                              message => 'Copied file from sample site',
-                              filename => $copied } );
+        $self->_add_status({
+            is_ok   => 'yes',
+            action  => "copy $desc config",
+            message => 'Copied file from sample site',
+            filename => $copied,
+        });
     }
 
 }
@@ -265,10 +279,12 @@ sub _copy_daemon_conf {
                          ->new( $source_daemon_dir )
                          ->run( $website_dir, \%vars );
     foreach my $copied ( @{ $transferred } ) {
-        $self->_add_status( { is_ok   => 'yes',
-                              action  => 'copy standalone daemon config',
-                              message => 'Copied file from sample site',
-                              filename => $copied } );
+        $self->_add_status({
+            is_ok   => 'yes',
+            action  => 'copy standalone daemon config',
+            message => 'Copied file from sample site',
+            filename => $copied,
+        });
     }
 }
 
@@ -278,49 +294,58 @@ sub _set_nowrite_files {
     my ( $self, $website_dir ) = @_;
     my $action = 'set nowrite file';
     my $html_dir = catdir( $website_dir, 'html' );
-    my $html_message = join( '', 'If a file is listed here it will not be ',
-                                 'updated when the package to which it ',
-                                 'belongs is updated.' );
+    my $html_message =
+        'If a file is listed here it will not be updated when the ' .
+        'package to which it belongs is updated.';
     eval {
-        OpenInteract2::Config::Readonly->write_config(
-            $html_dir,
-            { file    => [ 'index.html', 'main.css' ],
-              comment => $html_message } )
-        };
+        OpenInteract2::Config::Readonly
+            ->new( $html_dir )
+            ->write_readonly_files( [ 'index.html', 'main.css' ], $html_message );
+    };
     if ( $@ ) {
-        $self->_add_status( { is_ok    => 'no',
-                              action   => $action,
-                              filename => $html_dir,
-                              message  => "$@" } );
+        warn 
+        $self->_add_status({
+            is_ok    => 'no',
+            action   => $action,
+            filename => $html_dir,
+            message  => "$@",
+        });
     }
     else {
-        $self->_add_status( { is_ok    => 'yes',
-                              action   => $action,
-                              filename => $html_dir,
-                              message  => 'Read-only file created ok' } );
+        $self->_add_status({
+            is_ok    => 'yes',
+            action   => $action,
+            filename => $html_dir,
+            message  => 'Read-only file created ok',
+        });
     }
 
     my $tmpl_dir = catdir( $website_dir, 'template' );
     my $tmpl_status = { action   => $action,
                         filename => $tmpl_dir };
-    my $tmpl_message = join( '', 'These are templates that will not be ',
-                                 'overwritten when you run refresh the ',
-                                 'widgets (one template per line)'  );
-    eval { OpenInteract2::Config::Readonly->write_config(
-                                   $tmpl_dir,
-                                   { file    => [ 'base_main', 'base_simple' ],
-                                     comment => $tmpl_message } ) };
+    my $tmpl_message =
+        'These are templates that will not be overwritten when you ' .
+        'refresh the widgets or upgrade your site (one template per line)';
+    eval {
+        OpenInteract2::Config::Readonly
+            ->new( $tmpl_dir )
+            ->write_readonly_files( [ 'base_main', 'base_simple' ], $tmpl_message );
+    };
     if ( $@ ) {
-        $self->_add_status( { is_ok    => 'no',
-                              action   => $action,
-                              filename => $tmpl_dir,
-                              message  => "$@" } );
+        $self->_add_status({
+            is_ok    => 'no',
+            action   => $action,
+            filename => $tmpl_dir,
+            message  => "$@",
+        });
     }
     else {
-        $self->_add_status( { is_ok    => 'yes',
-                              action   => $action,
-                              filename => $tmpl_dir,
-                              message  => 'Read-only file created ok' } );
+        $self->_add_status({
+            is_ok    => 'yes',
+            action   => $action,
+            filename => $tmpl_dir,
+            message  => 'Read-only file created ok',
+        });
     }
 }
 
