@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website::CreateSecurity;
 
-# $Id: CreateSecurity.pm,v 1.3 2004/02/17 04:30:20 lachoy Exp $
+# $Id: CreateSecurity.pm,v 1.4 2004/06/13 18:19:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error oi_param_error );
 
-$OpenInteract2::Manage::Website::CreateSecurity::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::CreateSecurity::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 # METADATA
 
@@ -90,9 +90,7 @@ sub run_task {
     my $count = $creator->run;
     my $msg = join( '', "Processed ", $creator->num_processed, " and ",
                         "encountered ", $creator->num_failed, " failures. " );
-    $self->_add_status({ is_ok => 'yes',
-                         action => 'create security',
-                         message => $msg });
+    $self->_ok( 'create security', $msg );
 }
 
 OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
@@ -120,8 +118,7 @@ OpenInteract2::Manage::Website::CreateSecurity - Create security for multiple SP
     level    => 'read',
     website_dir => $website_dir,
  );
- my $task = OpenInteract2::Manage->new(
-                      'create_security', \%PARAMS );
+ my $task = OpenInteract2::Manage->new( 'create_security', \%PARAMS );
  my @status = $task->execute;
  foreach my $s ( @status ) {
      my $ok_label      = ( $s->{is_ok} eq 'yes' )
