@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website::CreateSuperuserPassword;
 
-# $Id: CreateSuperuserPassword.pm,v 1.9 2004/02/17 04:30:20 lachoy Exp $
+# $Id: CreateSuperuserPassword.pm,v 1.11 2004/10/02 23:22:28 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
@@ -8,7 +8,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use SPOPS::Utility;
 
-$OpenInteract2::Manage::Website::CreateSuperuserPassword::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::CreateSuperuserPassword::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 # METADATA
 
@@ -55,13 +55,19 @@ sub setup_task {
         oi_error "Changing superuser password from management task ",
                  "is disabled. See administrator and/or docs for details.";
     }
+    my $user_class = CTX->lookup_object( 'user' );
+    if ( $user_class->isa( 'SPOPS::LDAP' ) ) {
+        oi_error "Sorry, you cannot change passwords for a user in an LDAP ",
+                 "directory. Please use another tool to do change the password."
+    }
 }
 
 # RUN
 
 sub run_task {
     my ( $self ) = @_;
-    my %status = ();
+    my $action = 'create password';
+
     my $password = $self->param( 'password' );
     my $root_id = CTX->lookup_default_object_id( 'superuser' );
     my $root = eval {
@@ -69,8 +75,7 @@ sub run_task {
            ->fetch( $root_id, { skip_security => 1 } )
     };
     if ( $@ ) {
-        $status{is_ok}   = 'no';
-        $status{message} = "Error fetching superuser: $@";
+        $self->_fail( $action, "Error fetching superuser: $@" );
     }
     else {
         my $set_password = ( CTX->lookup_login_config->{crypt_password} )
@@ -79,19 +84,18 @@ sub run_task {
         $root->{password} = $set_password;
         eval { $root->save({ skip_security => 1 }) };
         if ( $@ ) {
-            $status{is_ok}   = 'no';
-            $status{message} = "Error saving superuser with new password: $@";
+            $self->_fail( $action,
+                          "Error saving superuser with new password: $@" );
         }
         else {
-            $status{is_ok}   = 'yes';
-            $status{message} =
-                'Changed password for superuser; you may wish to disable ' .
-                'further changes by setting the server configuration key ' .
-                "'login.disable_superuser_password_change' to a true value";
+            my $msg = join( '',
+                'Changed password for superuser; you may wish to disable ',
+                'further changes by setting the server configuration key ',
+                "'login.disable_superuser_password_change' to a true value" );
+            $self->_ok( $action, $msg );
         }
     }
     $self->notify_observers( progress => 'Password change complete' );
-    $self->_add_status( \%status );
     return;
 }
 
@@ -108,14 +112,14 @@ OpenInteract2::Manage::Website::CreateSuperuserPassword - Change password for su
 =head1 SYNOPSIS
 
  #!/usr/bin/perl
-
+ 
  use strict;
  use OpenInteract2::Manage;
-
+ 
  my $website_dir = '/home/httpd/mysite';
  my $task = OpenInteract2::Manage->new(
-                      'create_password', { password => 'foobar',
-                                           website_dir => '/path/to/mysite' } );
+     'create_password', { password => 'foobar',
+                          website_dir => '/path/to/mysite' });
  my @status = $task->execute;
  foreach my $s ( @status ) {
      my $ok_label      = ( $s->{is_ok} eq 'yes' )
@@ -132,6 +136,9 @@ If the server configuration key
 'login.disable_superuser_password_change' is enabled this task will
 not run.
 
+Also, if you are using LDAP to store your users you cannot use this to
+change the superuser password.
+
 =head1 REQUIRED OPTIONS
 
 =over 4
