@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website::InstallPackageSql;
 
-# $Id: InstallPackageSql.pm,v 1.10 2004/02/17 04:30:20 lachoy Exp $
+# $Id: InstallPackageSql.pm,v 1.11 2004/06/13 18:19:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
@@ -8,7 +8,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Setup;
 
-$OpenInteract2::Manage::Website::InstallPackageSql::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::InstallPackageSql::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
 
 sub get_name {
     return 'install_sql';
@@ -76,13 +76,14 @@ OpenInteract2::Manage::Website::InstallPackageSql - Install SQL structures, obje
 =head1 SYNOPSIS
 
  #!/usr/bin/perl
-
+ 
  use strict;
  use OpenInteract2::Manage;
-
+ 
  my $website_dir = '/home/httpd/mysite';
  my $task = OpenInteract2::Manage->new(
-                      'install_sql', \%PARAMS );
+     'install_sql', { website_dir => $website_dir,
+                      package     => 'mypackage' });
  my @status = $task->execute;
  foreach my $s ( @status ) {
      my $ok_label      = ( $s->{is_ok} eq 'yes' )
