@@ -1,6 +1,6 @@
 package OpenInteract2::Manage::Website::ReindexObjects;
 
-# $Id: ReindexObjects.pm,v 1.3 2004/02/17 04:30:20 lachoy Exp $
+# $Id: ReindexObjects.pm,v 1.6 2004/06/13 18:19:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Manage::Website::ReindexObjects::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::ReindexObjects::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 sub get_name {
     return 'reindex_objects';
@@ -47,86 +47,33 @@ sub run_task {
     my $action = 'reindex objects';
     my $object_tag = $self->param( 'spops' );
 
-    # Try to get the class corresponding to the object tag passed in
-
-    my $obj_class = eval { CTX->lookup_object( $object_tag ) };
-    if ( $@ or ! $obj_class ) {
-        my $error_msg = $@ || 'none returned';
-        my $msg = "Cannot retrieve objects without a class -- no match " .
-                  "for $object_tag. (Error: $error_msg)";
-        return $self->_bail( $action, $msg );
+    my $obj_class = eval { $self->_check_spops_key( $object_tag ) };
+    if ( $@ ) {
+        return $self->_fail( $action, "$@" );
     }
 
     # Ensure the object class is currently indexable
 
-    unless ( $obj_class->isa( 'OpenInteract2::FullText' ) ) {
-        my $msg = "Failed! This class ($obj_class) is not indexable. " .
+    unless ( $obj_class->isa( 'OpenInteract2::FullTextRules' ) ) {
+        my $msg = "Failed! The class '$obj_class' is not indexable. " .
                   "Please set its 'is_searchable' configuration key " .
-                  "to 'yes'.";
-        return $self->_bail( $action, $msg );
+                  "to 'yes' and list its content field(s) in " .
+                  "'fulltext_field'.";
+        return $self->_fail( $action, $msg );
     }
 
-    my $CONFIG = $obj_class->CONFIG;
-    my $ft_fields = $CONFIG->{fulltext_field};
-    unless ( scalar @{ $ft_fields } ) {
-        my $msg = "You must define one or more fields to index in the " .
-                  "'fulltext_field' key in your object configuration.";
-        return $self->_bail( $action, $msg );
-    }
-
-    # Retrieve all the objects -- but if the 'fulltext' column group
-    # is defined use it.
-
-    my ( $column_group );
-    if ( $CONFIG->{column_group}{fulltext} ) {
-        $column_group = 'fulltext';
-    }
-
-    my $iter = eval { $obj_class->fetch_iterator({
-                                     skip_security => 1,
-                                     where         => $self->param( 'query' ),
-                                     column_group  => $column_group }) };
+    my $where_clause = $self->param( 'query' );
+    my $indexer = CTX->fulltext_indexer;
+    my ( $count );
+    eval {
+        $indexer->create_class_index(
+            $obj_class, { skip_security => 1,
+                          where         => $where_clause })
+    };
     if ( $@ ) {
-        my $msg = "Failed to fetch objects for indexing: $@";
-        return $self->_bail( $msg );
+        return $self->_fail( $action, "$@" );
     }
-
-    my $start_time = scalar localtime;
-
-    my @errors = ();
-
-    # Index each object
-
-    my ( $count, $success ) = ( 0, 0 );
-    while ( my $obj = $iter->get_next ) {
-        $obj->reindex_object;
-        $count++;
-        if ( $@ ) {
-            push @errors, $obj->id . ": $@";
-        }
-        else {
-            $success++;
-        }
-    }
-    if ( scalar @errors ) {
-        my $msg = "Added $success/$count objects to index; errors:\n " .
-                  join( "\n", @errors );
-        return $self->_bail( $action, $msg );
-    }
-
-    my $msg = "Added $count/$count objects to index";
-    $self->_add_status({ is_ok    => 'yes',
-                         action   => $action,
-                         message  => $msg });
-    return;
-}
-
-sub _bail {
-    my ( $self, $action, $msg ) = @_;
-    $self->_add_status({ is_ok    => 'no',
-                         action   => $action,
-                         message  => $msg });
-    return undef;
+    return $self->_ok( $action, "Added $count objects to index" );
 }
 
 OpenInteract2::Manage->register_factory_type( get_name() => __PACKAGE__ );
@@ -146,14 +93,13 @@ OpenInteract2::Manage::Website::ReindexObjects - Index objects for a particular
  use strict;
  use OpenInteract2::Manage;
  
- my %PARAMS = ( spops => 'news' );
  my $website_dir = '/home/httpd/mysite';
  my $task = OpenInteract2::Manage->new(
-                      'reindex_objects', \%PARAMS );
+     'reindex_objects', { spops => 'news' });
  my @status = $task->execute;
  foreach my $s ( @status ) {
-     my $ok_label      = ( $s->{is_ok} eq 'yes' )
-                           ? 'OK' : 'NOT OK';
+     my $ok_label = ( $s->{is_ok} eq 'yes' )
+                      ? 'OK' : 'NOT OK';
      print "Status OK?  $s->{is_ok}\n",
            "$s->{message}\n";
  }
@@ -177,7 +123,7 @@ instance, 'news' if you're trying to reindex the objects from the
 =item B<query>=where-clause
 
 A WHERE clause that will be sent directly to the database. This will
-limit the object's you're trying to reindex.
+limit the objects you're trying to reindex.
 
 =back
 
