@@ -1,12 +1,12 @@
 package OpenInteract2::Manage::Website::RemovePackage;
 
-# $Id: RemovePackage.pm,v 1.5 2004/02/17 04:30:21 lachoy Exp $
+# $Id: RemovePackage.pm,v 1.6 2004/06/13 18:19:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
 use OpenInteract2::Context qw( CTX );
 
-$OpenInteract2::Manage::Website::RemovePackage::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::RemovePackage::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 sub get_name {
     return 'remove_package'
@@ -34,16 +34,13 @@ sub run_task {
         next unless ( $name );
         my $package = $repository->fetch_package( $name );
         eval { $repository->remove_package( $package ) };
-        my %status = ( action => "remove package $name" );
+        my $action = "remove package $name";
         if ( $@ ) {
-            $status{is_ok} = 'no';
-            $status{message} = "Error: $@";
+            $self->_fail( $action, "Error: $@" );
         }
         else {
-            $status{is_ok} = 'yes';
-            $status{message} = "Removed ok";
+            $self->_ok( $action, "Package removed" );
         }
-        $self->_add_status( \%status );
     }
 }
 
@@ -67,8 +64,8 @@ OpenInteract2::Manage::Website::RemovePackage - Remove a package from a website
  my $package      = 'mypkg';
  my $website_dir  = '/home/httpd/testsite';
  my $task = OpenInteract2::Manage->new(
-                      'remove_package', { package => $package,
-                                          website_dir => $website_dir } );
+     'remove_package', { package => $package,
+                         website_dir => $website_dir });
  my ( $status ) = $task->execute;
  print "Action:    $s->{action}\n",
        "Status OK? $s->{is_ok}\n",
@@ -79,7 +76,7 @@ OpenInteract2::Manage::Website::RemovePackage - Remove a package from a website
 
 Removes one or more packages from a website. This does not delete the
 files used by the package but instead just deletes it from the
-repository. Packages that aren't in the repository are dead to the
+repository. Packages that are not in the repository are dead to the
 website.
 
 =head1 STATUS MESSAGES
