@@ -1,13 +1,13 @@
 package OpenInteract2::Manage::Website::TestDB;
 
-# $Id: TestDB.pm,v 1.11 2004/02/17 04:30:21 lachoy Exp $
+# $Id: TestDB.pm,v 1.12 2004/06/13 18:19:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Manage::Website::TestDB::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::TestDB::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 sub get_name {
     return 'test_db';
@@ -24,13 +24,14 @@ sub run_task {
     my $datasource_config = CTX->lookup_datasource_config;
     my ( $error_msg );
 
+    my $action = 'check database connection';
+
     # Perform initial sanity checks
 
     unless ( ref $datasource_config ne 'HASH' and
              scalar keys %{ $datasource_config } ) {
-        my $msg = "No datasources defined; no connection attempted.";
-        $self->_add_status( { is_ok   => 'yes',
-                              message => $msg } );
+        $self->_ok( $action,
+                    'No DBI datasources; no connection attempted.' );
     }
 
     my $dbi_ds = 0;
@@ -40,55 +41,59 @@ sub run_task {
 DATASOURCE:
     while ( my ( $name, $ds_conf ) = each %{ $datasource_config } ) {
         next unless ( $ds_conf->{type} eq 'DBI' );
+        my %s = (
+            name       => $name,
+            is_default => ( $default_dbi eq $name ) ? 'yes' : 'no'
+        );
         $dbi_ds++;
-        my %s = ( name => $name, is_ok => 'no' );
-        $s{is_default} = ( $default_dbi eq $name ) ? 'yes' : 'no';
+
+        my $this_action = "$action '$name'";
         unless ( $ds_conf->{dsn} ) {
-            $s{message} = "You must define at least 'dsn' in the " .
-                          "datasource configuration";
-            $self->_add_status( \%s );
+            my $msg = "You must define at least 'dsn' in the " .
+                      "datasource configuration";
+            $self->_fail( $this_action, $msg, %s );
             next DATASOURCE;
         }
         my $db = eval { CTX->datasource( $name ) };
         if ( $@ ) {
-            $s{message} = $@;
-            $self->_add_status( \%s );
+            $self->_fail( $this_action, "$@", %s );
             next DATASOURCE;
         }
         unless ( $db and UNIVERSAL::isa( $db, 'DBI::db' ) ) {
-            $s{message} = "Connect failed (no error, but no database " .
-                          "handle returned)";
-            $self->_add_status( \%s );
+            my $msg = 'Connect failed (no error, but no database ' .
+                      'handle returned)';
+            $self->_fail( $this_action, $msg, %s );
             next DATASOURCE;
         }
         my $test_table = 'oi_test_create';
-        eval { $db->do( "CREATE TABLE $test_table " .
-                        "( oi_id int not null, primary key( oi_id ) )" ) };
+        eval {
+            $db->do( "CREATE TABLE $test_table " .
+                     "( oi_id int not null, primary key( oi_id ) )" ) };
         if ( $@ ) {
-            $s{message} = "Connected to database, but cannot create " .
-                          "table: $@";
-            $self->_add_status( \%s );
+            my $msg = "Connected to database, but cannot create table: $@";
+            $self->_fail( $this_action, $msg, %s );
             next DATASOURCE;
         }
-        $s{is_ok} = 'yes';
         eval { $db->do( "DROP TABLE $test_table" ) };
         if ( $@ ) {
-            $s{message} = "Connected to database and created table " .
-                          "ok, but DROP failed: $@. Please remove " .
-                          "table [$test_table] by hand.";
+            my $msg = "Connected to database and created table " .
+                      "ok, but DROP failed with '$@'. Please remove " .
+                      "table '$test_table' by hand.";
+            $self->_ok( $this_action, $msg, %s );
+            eval { $db->disconnect };
+            next DATASOURCE;
         }
         eval { $db->disconnect };
         if ( $@ ) {
-            $s{message} = "Connected to database, create table, " .
-                          "dropped table, but could not disconnect " .
-                          "from database: $@";
+            my $msg = "Connected to database, created table, " .
+                      "dropped table, but could not disconnect " .
+                      "from database: $@";
+            $self->_ok( $this_action, $msg, %s );
         }
-        $self->_add_status( \%s );
     }
     unless ( $dbi_ds ) {
-        $self->_add_status(
-            { is_ok   => 'yes',
-              message => 'No DBI datasources defined; no tests run' } );
+        $self->_ok( $action,
+                    'No DBI datasources defined; no tests run' );
     }
 }
 
@@ -105,13 +110,13 @@ OpenInteract2::Manage::Website::TestDB - Managment task
 =head1 SYNOPSIS
 
  #!/usr/bin/perl
-
+ 
  use strict;
  use OpenInteract2::Manage;
-
+ 
  my $website_dir = '/home/httpd/mysite';
  my $task = OpenInteract2::Manage->new(
-                      'test_db', { website_dir => $website_dir } );
+     'test_db', { website_dir => $website_dir } );
  my @status = $task->execute;
  foreach my $s ( @status ) {
      my $ok_label      = ( $s->{is_ok} eq 'yes' )
