@@ -1,13 +1,13 @@
 package OpenInteract2::Manage::Website::TestLDAP;
 
-# $Id: TestLDAP.pm,v 1.10 2004/02/17 04:30:21 lachoy Exp $
+# $Id: TestLDAP.pm,v 1.12 2004/06/13 18:19:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Manage::Website );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::Manage::Website::TestLDAP::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Manage::Website::TestLDAP::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 sub get_name {
     return 'test_ldap';
@@ -24,13 +24,14 @@ sub run_task {
     my $datasource_config = CTX->lookup_datasource_config;
     my ( $error_msg );
 
+    my $action = 'check LDAP connection';
+
     # Perform initial sanity checks
 
-    unless ( ref $datasource_config ne 'HASH' and
+    unless ( ref $datasource_config eq 'HASH' and
               scalar keys %{ $datasource_config } ) {
-        $self->_add_status(
-            { is_ok   => 'yes',
-              message => "No datasources defined; no connection attempted." } );
+        $self->_ok( $action,
+                    "No datasources defined; no connection attempted." );
         return;
     }
 
@@ -42,35 +43,34 @@ sub run_task {
 DATASOURCE:
     while ( my ( $name, $ds_conf ) = each %{ $datasource_config } ) {
         next unless ( $ds_conf->{type} eq 'LDAP' );
-        my %s = ( name => $name, is_ok => 'no' );
-        $s{is_default} = ( $default_ldap eq $name ) ? 'yes' : 'no';
+        my %s = (
+            name       => $name,
+            is_default => ( $default_ldap eq $name ) ? 'yes' : 'no'
+        );
+
+        my $this_action = "$action '$name'";
         unless ( $ds_conf->{host} ) {
-            $s{message} = "You must define 'host' in the datasource " .
-                          "configuration";
-            $self->_add_status( \%s );
+            my $msg = "You must define 'host' in the configuration";
+            $self->_fail( $this_action, $msg, %s );
             next DATASOURCE;
         }
         unless ( $ds_conf->{base_dn} ) {
-            $s{message} = "You must define 'base_dn' in the datasource " .
-                          "configuration";
-            $self->_add_status( \%s );
+            my $msg = "You must define 'base_dn' in the configuration";
+            $self->_fail( $this_action, $msg, %s );
             next DATASOURCE;
         }
         my $ldap = eval { CTX->datasource( $name ) };
         if ( $@ ) {
-            $s{message} = $@;
-            $self->_add_status( \%s );
+            $self->_fail( $this_action, "$@", %s );
             next DATASOURCE;
         }
         unless ( $ldap and UNIVERSAL::isa( $ldap, 'Net::LDAP' ) ) {
-            $s{message} = "Connect failed (no error, but no LDAP " .
-                          "handle returned)";
-            $self->_add_status( \%s );
+            my $msg = "Connect failed (no error, but no LDAP handle returned)";
+            $self->_fail( $this_action, $msg, %s );
             next DATASOURCE;
         }
-        $s{is_ok} = 'yes';
-        $s{message} = "Connected and bound to directory ok";
-        $self->_add_status( \%s );
+        my $msg = "Connected and bound to directory ok";
+        $self->_ok( $this_action, $msg, %s );
     }
     return;
 }
@@ -88,10 +88,10 @@ OpenInteract2::Manage::Website::TestLDAP - Task to test configured LDAP connecti
 =head1 SYNOPSIS
 
  #!/usr/bin/perl
-
+ 
  use strict;
  use OpenInteract2::Manage;
-
+ 
  my $website_dir = '/home/httpd/mysite';
  my $task = OpenInteract2::Manage->new(
                       'test_ldap', { website_dir => $website_dir } );
