@@ -1,13 +1,12 @@
 package OpenInteract2::Package;
 
-# $Id: Package.pm,v 1.36 2004/02/18 05:25:26 lachoy Exp $
+# $Id: Package.pm,v 1.41 2004/12/05 20:06:35 lachoy Exp $
 
 use strict;
 use base qw( Exporter Class::Accessor::Fast );
 use Archive::Zip             qw( :ERROR_CODES );
 use Cwd                      qw( cwd );
 use Data::Dumper             qw( Dumper );
-use Digest::MD5              qw();
 use ExtUtils::Manifest       ();
 use File::Basename           qw( basename dirname );
 use File::Copy               qw( cp );
@@ -25,7 +24,7 @@ use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Repository;
 use OpenInteract2::Util;
 
-$OpenInteract2::Package::VERSION   = sprintf("%d.%02d", q$Revision: 1.36 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Package::VERSION   = sprintf("%d.%02d", q$Revision: 1.41 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 @OpenInteract2::Package::EXPORT_OK = qw( DISTRIBUTION_EXTENSION );
@@ -58,18 +57,18 @@ sub new {
     if ( $params->{package_file} ) {
         unless ( -f $params->{package_file} ) {
             oi_error "Cannot initialize package with non-existent package ",
-                     "file. (Given [$params->{package_file}])";
+                     "file. (Given $params->{package_file})";
         }
         my $full_path = rel2abs( $params->{package_file} );
         $log->is_debug &&
-            $log->debug( "Setting full path for package file [$full_path]" );
+            $log->debug( "Setting full path for package file '$full_path'" );
         $self->package_file( $full_path );
         $to_read++;
     }
     elsif ( $params->{directory} ) {
         unless ( -d $params->{directory} ) {
             oi_error "Cannot initialize package with non-existent package ",
-                     "directory. (Given [$params->{directory}])";
+                     "directory. (Given $params->{directory})";
         }
         $self->directory( rel2abs( $params->{directory} ) );
         $to_read++;
@@ -111,7 +110,7 @@ sub _read_info_from_file {
 
     my $package_file = $self->package_file;
     $log->is_debug &&
-        $log->debug( "Reading package info from [$package_file]" );
+        $log->debug( "Reading package info from '$package_file'" );
     eval {
         my $filename = basename( $self->package_file );
         my $ext = '.' . DISTRIBUTION_EXTENSION;
@@ -144,11 +143,11 @@ sub _read_info_from_dir {
     $dir ||= $self->directory;
     unless ( -d $dir ) {
         oi_error "Cannot read package information from invalid ",
-                 "directory [$dir]";
+                 "directory '$dir'";
     }
 
     $log->is_debug &&
-        $log->debug( "Reading package info from [$dir]" );
+        $log->debug( "Reading package info from '$dir'" );
     $self->config( OpenInteract2::Config::Package->new({ directory => $dir }) );
     $self->name( $self->config->name );
     $self->version( $self->config->version );
@@ -200,7 +199,7 @@ sub _read_manifest {
         $manifest_dir = $self->directory;
     }
     unless ( -d $manifest_dir ) {
-        oi_error "Cannot read files from MANIFEST in [$manifest_dir]: ",
+        oi_error "Cannot read files from MANIFEST in '$manifest_dir': ",
                  "the directory is invalid";
     }
     my $pwd = cwd();
@@ -256,8 +255,7 @@ sub get_action_files {
         ];
     }
     my $dir = $self->directory;
-    my @action_files = map { catfile( $dir, $_ ) }
-                           @{ $base_files };
+    my @action_files = map { catfile( $dir, $_ ) } @{ $base_files };
     $self->_check_file_validity( \@action_files );
     return $base_files
 }
@@ -267,8 +265,7 @@ sub get_doc_files {
     my $files = $self->get_files;
     my @base_doc_files = grep { m|^doc| } @{ $files };
     my $dir = $self->directory;
-    my @check_files = map { catfile( $dir, $_ ) }
-                          @base_doc_files;
+    my @check_files = map { catfile( $dir, $_ ) } @base_doc_files;
     $self->_check_file_validity( \@check_files );
     return \@base_doc_files;
 }
@@ -292,7 +289,7 @@ sub _check_file_validity {
     my ( $self, $files ) = @_;
     foreach my $file ( @{ $files } ) {
         unless ( -f $file ) {
-            oi_error "Package file returned [$file] is invalid.";
+            oi_error "Package file returned '$file' is invalid.";
         }
     }
 }
@@ -343,10 +340,10 @@ sub install {
         chdir( $pwd );
         $class->_remove_directory_tree( $full_package_dir );
         oi_error "Cannot unpack the distribution into its final ",
-                 "directory [$full_package_dir]: $@";
+                 "directory '$full_package_dir': $@";
     }
     $log->is_info &&
-        $log->info( "Unpacked package into [$full_package_dir] ok" );
+        $log->info( "Unpacked package into '$full_package_dir' ok" );
 
     my $installed_package = $class->new({ directory  => $full_package_dir,
                                           repository => $repository });
@@ -520,13 +517,9 @@ sub remove {
 sub generate_distribution_digest {
     my ( $class, $package_file ) = @_;
     unless ( -f $package_file ) {
-        oi_error "Cannot generate digest: file [$package_file] invalid";
+        oi_error "Cannot generate digest: file '$package_file' invalid";
     }
-    my $fh = IO::File->new( $package_file );
-    $fh->binmode;
-    my $digest = Digest::MD5->new->addfile( $fh )->hexdigest;
-    $fh->close;
-    return $digest;
+    return OpenInteract2::Util->digest_file( $package_file );
 }
 
 # Find a file that exists in either the website directory or the base
@@ -554,7 +547,7 @@ sub read_file {
     my $full_file = $self->find_file( $relative_filename );
     return undef unless ( $full_file );
     open( IN, '<', $full_file )
-                    || die "Cannot read [$full_file]: $!";
+                    || oi_error "Cannot read '$full_file': $!";
     my @content = <IN>;
     close( IN );
     return join( '', @content );
@@ -611,7 +604,7 @@ sub _install_get_repository {
     if ( $repository ) {
         my $install_dir = $repository->full_package_dir;
         unless ( -d $install_dir ) {
-            oi_error "Specified installation directory [$install_dir] ",
+            oi_error "Specified installation directory '$install_dir' ",
                      "is invalid";
         }
     }
@@ -633,7 +626,7 @@ sub _install_check_modules {
     return unless ( ref $module eq 'ARRAY' and scalar @{ $module } );
     my @failed_modules = $class->_check_module_install( @{ $module } );
     return unless ( scalar @failed_modules );
-    oi_error "Package [", $config->name, "] requires the following ",
+    oi_error "Package '", $config->name, "' requires the following ",
              "modules that are not currently installed:\n  ",
              join( ', ', @failed_modules ), "\n",
              "Please install them and then reinstall.";
@@ -642,12 +635,11 @@ sub _install_check_modules {
 sub _install_check_dest_dir {
     my ( $class, $config, $repository ) = @_;
     my $full_package_name = join( '-', $config->name, $config->version );
-    my $full_package_dir = catfile(
-                               $repository->full_package_dir,
-                               $full_package_name );
+    my $full_package_dir = catfile( $repository->full_package_dir,
+                                    $full_package_name );
     if ( -d $full_package_dir ) {
         oi_error "The directory into which the distribution should be ",
-                 "unpacked [$full_package_dir] already exists.";
+                 "unpacked '$full_package_dir' already exists.";
     }
     return $full_package_dir;
 }
@@ -656,10 +648,10 @@ sub _install_copy_files {
     my ( $self ) = @_;
     unless ( $self->repository ) {
         my $pkg_dir = rel2abs( $self->directory );
-        warn "Cannot copy files from package [", $self->name, "] to ",
+        warn "Cannot copy files from package '", $self->name, "' to ",
              "website because there is no repository set in package. ",
-             "You will need to copy the files from [$pkg_dir/html] and ",
-             "[$pkg_dir/widget] (if they exist) to the website manually.\n";
+             "You will need to copy the files from '$pkg_dir/html' and ",
+             "'$pkg_dir/widget' (if they exist) to the website manually.\n";
         return;
     }
 
@@ -689,6 +681,8 @@ sub _install_package_files_to_website {
     my ( @copy_files );
     eval {
         my $count = 0;
+        my %ro_by_dir = ();
+BASE_FILE:
         foreach my $from_base ( @{ $base_files } ) {
 
             # By default we copy relpath/filename -> relpath/filename
@@ -697,29 +691,33 @@ sub _install_package_files_to_website {
 
             my $to_base = $dest_files->[ $count ] || $from_base;
 
+            my $full_source_path = catfile( $package_dir, $from_base );
             my $full_dest_path = catfile( $website_dir, $to_base );
             $self->_create_full_path( $full_dest_path );
 
-            # Yeah, this is slightly inefficient, but (a) it's much
-            # simpler than the alternative, (2) there aren't many
-            # times where packages have files to copy and (iii) you
-            # don't install packages very often...
+            my $full_dest_dir = dirname( $full_dest_path );
+            my $ro = $ro_by_dir{ $full_dest_dir };
+            unless ( $ro ) {
+                $ro_by_dir{ $full_dest_dir } =
+                    OpenInteract2::Config::Readonly->new( $full_dest_dir );
+                $ro = $ro_by_dir{ $full_dest_dir };
+            }
 
-            my $can_copy = OpenInteract2::Config::Readonly
-                              ->is_writeable_file( dirname( $full_dest_path ),
-                                                   $full_dest_path );
-            next unless ( $can_copy );
-            my $full_source_path = catfile(
-                                        $package_dir, $from_base );
-
-            # Backup the file if it already exists
+            # If file already exists check if we can write, and if so
+            # backup the file
 
             if ( -f $full_dest_path ) {
+                unless ( $ro->is_writeable( $to_base ) ) {
+                    $log->is_debug &&
+                        $log->debug( "Will not copy '$full_source_path' ",
+                                 "to '$full_dest_path': marked readonly" );
+                    next BASE_FILE;
+                }
                 rename( $full_dest_path, "$full_dest_path.$BACKUP_EXT" )
-                    || die "Cannot backup [$full_dest_path]: $!";
+                    || die "Cannot backup '$full_dest_path': $!";
             }
             cp( $full_source_path, $full_dest_path )
-                    || die "Cannot copy [$full_source_path] -> [$full_dest_path]: $!";
+                    || die "Cannot copy '$full_source_path' -> '$full_dest_path': $!";
             chmod( 0666, $full_dest_path ); # let umask work...
             push @copy_files, $full_dest_path;
             $count++;
@@ -808,7 +806,7 @@ sub _skel_create_subdirectories {
     my ( $class, $base_dir ) = @_;
     my @to_create = map { catdir( $base_dir, $_ ) } @PKG_SUBDIR;
     for ( my $i = 0; $i < scalar @to_create; $i++ ) {
-        eval { mkdir( "$to_create[ $i ]", 0777 ) || die $! };
+        eval { mkdir( $to_create[ $i ], 0777 ) || die $! };
 
         # If we fail, see if we can cleanup our mess
 
@@ -816,13 +814,13 @@ sub _skel_create_subdirectories {
             my $error = $@;
             for ( my $j = 0; $j < $i; $j++ ) {
                 eval {
-                    $class->_remove_directory_tree( "$to_create[ $j ]" )
+                    $class->_remove_directory_tree( $to_create[ $j ] )
                 };
                 warn "In process of cleaning up after failure, also ",
-                     "failed to remove directory [$to_create[$j]: $@";
+                     "failed to remove directory '$to_create[$j]': $@";
             }
             oi_error "Failed to package subdirectory ",
-                     "[$to_create[ $i ]]: $error";
+                     "'$to_create[ $i ]': $error";
         }
     }
     return \@to_create;
@@ -852,7 +850,7 @@ sub _skel_create_changelog {
     my $full_filename = catfile( $package_dir, $filename );
     eval { open( CHANGES, '>', $full_filename ) || die $! };
     if ( $@ ) {
-        oi_error "Cannot create changelog [$filename]: $@";
+        oi_error "Cannot create changelog '$filename': $@";
     }
     my $time_stamp = scalar localtime;
     print CHANGES <<INIT;
@@ -908,12 +906,12 @@ sub _export_archive_package {
     my $package_id = $self->full_name;
     my $export_dir = rel2abs( $package_id );
     if ( -d $export_dir ) {
-        oi_error "Directory [$export_dir] already exists. Please ",
+        oi_error "Directory '$export_dir' already exists. Please ",
                  "remove it before exporting package.";
     }
     eval { mkdir( $export_dir, 0777 ) || die $! };
     if ( $@ ) {
-        oi_error "Cannot create directory [$export_dir] used to ",
+        oi_error "Cannot create directory '$export_dir' used to ",
                  "archive package: $@";
     }
 
@@ -958,7 +956,7 @@ sub _create_archive {
 
     my $zip_filename = catfile( $dir, join( '.', $base_filename, 'zip' ) );
     if ( -f $zip_filename ) {
-        oi_error "Cannot create ZIP archive: [$zip_filename] already exists";
+        oi_error "Cannot create ZIP archive: '$zip_filename' already exists";
     }
 
     my $zip = Archive::Zip->new();
@@ -971,7 +969,7 @@ sub _create_archive {
         $msg = 'There is a format error in a ZIP file being read.'      if ( $rv == AZ_FORMAT_ERROR );
         $msg = 'There was an IO error.'                                 if ( $rv == AZ_IO_ERROR );
         $msg ||= 'Unknown error';
-        oi_error "Failed to create ZIP archive [$zip_filename]: $msg";
+        oi_error "Failed to create ZIP archive '$zip_filename': $msg";
     }
     return $zip_filename;
 }
@@ -980,11 +978,11 @@ sub _create_archive {
 sub _extract_archive {
     my ( $class, $filename ) = @_;
     unless ( -f $filename ) {
-        oi_error "Cannot extract archive from [$filename]: invalid file";
+        oi_error "Cannot extract archive from '$filename': invalid file";
     }
     my $zip = Archive::Zip->new( $filename );
     unless ( $zip ) {
-        oi_error "Failed to read ZIP file [$filename]";
+        oi_error "Failed to read ZIP file '$filename'";
     }
     my @extracted = ();
     my @errors = ();
@@ -1012,7 +1010,7 @@ sub _extract_archive {
         }
     }
     if ( scalar @errors ) {
-        oi_error "Errors unzipping files from [$filename]:\n  - ",
+        oi_error "Errors unzipping files from '$filename':\n  - ",
                  join( "\n  - ", @errors );
     }
     return \@extracted;
@@ -1147,6 +1145,7 @@ sub _check_package_config {
     my $config = $self->config;
     my $base_filename = $config->filename;
     my $package_dir   = $config->package_dir;
+    $package_dir =~ s|\\|\\\\|g; # for win32 people...
     $base_filename =~ s|^$package_dir/||;
     my %req_s = ( action   => 'Config required fields',
                   filename => $base_filename );
@@ -1230,7 +1229,7 @@ sub _check_manifest {
     my %extra_s = ( action => 'Extra files not in MANIFEST' );
     if ( scalar @extra ) {
         $extra_s{is_ok}   = 'no';
-        $extra_s{message} = 'Files not in MAIFEST found: ' .
+        $extra_s{message} = 'Files not in MANIFEST found: ' .
                             join( ', ', @extra );
     }
     else {
@@ -1288,7 +1287,7 @@ OpenInteract2::Package - Perform actions on individual packages
      print "Export failed: $@";
  }
  else {
-     print "Exported successfully to file [$export_filename]";
+     print "Exported successfully to file '$export_filename'";
  }
  
  # Read information about a package distribution
