@@ -1,6 +1,6 @@
 package OpenInteract2::Repository;
 
-# $Id: Repository.pm,v 1.19 2004/05/22 01:56:36 lachoy Exp $
+# $Id: Repository.pm,v 1.20 2004/06/13 02:05:31 lachoy Exp $
 
 use strict;
 use base qw( Exporter Class::Accessor::Fast );
@@ -13,7 +13,7 @@ use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Package;
 #use Scalar::Util             qw( blessed );
 
-$OpenInteract2::Repository::VERSION   = sprintf("%d.%02d", q$Revision: 1.19 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Repository::VERSION   = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
 @OpenInteract2::Repository::EXPORT_OK = qw( REPOSITORY_FILE );
 
 use constant REPOSITORY_FILE => 'repository.ini';
@@ -258,7 +258,9 @@ sub _read_repository {
         oi_error "Cannot read repository because file [$ini_file] ",
                  "does not exist";
     }
-    my $ini = OpenInteract2::Config::Ini->new({ filename => $ini_file });
+    my $ini = OpenInteract2::Config::IniFile->read_config({
+        filename => $ini_file
+    });
     foreach my $package_name ( $ini->sections ) {
         my $info = $ini->{ $package_name };
         $info->{name} = $package_name;
@@ -279,7 +281,7 @@ sub _save_repository {
             $log->warn( "Failed to remove old tmp file; will overwrite. ",
                         "Error: $!" );
     }
-    my $ini = OpenInteract2::Config::Ini->new();
+    my $ini = OpenInteract2::Config::IniFile->ini_factory();
     foreach my $pkg_info ( @{ $self->_package_info } ) {
         $ini->set( $pkg_info->{name},
                    version => $pkg_info->{version} );
