@@ -1,6 +1,6 @@
 package OpenInteract2::Request;
 
-# $Id: Request.pm,v 1.42 2004/04/28 01:26:00 lachoy Exp $
+# $Id: Request.pm,v 1.48 2004/11/28 17:50:46 lachoy Exp $
 
 use strict;
 use base qw( Class::Factory Class::Accessor::Fast );
@@ -15,7 +15,7 @@ use OpenInteract2::I18N;
 use OpenInteract2::SessionManager;
 use OpenInteract2::URL;
 
-$OpenInteract2::Request::VERSION = sprintf("%d.%02d", q$Revision: 1.42 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::VERSION = sprintf("%d.%02d", q$Revision: 1.48 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -23,7 +23,7 @@ my ( $log );
 # ACCESSORS
 
 my @FIELDS = qw(
-    server_name remote_host
+    now server_name remote_host
     user_agent referer cookie_header language_header
     url_absolute url_relative url_initial action_name task_name
     session auth_user auth_group auth_is_admin auth_is_logged_in
@@ -45,19 +45,6 @@ sub get_implementation_type {
     return $REQUEST_TYPE;
 }
 
-# Retrieve the current object
-
-sub get_current {
-    if ( $REQUEST_CLASS ) {
-        return $REQUEST_CLASS->get_current;
-    }
-    else {
-        oi_error "No request class defined -- run 'set_implementation_type()' ",
-                 "to set the type of requests we'll be processing.";
-    }
-}
-
-
 sub new {
     my ( $class, @params ) = @_;
     $log ||= get_logger( LOG_REQUEST );
@@ -79,6 +66,8 @@ sub new {
     $self->_parse_cookies;
     $self->_create_session;
 
+    $self->now( CTX->create_date() );
+
     CTX->request( $self );
     return $self;
 }
@@ -124,9 +113,9 @@ sub param_date {
                           $self->param( $name . '_month' ),
                           $self->param( $name . '_day' ) );
     return undef unless ( $y and $m and $d );
-    return DateTime->new( year  => $y,
-                          month => $m,
-                          day   => $d );
+    return DateTime->new( year   => $y,
+                          month  => $m,
+                          day    => $d );
 }
 
 sub param_datetime {
@@ -366,12 +355,13 @@ sub create_theme {
     $log ||= get_logger( LOG_REQUEST );
     my $user = $self->auth_user;
     unless ( $user ) {
-        $log->is_info &&
-            $log->info( "Theme not created, no user authenticated" );
+        $log->warn( "Theme not created, no user authenticated" );
         oi_error "Must authenticate before trying to fetch/create theme";
     }
-    my $theme_id = $user->{theme_id}
+    my $theme_id = $user->theme_id
                    || CTX->lookup_default_object_id( 'theme' );
+    $log->is_info &&
+        $log->info( "Trying to fetch theme with ID '$theme_id'" );
     my $theme = eval {
         CTX->lookup_object( 'theme' )->fetch( $theme_id )
     };
@@ -381,7 +371,7 @@ sub create_theme {
     }
     $self->theme( $theme );
     $log->is_info &&
-        $log->info( "Loaded theme '$theme_id' ok, getting values" );
+        $log->info( "Loaded theme '$theme_id' ok" );
 }
 
 
@@ -400,21 +390,32 @@ sub find_language {
     my $lang_config = CTX->lookup_language_config;
     if ( $self->auth_is_logged_in ) {
         my $user_lang = $self->auth_user->language;
+        $log->is_debug &&
+            $log->debug( "Added language from logged in user: $user_lang" );
         push @lang, $user_lang if ( $user_lang );
     }
     elsif ( my $session_lang = $self->session->{language} ) {
+        $log->is_debug &&
+            $log->debug( "Added language from session: $session_lang" );
         push @lang, ref( $session_lang ) eq 'ARRAY'
                          ? @{ $session_lang } : $session_lang;
     }
     elsif ( my @param_lang = $self->param( $lang_config->{choice_param_name} ) ) {
+        $log->is_debug &&
+            $log->debug( "Added language from parameter: $session_lang" );
         push @lang, @param_lang;
     }
     else {
+        $log->is_debug &&
+            $log->debug( "Added default language: $lang_config->{default_language}" );
         push @lang, $lang_config->{default_language};
     }
 
     if ( my @browser_lang = $self->_find_browser_languages ) {
-        push @lang, @browser_lang;
+        $log->is_debug &&
+            $log->debug( "Added language to head from browser: ",
+                         join( ', ', @browser_lang ) );
+        unshift @lang, @browser_lang;
     }
 
     if ( my @clubber_lang = $self->_find_custom_languages( @lang ) ) {
@@ -430,15 +431,19 @@ sub _find_browser_languages {
     return () unless ( $self->language_header );
     $log ||= get_logger( LOG_REQUEST );
 
-    my @raw_lang_info = split ( /,\s+/, $self->language_header );
+    $log->is_debug &&
+        $log->debug( "Found the following language header from the browser: ",
+                     $self->language_header );
+    my @raw_lang_info = split ( /\s*,\s*/, $self->language_header );
     my @lang_data = ();
     foreach my $lang_and_weight ( @raw_lang_info ) {
         my ( $lang, $weight ) = split( ';', $lang_and_weight );
         $weight ||= 1;
+        $weight =~ s/^q=\s*//;
         push @lang_data, [ $lang, $weight ];
     }
     my @langs = map { $_->[0] }
-                    sort { $a->[1] <=> $b->[1] } @lang_data;
+                    sort { $b->[1] <=> $a->[1] } @lang_data;
     $log->is_debug &&
         $log->debug( "Found the following languages from the browser: ",
                      join( ', ', @langs ) );
@@ -474,7 +479,13 @@ sub language_handle {
         my @langs = $self->language;
         $log->info( "Retrieved languages for request: ", join( ', ', @langs ) );
         $self->{_lang_handle} = OpenInteract2::I18N->get_handle( @langs );
-        $log->debug( "Language handle isa: ", ref( $self->{_lang_handle} ) );
+        if ( $log->is_debug ) {
+            my $type = ref( $self->{_lang_handle} );
+            no strict 'refs';
+            my @parents = @{ $type . '::ISA' };
+            $log->debug( "Language handle is of type: $type with parents: ",
+                         join( ', ', @parents ) );
+        }
     }
     return $self->{_lang_handle};
 }
@@ -493,17 +504,6 @@ sub factory_error {
     die @msg, "\n";
 }
 
-OpenInteract2::Request->register_factory_type(
-                    apache     => 'OpenInteract2::Request::Apache' );
-OpenInteract2::Request->register_factory_type(
-                    apache2    => 'OpenInteract2::Request::Apache2' );
-OpenInteract2::Request->register_factory_type(
-                    cgi        => 'OpenInteract2::Request::CGI' );
-OpenInteract2::Request->register_factory_type(
-                    lwp        => 'OpenInteract2::Request::LWP' );
-OpenInteract2::Request->register_factory_type(
-                    standalone => 'OpenInteract2::Request::Standalone' );
-
 
 ########################################
 # OVERRIDE
@@ -511,9 +511,6 @@ OpenInteract2::Request->register_factory_type(
 # Initialize new object
 sub init          { oi_error 'Subclass must implement init()' }
 
-# Clear out current object
-sub clear_current { oi_error 'Subclass must implement clear_current()' }
-
 1;
 
 __END__
@@ -529,10 +526,7 @@ OpenInteract2::Request - Represent a single request
  OpenInteract2::Request->set_implementation_type( 'cgi' );
  
  # Later...
- use OpenInteract2::Request;
  
- my $req = OpenInteract2::Request->get_current;
- # also:
  my $req = CTX->request;
  print "All parameters: ", join( ', ', $req->param(), "\n";
  print "User agent: ", $req->user_agent(), "\n";
@@ -665,16 +659,17 @@ with that format an exception will be thrown.
 B<assign_request_url( $full_url_path )>
 
 This method is normally only called by the implementing subclass. The
-subclass should pass the full, absolute URL path (no protocol, host or
-port) so the C<url_absolute> and C<url_relative> properties are
-properly set. This also sets the action name and task for use by the
-controller.
+subclass should pass the full, absolute URL path -- no protocol, host
+or port, but query arguments should be included. With this the
+C<url_absolute> and C<url_relative> properties are properly set. The
+method also sets the action name and task for use by the controller,
+delegating the actual work to L<OpenInteract2::URL>.
 
 If you want to do any behind-the-scenes redirection before the
 L<OpenInteract2::Controller|OpenInteract2::Controller> is
 instantiated, you can pass a path to this and the correct action will
 be processed. For instance, you can configure your site to force users
-to login, so no matter what URL is requested by a user who is not
+to login so no matter what URL is requested by a user who is not
 logged in they will always get your login page. This is done in the
 L<OpenInteract2::Auth|OpenInteract2::Auth> class -- if the user is not
 logged in it assigns a new request URL which changes the action
@@ -888,6 +883,11 @@ Returns: the upload object
 
 =head2 Parent initialization
 
+The following methods are available for subclasses -- the idea is they
+get the relevant data in a platform-dependent manner (parsing a
+header, reading an envionment variable, whatever) and pass it to this
+class to parse the data and place them in the right structure.
+
 B<_parse_cookies()>
 
 Reads the C<cookie_header> property and parses it into the name/value
@@ -906,17 +906,14 @@ value as the session ID passed to
 L<OpenInteract2::SessionManager|OpenInteract2::SessionManager> to
 create the session, which is stored in the C<session> property.
 
-B<_find_language()>
-
-...
-
-
 =head1 SEE ALSO
 
 L<Class::Factory|Class::Factory>
 
 L<OpenInteract2::Request::Apache|OpenInteract2::Request::Apache>
 
+L<OpenInteract2::Request::Apache2|OpenInteract2::Request::Apache2>
+
 L<OpenInteract2::Request::CGI|OpenInteract2::Request::CGI>
 
 L<OpenInteract2::Request::LWP|OpenInteract2::Request::LWP>
