@@ -1,6 +1,6 @@
 package OpenInteract2::Request::Apache;
 
-# $Id: Apache.pm,v 1.14 2004/02/18 05:25:28 lachoy Exp $
+# $Id: Apache.pm,v 1.16 2004/11/28 17:50:46 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Request );
@@ -12,7 +12,7 @@ use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Upload;
 use OpenInteract2::URL;
 
-$OpenInteract2::Request::Apache::VERSION = sprintf("%d.%02d", q$Revision: 1.14 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::Apache::VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -37,9 +37,14 @@ sub init {
 
     # Set the URI and parse it
 
-    $self->assign_request_url( $apache->uri );
+    my $full_uri = $apache->uri;
+    my $query_args = $apache->args;
+    if ( $query_args ) {
+        $full_uri .= "?$query_args";
+    }
+    $self->assign_request_url( $full_uri );
 
-    # Setup the GET/SET params
+    # Setup the GET/POST params
 
     my $num_param = 0;
     foreach my $field ( $self->apache->param() ) {
@@ -60,12 +65,13 @@ sub init {
     my $num_uploads = 0;
     foreach my $upload ( $self->apache->upload() ) {
         my $oi_upload = OpenInteract2::Upload->new({
-                              name         => $upload->name,
-                              content_type => $upload->type,
-                              size         => $upload->size,
-                              filehandle   => $upload->fh,
-                              filename     => $upload->filename,
-                              tmp_name     => $upload->tempname });
+            name         => $upload->name,
+            content_type => $upload->type,
+            size         => $upload->size,
+            filehandle   => $upload->fh,
+            filename     => $upload->filename,
+            tmp_name     => $upload->tempname
+        });
         $self->_set_upload( $upload->name, $oi_upload );
         $num_uploads++;
     }
@@ -128,4 +134,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
