@@ -1,6 +1,6 @@
 package OpenInteract2::Request::CGI;
 
-# $Id: CGI.pm,v 1.18 2004/05/17 14:19:50 lachoy Exp $
+# $Id: CGI.pm,v 1.20 2004/11/28 17:50:46 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Request );
@@ -11,15 +11,13 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Upload;
 use OpenInteract2::URL;
 
-$OpenInteract2::Request::CGI::VERSION = sprintf("%d.%02d", q$Revision: 1.18 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::CGI::VERSION = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
 my @FIELDS = qw( cgi );
 OpenInteract2::Request::CGI->mk_accessors( @FIELDS );
 
-my ( $CURRENT );
-
 sub init {
     my ( $self, $params ) = @_;
     $log ||= get_logger( LOG_REQUEST );
@@ -43,8 +41,11 @@ sub init {
     CTX->assign_deploy_url( $base_url );
 
     my $full_url = join( '', $base_url, $cgi->path_info );
-    $log->is_debug &&
-        $log->debug( "Full OI URL '$full_url'" );
+    my $query_args = $cgi->query_string;
+    if ( $query_args ) {
+        $full_url .= "?$query_args";
+    }
+    $log->is_debug && $log->debug( "Full OI URL from CGI: $full_url" );
     $self->assign_request_url( $full_url );
 
     # Then the various headers, properties, etc.
@@ -64,12 +65,9 @@ sub init {
 
     $log->is_info &&
         $log->info( "Finished creating CGI request" );
-    return $CURRENT = $self;
+    return $self;
 }
 
-sub get_current   { return $CURRENT }
-sub clear_current { $CURRENT = undef }
-
 sub _assign_params_from_cgi {
     my ( $self, $cgi ) = @_;
 
