@@ -1,6 +1,6 @@
 package OpenInteract2::Request::LWP;
 
-# $Id: LWP.pm,v 1.19 2004/05/22 15:57:25 lachoy Exp $
+# $Id: LWP.pm,v 1.21 2004/11/28 17:50:46 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Request );
@@ -13,15 +13,13 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Upload;
 
-$OpenInteract2::Request::LWP::VERSION = sprintf("%d.%02d", q$Revision: 1.19 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::LWP::VERSION = sprintf("%d.%02d", q$Revision: 1.21 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
 my @FIELDS = qw( lwp );
 OpenInteract2::Request::LWP->mk_accessors( @FIELDS );
 
-my ( $CURRENT );
-
 sub init {
     my ( $self, $params ) = @_;
     $log ||= get_logger( LOG_REQUEST );
@@ -32,6 +30,7 @@ sub init {
     my $lwp_request = $params->{request};
     $self->lwp( $lwp_request );
 
+    # TODO: check to see that this has the query args on it
     $self->assign_request_url( $lwp_request->uri );
 
     $self->server_name( $params->{server_name} );
@@ -51,14 +50,9 @@ sub init {
     $self->_parse_request;
     $log->is_debug &&
         $log->debug( "Parsed request ok" );
-    $CURRENT = $self;
     return $self;
 }
 
-sub get_current   { return $CURRENT }
-sub clear_current { $CURRENT = undef }
-
-
 sub _parse_request {
     my ( $self ) = @_;
     my $request = $self->lwp;
