@@ -1,6 +1,6 @@
 package OpenInteract2::Request::Standalone;
 
-# $Id: Standalone.pm,v 1.10 2004/02/18 05:25:28 lachoy Exp $
+# $Id: Standalone.pm,v 1.13 2004/11/28 17:50:46 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::Request );
@@ -12,12 +12,10 @@ use OpenInteract2::Upload;
 use OpenInteract2::URL;
 use Sys::Hostname;
 
-$OpenInteract2::Request::Standalone::VERSION = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Request::Standalone::VERSION = sprintf("%d.%02d", q$Revision: 1.13 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
-my ( $CURRENT );
-
 sub init {
     my ( $self, $props ) = @_;
     $log ||= get_logger( LOG_REQUEST );
@@ -29,8 +27,7 @@ sub init {
     # This will die if any problems found
     $self->_check_properties( $props );
 
-    $log->is_debug &&
-        $log->debug( "Full OI URL [$props->{url}]" );
+    $log->is_debug && $log->debug( "Full URL from property: $props->{url}" );
     $self->assign_request_url( $props->{url} );
 
     # Then the various headers, properties, etc.
@@ -81,13 +78,9 @@ sub init {
 
     $log->is_info &&
         $log->info( "Finished creating Standalone request" );
-
-    return $CURRENT = $self;
+    return $self;
 }
 
-sub get_current   { return $CURRENT }
-sub clear_current { $CURRENT = undef }
-
 sub _set_property_defaults {
     my ( $self, $props ) = @_;
     $props->{param}       ||= {};
@@ -295,4 +288,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
