@@ -1,6 +1,6 @@
 package OpenInteract2::Response;
 
-# $Id: Response.pm,v 1.22 2004/04/28 01:29:46 lachoy Exp $
+# $Id: Response.pm,v 1.27 2004/11/09 12:15:32 sjn Exp $
 
 use strict;
 use base qw( Class::Factory Class::Accessor::Fast );
@@ -10,7 +10,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX DEPLOY_URL );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::Response::VERSION = sprintf("%d.%02d", q$Revision: 1.22 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Response::VERSION = sprintf("%d.%02d", q$Revision: 1.27 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -20,7 +20,9 @@ my ( $log );
 # TODO: 'error_hold' is temporary, until we get the error reporting
 # back to the template worked out
 
-my @FIELDS = qw( status controller send_file send_filehandle content );
+my @FIELDS = qw(
+    status controller send_file send_filehandle content charset
+);
 __PACKAGE__->mk_accessors( @FIELDS, 'error_hold' );
 
 my ( $RESPONSE_TYPE, $RESPONSE_CLASS );
@@ -38,15 +40,6 @@ sub get_implementation_type {
     return $RESPONSE_TYPE;
 }
 
-# Retrieve the current object
-
-# XXX: This has the potential of an endless loop if 'get_current()'
-# not defined in impl; maybe check whether it's defined in
-# set_implementation_type()?
-
-sub get_current { return $RESPONSE_CLASS->get_current }
-
-
 sub new {
     my ( $class, @params ) = @_;
     $log ||= get_logger( LOG_RESPONSE );
@@ -76,6 +69,16 @@ sub content_type {
 }
 
 
+sub content_type_header {
+    my ( $self ) = @_;
+    my $content_type = $self->content_type;
+    if ( $self->charset ) {
+        $content_type .= "; charset=" . $self->charset;
+    }
+    return $content_type;
+}
+
+
 # TODO: We may want to dereference $self->{_header} before sending it
 # back, otherwise people can add headers directly to the hash. OTOH,
 # this may be a good thing...
@@ -223,17 +226,6 @@ sub factory_error {
     die @msg, "\n";
 }
 
-__PACKAGE__->register_factory_type(
-                    apache     => 'OpenInteract2::Response::Apache' );
-__PACKAGE__->register_factory_type(
-                    apache2    => 'OpenInteract2::Response::Apache2' );
-__PACKAGE__->register_factory_type(
-                    cgi        => 'OpenInteract2::Response::CGI' );
-__PACKAGE__->register_factory_type(
-                    lwp        => 'OpenInteract2::Response::LWP' );
-__PACKAGE__->register_factory_type(
-                    standalone => 'OpenInteract2::Response::Standalone' );
-
 
 ########################################
 # OVERRIDE
@@ -241,9 +233,6 @@ __PACKAGE__->register_factory_type(
 # Initialize new object
 sub init          { die "Subclass must implement init()" }
 
-# Clear out current object
-sub clear_current { die "Subclass must implement clear_current()" }
-
 # Set/send HTTP headers + cookies + content
 sub send          { die "Subclass must implement send()" }
 
@@ -264,7 +253,7 @@ OpenInteract2::Response - Information about and actions on an HTTP response
  
  use HTTP::Status qw( RC_OK );
  
- my $response = OpenInteract2::Response->get_current;
+ my $response = CTX->response;
  $response->status( RC_OK );                 # default
  $response->content_type( 'text/html' )      # default
  $response->header( 'X-Powered-By' => 'OpenInteract 2.0' );
@@ -283,8 +272,6 @@ OpenInteract2::Response - Information about and actions on an HTTP response
 
 =head2 Class Methods
 
-B<get_current()>
-
 B<set_implementation_type( $type )>
 
 B<get_implementation_type()>
@@ -295,10 +282,25 @@ B<new()>
 
 B<content_type( [ $content_type ] )>
 
+Get/set the content type. This will be used in the header.
+
+B<content_type_header>
+
+Retrieve a content type usable for the header. This includes the
+C<charset> if it has been set.
+
 B<header( [ $name, $value ] )>
 
+If both arguments passed in, set the header C<$name> to C<$value>.
+
+If only C<$name>, return its header value.
+
+If neither, pass a hashref with all set headers.
+
 B<remove_header( $name )>
 
+Deletes the header C<$name> from the response.
+
 B<is_redirect>
 
 Returns true is the C<status> has been set to be a redirect, false if
@@ -318,8 +320,6 @@ B<set_file_info()>
 
 B<init()>
 
-B<clear_current()>
-
 =head1 PROPERTIES
 
 All of the properties can be get and set by their name. For example:
@@ -342,9 +342,9 @@ instance, returning from a '/Foo/edit/' you may want to set the return
 URL to '/Foo/show/' or something else harmless so you don't
 accidentally submit a new 'edit'. (Redirects are good for this, too.)
 
-When set the response object ensures the given URL is located under
-the server context; therefore, the value returned from this property
-is always located under the server context.
+When you set a return URL the response object ensures the given URL is
+located under the server context; therefore, the value returned from
+this property is always located under the server context.
 
 B<send_file> - Filename of file to send directly to the user. It is
 generally a good idea to set the 'Content-Type' header (via
@@ -358,6 +358,9 @@ same information:
  $response->content( $foo );
  $response->content( \$foo );
 
+B<charset> - Set the character set for this response. If unset we do
+not pass it along with the content type.
+
 =head1 SUBCLASSING
 
 The actual work to send the correct data to the client is accomplished
@@ -370,16 +373,6 @@ by a subclass of this class. Subclasses must do the following:
 This method is called after the response is initialized. It must
 return the response object.
 
-=item B<Implement get_current()>
-
-This must return the current response object
-
-=item B<Implement clear_current()>
-
-This must remove any reference to the current response
-object. Successive calls to C<get_current()> before the next response
-object is created must return C<undef>.
-
 =item B<Implement send()>
 
 This method will send the headers (including cookies) and content to
