@@ -1,51 +1,52 @@
 package OpenInteract2::ResultsManage;
 
-# $Id: ResultsManage.pm,v 1.7 2004/02/18 05:25:26 lachoy Exp $
+# $Id: ResultsManage.pm,v 1.12 2004/10/05 03:08:25 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor::Fast );
-use Data::Dumper  qw( Dumper );
+use File::Basename           qw( basename );
+use File::Spec::Functions    qw( catfile );
 use IO::File;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::ResultsIterator;
+use Scalar::Util             qw( blessed );
 use SPOPS::Utility;
 
-$OpenInteract2::ResultsManage::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::ResultsManage::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
-use constant FILENAME_WIDTH => 20;
+use constant FILENAME_WIDTH => 10;
 
 my $LOCK_EXT         = 'lock';
-my $RECORD_SEP       = '-->';
+my $RECORD_SEP       = ' // ';
 my $EXTRA_NAME_SEP   = ',';
-my $MIXED_IDENTIFIER = 'MIXED';
 
 my @FIELDS  = qw(
-    search_id min max results_dir keywords
-    num_records time date extra_name num_extra record_class result_list
+    search_id filename keywords
+    min max per_page page_num
+    num_records time date extra_name result_list
 );
 __PACKAGE__->mk_accessors( @FIELDS );
 
+
+# NOTE: All internal methods should die() instead of throwing an
+# exception, since we wrap everything that could fail in an eval at
+# the user entrance level
+
 ########################################
 # CLASS METHODS
 
 sub new {
-    my ( $pkg, $p ) = @_;
+    my ( $pkg, $params ) = @_;
     my $class = ref $pkg || $pkg;
-    my %data = map { $_ => $p->{ $_ } } @FIELDS;
-    $data{results_dir} ||= $class->get_results_dir;
+    my %data = map { $_ => $params->{ $_ } } @FIELDS;
     return bless( \%data, $class );
 }
 
-sub get_results_dir {
-    my ( $class ) = @_;
-    return CTX->lookup_directory( 'overflow' );
-}
-
 sub find_page_boundaries {
     my ( $class, $page_num, $per_page ) = @_;
     return ( 0, 0 ) unless ( $page_num and $per_page );
@@ -54,19 +55,67 @@ sub find_page_boundaries {
     return ( $min, $max );
 }
 
+sub set_page_boundaries {
+    my ( $self, $page_num, $per_page ) = @_;
+    $self->page_num( $page_num );
+    $self->per_page( $per_page );
+    my ( $min, $max ) = $self->find_page_boundaries( $page_num, $per_page );
+    $self->min( $min );
+    $self->max( $max );
+}
+
 # Note that $item can be a class or an object -- if object, we'll take
 # the number of records from it.
 
 sub find_total_page_count {
-    my ( $item, $per_page, $p_num_records ) = @_;
-    my $num_records = ( ref $item and $item->{num_records} )
-                        ? $item->{num_records} : $p_num_records;
+    my ( $item, $per_page, $num_records ) = @_;
+    if ( blessed( $item ) ) {
+        $per_page    ||= $item->per_page;
+        $num_records ||= $item->num_records;
+    }
     return 0 unless ( $per_page and $num_records );
+
     my $num_pages = $num_records / $per_page;
-    return ( int $num_pages != $num_pages ) ? int( $num_pages ) + 1 : int $num_pages;
+    return ( int $num_pages != $num_pages )
+             ? int( $num_pages ) + 1 : int $num_pages;
 }
 
+sub get_metadata {
+    my ( $item, $search_id ) = @_;
+    $log ||= get_logger( LOG_APP );
 
+    my $self = ( ref( $item ) )
+                 ? $item : $item->new();
+    $self->search_id( $search_id );
+    my $results_filename = $self->_build_results_filename;
+
+    return {} unless ( -f $results_filename );
+    eval {
+        open( META, $results_filename ) || die "Cannot open '$results_filename': $!"
+    };
+    if ( $@ ) {
+        $log->error( "Error opening file '$results_filename' to ",
+                     "read metadata. $@" );
+        return {};
+    }
+    my %meta_info = ();
+    while ( <META> ) {
+        chomp;
+        s/^\s+//;
+        s/\s+$//;
+        last unless ( s/^\#\s*// );
+        my ( $k, $v ) = split /\s*:\s*/, $_, 2;
+        if ( $k =~ /^extra/ ) {
+            push @{ $meta_info{extra_field} }, $v;
+        }
+        else {
+            $meta_info{ $k } = $v;
+        }
+    }
+    close( META );
+    $meta_info{date} = scalar localtime( $meta_info{time} );
+    return \%meta_info;
+}
 
 
 ########################################
@@ -80,64 +129,59 @@ sub clear {
     return $self;
 }
 
+sub assign_metadata {
+    my ( $self, $metadata ) = @_;
+    for my $field ( @FIELDS ) {
+        $self->$field( $metadata->{ $field } ) if ( $metadata->{ $field } );
+    }
+}
 
 ########################################
 # SAVE RESULTS
-########################################
-
-# Save given results to a results file and a meta file
 
 sub save {
     my ( $self, $to_save, $p ) = @_;
     $log ||= get_logger( LOG_APP );
 
-    my ( $is_empty );
-
-    $is_empty++ unless( $to_save );
-    $is_empty++ if ( ref $to_save eq 'ARRAY' and ! scalar @{ $to_save } );
-    $is_empty++ if ( UNIVERSAL::isa( $to_save, 'SPOPS::Iterator' ) and ! $to_save->has_next );
-
-    if ( $is_empty ) {
+    if ( ! $to_save
+         || ( ref $to_save eq 'ARRAY' && ! scalar @{ $to_save } )
+         || ( UNIVERSAL::isa( $to_save, 'SPOPS::Iterator' ) && ! $to_save->has_next ) ) {
         $log->error( "Bailing out of saving search results -- nothing to save!" );
-        return undef;
+        return $self;
     }
 
-    $log->is_debug &&
-        $log->debug( "Trying to save search results." );
+    $log->is_info &&
+        $log->info( "Trying to store search results" );
 
-    my %params = ( force_mixed => $p->{force_mixed},
-                   extra       => $p->{extra},
-                   extra_name  => $p->{extra_name} );
+    my %params = ( extra_name  => $p->{extra_name} );
 
     # First ensure we have a results directory in the object
 
-    $self->{results_dir} ||= $self->get_results_dir;
+    unless ( -d $self->directory ) {
+        oi_error "No configured results directory exists. ",
+                 "(Tried: ", $self->directory, "). Please ensure that ",
+                 "the server configuration key 'dir.overflow' is defined.";
+    }
 
     # Generate a search ID and get the filename, then lock the
     # filename from further use while we're working
 
     $params{search_id} = $self->generate_search_id;
-    $log->debug( "Generated search ID '$params{search_id}'" );
-    $self->results_lock( $params{search_id} );
+    $log->is_debug &&
+        $log->debug( "Generated search ID '$params{search_id}'" );
+    $self->_lock_results( $params{search_id} );
     my ( $num_records );
-    my $out      = IO::File->new();
-    my $meta_out = IO::File->new();
+    my $out = IO::File->new();
 
     # First write out the actual data, then write out the metadata
 
     eval {
-        my $results_file = $self->build_results_filename( $params{search_id} );
+        my $results_file = $self->_build_results_filename( $params{search_id} );
+        $self->filename( basename( $results_file ) );
         $out->open( "> $results_file" )
                     || die "Cannot open '$results_file' for writing: $!\n";
-        my $results_info = $self->persist( $out, $to_save, \%params );
+        $num_records = $self->_persist( $out, $to_save, \%params );
         $out->close();
-
-        my $meta_file = $self->build_meta_filename( $params{search_id} );
-        $meta_out->open( "> $meta_file" )
-                         || die "Cannot open '$meta_file' for writing: $!\n";
-        $self->persist_meta( $meta_out, $results_info, \%params );
-        $meta_out->close();
-        $num_records = $results_info->{num_records};
     };
 
     # If we find an error anywhere along the way, be sure the files
@@ -147,255 +191,150 @@ sub save {
     if ( $@ ) {
         $log->error( "Search result save failure. $@" );
         $out->close();
-        $meta_out->close();
-        $self->results_clear( $params{search_id} );
-        die "Search result save failure: $@\n";
+        $self->_clear_results( $params{search_id} );
+        oi_error "Search result save failure: $@";
     }
 
     # Clear out the lockfile
 
-    $self->results_unlock( $params{search_id} );
+    $self->_unlock_results( $params{search_id} );
 
     # Set various information into the object
 
-    $log->is_debug &&
-        $log->debug( "Results saved ok: $num_records" );
+    $log->is_info &&
+        $log->info( "Results ($num_records) saved ok under ID $params{search_id}" );
     $self->num_records( $num_records );
-    return $self->search_id( $params{search_id} );
+    $self->search_id( $params{search_id} );
+    return $self;
 }
 
 
-sub persist {
+sub _persist {
     my ( $self, $out, $to_save, $params ) = @_;
-    die "Item to be saved must be a reference!\n" unless ( ref $to_save );
+
+    my ( $results );
+
+    # First we have to generate the content to write out
+
     if ( ref $to_save eq 'ARRAY' ) {
-        return $self->persist_list( $out, $to_save, $params );
+        $results = $self->_generate_records_from_list( $to_save, $params );
     }
     elsif ( UNIVERSAL::isa( $to_save, 'SPOPS::Iterator' ) ) {
-        return $self->persist_iterator( $out, $to_save, $params );
+        $results = $self->_generate_records_from_iterator( $to_save, $params );
     }
-    die "Item to be saved must either be arrayref or Iterator!\n";
-}
-
-
-sub persist_list {
-    my ( $self, $out, $to_save, $params ) = @_;
-
-    # See if the resultset is homogenous -- if the user wants it mixed
-    # then keep it that way, otherwise look at the data passed in to
-    # save
-
-    my %info = ( record_class => undef );
-    $info{record_class}   = $MIXED_IDENTIFIER if ( $params->{force_mixed} );
-    $info{record_class} ||= $self->review_results_class( $to_save );
-
-    # 'extra' items are additional pieces of information included with
-    # each record; they can only be saved with non-iterators
-
-    if ( ref $params->{extra} eq 'ARRAY' ) {
-        $info{has_extra}  = ( ref $params->{extra}->[0] eq 'ARRAY' )
-                              ? scalar @{ $params->{extra}->[0] } : 1;
-        $info{extra_name} = $params->{extra_name} || [];
+    else {
+        die "Item to be saved must either be arrayref or iterator!\n";
     }
 
+    my $num_results = scalar( @{ $results } );
+    # next, start writing the file with the metadata...
 
-    # Go through the items to save and derive a value and class for
-    # each -- it's ok if the class is blank since that means we're
-    # just saving raw data
-
-    my $count = 0;
-    foreach my $item ( @{ $to_save } ) {
-        my @result_info = ( ref $item )
-                            ? ( ref $item, scalar( $item->id ) )
-                            : ( $info{record_class}, $item );
-        $result_info[0] = '' if ( $info{record_class} eq $MIXED_IDENTIFIER );
-        if ( $info{has_extra} ) {
-            if ( ref $params->{extra}->[ $count ] eq 'ARRAY' ) {
-                push @result_info, @{ $params->{extra}->[ $count ] };
-            }
-            else {
-                push @result_info, $params->{extra}->[ $count ];
-            }
-        }
-        $out->print( join( $RECORD_SEP, @result_info ), "\n" );
-        $count++;
-    }
-    $info{num_records} = $count;
-    return \%info;
-}
-
-
-sub persist_iterator {
-    my ( $self, $out, $to_save, $params ) = @_;
-    my %info = ( record_class => undef, num_records => 0 );
-    while ( my $item = $to_save->get_next ) {
-        $info{record_class} ||= ref $item;
-        $out->print( join( $RECORD_SEP, $info{record_class},
-                                        scalar( $item->id ) ), "\n" );
-        $info{num_records}++;
-    }
-    return \%info;
-}
-
-
-# See whether we have a homogenous resultset or not -- return the
-# class of all objects if they're all the same, otherwise return the
-# global $MIXED_IDENTIFIER which tells us it's heterogeneous
-
-sub review_results_class {
-    my ( $self, $result_list ) = @_;
-    my ( $main_class );
-    foreach my $result ( @{ $result_list } ) {
-        my $result_class = ref $result;
-        next unless ( $result_class );
-        return $MIXED_IDENTIFIER if ( $main_class and $main_class ne $result_class );
-        $main_class ||= $result_class;
-    }
-    return $main_class;
-}
-
-
-########################################
-# METADATA
-########################################
-
-sub persist_meta {
-    my ( $self, $out, $info, $params ) = @_;
-    $self->{results_dir} ||= $self->find_results_dir;
-    my %meta_info = (
-         time         => time,
-         num_records  => $info->{num_records},
-         record_class => $info->{record_class},
-         has_extra    => $info->{has_extra},
-         extra_name   => $info->{extra_name},
-         num_extra    => ( ref $info->{extra_name} eq 'ARRAY' )
-                           ? scalar $info->{extra_name} : 0,
-         filename     => $params->{filename},
-         results_dir  => $self->results_dir,
-         search_id    => $params->{search_id},
+    $out->print(
+        join( "\n",
+              "# time:        " . time,
+              "# num_records: " . $num_results,
+              "# filename:    " . $self->filename,
+              "# directory:   " . $self->directory,
+              "# search_id:   " . $params->{search_id} ),
+        "\n",
     );
-    $out->print( Dumper( \%meta_info ) );
-}
 
-
-sub get_meta {
-    my ( $self, $search_id ) = @_;
-    $log ||= get_logger( LOG_APP );
-
-    my $meta_filename = $self->build_meta_filename( $search_id );
-    return {} unless ( -f $meta_filename );
-    eval { open( META, $meta_filename ) || die "Cannot open ($meta_filename): $!" };
-    if ( $@ ) {
-        $log->error( "Error opening meta file. $@" );
-        return {};
+    my $extra_name = $params->{extra_name} || [];
+    my $num_extra = 0;
+    foreach my $name ( @{ $extra_name } ) {
+        $num_extra++;
+        $out->print( "# extra $num_extra: ", $name, "\n" );
     }
-    local $/ = undef;
-    no strict 'vars';
-    my $meta_info = eval <META>;
-    close( META );
-    $meta_info->{date} = scalar localtime( $meta_info->{time} );
-    return $meta_info;
+
+    # ...and then the actual records
+
+    $out->print( join( "\n", @{ $results } ) );
+
+    return $num_results;
 }
 
 
+sub _generate_records_from_list {
+    my ( $self, $record_list ) = @_;
+
+    my @all_records = ();
+    foreach my $item ( @{ $record_list } ) {
+        next unless ( $item );
+        my @result_info = ();
+        if ( blessed( $item ) ) {
+            push @result_info, ref( $item ), $item->id;
+        }
+        elsif ( ref( $item ) eq 'ARRAY' ) {
+            @result_info = @{ $item };
+        }
+        else {
+            die "Record #", scalar( @all_records ), " is neither an object ",
+                "nor an arrayref. (Record: $item )\n";
+        }
+        push @all_records, join( $RECORD_SEP, @result_info );
+    }
+    $log->is_debug &&
+        $log->debug( "Generated ", scalar( @all_records ), " records ",
+                     "from list" );
+    return \@all_records;
+}
+
+
+sub _generate_records_from_iterator {
+    my ( $self, $iterator ) = @_;
+    my @all_records = ();
+    while ( my $item = $iterator->get_next ) {
+        push @all_records, join( $RECORD_SEP, ref( $item ), scalar( $item->id ) );
+    }
+    return \@all_records;
+}
+
+
+
 ########################################
 # RETRIEVE RESULTS
-########################################
-
-# Returns either ( \@classes, \@ids, $num_records ) or \@ids depending
-# on context
 
 sub retrieve {
     my ( $self, $p ) = @_;
     $log ||= get_logger( LOG_APP );
 
     unless ( $self->search_id ) {
-        die "Cannot retrieve results without a search_id! Please ",
-            "set at object initialization or as a property of the ",
-            "object before running retrieve().\n";
+        oi_error "Cannot retrieve results without a search_id! Please ",
+                 "set at object initialization or as a property of the ",
+                 "object before running retrieve().";
     }
 
+    my $return_type = lc $p->{return_type} || 'list';
+
     # 'min' and 'max' can be properties or passed in
 
-    $self->min( $p->{min} ) unless ( defined $self->min );
-    $self->max( $p->{max} ) unless ( defined $self->max );
+    my $min = $p->{min} || $self->min;
+    my $max = $p->{max} || $self->max;
+    $self->min( $min );
+    $self->max( $max );
 
     # Clear out the number of records
 
     $self->num_records(0);
 
-    $log->is_debug &&
-        $log->debug( "Retrieving raw search results for ",
+    $log->is_info &&
+        $log->info( "Retrieving raw search results for ",
                      "ID '", $self->search_id, "'" );
-    $self->assign_results_to_object( $self->retrieve_raw_results( $p ) );
 
-    # If they asked for an iterator return it, but first clear out any
-    # min/max values since they've already been preselected
+    my $raw_results = $self->_retrieve_raw_results;
+    $log->is_info &&
+        $log->info( "Found: ", scalar @{ $raw_results }, " results; asked ",
+                    "to return '$return_type'" );
 
-    if ( $p->{return} eq 'iterator' ) {
-        $self->min(0);
-        $self->max(0);
-        $p->{min} = $p->{max} = 0;
-        return $self->retrieve_iterator( $p );
-    }
-    return $self;
+    return ( $return_type eq 'iterator' )
+             ? $self->_retrieve_iterator( $raw_results, $p )
+             : $raw_results;
 }
 
+# Retrieve the results and store them in the object, respecting the
+# min/max set in the object.
 
-# Note that this only works on saved SPOPS objects
-
-sub retrieve_iterator {
-    my ( $self, $p ) = @_;
-    $log ||= get_logger( LOG_APP );
-
-    # 'min' and 'max' can be properties or passed in
-
-    $self->min( $p->{min} ) unless ( defined $self->min );
-    $self->max( $p->{max} ) unless ( defined $self->max );
-
-    $log->is_debug &&
-        $log->debug( "Retrieving search iterator for ID",
-                     "'", $self->search_id, "'" );
-
-    unless ( $self->result_list ) {
-        $self->assign_results_to_object( $self->retrieve_raw_results( $p ) );
-    }
-    if ( $self->num_records <= 0 ) {
-        return OpenInteract2::ResultsIterator->new({ results => $self });
-    }
-
-    unless ( $self->record_class ) {
-        die "Cannot create iterator! Search results were not saved with ",
-            "a classname. [Search ID: ", $self->search_id, "]\n";
-    }
-    if ( $self->record_class eq $MIXED_IDENTIFIER ) {
-        $self->min(0);
-        $self->max(0);
-        return OpenInteract2::ResultsIterator->new({
-                     results       => $self,
-                     skip_security => $p->{skip_security} });
-    }
-    return $self->record_class->fetch_iterator({ id_list => $self->get_id_list });
-}
-
-
-# Take the result list internally and return a list of all IDs
-
-sub get_id_list {
-    my ( $self ) = @_;
-    unless ( $self->result_list ) {
-        die "Results not yet saved for this object!\n"
-    }
-    return [ map { $_->{id} } @{ $self->result_list } ];
-}
-
-
-
-# Returns a hashref of information about the results, including the ID
-# list, the class, results save time. Pass in min/max in the hashref
-# (second arg) to have the results be paged.
-
-sub retrieve_raw_results {
+sub _retrieve_raw_results {
     my ( $self, $p ) = @_;
     $log ||= get_logger( LOG_APP );
 
@@ -403,45 +342,61 @@ sub retrieve_raw_results {
         oi_error "No search_id defined in object!";
     }
 
-    my $meta_info = $self->get_meta({ search_id => $self->search_id });
+    my $meta_info = $self->get_metadata( $self->search_id );
+    $self->assign_metadata( $meta_info );
+
     $log->is_debug &&
         $log->debug( "[Run on: $meta_info->{date}] ",
                      "[Saved: $meta_info->{num_records}] ",
                      "[Type: $meta_info->{record_class}]" );
-    if ( $meta_info->{num_records} <= 0 ) {
-        return $meta_info;
+    if ( $self->num_records <= 0 ) {
+        return []
     }
 
-    my $filename = $self->build_results_filename;
-    eval { open( RESULTS, $filename ) || die "Cannot open '$filename' for reading: $!\n" };
+    my $filename = $self->_build_results_filename;
+    eval {
+        open( RESULTS, $filename )
+            || die "Cannot open '$filename' for reading: $!"
+    };
     if ( $@ ) {
         $log->error( "Search result retrieval failure. $@" );
-        return undef;
+        return [];
     }
 
+    my @records = ();
+
+    my ( $min, $max ) = ( $self->min, $self->max );
     my $count = 1;
-    my $min = ( defined $self->min ) ? $self->min : $p->{min};
-    my $max = ( defined $self->max ) ? $self->max : $p->{max};
+
     while ( <RESULTS> ) {
+        next if ( /^\#/ );
         if ( $min and $count < $min ) { $count++; next; }
         if ( $max and $count > $max ) { last; }
         chomp;
-        my ( $item_class, $item_value, @extra ) =
-            split /$RECORD_SEP/, $_, 2 + $meta_info->{num_extra};
-        my $result_info = { id => $item_value };
-        if ( $meta_info->{record_class} eq $MIXED_IDENTIFIER ) {
-            $result_info->{class} = $item_class;
-        }
-
-        # Set the extra information in the result -- note that it's
-        # ALWAYS an arrayref, even if there's only one.
-
-        $result_info->{extra} = \@extra if ( $meta_info->{num_extra} );
-        push @{ $meta_info->{result_list} }, $result_info;
+        push @records, [ split /$RECORD_SEP/, $_ ];
         $count++;
     }
     close( RESULTS );
-    return $meta_info;
+
+    # Reset these since we've already got the data...
+
+    $self->min(0);
+    $self->max(0);
+
+    $self->result_list( \@records );
+    return $self->result_list;
+}
+
+
+# Note that this only works on saved SPOPS objects
+
+sub _retrieve_iterator {
+    my ( $self, $raw_results, $p ) = @_;
+    return OpenInteract2::ResultsIterator->new({
+        results       => $raw_results,
+        extra_name    => $self->extra_name,
+        skip_security => $p->{skip_security}
+    });
 }
 
 
@@ -456,57 +411,43 @@ sub assign_results_to_object {
 
 #######################################
 # FILENAME/DIRECTORY METHODS
-########################################
 
-sub build_results_filename {
+sub directory {
+    my ( $self, $directory ) = @_;
+    if ( $directory ) {
+    }
+    unless ( $self->{directory} ) {
+        $self->{directory} = CTX->lookup_directory( 'overflow' );
+    }
+    return $self->{directory};
+}
+
+sub _build_results_filename {
     my ( $self, $p_search_id ) = @_;
     my $search_id = $self->search_id || $p_search_id;
     unless ( $search_id ) {
-        die "Cannot build a results filename without a search_id ",
-            "as property or parameter!\n";
+        oi_error "Cannot build a results filename without a ",
+                 "search_id as property or parameter!";
     }
-    unless ( $self->results_dir ) {
-        $self->results_dir( $self->get_results_dir );
-    }
-    return File::Spec->catfile( $self->results_dir, $search_id );
+    return catfile( $self->directory, $search_id );
 }
 
 
-sub build_meta_filename {
+sub _build_lock_filename {
     my ( $self, $p_search_id ) = @_;
     my $search_id = $self->search_id || $p_search_id;
     unless ( $search_id ) {
-        die "Cannot build a results filename without a search_id ",
-            "as property or parameter!\n";
+        oi_error "Cannot build a lock filename without a search_id ",
+                 "as property or parameter!";
     }
-    unless ( $self->results_dir ) {
-        $self->results_dir( $self->get_results_dir );
-    }
-    return File::Spec->catfile( $self->results_dir, "$search_id.meta" );
-}
-
-
-sub build_lock_filename {
-    my ( $self, $p_search_id ) = @_;
-    my $search_id = $self->search_id || $p_search_id;
-    unless ( $search_id ) {
-        die "Cannot build a lock filename without a search_id ",
-            "as property or parameter!\n";
-    }
-    unless ( $self->results_dir ) {
-        $self->results_dir( $self->get_results_dir );
-    }
-    return File::Spec->catfile( $self->results_dir, "$search_id.$LOCK_EXT" );
+    return catfile( $self->directory, "$search_id.$LOCK_EXT" );
 }
 
 
 sub get_all_result_filenames {
     my ( $self ) = @_;
-    unless ( $self->results_dir ) {
-        $self->results_dir( $self->get_results_dir );
-    }
-    opendir( RESULTS, $self->results_dir )
-             || die "Cannot open results directory '", $self->results_dir, "': $!";
+    opendir( RESULTS, $self->directory )
+             || oi_error "Cannot open results directory '", $self->directory, "': $!";
     my @results_files = grep ! /\./, grep { length $_ == FILENAME_WIDTH } readdir( RESULTS );
     closedir( RESULTS );
     return \@results_files;
@@ -518,11 +459,10 @@ sub get_all_result_filenames {
 # during this method because if this is called we have bigger
 # problems...
 
-sub results_clear {
+sub _clear_results {
     my ( $self, $search_id ) = @_;
-    eval { $self->results_unlock( $search_id ) };
-    unlink( $self->build_results_filename( $search_id ) );
-    unlink( $self->build_meta_filename( $search_id ) );
+    eval { $self->_unlock_results( $search_id ) };
+    unlink( $self->_build_results_filename( $search_id ) );
 }
 
 
@@ -538,31 +478,39 @@ sub generate_search_id {
     my ( $self ) = @_;
     $log ||= get_logger( LOG_APP );
 
-    unless ( $self->results_dir ) {
-        $self->results_dir( $self->get_results_dir );
-    }
-
-    unless ( -d $self->results_dir ) {
-        $log->error( "Search results directory '", $self->results_dir, "'",
+    my $results_dir = $self->directory;
+    unless ( -d $results_dir ) {
+        $log->error( "Search results directory '$results_dir'",
                       "is not a directory" );
-        die "Configuration option for writing search results ",
-            "'", $self->results_dir, "' is not a directory";
+        oi_error "Configuration option for writing search results ",
+                 "'$results_dir' is not a directory";
     }
-    unless ( -w $self->results_dir ) {
-        $log->error( "Search results dir '", $self->results_dir, "' is not writeable" );
-        die "Configuration option for writing search results ",
-            "'", $self->results_dir, "' exists but is not writeable";
+    unless ( -w $results_dir ) {
+        $log->error( "Search results directory '$results_dir' ",
+                     "is not writeable" );
+        oi_error "Configuration option for writing search results ",
+                 "'$results_dir' exists but is not writeable";
     }
+    my $iterations = 0;
+    my ( $search_id );
+FIND_ID:
     while ( 1 ) {
-        my $search_id = SPOPS::Utility->generate_random_code( FILENAME_WIDTH );
-        my $filename = $self->build_results_filename( $search_id );
-        my $lockfile = $self->build_lock_filename( $search_id );
+        $search_id = SPOPS::Utility->generate_random_code( FILENAME_WIDTH );
+        my $filename = $self->_build_results_filename( $search_id );
+        my $lockfile = $self->_build_lock_filename( $search_id );
+        if ( $iterations > 20 ) {
+            oi_error "Tried 20 times to get a search ID in '$results_dir'; ",
+                     "this indicates that either the random number generator ",
+                     "is malfunctioning or there are so many files in the ",
+                     "directory that we cannot generate a unique ID.";
+        }
+        $iterations++;
         next if ( -f $filename || -f $lockfile );
-        $log->is_debug &&
-            $log->debug( "Found non-existent search info for ",
-                         "'$search_id' in '", $self->results_dir, "'" );
-        return $search_id;
+        $log->is_debug && $log->debug( "Found unused search filename ",
+                                       "in '$results_dir': '$search_id'" );
+        last FIND_ID;
     }
+    return $search_id;
 }
 
 
@@ -572,11 +520,11 @@ sub generate_search_id {
 
 # Lock the results file using another file
 
-sub results_lock {
+sub _lock_results {
     my ( $self, $search_id ) = @_;
-    my $lock_file = $self->build_lock_filename( $search_id );
+    my $lock_file = $self->_build_lock_filename( $search_id );
     open( LOCK, "> $lock_file" )
-        || die "Cannot open lockfile '$lock_file' for writing: $!";
+        || oi_error "Cannot open lockfile '$lock_file' for writing: $!";
     print LOCK scalar localtime;
     close( LOCK );
 }
@@ -584,12 +532,12 @@ sub results_lock {
 
 # Unlock the results file by deleting the lockfile.
 
-sub results_unlock {
+sub _unlock_results {
     my ( $self, $search_id ) = @_;
-    my $lock_file = $self->build_lock_filename( $search_id );
+    my $lock_file = $self->_build_lock_filename( $search_id );
     return unless ( -f $lock_file );
     unlink( $lock_file )
-          || die "Cannot remove lockfile '$lock_file': $!";
+          || oi_error "Cannot remove lockfile '$lock_file': $!";
 }
 
 1;
@@ -615,7 +563,7 @@ OpenInteract2::ResultsManage - Save and retrieve generic search results
  ... another request from this user ...
  
  my $results = OpenInteract2::ResultsManage->new({
-                              search_id => $R->{session}{this_search_id} });
+                              search_id => $request->session->{this_search_id} });
  my $result_list = $results->retrieve();
  
  # Use with paged results
@@ -684,13 +632,6 @@ You can force all the IDs passed in to be of a particular class.
 
 =item *
 
-B<force_mixed> (bool) (optional)
-
-Forces the resultset to be treated as heterogeneous (mixed) even if
-all objects are of the same class.
-
-=item *
-
 B<extra> (\@) (optional)
 
 Each item represents extra information to save along with each
@@ -791,6 +732,35 @@ out yourself.
 
 Parameters: same as C<retrieve()>
 
+B<get_metadata( $search_id )>
+
+Fetch metadata only about a search. Returns a hashref with the
+following keys:
+
+=over 4
+
+=item *
+
+B<time> - results storage time in epoch seconds
+
+=item *
+
+B<date> - results storage time in human-readable format
+
+=item *
+
+B<num_records> - number of records stored
+
+=item *
+
+B<filename> - name of file (only the filename)
+
+=item *
+
+B<directory> - 
+
+=back
+
 B<find_total_page_count( $records_per_page, [ $num_records ] )>
 
 If called as an object then use 'num_records' property of object. If
@@ -824,17 +794,17 @@ Example:
 
 =head1 INTERNAL METHODS
 
-B<build_results_filename()>
+B<_build_results_filename()>
 
 B<generate_search_id()>
 
-B<results_lock()>
+B<_lock_results()>
 
-B<results_unlock()>
+B<_unlock_results()>
 
-B<results_clear()>
+B<_clear_results()>
 
-B<retrieve_raw_results()>
+B<_retrieve_raw_results()>
 
 =head1 DATA FORMAT
 
@@ -933,27 +903,6 @@ more use out of this module.
  objects and see if the usage holds up (including with the
  ResultsIterator).
 
-B<Objectify?>
-
-Think about creating a 'search_results' object that can access the
-resultset along with metadata about the results (number of items, time
-searched, etc.). This would likely prove easier to work with in the
-future.
-
-What would also be interesting is combine this with the interface for
-L<SPOPS::Iterator|SPOPS::Iterator> and the currently impelemented
-L<OpenInteract2::ResultsIterator|<OpenInteract2::ResultsIterator>, so
-we could do something like:
-
- my $search = OpenInteract2::ResultsManage->new( $search_id );
- print "Search initially run: $search->{search_date}\n",
-       "Number of results: $search->{num_records}\n";
- $search->set_min( 10 );
- $search->set_max( 25 );
- while ( my $obj = $search->get_next ) {
-   print "Object retrieved is a ", ref $obj, " with ID ", $obj->id, "\n";
- }
-
 =head1 COPYRIGHT
 
 Copyright (c) 2001-2004 Chris Winters. All rights reserved.
