@@ -1,6 +1,6 @@
 package OpenInteract2::SPOPS;
 
-# $Id: SPOPS.pm,v 1.25 2004/02/26 00:58:57 lachoy Exp $
+# $Id: SPOPS.pm,v 1.26 2004/11/27 20:47:21 lachoy Exp $
 
 use strict;
 use Digest::MD5              qw( md5_hex );
@@ -11,7 +11,7 @@ use OpenInteract2::Exception qw( oi_error );
 use OpenInteract2::Util;
 use SPOPS::ClassFactory      qw( OK NOTIFY );
 
-$OpenInteract2::SPOPS::VERSION = sprintf("%d.%02d", q$Revision: 1.25 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SPOPS::VERSION = sprintf("%d.%02d", q$Revision: 1.26 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -266,12 +266,17 @@ sub fetch_updates {
 # SECURITY
 
 # Override method in SPOPS::Secure since we already know the
-# user/group information from $R
+# user/group information from the context
 
 sub get_security_scopes {
     my ( $self, $p ) = @_;
     my $req = CTX->request;
-    return ( $req->auth_user, $req->auth_group );
+    if ( $req ) {
+        return ( $req->auth_user, $req->auth_group );
+    }
+    else {
+        return ( undef, [] );
+    }
 }
 
 
@@ -292,7 +297,7 @@ sub get_supergroup_id  {
 
 sub global_datasource_handle {
     my ( $self, $connect_key ) = @_;
-    $connect_key ||= $self->CONFIG->{datasource};
+    $connect_key ||= $self->CONFIG->{datasource_config}{spops};
     return CTX->datasource( $connect_key );
 }
 
