@@ -1,12 +1,12 @@
 package OpenInteract2::SPOPS::LDAP;
 
-# $Id: LDAP.pm,v 1.6 2004/02/17 04:30:21 lachoy Exp $
+# $Id: LDAP.pm,v 1.7 2004/06/22 11:54:17 sjn Exp $
 
 use strict;
 use base qw( OpenInteract2::SPOPS );
 use OpenInteract2::Context   qw( CTX );
 
-$OpenInteract2::SPOPS::LDAP::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SPOPS::LDAP::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 # See OpenInteract2::Config::Initializer for initialization behavior
 
@@ -16,7 +16,7 @@ $OpenInteract2::SPOPS::LDAP::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /
 sub connection_info {
     my ( $self, $connect_key ) = @_;
     $connect_key ||= $self->get_connect_key();
-    return \%{ $self->global_config->{ldap_info}{ $connect_key } };
+    return \%{ $self->global_config->{datasource}{ $connect_key } };
 }
 
 
