@@ -1,6 +1,6 @@
 package OpenInteract2::SQLInstall;
 
-# $Id: SQLInstall.pm,v 1.20 2004/05/22 02:01:48 lachoy Exp $
+# $Id: SQLInstall.pm,v 1.24 2004/12/05 20:46:56 lachoy Exp $
 
 use strict;
 use base qw( Class::Accessor::Fast );
@@ -11,7 +11,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use SPOPS::Import;
 
-$OpenInteract2::SQLInstall::VERSION  = sprintf("%d.%02d", q$Revision: 1.20 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SQLInstall::VERSION  = sprintf("%d.%02d", q$Revision: 1.24 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -44,6 +44,8 @@ sub new_from_package {
 
 sub new {
     my ( $class, $params ) = @_;
+    $log ||= get_logger( LOG_INIT );
+
     my $self = bless( { _status    => {},
                         _error     => {},
                         _statement => {},
@@ -148,6 +150,10 @@ sub install_all {
     unless ( UNIVERSAL::isa( $self->package, 'OpenInteract2::Package' ) ) {
         oi_error 'Cannot install without first setting package';
     }
+
+    $log->is_info &&
+        $log->info( "Installing structure, data and security for package ",
+                    $self->package->full_name );
     $self->install_structure;
     $self->install_data;
     $self->install_security;
@@ -163,6 +169,11 @@ sub install_structure {
     unless ( UNIVERSAL::isa( $self->package, 'OpenInteract2::Package' ) ) {
         oi_error 'Cannot install structure without first setting package';
     }
+
+    $log->is_info &&
+        $log->info( "Installing structure for package ",
+                    $self->package->full_name );
+
     my $package_name = $pkg->name;
 
     # Note: We can't have the importer send the SQL directly to the
@@ -188,6 +199,8 @@ sub install_structure {
 STRUCTURE:
     foreach my $structure_set ( @sets ) {
         my ( $ds_name, $ds_info, $ds );
+        $log->is_info &&
+            $log->info( "Trying to evaluate structure '$structure_set'" );
         eval {
             if ( $structure_set eq 'system' ) {
                 $ds_name = CTX->lookup_system_datasource_name;
@@ -334,7 +347,9 @@ DATAFILE:
                 next DATAFILE;
             }
         }
-        $log->warn( "Data structure read from '$full_file': ", CTX->dump( $data_struct ) );
+        $log->is_debug &&
+            $log->debug( "Data structure read from '$full_file': ",
+                         CTX->dump( $data_struct ) );
         my $import_type = $data_struct->[0]->{import_type};
         unless ( $import_type ) {
             $self->_set_state( $full_file,
@@ -348,25 +363,21 @@ DATAFILE:
             $importer = SPOPS::Import->new( $import_type )
                                      ->assign_raw_data( $data_struct );
         };
-        if ( $@ ) {
+        if ( $@ || ! $importer ) {
+            my $error = $@ || 'No exception, but importer object not returned';
             $self->_set_state( $full_file,
                                undef,
-                               "Failed to create importer: $@",
+                               "Failed to create importer: $error",
                                undef );
             next DATAFILE;
         }
 
-        # XXX: Need to modify this to handle Import::DBI::Data
-        # format. Allow packager to specify into which datasource we
-        # should stick the data (e.g., 'system', 'datasource: foo' or
-        # an spops-key)
-
         my ( $ds_name );
         if ( $import_type eq 'object' ) {
             my $spops_class = $data_struct->[0]->{spops_class};
             $ds_name = $spops_class->CONFIG->{datasource};
         }
-        elsif ( $import_type eq 'dbdata' ) {
+        elsif ( $import_type =~ /^(dbdata|dbupdate|dbdelete)$/ ) {
             my $ds_lookup = $data_struct->[0]->{datasource_pointer};
             if ( $ds_lookup eq 'system' ) {
                 $ds_name = CTX->lookup_system_datasource_name;
@@ -900,7 +911,7 @@ for you as well.
 
 =head2 Subclassing: Methods to override
 
-First, the basics. Here's the scoop on what you can override:
+First, the basics. Here is the scoop on what you can override:
 
 B<init( \%params )>
 
@@ -908,7 +919,7 @@ Called from C<new()> just before returning the object. All items in
 C<\%params> that are object fields have already been set in the
 object, the other entries remain untouched.
 
-If there's a problem you should C<die> with a useful error message.
+If there is a problem you should C<die> with a useful error message.
 
 Returns: nothing.
 
@@ -938,7 +949,7 @@ For structures to be installed to the OI system database.
 
 For structures to be installed to a particular datasource 'NAME'. This
 is useful for tables that can be configured for a particular
-datasource but aren't an SPOPS object. The method should lookup the
+datasource but are not an SPOPS object. The method should lookup the
 proper datasource from the server configuration or some other
 resource.
 
@@ -1032,7 +1043,7 @@ This is B<optional> and called by the process behind C<install_data()>
 and C<install_security()>. By default OI will change fields marked
 under 'transform_default' and 'transform_now' as discussed in the data
 import documentation below. But if you have other install-time
-transformations you'd like to accomplish you can do them here.
+transformations you would like to accomplish you can do them here.
 
 The C<$importer> is a L<SPOPS::Import|SPOPS::Import> object. You can
 get the field order and modify the data in-place:
@@ -1044,7 +1055,7 @@ get the field order and modify the data in-place:
      $data->[ $idx ] = ( $install_time % 2 == 0 ) ? 'even' : 'odd';
  }
 
-So here's an example of a subclass that puts a number of the above
+So here is an example of a subclass that puts a number of the above
 items together:
 
  package OpenInteract2::MyPackage::SQLInstall;
@@ -1065,7 +1076,7 @@ items together:
      return 'objectA';
  }
  
- # We don't care what the value of $set is since there's only one
+ # We don't care what the value of $set is since there is only one
  # possible value
  
  sub get_structure_file {
@@ -1098,7 +1109,7 @@ override C<get_migration_information()>, specifying the keys and
 tables to use for the migration. This is recommended.
 
 Note that C<$old_datasource> is just a DBI database handle which you
-can create and connect in any manner you choose. It's normally
+can create and connect in any manner you choose. It is normally
 specified by the user and created by the framework for you.
 
 B<get_migration_information()>
@@ -1183,7 +1194,7 @@ data to be saved change the SPOPS object.
 
 =back
 
-Here's an example of the most common case: we're moving data between a
+Here is an example of the most common case: we're moving data between a
 table and an SPOPS class with no transformation, the same table name
 and the same field names:
 
@@ -1192,7 +1203,7 @@ and the same field names:
      return [ \%user_info ];
  }
 
-Here's an example where we're using the same table name between the
+Here is an example where we're using the same table name between the
 two databases but the fieldnames are changing:
 
  sub get_migration_info {
@@ -1203,7 +1214,7 @@ two databases but the fieldnames are changing:
      return [ \%user_info ];
  }
 
-Here's an example where the table names change as well:
+Here is an example where the table names change as well:
 
  sub get_migration_info {
      my %user_info = (
@@ -1216,7 +1227,7 @@ Here's an example where the table names change as well:
      return [ \%user_info ];
  }
 
-And here's an example of a transformation subroutine that smashes the
+And here is an example of a transformation subroutine that smashes the
 first and last name into a new field, wiki name:
 
  sub _create_wiki_name {
@@ -1243,7 +1254,7 @@ tables that aren't represented by SPOPS objects.
 Note that you cannot specify a destination datasource for this type of
 migration. We just use the default DBI datasource.
 
-For each B<data-to-data> migration here's what you need to specify:
+For each B<data-to-data> migration here is what you need to specify:
 
 =over 4
 
@@ -1251,7 +1262,7 @@ For each B<data-to-data> migration here's what you need to specify:
 
 B<table> ($ or \%)
 
-You can either use a scalar to name the table, in which case it's the
+You can either use a scalar to name the table, in which case it is the
 same name in the old and new databases, or you can name the table the
 old data are held in using the key 'old', new data using 'new'.
 
@@ -1272,13 +1283,13 @@ B<transform_sub> (\& or \@) (optional)
 Pass along any transformation subroutines in an arrayref of
 coderefs. (A single routine can be passed by itself.) Each subroutine
 should take three arguments: the migration information, the arrayref
-of data pulled from the database, and a hashref of new field to that
-field's value. The routine should not return anything, instead
+of data pulled from the database, and a hashref of new field to the
+value of that field. The routine should not return anything, instead
 modifying the hashref of new field data in place.
 
 =back
 
-Here's an example of the most common case: we're moving data between
+Here is an example of the most common case: we're moving data between
 two tables with the same structure with no transformation:
 
  sub get_migration_info {
@@ -1287,7 +1298,7 @@ two tables with the same structure with no transformation:
      return [ \%sys_group_info ];
  }
 
-Here's an example where we're using the same table name between the
+Here is an example where we're using the same table name between the
 two databases but the fieldnames are changing:
 
  sub get_migration_info {
@@ -1297,7 +1308,7 @@ two databases but the fieldnames are changing:
      return [ \%sys_group_info ];
  }
 
-Here's an example where the table names change as well:
+Here is an example where the table names change as well:
 
  sub get_migration_info {
      my %sys_group_info = ( table => { old => 'sys_group_user',
@@ -1316,7 +1327,7 @@ up some more.
 
 The data file discussed below is a Perl data structure. This does
 against the general OI2 bias against using data structures for humans
-to edit, but since this is generally a write-once operation it's not
+to edit, but since this is generally a write-once operation it is not
 as important that it be human-readable.
 
 To begin, there are two elements to a data file. The first element
@@ -1342,7 +1353,8 @@ B<SQL Processing>
 
 SQL processing allows you to present elements of a SQL statement and
 plug in values as many times as necessary. This can be used most
-anywhere and for anything.
+anywhere and for anything. And you can use this for updating and
+deleting data as well as inserting.
 
 =head2 Object Processing
 
@@ -1413,27 +1425,49 @@ There are currently just a few behaviors you can set to transform the
 data before it gets saved (see C<transform_data()> above), but the
 interface is there to do just about anything you can imagine.
 
-If you're interested in learning more about this process see
+If you are interested in learning more about this process see
 L<SPOPS::Manual::ImportExport|SPOPS::Manual::ImportExport>.
 
-=head2 SQL Processing
+=head2 SQL Processing: Inserting Raw Data
 
 The actions performed when you just want to insert data into tables is
 similar to those performed when you are inserting objects. The only
 difference is that you need to specify a little more. Here is an
 example:
 
-  $data_link = [ { import_type => 'dbdata',
-                   sql_table   => 'sys_group_user',
-                   field_order => [ qw/ group_id user_id / ] },
+  $data_link = [ { import_type        => 'dbdata',
+                   datasource_pointer => 'group',
+                   sql_table          => 'sys_group_user',
+                   field_order        => [ qw/ group_id user_id / ] },
                  [ 1, 1 ]
   ];
 
-So we specify the import type ('dbdata'), the table to operate on
+So we specify the import type ('dbdata', which corresponds to
+L<SPOPS::Import::DBI::Data>), the table to operate on
 ('sys_group_user'), the order of fields in the data rows
 ('field_order', just like with processing objects) and then list the
 data.
 
+You must also tell OI2 which datasource to use using the
+'datasource_pointer' parameter. Typically you will want to use the
+datasource associated with a particular SPOPS object, which you can do
+by specifying the name of the SPOPS object:
+
+ # uses the datasource associated with the SPOPS 'group' object
+ datasource_pointer => 'group',
+
+You can also explicitly name the datasource:
+
+ # name the actual datasource to use
+ datasource_pointer => 'datasource: main_server',
+
+Finally, you can tell OI2 to use whatever it is using as the 'system'
+datasource, which is mapped in the 'datasource_config.system' server
+configuration key:
+
+ # use the 'system' datasource
+ datasource_pointer => 'system',
+
 You are also able to specify the data types. Most of the time this
 should not be necessary: if the database driver (e.g.,
 L<DBD::mysql|DBD::mysql>) supports it, the
@@ -1465,6 +1499,85 @@ Here is a sample usage:
 
 Additionally you can create Perl code to do this for you.
 
+=head2 SQL Processing: Updating Data
+
+In a SQL installation you can also update existing data. This can be
+very useful if you are upgrading package versions and need to change
+data formats, modify content, or whatever.
+
+Declaring an update is fairly simple -- unlike the 'dbdata' import
+type you do not need to specify any data, just metadata:
+
+  $update = [ { import_type => 'dbupdate',
+                datasource_pointer  => 'group',
+                sql_table   => 'sys_group_user',
+                where       => 'group_id > ?',
+                value       => [ '10' ],
+                field       => [ 'name' ],
+                field_value => [ 'A New Group' ],
+              } ];
+
+(See L<SQL Processing: Inserting Data> for how to declare a datasource
+using 'datasource_pointer'.)
+
+The fields you can use are specified in
+L<SPOPS::Import::DBI::Update>. Note that you can do this
+programmatically as well:
+
+ sub install_data {
+     my ( $self ) = @_;
+     my $action_name = 'update group name';
+
+     my $importer = SPOPS::Import->new( 'dbupdate' );
+     my $ds_name = CTX->spops_config->{group}{datasource};
+     $importer->db( CTX->datasource( $ds_name ) );
+     $importer->table( 'sys_group_user' );
+     $importer->where( 'group_id > ?' );
+     $importer->add_where_param( '10' );
+     $importer->set_update_data({ name => 'A New Group' });
+     my $status = eval { $importer->run() };
+     if ( $@ ) {
+         my $error = $@ || $status->[0][2];
+         $self->_set_state( $action_name,
+                            undef,
+                            "Failed to update group names: $error",
+                            undef );
+     }
+     else {
+         $self->_set_state( $action_name,
+                            $status->[0][1],
+                            'Updated group names ok',
+                            undef );
+     }
+
+     # If you have additional processing...
+     return $self->SUPER::install_data();
+ }
+
+=head2 SQL Processing: Deleting Data
+
+In a SQL installation you can also delete existing data. This can be
+very useful if you are upgrading package versions and need to remove
+deprecated data or ensure an existing dataset is consistent.
+
+Declaring a delete is fairly simple -- unlike the 'dbdata' import
+type you do not need to specify any data, just metadata:
+
+  $update = [ { import_type => 'dbdelete',
+                datasource_pointer => 'group',
+                sql_table   => 'sys_group_user',
+                where       => 'group_id > ?',
+                value       => [ '10' ]
+              } ];
+
+(See L<SQL Processing: Inserting Data> for how to declare a datasource
+using 'datasource_pointer'.)
+
+The fields you can use are specified in
+L<SPOPS::Import::DBI::Delete>. You can perform this action
+programmatically as well -- see the docs for updating data for an
+example.
+
 =head1 DEVELOPERS: CUSTOM BEHAVIOR
 
 (Or: "The Declaration Is Not Enough")
@@ -1492,12 +1605,12 @@ and any errors that were encountered.
 
 The word B<file> is in quotes because it should really be something
 more abstract like 'distinct action'. But because most of the time
-actions are file-based and everyone understands files, that's the way
-it is. But you're not constrained by this. So in the example above
+actions are file-based and everyone understands files, that is the way
+it is. But you are not constrained by this. So in the example above
 where we create the superuser object I could give that action a name
 of 'create administrator' and everyone would know what I meant.
 
-For example, here's what such an implementation might look like:
+For example, here is what such an implementation might look like:
 
  sub install_data {
      my ( $self ) = @_;
@@ -1555,10 +1668,6 @@ B<_set_datasource( $file, $datasource_name )>
 
 B<_set_state( $file, 0|1, $error, $statement )>
 
-=head1 BUGS
-
-None known.
-
 =head1 TO DO
 
 B<Dumping data for transfer>
