@@ -1,6 +1,6 @@
 package OpenInteract2::SessionManager;
 
-# $Id: SessionManager.pm,v 1.7 2004/02/18 05:25:26 lachoy Exp $
+# $Id: SessionManager.pm,v 1.8 2004/11/27 22:56:51 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
@@ -8,7 +8,7 @@ use OpenInteract2::Constants qw( :log SESSION_COOKIE );
 use OpenInteract2::Context   qw( CTX DEPLOY_URL );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::SessionManager::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SessionManager::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -28,7 +28,7 @@ sub create {
         $class->_create_session( $session_config, $session_id )
     };
     if ( $@ ) {
-        $log->warn( "Error fetching session with ID [$session_id]: $@\n",
+        $log->warn( "Error fetching session with ID '$session_id': $@\n",
                     "Continuing..." );
         OpenInteract2::Cookie->expire( SESSION_COOKIE );
         return {};
@@ -85,42 +85,17 @@ sub is_session_valid {
 sub save {
     my ( $class, $session ) = @_;
     $log ||= get_logger( LOG_SESSION );
-    return 1 unless ( ref $session );
+
+    unless ( ref $session ) {
+        $log->is_info && $log->info( "No session found, not storing" );
+        return 1;
+    }
 
     if ( tied %{ $session } ) {
-        my %useful_session_keys = map { $_ => 1 } keys %{ $session };
-        delete $useful_session_keys{_session_id};
-        delete $useful_session_keys{is_new};
-        if ( ref $session->{_oi_cache} and
-                 scalar keys %{ $session->{_oi_cache} } == 0 ) {
-            delete $useful_session_keys{_oi_cache};
-        }
-        if ( scalar keys %useful_session_keys > 0 ) {
-            my $is_new = $session->{is_new};
-            delete $session->{is_new};
-            $class->_save_session( $session, $is_new );
-        }
-        else {
-            $log->is_debug &&
-                $log->debug( "Tied session found, not saving since ",
-                             "it doesn't have useful info" );
-        }
+        $class->_store_tied_session( $session );
     }
     elsif ( ref $session eq 'HASH' ) {
-        return 1 unless ( scalar keys %{ $session } );
-        $log->is_info &&
-            $log->info( "Create new session with data from hashref" );
-        my $new_session = $class->_create_session;
-        if ( $new_session ) {
-            foreach my $key ( keys %{ $session } ) {
-                $new_session->{ $key } = $session->{ $key };
-            }
-            $class->_save_session( $new_session, 1 );
-        }
-        else {
-            $log->error( "No value returned from _create_session; ",
-                         "this shouldn't happen..." );
-        }
+        $class->_store_hashref_session( $session );
     }
     else {
         $log->warn( "No session reference returned from request. ",
@@ -129,7 +104,52 @@ sub save {
     return 1;
 }
 
+sub _store_tied_session {
+    my ( $class, $session ) = @_;
+    my %useful_session_keys = map { $_ => 1 } keys %{ $session };
+    delete $useful_session_keys{_session_id};
+    delete $useful_session_keys{is_new};
+    if ( ref $session->{_oi_cache} and
+         scalar keys %{ $session->{_oi_cache} } == 0 ) {
+        delete $useful_session_keys{_oi_cache};
+    }
+    if ( scalar keys %useful_session_keys > 0 ) {
+        $log->is_info &&
+            $log->info( "Storing tied session because of useful keys: ",
+                        join( ', ', keys %useful_session_keys ) );
+        my $is_new = $session->{is_new};
+        delete $session->{is_new};
+        $class->_save_session( $session, $is_new );
+    }
+    else {
+        $log->is_debug &&
+            $log->debug( "Tied session, no useful info; removing..." );
+        tied( %{ $session } )->delete();
+    }
+}
 
+sub _store_hashref_session {
+    my ( $class, $session ) = @_;
+    unless ( scalar keys %{ $session } ) {
+        $log->is_debug &&
+            $log->debug( "Hashref session, no useful info; not storing..." );
+        return 1;
+    }
+    $log->is_info &&
+        $log->info( "Create new session with data from hashref using ",
+                    "keys: ", keys %{ $session } );
+    my $new_session = $class->_create_session;
+    if ( $new_session ) {
+        foreach my $key ( keys %{ $session } ) {
+            $new_session->{ $key } = $session->{ $key };
+        }
+        $class->_save_session( $new_session, 1 );
+    }
+    else {
+        $log->error( "No value returned from _create_session; ",
+                     "this shouldn't happen..." );
+    }
+}
 
 sub _save_session {
     my ( $class, $session, $is_new ) = @_;
@@ -149,7 +169,8 @@ sub _save_session {
     untie %{ $session };
     if ( $is_new ) {
         $log->is_info &&
-            $log->info( "Sending cookie for new session" );
+            $log->info( "Sending cookie for new session; cookie should ",
+                        "expire in: ", $expiration );
         OpenInteract2::Cookie->create(
                               { name    => SESSION_COOKIE,
                                 value   => $session_id,
