@@ -1,6 +1,6 @@
 package OpenInteract2::SessionManager::DBI;
 
-# $Id: DBI.pm,v 1.3 2004/02/18 05:25:28 lachoy Exp $
+# $Id: DBI.pm,v 1.4 2004/11/27 22:55:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SessionManager );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::SessionManager::DBI::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SessionManager::DBI::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -32,7 +32,7 @@ sub _create_session {
     if ( $impl_class =~ /MySQL$/ ) {
         $session_params->{LockHandle} = $session_params->{Handle};
         $log->is_debug &&
-            $log->debug( "Using MySQL session store, with LockHandle parameter" );
+            $log->debug( "Using MySQL store + LockHandle parameter" );
     }
 
     my %session = ();
