@@ -1,15 +1,16 @@
 package OpenInteract2::SessionManager::File;
 
-# $Id: File.pm,v 1.4 2004/02/21 20:38:54 lachoy Exp $
+# $Id: File.pm,v 1.6 2004/11/27 22:55:54 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SessionManager );
+use File::Spec::Functions    qw( catdir );
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::SessionManager::File::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SessionManager::File::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -21,7 +22,7 @@ sub _create_session {
     my $impl_class = $session_config->{impl_class};
     my $session_params = $session_config->{params};
     $log->is_info &&
-        $log->info( "Trying to fetch File session [$session_id] ",
+        $log->info( "Trying to fetch File session '$session_id' ",
                     "with [Dir: $session_params->{Directory}] ",
                     "[LockDir: $session_params->{LockDirectory}] ",
                     "[Impl: $impl_class]" );
@@ -41,13 +42,24 @@ sub _validate_config {
                       "correct session implementation. (Normally: ",
                       "Apache::Session::File)" );
     }
+
     my $dir = $session_config->{params}{Directory};
+    my $website_dir = CTX->lookup_directory( 'website' );
+    if ( $dir && $dir !~ m!^(/|\w:)! ) {
+        $dir = catdir( $website_dir, $dir );
+        $session_config->{params}{Directory} = $dir;
+    }
     unless ( -d $dir ) {
         push @error_msg,
             join( '', "Server configuration key 'session_info.params.Directory' ",
                       "must refer to a valid directory. (Given: $dir)" );
     }
+
     my $lock_dir = $session_config->{params}{LockDirectory};
+    if ( $lock_dir && $lock_dir !~ m!^(/|\w:)! ) {
+        $lock_dir = catdir( $website_dir, $lock_dir );
+        $session_config->{params}{LockDirectory} = $lock_dir;
+    }
     unless ( -d $lock_dir ) {
         push @error_msg,
             join( '', "Server configuration key 'session_info.params.LockDirectory' ",
@@ -89,6 +101,18 @@ B<_validate_config( $session_config )>
 
 Ensure our configuration is valid.
 
+For both the directories: if the directory is defined and there is no
+leading '/' or '\w:' pattern we prepend the website directory. So:
+
+ [session_info params]
+ Directory     = cache/sessions
+ LockDirectory = cache/sessions_lock
+
+becomes:
+
+ Directory     => "$WEBSITE_DIR/cache/sessions"
+ LockDirectory => "$WEBSITE_DIR/cache/sessions_lock"
+
 =over 4
 
 =item *
@@ -101,8 +125,7 @@ Specify the directory in which to store sessions.
 
 B<session_info.params.LockDirectory> (REQUIRED)
 
-Specify the directory in which to store lock information. No default
-is currently defined.
+Specify the directory in which to store lock information.
 
 =back
 
