@@ -1,6 +1,6 @@
 package OpenInteract2::SessionManager::SQLite;
 
-# $Id: SQLite.pm,v 1.3 2004/02/18 05:25:28 lachoy Exp $
+# $Id: SQLite.pm,v 1.4 2004/11/27 22:55:53 lachoy Exp $
 
 use strict;
 use base qw( OpenInteract2::SessionManager );
@@ -9,7 +9,7 @@ use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 
-$OpenInteract2::SessionManager::SQLite::VERSION = sprintf("%d.%02d", q$Revision: 1.3 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::SessionManager::SQLite::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -26,10 +26,11 @@ sub _create_session {
         $params{DataSource} = "DBI:SQLite:$dsn";
     }
     else {
-        oi_error "Insufficient parameters (this should have been caught earlier)";
+        oi_error "Insufficient parameters (this should have been caught ",
+                 "earlier): no 'Handle' or 'DataSource' defined";
     }
     $log->is_debug &&
-        $log->debug( "Trying to fetch SQLite session [$session_id] ",
+        $log->debug( "Trying to fetch SQLite session '$session_id' ",
                      "[DSN: $params{DataSource}] [Impl: $impl_class] ",
                      "[Handle: $params{Handle}]" );
     my %session = ();
