@@ -1,6 +1,6 @@
 package OpenInteract2::Setup;
 
-# $Id: Setup.pm,v 1.42 2004/03/19 03:09:37 lachoy Exp $
+# $Id: Setup.pm,v 1.54 2004/12/05 20:54:03 lachoy Exp $
 
 use strict;
 use File::Copy               qw( cp );
@@ -8,22 +8,22 @@ use File::Basename           qw();
 use File::Path               qw();
 use File::Spec::Functions    qw( :ALL );
 use Log::Log4perl            qw( get_logger );
-use OpenInteract2::Config;
 use OpenInteract2::Config::Initializer;
-use OpenInteract2::Config::Base;
+use OpenInteract2::Config::GlobalOverride;
 use OpenInteract2::ContentGenerator;
-use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Context   qw( CTX );
+use OpenInteract2::Constants qw( :log );
 use OpenInteract2::Exception qw( oi_error );
-use OpenInteract2::Filter;
 use OpenInteract2::I18N::Initializer;
 use OpenInteract2::Manage;
+use OpenInteract2::Observer;
 use OpenInteract2::Package;
 use OpenInteract2::Repository;
+use OpenInteract2::URL; # don't get rid of this...
 use OpenInteract2::Util;
 use SPOPS::Initialize;
 
-$OpenInteract2::Setup::VERSION = sprintf("%d.%02d", q$Revision: 1.42 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Setup::VERSION = sprintf("%d.%02d", q$Revision: 1.54 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -32,30 +32,10 @@ sub new {
     return bless( {}, $class );
 }
 
+# Subclasses can override
 
-########################################
-# SERVER CONFIG
-
-# Just grab the config and set the runtime info.
-
-sub read_server_config {
-    my ( $self ) = @_;
-    my $base_config = CTX->base_config;
-    unless ( ref $base_config eq 'OpenInteract2::Config::Base' ) {
-        oi_error "'base_config' property of context not set properly";
-    }
-    my $server_config_file = $base_config->get_server_config_file;
-    unless ( $server_config_file ) {
-        oi_error "Cannot read server configuration: file not defined ",
-                 "in base config";
-    }
-    my $server_conf = OpenInteract2::Config->new(
-                            $base_config->config_type,
-                            { filename => $server_config_file } );
-    $server_conf->{dir}{website} = $base_config->website_dir;
-    $server_conf->translate_dirs;
-    return $server_conf;
-}
+sub run_pre_process  {}
+sub run_post_process {}
 
 
 ########################################
@@ -70,6 +50,8 @@ sub read_repository {
     unless ( ref $base_config eq 'OpenInteract2::Config::Base' ) {
         oi_error "'base_config' property of context not set properly";
     }
+    get_logger( LOG_INIT )->info( "Creating context from base config ",
+                                  "with '", $base_config->website_dir, "'" );
     return OpenInteract2::Repository->new( $base_config );
 }
 
@@ -81,6 +63,8 @@ sub read_packages {
         oi_error "Cannot retrieve packages for a website without first ",
                  "opening and assigning a repository to the context.";
     }
+    get_logger( LOG_INIT )->info( "Retrieving packages from repository ",
+                                  "with '", $repos->website_dir, "'" );
     return $repos->fetch_all_packages;
 }
 
@@ -92,11 +76,18 @@ sub read_packages {
 # separate directory -- if it currently exists we clear it out first.
 
 sub create_temp_lib {
-    my ( $self, $params ) = @_;
+    my ( $self, $params, $do_skip ) = @_;
     $log ||= get_logger( LOG_INIT );
 
     my $full_temp_lib_dir = CTX->lookup_temp_lib_directory;
     unshift @INC, $full_temp_lib_dir;
+    $log->info( "Added '$full_temp_lib_dir' to \@INC" );
+
+    if ( $do_skip && -d $full_temp_lib_dir ) {
+        $log->info( "Passed command to skip temp_lib creation and it ",
+                    "already exists; returning" );
+        return;
+    }
 
     my $create_option = $params->{temp_lib_create};
     my $do_create = ( $create_option and $create_option eq 'create' );
@@ -122,6 +113,7 @@ sub create_temp_lib {
             oi_error "Tried to remove directory '$full_temp_lib_dir' but ",
                      "no directories removed. Please check permissions.";
         }
+        $log->info( "Removed existing temp lib dir ok" );
     }
     eval { mkdir( $full_temp_lib_dir, 0777 ) || die $! };
     if ( $@ ) {
@@ -130,7 +122,8 @@ sub create_temp_lib {
 
     my $packages = CTX->packages;
     unless ( ref $packages eq 'ARRAY' and scalar @{ $packages } ) {
-        oi_error "Property 'packages' must be set in context";
+        oi_error "Cannot read perl modules from packages to copy into ",
+                 "temp lib directory: property 'packages' not set";
     }
 
     my ( @all_files );
@@ -219,8 +212,8 @@ ACTIONFILE:
             $log->is_debug &&
                 $log->debug( "Action file: $full_action_path" );
             my $action_ini = eval {
-                OpenInteract2::Config::Ini->new(
-                                   { filename => $full_action_path });
+                OpenInteract2::Config::IniFile->read_config({
+                    filename => $full_action_path });
             };
             if ( $@ ) {
                 $log->error( "Failed to read '$full_action_path': $@" );
@@ -329,14 +322,14 @@ sub register_action_types {
 ########################################
 # INITIALIZE OBSERVERS
 
-# sets the filter registry in CTX, adds config watchers to
+# sets the observer registry in CTX, adds config watchers to
 # OI2::Config::Initializer
 
 sub initialize_observers {
     my ( $self ) = @_;
 
-    # Filters
-    OpenInteract2::Filter->initialize;
+    # Observers
+    OpenInteract2::Observer->initialize;
 
     # Configuration watchers
     OpenInteract2::Config::Initializer->read_observers;
@@ -371,7 +364,8 @@ SPOPSFILE:
                 $log->debug( "SPOPS file: $spops_file" );
             my $full_spops_path = $package->find_file( $spops_file );
             my $spops_ini = eval {
-                OpenInteract2::Config::Ini->new({ filename => $full_spops_path });
+                OpenInteract2::Config::IniFile->read_config({
+                    filename => $full_spops_path });
             };
             if ( $@ ) {
                 $log->error( "Failed to read '$full_spops_path': $@" );
@@ -496,6 +490,40 @@ sub read_localized_messages {
 }
 
 
+########################################
+# INDEXERS
+
+sub initialize_indexers {
+    my ( $self ) = @_;
+    $log ||= get_logger( LOG_INIT );
+
+    my $all_idx_config = CTX->lookup_fulltext_config;
+    unless ( ref $all_idx_config eq 'HASH' ) {
+        $log->warn( "Fulltext configuration does not return a ",
+                    "hash reference; continuing with setup, but ",
+                    "this could bode poorly for server operation." );
+        return;
+    }
+
+    foreach my $indexer_name ( keys %{ $all_idx_config } ) {
+        next if ( $indexer_name eq 'default' );
+        my $indexer_class = $all_idx_config->{ $indexer_name }{class};
+        unless ( $indexer_class ) {
+            $log->warn( "Indexer '$indexer_name' is not associated with ",
+                        "a class; continuing with setup,  but this could ",
+                        "bode poorly for server operation." );
+        }
+        eval "require $indexer_class";
+        if ( $@ ) {
+            oi_error "Error bringing in indexer '$indexer_name' ",
+                     "class '$indexer_class': $@";
+        }
+        $log->is_info &&
+            $log->info( "Included indexer '$indexer_name' class ",
+                        "'$indexer_class' ok" );
+    }
+}
+
 ########################################
 # DATASOURCES
 
@@ -555,8 +583,7 @@ sub create_cache {
 
     my $cache_config = CTX->lookup_cache_config;
     unless ( lc $cache_config->{use} eq 'yes' ) {
-        $log->is_debug &&
-            $log->debug( "Cache not configured for usage" );
+        $log->is_debug && $log->debug( "Cache not configured for usage" );
         return undef;
     }
 
@@ -570,10 +597,11 @@ sub create_cache {
         return undef;
     }
     my $cache = $cache_class->new( $cache_config );
-    $log->is_debug &&
-        $log->debug( "Cache setup ok" );
+    $log->is_debug && $log->debug( "Cache setup with '$cache_class' ok" );
 
     if ( $cache_config->{cleanup} eq 'yes' ) {
+    $log->is_debug &&
+        $log->debug( "Cache configured for cleanup at startup, purging..." );
         $cache->purge;
     }
 
@@ -585,8 +613,28 @@ sub create_cache {
 
 sub read_system_classes {
     my ( $self ) = @_;
-    my $system_classes = CTX->lookup_class;
-    return $self->require_module({ class => [ values %{ $system_classes } ] });
+
+    # first read the system classes...
+
+    my $conf_system_classes = CTX->lookup_class;
+
+    # TODO: fix this (don't include 'template' class in 'system_class'?)
+    # Don't include the SiteTemplate file at startup because it gets
+    # copied later to the tmplib and included
+    my @system_classes = grep { $_ ne 'OpenInteract2::SiteTemplate' }
+                              values %{ $conf_system_classes };
+    return $self->require_module({ class => \@system_classes });
+}
+
+sub register_in_factory {
+    my ( $self, $mappings, $factory ) = @_;
+    $log ||= get_logger( LOG_INIT );
+    while ( my ( $impl_name, $impl_class ) = each %{ $mappings } ) {
+        $log->is_info &&
+            $log->info( "Registering in factory $factory: ",
+                        "$impl_name => $impl_class" );
+        $factory->register_factory_type( $impl_name, $impl_class );
+    }
 }
 
 
@@ -643,15 +691,7 @@ OpenInteract2::Setup - Setup an OpenInteract2::Context object
  # Just used for less typing...
  
  my $setup = OpenInteract2::Setup->new;
- 
- # Grab server configuration
- 
- my $config = $setup->read_server_config({
-                              website_dir => '/path/to/mysite' });
- 
- my $config = $setup->read_server_config({
-                              base_config => $base_config });
- 
+  
  # Create a temporary library -- a single directory where we copy all
  # Perl modules from the packages used. (The 'create' option clears
  # out the old directory and replaces it.)
@@ -683,10 +723,76 @@ OpenInteract2::Setup - Setup an OpenInteract2::Context object
  my $required = $setup->require_module({ class => \@class_list });
  my $required = $setup->require_module({ filename => 'apache_modules.dat' });
  
+ # Declare a custom subclass for setup in $WEBSITE_DIR/conf/server.ini
+ [system_class]
+ setup = My::CustomSetup
+ 
+ package My::CustomSetup;
+ 
+ use base qw( OpenInteract2::Setup );
+ 
+ sub run_pre_process {
+     my ( $self ) = @_;
+     # perform actions before the setup runs
+ }
+ 
+ sub run_post_process {
+     my ( $self ) = @_;
+     # perform actions after the setup runs
+ }
+
 =head1 DESCRIPTION
 
+This class exists only to setup the L<OpenInteract2::Context> object
+and only gets used once, when the context is first created.
+
 =head1 METHODS
 
+=head2 Subclassing
+
+You can create your own routines to run at context initialization by
+telling OpenInteract to use your setup class. How to do this:
+
+ # In $WEBSITE_DIR/conf/server.ini
+ 
+ [system_class]
+ setup = My::CustomSetup
+
+This tells OI about your class. Now you can override functionality
+from L<OpenInteract2::Setup> and also implement hooks to run before
+and/or after the setup process:
+
+ package My::CustomSetup;
+ 
+ use base qw( OpenInteract2::Setup );
+ use File::Path             qw( rmtree );
+ use OpenInteract2::Context qw( CTX );
+ 
+ sub run_post_process {
+     my ( $self ) = @_;
+     # initialize Class::DBI classes, load cached data, whatever....
+ }
+ 
+ # always recreate the temporary library
+ 
+ sub create_temp_dir {
+     my ( $self ) = @_;
+     my $temp_lib = CTX->lookup_temp_lib_directory;
+     rmtree( $temp_lib );
+     return $self->SUPER::create_temp_lib;
+ }
+
+B<run_pre_process()>
+
+This method is called just after the L<OpenInteract2::Context> is
+created and has read in the server configuration.
+
+B<run_post_process()>
+
+This method is called after all setup has completed.
+
+=head2 Setup methods
+
 B<read_server_config()>
 
 The C<base_config> property of the context must be defined before this
@@ -724,7 +830,7 @@ B<create_temp_dir( \%params )>
 Optionally copies all .pm files from all packages in a website to a
 temporary library directory. Unlike OI 1.x the default is to leave the
 directory as-is if it already exists and only overwrite it on
-demand. So if the directory exists and the refresh file doesn't exist
+demand. So if the directory exists and the refresh file does not exist
 (more below), no files will be copied unless the 'temp_lib_create' key
 in C<\%params> is set to 'create'.
 
@@ -733,7 +839,7 @@ an exception is thrown.
 
 The refresh file is created by certain OI2 management tasks and
 signals that the library directory needs to be refreshed. One such
-task is installing a new package, the assumption being that you'll
+task is installing a new package, the assumption being that you will
 only need to refresh the temporary library directory when the
 libraries actually change.
 
@@ -838,14 +944,14 @@ B<initialize_action_classes( \@action_classes )>
 Calls C<init_at_startup()> on each class in
 C<\@action_classes>. Catches any exceptions thrown and logs them but
 continues with the process. A class is considered successfully
-initialized if it doesn't throw an exception.
+initialized if it does not throw an exception.
 
 Returns: Arrayref of all classes successfully initialized.
 
 B<initialize_observers()>
 
-Initializes the filter observers from the server and packages (see
-L<OpenInteract2::Filter|OpenInteract2::Filter>), reads the
+Initializes the observers from the server and packages (see
+L<OpenInteract2::Observer|OpenInteract2::Observer>), reads the
 configuration observers from the server and packages (see
 L<OpenInteract2::Config::Initializer|OpenInteract2::Config::Initializer>).
 
@@ -902,6 +1008,12 @@ which does all the work toward creating and initializing SPOPS classes.
 
 Returns: Arrayref of SPOPS classes properly read and initialized.
 
+B<initialize_indexers()>
+
+Bring in the 'class' for each of the configured full-text indexers.
+
+Returns: nothing; if we cannot include a class we throw an exception
+
 B<initialize_controller()>
 
 Reads in all controllers from server configuration and registers them
