@@ -1,6 +1,6 @@
 package OpenInteract2::TT2::Plugin;
 
-# $Id: Plugin.pm,v 1.10 2004/05/22 02:03:39 lachoy Exp $
+# $Id: Plugin.pm,v 1.16 2004/11/25 03:58:57 lachoy Exp $
 
 use strict;
 use base qw( Template::Plugin );
@@ -15,7 +15,7 @@ use OpenInteract2::URL;
 use SPOPS::Secure              qw( :level :scope );
 use SPOPS::Utility;
 
-$OpenInteract2::TT2::Plugin::VERSION  = sprintf("%d.%02d", q$Revision: 1.10 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::TT2::Plugin::VERSION  = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -71,7 +71,7 @@ SYMBOL:
 
 sub show_all_plugins {
     my ( $self ) = @_;
-    my $generator = CTX->content_generator( 'tt' );
+    my $generator = CTX->content_generator( 'TT' );
 
     # Yes, this is relying on a private data structure...
     my %plugin_info = %{ $generator->{_plugin_class} };
@@ -168,7 +168,7 @@ sub box_remove {
 
 sub object_description {
     my ( $self, $obj ) = @_;
-    return {} unless ( ref $obj and $obj->isa( 'SPOPS' ) );
+    return {} unless ( ref $obj and $obj->can( 'object_description' ) );
     return $obj->object_description;
 }
 
@@ -341,6 +341,11 @@ sub html_decode {
 
 my $U = OpenInteract2::URL->new();
 
+sub add_params_to_url {
+    my ( $self, $url, $p ) = @_;
+    return $U->add_params_to_url( $url, $p );
+}
+
 sub make_url {
     my ( $self, $p ) = @_;
     $log ||= get_logger( LOG_TEMPLATE );
@@ -348,26 +353,27 @@ sub make_url {
         $log->debug( "Plugin trying to create URL with: ",
                      join( '; ', map { "$_ = $p->{$_}" } keys %{ $p } ) );
     my ( $url_base );
+    my $no_escape = $p->{do_not_escape};
+    delete $p->{do_not_escape};
     if ( $p->{BASE} ) {
         $url_base = $p->{BASE};
         delete $p->{ $_ } for ( qw( ACTION TASK BASE IMAGE STATIC ) );
-        return $U->create( $url_base, $p );
+        return $U->create( $url_base, $p, $no_escape );
     }
     elsif ( $p->{ACTION} ) {
         my ( $action, $task ) = ( $p->{ACTION}, $p->{TASK} );
         delete $p->{ $_ } for ( qw( ACTION TASK BASE IMAGE STATIC ) );
-        return $U->create_from_action(
-                         $action, $task, $p );
+        return $U->create_from_action( $action, $task, $p, $no_escape );
     }
     elsif ( $p->{IMAGE} ) {
         my $image_url = $p->{IMAGE};
         delete $p->{ $_ } for ( qw( ACTION TASK BASE IMAGE STATIC ) );
-        return $U->create_image( $image_url, $p );
+        return $U->create_image( $image_url, $p, $no_escape );
     }
     elsif ( $p->{STATIC} ) {
         my $static_url = $p->{STATIC};
         delete $p->{ $_ } for ( qw( ACTION TASK BASE IMAGE STATIC ) );
-        return $U->create_static( $static_url, $p );
+        return $U->create_static( $static_url, $p, $no_escape );
     }
     else {
         return q{javascript:alert('Incorrect parameters passed to make_url()')};
@@ -512,8 +518,7 @@ sub is_admin {
 
 sub return_url {
     my ( $self ) = @_;
-    return CTX->response->return_url()
-           || CTX->request->url_absolute();
+    return CTX->response->return_url() || CTX->request->url_absolute();
 }
 
 
@@ -706,6 +711,10 @@ OpenInteract2::TT2::Plugin - Custom OpenInteract functionality in templates
  
  Item: [% OI.html_decode( news.news_item ) %]
  
+ # Add parameters to an existing URL
+ [% display_no_template_url = OI.add_params_to_url( my_path, no_template = 'yes' ) %]
+ <a href="[% display_no_template_url %]">View Printable</a>
+
  # Works, but not as useful...
  [% edit_url = OI.make_url( BASE = '/User/show/', user_id = OI.login.user_id,
                             edit = 1, show_all = 'yes' ) %]
@@ -1172,6 +1181,14 @@ displays:
 
  <p>This is the first paragraph</p>
 
+B<add_params_to_url( $url, \%params )>
+
+Delegates to L<OpenInteract2::URL> for C<add_params_to_url()> which
+just adds the key/value pairs in C<\%params> to C<$url>, adding a
+query separator if necessary and doing any escaping of the
+paramters.. Note that C<$url> is already presumed to be contextualized
+(under the correct deployment context) and will not be escaped.
+
 B<make_url( \%params )>
 
 Creates a URL given a number of parameters, taking care to perform any
