@@ -1,19 +1,16 @@
 package OpenInteract2::URL;
 
-# $Id: URL.pm,v 1.20 2004/03/16 21:00:44 lachoy Exp $
+# $Id: URL.pm,v 1.28 2004/11/27 18:27:33 lachoy Exp $
 
 use strict;
 use Log::Log4perl            qw( get_logger );
 use OpenInteract2::Constants qw( :log );
-use OpenInteract2::Context   qw(
-    CTX DEPLOY_URL DEPLOY_IMAGE_URL DEPLOY_STATIC_URL
-);
+use OpenInteract2::Context   qw( CTX DEPLOY_URL DEPLOY_IMAGE_URL DEPLOY_STATIC_URL );
 use OpenInteract2::Log       qw( uchk );
 use URI;
 
 use constant QUERY_ARG_SEPARATOR => '&amp;';
 
-# shorten some typing...
 my ( $log );
 
 sub new {
@@ -26,7 +23,7 @@ sub new {
 
 sub parse_absolute_to_relative {
     my ( $class, $url_absolute ) = @_;
-    my $deployed_under = DEPLOY_URL;;
+    my $deployed_under = DEPLOY_URL;
     $url_absolute =~ s/^$deployed_under//;
     return $url_absolute;
 }
@@ -77,7 +74,7 @@ sub create_relative_to_absolute {
 }
 
 sub create {
-    my ( $class, $url_base, $params ) = @_;
+    my ( $class, $url_base, $params, $do_not_escape ) = @_;
     $log ||= get_logger( LOG_OI );
     my $param_info = ( $log->is_debug )
                        ? join( '; ', map { "$_ = $params->{$_}" }
@@ -87,50 +84,67 @@ sub create {
         delete $params->{IMAGE};
         $log->is_debug &&
             $log->debug( "Creating image URL from '$url_base' ",
-                         "and params [$param_info]" );
-        return $class->create_image( $url_base, $params );
+                         "and params '$param_info'" );
+        return $class->create_image( $url_base, $params, $do_not_escape );
     }
     elsif ( $params->{STATIC} ) {
         delete $params->{STATIC};
         $log->is_debug &&
             $log->debug( "Creating static URL from '$url_base' ",
-                         "and params [$param_info]" );
-        return $class->create_image( $url_base, $params );
+                         "and params '$param_info'" );
+        return $class->create_image( $url_base, $params, $do_not_escape );
     }
     $log->is_debug &&
-    $log->debug( "Creating deployment URL from '$url_base' ",
-                 "and params [$param_info]" );
-    return $class->_create_deployment( DEPLOY_URL, $url_base, $params );
+        $log->debug( "Creating deployment URL from '$url_base' ",
+                     "and params '$param_info'" );
+    return $class->_create_deployment(
+        DEPLOY_URL, $url_base, $params, $do_not_escape );
 }
 
 sub create_image {
-    my ( $class, $url_base, $params ) = @_;
+    my ( $class, $url_base, $params, $do_not_escape ) = @_;
     return $class->_create_deployment(
-               DEPLOY_IMAGE_URL, $url_base, $params );
+               DEPLOY_IMAGE_URL, $url_base, $params, $do_not_escape );
 }
 
 sub create_static {
-    my ( $class, $url_base, $params ) = @_;
+    my ( $class, $url_base, $params, $do_not_escape ) = @_;
     return $class->_create_deployment(
-               DEPLOY_STATIC_URL, $url_base, $params );
+               DEPLOY_STATIC_URL, $url_base, $params, $do_not_escape );
 }
 
 # TODO: Modify to check 'REDIRECT' parameter to see if we should use
 # '&amp;' or '&' for query argument separator?
 
 sub _create_deployment {
-    my ( $class, $deploy_under, $url_base, $params ) = @_;
-    if ( $deploy_under ) {
-        $url_base = join( '', $deploy_under, $url_base );
+    my ( $class, $deploy_under, $url_base, $params, $do_not_escape ) = @_;
+    my ( $is_absolute ) = $url_base =~ /^\s*http:/;
+
+    # Absolute URLs don't get touched, so the escaping +
+    # contextualization doesn't get done to them
+    unless ( $is_absolute ) {
+        unless ( $do_not_escape ) {
+            $url_base = _url_escape( $url_base );
+        }
+        if ( $deploy_under ) {
+            $url_base = join( '', $deploy_under, $url_base );
+        }
     }
     $params ||= {};
     return $url_base unless ( scalar keys %{ $params } );
 
+    return $class->add_params_to_url( $url_base, $params );
+}
+
+sub add_params_to_url {
+    my ( $class, $url, $params ) = @_;
 	my $query = join( QUERY_ARG_SEPARATOR,
-                      map  { "$_=" . _url_escape( $params->{ $_ } ) }
+                      map  { _url_escape( $_ ) . "=" . _url_escape( $params->{ $_ } ) }
                       grep { defined $params->{ $_ } }
                       keys %{ $params } );
-    return "$url_base?$query";
+    return ( $url =~ /\?/ ) 
+             ? join( QUERY_ARG_SEPARATOR, $url, $query )
+             : "$url?$query";
 
 }
 
@@ -141,7 +155,7 @@ sub _create_deployment {
 # action has a ->url property set.
 
 sub create_from_action {
-    my ( $class, $action, $task, $params ) = @_;
+    my ( $class, $action, $task, $params, $do_not_escape ) = @_;
     $log ||= get_logger( LOG_OI );
 
     my $info = eval { CTX->lookup_action_info( $action ) };
@@ -155,7 +169,7 @@ sub create_from_action {
 
     # ...if a URL for the action isn't found
     unless ( $info->{url_primary} ) {
-        $log->warn( "Request URL for action [$action] but ",
+        $log->warn( "Request URL for action '$action' but ",
                     "primary URL was not found in action info; ",
                     "probably means it's not URL-accessible" );
         return undef;
@@ -166,16 +180,34 @@ sub create_from_action {
     $log->is_debug &&
         $log->debug( uchk( "Creating URL from action '%s' and task " .
                            "'%s' -- '%s'", $action, $task, $url_base ) );
-    return $class->create( $url_base, $params );
+    return $class->create( $url_base, $params, $do_not_escape );
 }
 
 sub _url_escape {
     my ( $to_encode ) = shift;
     return undef unless defined( $to_encode );
-    $to_encode =~ s/([^a-zA-Z0-9_.-])/uc sprintf("%%%02x",ord($1))/eg;
+    $to_encode =~ s/([^a-zA-Z0-9_~\.\-\*\'\(\)\/\s])/uc sprintf("%%%02x",ord($1))/eg;
+    $to_encode =~ s/\s/%20/g;
     return $to_encode;
 }
 
+########################################
+# URL REMOVAL
+
+sub strip_deployment_context {
+    my ( $class, $url ) = @_;
+    return ''  unless ( $url );
+    return '/' if ( $url eq '/' );
+    return ''  if ( $url eq DEPLOY_URL );
+
+    # Since we've taken care of the '/context' case with the previous
+    # statement we can assume any deployment context ends with a '/'
+
+    my $deployment_context = DEPLOY_URL;
+    $url =~ s|^$deployment_context/|/|;
+    return $url;
+}
+
 1;
 
 __END__
@@ -202,7 +234,9 @@ All methods check the following configuration item:
  context_info.deployed_under
 
 to see under what context the application is deployed. Many times this
-will be empty, which means the application sits at the root.
+will be empty, which means the application sits at the root. This
+value may also set by the L<OpenInteract2::Context> method
+C<assign_deploy_url()>.
 
 =head1 METHODS
 
@@ -312,7 +346,7 @@ the current server context to it and return that.
 
 Returns: URL with leading server context.
 
-B<create( $base_url, \%params )>
+B<create( $base_url, [ \%params, $do_not_escape ] )>
 
 Create a URL using the deployed context (if any), a C<$base_url> and
 C<\%params> as a query string. This allows you to deploy your
@@ -321,8 +355,22 @@ continue to work properly.
 
 If no C<\%params> are specified then the resulting URL will B<not>
 have a trailing '?' to indicate the start of a query string. This is
-important to note if you're doing further manipulation of the URL,
-such as you with if you were embedding it in generated Javascript.
+important to note if you are doing further manipulation of the URL,
+such as you with if you were embedding it in generated
+Javascript. Note that the parameter names and values are URI-escaped.
+
+Unless C<$do_not_escape> is set to a true value we also escape the
+C<$base_url>. (This makes URL-escaping the default.) So if you
+specify:
+
+  $url->create( '/foo/bar is baz/' );
+
+You'll get in return:
+
+  /foo/bar%20is%20baz/
+
+Finally: if C<$base_url> begins with 'http:' we do not modify it in
+any way (including escaping it) except to append the C<\%params>.
 
 Return: URL formed from the deployed context, C<$base_url> and
 C<\%params>.
@@ -363,7 +411,7 @@ Examples:
  $url = OpenInteract2::URL->create( '/foo', { name => 'Mario Lemieux' } );
  # $url = '/cgi-bin/oi.cgi/Public/foo?name=Mario%20Lemiux'
 
-B<create_image( $base_url, \%params )>
+B<create_image( $base_url, [ \%params, $do_not_escape ] )>
 
 Create a URL using the deployed image context (if any), a C<$base_url>
 and C<\%params> as a query string. This allows you to keep your images
@@ -372,9 +420,13 @@ properly.
 
 If no C<\%params> are specified then the resulting URL will B<not>
 have a trailing '?' to indicate the start of a query string. This is
-important to note if you're doing further manipulation of the URL,
+important to note if you are doing further manipulation of the URL,
 such as you with if you were embedding it in generated Javascript.
 
+Unless C<$do_not_escape> is set to a true value we URI-escape the
+C<$base_url>. (We always URI-escape the query arguments and values
+created from C<\%params>.)
+
 Return: URL formed from the deployed context, C<$base_url> and
 C<\%params>.
 
@@ -406,9 +458,13 @@ URLs continue to work properly.
 
 If no C<\%params> are specified then the resulting URL will B<not>
 have a trailing '?' to indicate the start of a query string. This is
-important to note if you're doing further manipulation of the URL,
+important to note if you are doing further manipulation of the URL,
 such as you with if you were embedding it in generated Javascript.
 
+Unless C<$do_not_escape> is set to a true value we URI-escape the
+C<$base_url>. (We always URI-escape the query arguments and values
+created from C<\%params>.)
+
 Return: URL formed from the deployed context, C<$base_url> and
 C<\%params>.
 
@@ -428,7 +484,7 @@ Examples:
  $url = OpenInteract2::URL->create_static( '/reports/q1-2003-01.pdf' );
  # $url = '/STAT/reports/q1-2003-01.pdf'
 
-B<create_from_action( $action, $task, \%params )>
+B<create_from_action( $action, [ $task, \%params, $do_not_escape ] )>
 
 Similar to C<create()>, except first we find the primary URL for
 C<$action> from the L<OpenInteract2::Context|OpenInteract2::Context>
@@ -439,6 +495,10 @@ If C<$action> is not found in the context we return C<undef>. And if
 there is no primary URL for C<$action> in the context we also return
 C<undef>.
 
+Unless C<$do_not_escape> is set to a true value we URI-escape the URL
+created from the action name and task. (We always URI-escape the query
+arguments and values created from C<\%params>.)
+
 See discussion in L<OpenInteract2::Action|OpenInteract2::Action> under
 C<MAPPING URL TO ACTION> for what the 'primary URL' is and other
 issues.
@@ -486,7 +546,33 @@ Examples, assuming that 'Foo' is the primary URL for action 'foo'.
  
  $url = OpenInteract2::URL->create_from_action(
                     'foo', 'detail', { name => 'Mario Lemieux' } );
- # $url = '/cgi-bin/oi.cgi/Public/Foo/detail/?name=Mario%20Lemiux'
+ # $url = '/cgi-bin/oi.cgi/Public/Foo/detail/?name=Mario%20Lemieux'
+
+C<add_params_to_url( $url, \%params )>
+
+Adds the escaped key/value pairs in C<\%params> as GET parameters to
+C<$url>, which is assumed to be contextualized and escaped already.
+
+So:
+
+ my $url = '/foo/bar';
+ my %params = ( id => '55', undercover => 'yes' );
+ my $url_with_params = OpenInteract2::URL->add_params_to_url( $url, \%params );
+ # $url_with_params = '/foo/bar?id=55&undercover=yes
+
+The method can detect if you've already got query parameters in your
+url:
+
+
+ my $url = '/foo/bar?keep=no';
+ my %params = ( id => '55', undercover => 'yes' );
+ my $url_with_params = OpenInteract2::URL->add_params_to_url( $url, \%params );
+ # $url_with_params = '/foo/bar?keep=no&id=55&undercover=yes
+
+B<strip_deployment_context( $url )>
+
+Removes any deployment context from C<$url> and returns the modified
+string.
 
 =head1 SEE ALSO
 
