@@ -1,9 +1,9 @@
 package OpenInteract2::Util;
 
-# $Id: Util.pm,v 1.12 2004/02/18 05:25:26 lachoy Exp $
+# $Id: Util.pm,v 1.16 2004/12/05 21:08:20 lachoy Exp $
 
 use strict;
-use DateTime;
+use Digest::MD5;
 use Log::Log4perl            qw( get_logger );
 use Mail::Sendmail ();
 use MIME::Lite     ();
@@ -12,7 +12,7 @@ use OpenInteract2::Context   qw( CTX );
 use OpenInteract2::Exception qw( oi_error );
 use SPOPS::Secure            qw( :level :verbose );
 
-$OpenInteract2::Util::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract2::Util::VERSION = sprintf("%d.%02d", q$Revision: 1.16 $ =~ /(\d+)\.(\d+)/);
 
 my ( $log );
 
@@ -37,8 +37,8 @@ sub now {
     my ( $class, $p ) = @_;
     $p->{format} ||= '%Y-%m-%d %T';
     $p->{time}   ||= time;
-    return DateTime->from_epoch( epoch => $p->{time} )
-                   ->strftime( $p->{format} );
+    return CTX->create_date({ epoch => $p->{time} })
+              ->strftime( $p->{format} );
 }
 
 
@@ -47,7 +47,7 @@ sub now {
 # Signature: $date_string = $class->today();
 
 sub today {
-    return $_[0]->now( { format => '%Y-%m-%e' } );
+    return $_[0]->now({ format => '%Y-%m-%e' });
 }
 
 
@@ -58,11 +58,11 @@ sub today {
 sub read_file_lines {
     my ( $class, $filename ) = @_;
     unless ( -f $filename ) {
-        oi_error "Cannot open [$filename]: file does not exist";
+        oi_error "Cannot open '$filename': file does not exist";
     }
     eval { open( MOD, '<', $filename ) || die $! };
     if ( $@ ) {
-        oi_error "Cannot open [$filename]: $@";
+        oi_error "Cannot read '$filename': $@";
     }
     my @lines = ();
     while ( <MOD> ) {
@@ -80,11 +80,11 @@ sub read_file_lines {
 sub read_file_perl {
     my ( $class, $filename ) = @_;
     unless ( -f $filename ) {
-        oi_error "Cannot open [$filename]: file does not exist";
+        oi_error "Cannot open '$filename': file does not exist";
     }
     eval { open( PF, '<', $filename ) || die $! };
     if ( $@ ) {
-        oi_error "Cannot open [$filename]: $@";
+        oi_error "Cannot read '$filename': $@";
     }
     local $/ = undef;
     my $raw = <PF>;
@@ -99,6 +99,16 @@ sub read_file_perl {
     return $data;
 }
 
+sub digest_file {
+    my ( $class, $file ) = @_;
+    my $md5 = Digest::MD5->new();
+    open( IN, '<', $file ) || die "Cannot read '$file' for digest: $!";
+    binmode( IN );
+    $md5->addfile( *IN );
+    close( IN );
+    return $md5->hexdigest;
+}
+
 ########################################
 # EMAIL ROUTINES
 
@@ -294,6 +304,22 @@ B<today()>
 Returns today's date in a string formatted '%Y-%m-%d', e.g.,
 '2003-04-01' for April 1, 2003.
 
+=head1 FILE METHODS
+
+B<read_file_lines( $filename )>
+
+Returns content of C<$filename> as an arrayref of lines, with blanks
+and comments skipped.
+
+B<read_perl_file( $filename )>
+
+Returns content of C<$flename> evaluated as a Perl data structure.
+
+B<digest_file( $filename )>
+
+Returns the hex MD5 digest of C<$filename> contents. (See
+L<Digest::MD5> for restrictions, notably regarding unicode.)
+
 =head1 MAIL METHODS
 
 B<send_email( \% )>
@@ -440,4 +466,4 @@ it under the same terms as Perl itself.
 
 =head1 AUTHORS
 
-Chris Winters E<lt>chris@cwinters.comE<gt>
\ No newline at end of file
+Chris Winters E<lt>chris@cwinters.comE<gt>
