@@ -1,6 +1,6 @@
 CREATE TABLE full_text_index (
- object_key    char(32) not null,
+ ft_id         int not null,
  term          varchar2(30) not null,
  occur         int not null,
- primary key   ( term, object_key )
+ primary key   ( ft_id, term )
 )
\ No newline at end of file
