@@ -1,4 +1,5 @@
 CREATE TABLE page (
+ page_id          %%INCREMENT%%,
  location         varchar(150) not null,
  directory        varchar(150),
  title            varchar(250),
@@ -11,9 +12,10 @@ CREATE TABLE page (
  expires_on       %%DATETIME%%,
  is_active        char(3) default 'no',
  content_location varchar(150),
- storage          varchar(10) default 'database',
+ storage          varchar(10) default 'file',
  mime_type        varchar(50),
  page_size        int default 0,
- notes            text,
- primary key      ( location )
+ notes            varchar(200),
+ primary key      ( page_id ),
+ unique           ( location )
 )
