@@ -1,4 +1,5 @@
 CREATE TABLE page (
+ page_id          int not null,
  location         varchar2(150) not null,
  directory        varchar2(150) null,
  title            varchar2(250) null,
@@ -11,9 +12,10 @@ CREATE TABLE page (
  expires_on       date null,
  is_active        char(3) default 'no',
  content_location varchar2(150) null,
- storage          varchar2(10) default 'database',
+ storage          varchar2(10) default 'file',
  mime_type        varchar2(50) null,
  page_size        int default 0,
  notes            varchar2(500) null,
- primary key      ( location )
+ primary key      ( page_id ),
+ unique           ( location )
 )
