@@ -1,7 +1,7 @@
 CREATE TABLE sys_error (
  error_id      char(12) not null,
  category      varchar(50) not null,
- message       blob,
+ err_message   blob,
  loc_class     varchar(60),
  loc_line      int,
  user_id       %%USERID_TYPE%%,
