@@ -1,7 +1,7 @@
 CREATE TABLE sys_error (
  error_id      char(12) not null,
  category      varchar2(50) not null,
- message       varchar2(500) null,
+ err_message   varchar2(500) null,
  loc_class     varchar2(60) null,
  loc_line      smallint null,
  user_id       %%USERID_TYPE%% null,
