@@ -1,4 +1,4 @@
-# $Id: utils.pl,v 1.51 2004/05/22 17:40:04 lachoy Exp $
+# $Id: utils.pl,v 1.85 2004/12/05 20:54:35 lachoy Exp $
 
 use strict;
 use Data::Dumper             qw( Dumper );
@@ -22,12 +22,15 @@ $Data::Dumper::Indent = 1;
 my ( $log );
 
 BEGIN {
-    $log = OpenInteract2::Log->init_file( 'oi2_tests.log', $INFO );
-    $log->info( "Starting test run" );
+    #my $log_level = $DEBUG;
+    # TODO: Change before distributing!
+    my $log_level = $WARN;
+    $log = OpenInteract2::Log->init_file( 'oi2_tests.log', $log_level );
+    $log->warn( "Starting test run [$0] [", scalar localtime, "]" );
 }
 
 END {
-    $log->info( "Finished test run" );
+    $log->warn( "Finished test run [$0] [", scalar localtime, "]" );
 }
 
 sub main::LOG {
@@ -43,22 +46,22 @@ sub main::barf {
 
 sub main::get_package_versions {
     return (
-         base            => '2.10',
-         base_box        => '2.11',
+         base            => '2.11',
+         base_box        => '2.17',
          base_error      => '2.10',
-         base_group      => '2.11',
-         base_page       => '2.21',
-         base_security   => '2.13',
-         base_template   => '3.11',
-         base_theme      => '2.09',
-         base_user       => '2.27',
-         comments        => '1.10',
-         full_text       => '2.09',
-         lookup          => '2.04',
-         news            => '2.13',
+         base_group      => '2.16',
+         base_page       => '2.28',
+         base_security   => '2.18',
+         base_template   => '3.15',
+         base_theme      => '2.10',
+         base_user       => '2.35',
+         comments        => '1.18',
+         full_text       => '2.58',
+         lookup          => '2.07',
+         news            => '2.20',
          object_activity => '2.11',
-         system_doc      => '2.05',
-         whats_new       => '2.04',
+         system_doc      => '2.08',
+         whats_new       => '2.10',
    );
 }
 
@@ -105,6 +108,14 @@ sub main::get_tmp_dir {
     return catdir( get_test_dir(), '_tmp' );
 }
 
+sub main::create_tmp_dir {
+    my $tmp_dir = get_tmp_dir();
+    unless ( -d $tmp_dir ) {
+        LOG()->debug( "Creating temp dir '$tmp_dir'" );
+        mkdir( $tmp_dir, 0777 );
+    }
+}
+
 # Get the base website directory for testing
 
 sub main::get_test_site_dir {
@@ -158,8 +169,7 @@ sub main::get_test_file {
         $filename = [ $filename ];
     }
     $type ||= 'content';
-    my $full_filename = catfile( get_test_dir(),
-                                             @{ $filename } );
+    my $full_filename = catfile( get_test_dir(), @{ $filename } );
     if ( $type eq 'name' ) {
         return $full_filename;
     }
@@ -182,11 +192,7 @@ sub main::get_test_file {
 ########################################
 # WEBSITE INSTALL/CONTEXT INIT
 
-sub main::install_website {
-    my $source_dir  = get_source_dir();
-    my $website_dir = get_test_site_dir();
-    my $is_recent = _is_recent_website( $website_dir );
-
+sub main::initialize_website_libraries {
     eval {
         require SPOPS::DBI::SQLite;
     };
@@ -201,6 +207,14 @@ sub main::install_website {
     if ( $@ ) {
         die "Failed to require file session modules: $@";
     }
+}
+
+sub main::install_website {
+    my $source_dir  = get_source_dir();
+    my $website_dir = get_test_site_dir();
+    my $is_recent = _is_recent_website( $website_dir );
+
+    initialize_website_libraries();
 
     if ( -d $website_dir and $is_recent ) {
         return $website_dir;
@@ -220,11 +234,7 @@ sub main::install_website {
         LOG()->debug( "Removing existing db file '$db_file'" );
         unlink( $db_file );
     }
-    my $tmp_dir = get_tmp_dir();
-    unless ( -d $tmp_dir ) {
-        LOG()->debug( "Creating temp dir '$tmp_dir'" );
-        mkdir( $tmp_dir, 0777 );
-    }
+    create_tmp_dir();
 
     # let any errors bubble up
     my $manage = OpenInteract2::Manage->new( 'create_website',
@@ -234,15 +244,8 @@ sub main::install_website {
     $manage->execute;
     LOG()->debug( "Executed management task ok" );
 
-    _write_website_check_file();
-    _modify_server_config();
-
-    CTX->setup({ skip => 'activate spops' });
-    OpenInteract2::Manage->new( 'install_sql',
-                                { website_dir => $website_dir,
-                                  package     => [ 'SYSTEM' ] } )
-                         ->execute;
-    OpenInteract2::Setup->activate_spops_classes;
+    write_website_check_file();
+    modify_website_post_creation( $website_dir );
     return $website_dir;
 }
 
@@ -255,7 +258,7 @@ sub _is_recent_website {
     return 1;
 }
 
-sub _write_website_check_file {
+sub main::write_website_check_file {
     my $check_recent = _get_website_check_file();
     open( RECENT, '>', $check_recent )
                     || die "Cannot open file to check whether site is recently installed: $!";
@@ -268,28 +271,31 @@ sub _get_website_check_file {
     return catfile( get_tmp_dir(), '_site_time' );
 }
 
+sub main::modify_website_post_creation {
+    my ( $website_dir ) = @_;
+    modify_server_config();
+    CTX->setup({ skip => 'activate spops' });
+    OpenInteract2::Manage->new(
+        'install_sql', {
+            website_dir => $website_dir,
+            package     => [ 'SYSTEM' ],
+        })->execute();
+    OpenInteract2::Setup->activate_spops_classes;
+}
+
 # Write out SQLite information so that the Context gets read in
 # properly (SPOPS classes need this); use file-based sessions and
 # write the appropriate directories
 
-sub _modify_server_config {
+sub main::modify_server_config {
     my $site_dir = get_test_site_dir();
     my $config_file = catfile( $site_dir, 'conf', 'server.ini' );
     my $db_file = get_test_site_db_file();
+
     my $ini = OpenInteract2::Config::Ini->new({ filename => $config_file });
     $ini->{datasource}{main}{spops}       = 'SPOPS::DBI::SQLite';
     $ini->{datasource}{main}{driver_name} = 'SQLite';
     $ini->{datasource}{main}{dsn}         = "dbname=$db_file";
-    $ini->{session_info}{class}           = 'OpenInteract2::SessionManager::File';
-    $ini->{session_info}{impl_class}      = 'Apache::Session::File';
-
-    my $session_dir = catdir( $site_dir, 'cache', 'session' );
-    File::Path::mkpath( $session_dir );
-    $ini->{session_info}{params}{Directory} = $session_dir;
-    my $lock_dir = catdir( $site_dir, 'cache', 'session_lock' );
-    File::Path::mkpath( $lock_dir );
-    $ini->{session_info}{params}{LockDirectory} = $lock_dir;
-
     $ini->write_file;
 }
 
